<?php
namespace Folha\Entities;

use HCM\Util\DateUtil;
use Importacao\Logic\Integracao\ProjetoImportacao;

class MigEstruturam extends Base\MigEstruturam
{

    /**
     * @param $cdintestrutura
     * @throws \Exception
     * @internal param $nrestruturam
     * @return \Folha\Entities\MigEstruturam
     */
    public function setCdintestrutura($cdintestrutura) {
        if ($cdintestrutura == '') {
            throw new \Exception("Campo Obrigatório: 'Nº Estrutura' - '$cdintestrutura'");
        }

        $nrtipoestrutura = $this->getNrtipoestrutura();

        $cdintestrutura = \Importacao\Logic\Validacoes::verificaChaveDuplicada('ESTRUTURAM', 'CDINTESTRUTURA', ProjetoImportacao::getNrorg(), $cdintestrutura, 'NRTIPOESTRUTURA', $nrtipoestrutura);
        $this->cdintestrutura = $cdintestrutura;
    }

    /**
     * @param mixed $dtfimvigencia
     * @throws \Exception
     * @return \Folha\Entities\MigEstruturam|void
     */
    public function setDtfimvigencia($dtfimvigencia)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtfimvigencia)) {
            if (!empty($dtfimvigencia)) {
                throw new \Exception("Fim de Vigência: Data '$dtfimvigencia' com formato inválido ou em branco.");
            } else {
                throw new \Exception(null);
            }
        }

        if (!($dtfimvigencia instanceof \DateTime)) {
            $dtfimvigencia = DateUtil::getDataDeString($dtfimvigencia);
        }

        $this->dtfimvigencia = $dtfimvigencia;
    }

    /**
     * @param mixed $dtinclusao
     * @return \Folha\Entities\MigEstruturam|void
     */
    public function setDtinclusao($dtinclusao)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtinclusao)) {
            throw new \Exception("Data '$dtinclusao' com formato inválido ou em branco.");
        }

        if (!($dtinclusao instanceof \DateTime)) {
            $dtinclusao = DateUtil::getDataDeString($dtinclusao);
        }

        $this->dtinclusao = $dtinclusao;
    }

    /**
     * @param mixed $dtinivigencia
     * @return \Folha\Entities\MigEstruturam|void
     */
    public function setDtinivigencia($dtinivigencia)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtinivigencia)) {
            throw new \Exception("Campo Obrigatório - Inicio Vigência: Data '$dtinivigencia' com formato inválido ou em branco.");
        }

        if (!($dtinivigencia instanceof \DateTime)) {
            $dtinivigencia = DateUtil::getDataDeString($dtinivigencia);
        }

        $this->dtinivigencia = $dtinivigencia;
    }

    /**
     * @param mixed $dtultatu
     * @throws \Exception
     * @return \Folha\Entities\MigEstruturam|void
     */
    public function setDtultatu($dtultatu)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtultatu)) {
            throw new \Exception("Data '$dtultatu' com formato inválido ou em branco.");
        }

        if (!($dtultatu instanceof \DateTime)) {
            $dtultatu = DateUtil::getDataDeString($dtultatu);
        }

        $this->dtultatu = $dtultatu;
    }

    /**
     * @param $nmestruturam
     * @return \Folha\Entities\MigEstruturam
     */
    public function setNmestruturam ($nmestruturam) {
        $nmestruturam = substr($nmestruturam, 0, 50);
        $this->nmestruturam = $nmestruturam;
    }
    
}