// FILE: ./bower_components/zh-reports/dist/zhReports.js

// FILE: src/FloatingReportCardController.js
var FloatingReportCardController = function($scope, $rootScope, ScreenService, templateManager, ApplicationContext, restEngine, ZHPromise, eventAggregator) {

	//------ Control variables
	var editingWidget = $scope.$parent.widget;

    /**
     * Checks if the card is already opened and reconfigure the state of it if it not.
     *
     * @param  {jquery.Event} e   Event that triggered the click.
     */
	function checkFloatingCardOverflow(e) {
		var actionElement = $(e.target).closest(".float-action");
		var floatingControl = actionElement.parents(".zh-floating-control");
		var widgetContainer = actionElement.closest(".container");
		var actionTop, actionBottom;
		var widgetTop, widgetBottom;

		if (!actionElement.hasClass("opened")) {
			actionElement.removeClass("fix-position-top");
			actionElement.removeClass("fix-position-bottom");

			actionTop = actionElement.offset().top;
			widgetTop = widgetContainer.offset().top;
			widgetBottom = widgetTop + widgetContainer.height();
			if (floatingControl.hasClass("pos-top")) {
				actionTop = actionTop - 200 + actionElement.height();
				if (actionTop < widgetTop) {
					actionElement.addClass("fix-position-top");
				}
			}
			else {
				actionBottom = actionTop + 200;
				if (actionBottom > widgetBottom) {
					actionElement.addClass("fix-position-bottom");
				}
			}
		}
	}

	/**
	 * Toggle the report action when it's template is configured as card.
	 *
	 * @param  {jquery.Event} e   Event that triggered the toggle.
	 */
	$scope.toggleFloatReportCard = function(e) {
		checkFloatingCardOverflow(e);
		$scope.toggleAction(e);
	};

	editingWidget.toggleFloatReportCard = $scope.toggleFloatReportCard;

	/**
	 * Change the report orientation.
	 *
	 * @param  {jquery.Event} e   Event that triggered the toggle.
	 * @param  {String} orientation   Report orientation.
	 */
	$scope.setOrientation = function(e, orientation) {
		$scope.widget.reportOrientation = orientation;
		e.stopPropagation();
	};

    $scope.getVisibilityActionXlsReport = function (widget, format) {
        var isvisible = false;
        if (widget && widget.floatingControl && widget.floatingControl.xlsAction !== false) {
            if (widget.floatingControl.xlsAction && widget.floatingControl.xlsAction.runAt === 'server' && widget.template.endsWith('widget/grid.html')) {
                if (format === 'origin') {
                    isvisible = false;
                }else{
                    isvisible = widget.floatingControl.xlsAction[format] !== false;
                }
            } else if (format === 'origin') {
                isvisible = true;
            }
        }
        return isvisible;
    };
};

ZeedhiController.controller('FloatingReportCardController', FloatingReportCardController);

// FILE: src/XLSZhReport.js

function ZhReportsXLS() {
    var expressionZeedhiToXls = {
        "AVG": "AVERAGE",
        "COUNT": "COUNTA",
        "MAX": "MAX",
        "MIN": "MIN",
        "SUM": "SUM"
    };

    this.labelByFormat = {
        "F1":"XLS (all columns - with group)",
        "F2":"XLS (grid mirror - with group)",
        "F3":"XLS (all columns - no group)",
    };

    // literally the screen for xls
    var isFormat2  = function (format) {
        return format === 'F2';
    };

    // raw dataset good for tinkering with data
    var isFormat3  = function (format) {
        return format === 'F3' || format === 'ERROR_LOAD';
    };
    this.isFormat3 = isFormat3;

    var colunmXLS = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';

    var getColumnsNameFormat2 = function (columns, metaData) {
        var columnsNameGroup = metaData.groups.map(function(row){
            return row.field;
        });
        var columnsName = [];
        Object.entries(columns).forEach(function (row) {
            var columnName = row[0];
            if(columnsNameGroup.indexOf(columnName) === -1){
                var index = row[1].sequence;
                columnsName[index] = columnName;
            }
        });
        columnsName = columnsName.filter(function(columnName){
            return  typeof columnName === "string";
        });
        return columnsName;
    };

    var getColumnsNameFormat3 = function (metaData) {

        var columns = metaData.columns;
        var columnsNameGroup = metaData.groups.map(function (row) {
            return row.field;
        });
        var arrayColumns = Object.entries(columns);
        var maxSequence = 0;
        arrayColumns.forEach(function (row) {
            if (row[1].sequence > maxSequence) {
                maxSequence = row[1].sequence;
            }
        });

        arrayColumns.forEach(function (row) {
            var columnName = row[0];
            if (columnsNameGroup.indexOf(columnName) !== -1) {
                row[1].sequence = row[1].sequence + maxSequence+1;
            }
        });
    };

    var getColumnsName = function (columns, metaData, lengthGroup) {
        var columnsNameGroup = metaData.groups.map(function (row) {
            return row.field;
        });
        var columnsName = [];
        Object.entries(columns).forEach(function (row) {
            var columnName = row[0];
            var index = row[1].sequence;
            if (columnsNameGroup.indexOf(columnName) === -1) {
                columnsName[index + lengthGroup] = columnName;
            } else {
                columnsName[index] = columnName;
            }
        });
        columnsName = columnsName.filter(function (columnName) {
            return typeof columnName === "string";
        });
        return columnsName;
    };

    var initVars = function (metaData) {
        metaData.xlsMergedCell = [];
        var columns = metaData.columns;
        var lengthGroup = metaData.groups.length;
        var indexLastGroup = lengthGroup - 1;
        var columnsName = [];
        if(isFormat2(metaData.formatXLS)){
            columnsName = getColumnsNameFormat2(columns, metaData);
        }else{
            columnsName = getColumnsName(columns, metaData, lengthGroup);
        }
        var rowValues = [];
        var formatedDataSet = [];
        var groups = [];
        groups.groupEnd = {};
        groups.groupEnd.cellsfunc = {};
        return [columns, indexLastGroup, columnsName, rowValues, formatedDataSet, groups];
    };

    function setRowGroupFormat2(row, rowValues, groups, metaData, formatedDataSet, columnsName, columns, indexLastGroup) {
        var label = row.__groupLabel + ':' + row.__groupValue;
        var index = row.__groupIndex;
        if (row.__groupHeader) {
            rowValues[index] = label;
            groups[index] = {"init": null, "end": null};
            formatedDataSet.push(rowValues);
            rowValues = [];
        } else if (row.__groupFooter) {
            if (row.__groupLabel === undefined) {
                rowValues.push('Total');
            } else {
                rowValues.push('Total (' + label + ')');
            }
            formatedDataSet.push(rowValues);
            rowValues = [];
            var funcXls = null;
            columnsName.forEach(function (column, columnIndex) {
                    if ((row[column] || row[column] == 0) && index !== undefined) {
                        var letter = colunmXLS[rowValues.length];
                        funcXls = expressionZeedhiToXls[columns[column].expression];
                        var cellsfunc = letter + groups[index].init + ":" + letter + groups[index].end;
                        var expression = '';
                        if (indexLastGroup == index) {
                            expression = '=' + funcXls + '(' + cellsfunc + ")";
                        } else {
                            expression = '=' + funcXls + '(' + groups[index].cellsfunc[column] + ")";
                            cellsfunc = groups[index].cellsfunc[column];
                            if (index === 0) {
                                if (groups.groupEnd.cellsfunc[column]) {
                                    groups.groupEnd.cellsfunc[column] += "," + groups[index].cellsfunc[column];
                                } else {
                                    groups.groupEnd.cellsfunc[column] = groups[index].cellsfunc[column];
                                }
                            }
                            groups[index].cellsfunc[column] = null;
                        }
                        rowValues.push(expression);
                        groups.forEach(function (group, indexGroup) {
                            if (indexGroup !== indexLastGroup) {
                                if (!group.cellsfunc) {
                                    group.cellsfunc = {};
                                }
                                if (group.cellsfunc[column]) {
                                    if(!group.cellsfunc[column].includes(cellsfunc)){
                                        group.cellsfunc[column] += ',' + cellsfunc;
                                    }
                                } else {
                                    group.cellsfunc[column] = cellsfunc;
                                }
                            }
                        });
                    } else {
                        var cell = row[column];

                        if (row.__groupSummary) {
                            var groupEndFunc = groups.groupEnd.cellsfunc;
                            if (groupEndFunc[column]) {
                                funcXls = expressionZeedhiToXls[columns[column].expression];
                                cell = '=' + funcXls + '(' + groupEndFunc[column] + ")";
                            }
                        }
                        rowValues.push(cell);
                    }
            });
        }
        return rowValues;
    }

    function setRowGroup(row, rowValues, groups, metaData, formatedDataSet, columnsName, columns, indexLastGroup) {
        var label = row.__groupLabel + ':' + row.__groupValue;
        var index = row.__groupIndex;
        if (row.__groupHeader) {
            rowValues[index] = label;
            groups[index] = {"init": null, "end": null};
        } else if (row.__groupFooter) {
            if (row.__groupLabel === undefined) {
                rowValues.push('Total');
            } else {
                rowValues.push('Total (' + label + ')');
            }
            var funcXls = null;
            if (groups[index]) {
                metaData.xlsMergedCell.push({
                    'start_row': groups[index].init,
                    'start_col': colunmXLS[index],
                    'end_row': formatedDataSet.length + 2,
                    'end_col': colunmXLS[index],
                });
            }
            columnsName.forEach(function (column, columnIndex) {
                if (!(row.__groupFooter && columnIndex === 0)) {
                    if ((row[column] || row[column] == 0) && index !== undefined) {
                        var letter = colunmXLS[rowValues.length];
                        funcXls = expressionZeedhiToXls[columns[column].expression];
                        var cellsfunc = letter + groups[index].init + ":" + letter + groups[index].end;
                        var expression = '';
                        if (indexLastGroup == index) {
                            expression = '=' + funcXls + '(' + cellsfunc + ")";
                        } else {
                            expression = '=' + funcXls + '(' + groups[index].cellsfunc[column] + ")";
                            cellsfunc = groups[index].cellsfunc[column];
                            if (index === 0) {
                                if (groups.groupEnd.cellsfunc[column]) {
                                    groups.groupEnd.cellsfunc[column] += "," + groups[index].cellsfunc[column];
                                } else {
                                    groups.groupEnd.cellsfunc[column] = groups[index].cellsfunc[column];
                                }
                            }
                            groups[index].cellsfunc[column] = null;
                        }
                        rowValues.push(expression);
                        groups.forEach(function (group, indexGroup) {
                            if (indexGroup !== indexLastGroup) {
                                if (!group.cellsfunc) {
                                    group.cellsfunc = {};
                                }
                                if (group.cellsfunc[column]) {
                                    if(!group.cellsfunc[column].includes(cellsfunc)){
                                        group.cellsfunc[column] += ',' + cellsfunc;
                                    }
                                } else {
                                    group.cellsfunc[column] = cellsfunc;
                                }
                            }
                        });
                    } else {
                        var cell = row[column];

                        if (row.__groupSummary) {
                            var groupEndFunc = groups.groupEnd.cellsfunc;
                            if (groupEndFunc[column]) {
                                funcXls = expressionZeedhiToXls[columns[column].expression];
                                cell = '=' + funcXls + '(' + groupEndFunc[column] + ")";
                            }
                        }
                        rowValues.push(cell);
                    }
                }
            });
        }
        return rowValues;
    }

    function setIndexGroups(groups, formatedDataSet) {
        groups.forEach(function (group) {
            if (!group.init) {
                group.init = formatedDataSet.length + 2;
            }
            group.end = formatedDataSet.length + 2;
        });
    }

    function setRowNormal(columnsName, rowValues, row) {
        columnsName.forEach(function (column) {
            rowValues.push(row[column]);
        });
    }

    this.getFormatDataSet = function (metaData, dataSetFormat, dataSet) {
        if(isFormat3(metaData.formatXLS)){
            metaData.reportXLS = false;
            getColumnsNameFormat3(metaData);
            return dataSet;
        }else{
            return this.formatDataSet(metaData,dataSetFormat);
        }
    };

    this.formatDataSet = function (metaData, dataSet) {
        var initVar = initVars(metaData);
        var columns = initVar[0];
        var indexLastGroup = initVar[1];
        var columnsName = initVar[2];
        var rowValues = initVar[3];
        var formatedDataSet = initVar[4];
        var groups = initVar[5];

        dataSet.forEach(function (row) {
            if (row.__group) {
                if(isFormat2(metaData.formatXLS)){
                    rowValues = setRowGroupFormat2(row, rowValues, groups, metaData, formatedDataSet, columnsName, columns, indexLastGroup);
                }else{
                    rowValues = setRowGroup(row, rowValues, groups, metaData, formatedDataSet, columnsName, columns, indexLastGroup);
                }
            } else {
                setIndexGroups(groups, formatedDataSet);

                setRowNormal(columnsName, rowValues, row);
            }
            if (!row.__groupHeader) {
                formatedDataSet.push(rowValues);
            }
            rowValues = [];
        });

        return [columnsName].concat(formatedDataSet);
    };

}

Configuration(function (ContextRegister) {
    ContextRegister.register('ZhReportsXLS', ZhReportsXLS);
});


// FILE: src/ZhReports.js
/* global Util, Configuration*/
function ZhReports(templateManager, ZHPromise, ScreenService, restEngine, ZhUtil, eventAggregator, DecodeValueFieldService, ZhLogger, eventEngine, ZhReportsXLS) {

    var reportConfig = {
        PDF:{
            uri: '/generateReport',
            type: 'PDF',
            action: 'pdfAction'
        },
        XLS:{
            uri: '/generateXLS',
            type: 'XLS',
            action: 'xlsAction'
        },
        CSV:{
            uri: '/generateCSV',
            type: 'CSV',
            action: 'csvAction'
        }
    };
    var typeXLSLocal = 'XLSLocal';

    var maxVisibleColumns = {
        'LANDSCAPE': 15,
        'PORTRAIT': 10
    };

    var reportNameToReportFunction = {
        "=": "is equal to",
        "IN": "is among",
        "NOT_IN": "is not among",
        "!=": "is different of",
        ">": "is bigger than",
        "<": "is lower than",
        ">=": "is not lower than",
        "<=": "is not bigger than",
        "BETWEEN": ["is between", "and"],
        "NOT_BETWEEN": ["is lower than", "and bigger than"],
        "LIKE": "has",
        "LIKE_I": "has",
        "LIKE_ALL": "has any of",
        "NOT_LIKE": "does not have",
        "IS_NULL": "is not defined",
        "IS_NOT_NULL": "is defined",
        "ORDER_DESC": "ordered descending",
        "ORDER_ASC": "ordered ascending",
        "ORDER_BY": "ordered",
        "GROUP_BY": "grouped"
    };

    eventEngine.registerEvent('BeforeGenerateReport', 'beforeGenerateReport');

    function triggerBeforeGenerateReport(widget, metaData){
        if(widget.beforeGenerateReport){
            return widget.beforeGenerateReport({
                'metadata': metaData
            });
        }
    }

    /**
     * Get the text related to the filter that is being used.
     *
     * @param {Field}  field  - Field with the data related to the filter.
     * @param {Object} filter - Filter used to create the report.
     *
     * @return {String} Text to be shown woth data related to the given filter.
     */
    function getFieldFilterValue(field, filter) {
        return getFieldFilterDefaultText(filter, filter.value, ScreenService.i18n(reportNameToReportFunction[filter.operator]));
    }

    /**
     * Configure the default value for the variable if it's not defined.
     *
     * @param {Mixed} value        - The variable to be tested.
     * @param {Mixed} defaultValue - The value attributed the variable if it's not defined.
     *
     * @return {Mixed} The value that the variable should recieve.
     */
    function notUndefinedOrDefault(value, defaultValue) {
        return value === undefined ? defaultValue : value;
    }

    /**
     * Tests if the given type is PDF.
     *
     * @param {String} type - The type to be tested.
     *
     * @return {Boolean} Tells if the given type is PDF.
     */
    function isPdfFormat(type) {
        return type === reportConfig.PDF.type;
    }

    function isPdfOrXlsLocalFormat(type) {
        return type === reportConfig.PDF.type || type === typeXLSLocal;
    }

    function isXlsLocalFormat(type) {
        return type === typeXLSLocal;
    }
     /**
     * Check which type of template need to be returned.
     *
     * @return {String} Template type to be used.
     */
    function checkZhReportActionDisplayMode() {
        if( !templateManager.project.zhReportActionDisplayMode ) {
            return 'zh-reports#floating-report-card.html';
        } else if (templateManager.project.zhReportActionDisplayMode === 'buttons') {
            return 'zh-reports#floating-report.html';
        }
    }

    eventAggregator.subscribe('beforeProjectStartup', function() {
        templateManager.project.customFloatingActions.push({
            'id': '#reportAction#',
            'name': 'reportAction',
            'label': ScreenService.i18n('Export'),
            "expandable": !templateManager.project.zhReportActionDisplayMode,
            'order': 10,
            'icon': 'file-export',
            'template': checkZhReportActionDisplayMode(),
            'isVisible': function(widget) {
                var show = true;
                if (widget.floatingControl) {
                    var showPdfAction = notUndefinedOrDefault(widget.floatingControl.pdfAction, true);
                    var showXlsAction = notUndefinedOrDefault(widget.floatingControl.xlsAction, true);
                    var showCsvAction = notUndefinedOrDefault(widget.floatingControl.csvAction, true);
                    show = showPdfAction || showXlsAction || showCsvAction;
                }

                return show;
            }
        });
    });

    /**
     * Checks if the propertie 'reportsUrl' is configured on the environment.json.
     *
     * @throws {Error} Message warning that the propertie should be configured at the file.
     */
    var checkConfiguration = function() {
        if (!(templateManager.project && templateManager.project.reportsUrl)) {
            throw (ScreenService.i18n(
                'Need report configuration in "environment.json": "reportsUrl"!'));
        }
    };

    /**
     * Returns the format of the column.
     *
     * @param {Field} column - The Field to test it's format.
     *
     * @return {Object} The Field's format.
     */
    var getFormatOfColumn = function(column) {
        var format = column.format;
        if (!format && column.mask) {
            column.mask.params = column.mask.params || {};
            format = {};
            format.params = column.mask.params;
            format.type = column.mask.type;
            if (Util.isString(format.params.mask) && Util.stringStartsWith(format.params.mask, '@') && Util.stringEndsWith(format.params.mask, '@')) {
                format.params.mask = ZhUtil.evaluate(format.params.mask);
            }
        }
        return format;
    };

    /**
     * Build a column to the metadata based on the given field.
     *
     * @param {Field}  column - Field base to create the column to the report.
     * @param {String} size   - The size of the Field, in percentage inside the report.
     *
     * @return {Object} Column to the metadata, with the necessary data.
     */
    var buildColumn = function(column, size) {
        if (Util.isUndefined(column.reportAlign)) {
            column.reportAlign = column.align || 'left';
        }
        return {
            align: column.reportAlign,
            description: ScreenService.i18n(column.labelOnReport || column.label),
            expression: column.expression,
            format: getFormatOfColumn(column),
            sequence: column.sequenceInList,
            size: size,
            xlsType: column.xlsType
        };
    };

    /**
     * Filter the widgetColumns by just the visible fields.
     *
     * @param {Array.<Field>}  widgetColumns               - Array to be filtered.
     * @param {Boolean}        reportShowOnlyVisibleFields - Tells if the report should show only visible fields.
     * @param {String}         [reportType='PDF']          - The type of the report.
     * @param {Array.<String>} [groups]                    - List of the field names that are grouped.
     *
     * @return {Array.<Field>} Filtered array with all fields that are visible on the report.
     */
    var filterVisibleColumns = function(widgetColumns, reportShowOnlyVisibleFields, reportType, groups) {
        var showGroupedColumns = !isPdfFormat(reportType);
        var columns = widgetColumns.filter(function(column) {
            var isGroupedColumn = groups ? groups.indexOf(column.name) != -1 : column.grouped;
            var columnGroupVisibilitity = showGroupedColumns && isGroupedColumn;

            var isVisibleOnReport = Util.isUndefinedOrNull(column.isVisibleOnReport) || column.isVisibleOnReport;
            var columnVisibility = isVisibleOnReport && (!reportShowOnlyVisibleFields || (column.isVisible && column.showOnList));

            return column.aclIsVisible && (columnGroupVisibilitity || columnVisibility);
        });

        if(showGroupedColumns && groups) updateColumnsSequences(columns, groups);

        return columns;
    };

    function updateColumnsSequences(columns, groups) {
        var groupsName = Object.keys(groups);
        var columnsName = Object.keys(columns);
        var groupSequence = 0;

        columnsName.forEach(function(colName) {
            if(groupsName.indexOf(colName) !== -1) {
                columns[colName].sequence += groups.length;
            } else {
                columns[colName].sequence += groupSequence;
                groupSequence++;
            }
        });
    }

    /**
     * Returns the max visible columns on the report.
     *
     * @param  {Widget}    widget       -   Widget where the report is being generated.
     * @param  {String}    reportType   -   The type of the report.
     *
     * @return {Integer} The max of visible columns on the report.
     */
    var getMaxVisibleColumns = function(widget, reportType) {
        var maxColumns;
        if (reportType==reportConfig.PDF.type) {
            maxColumns = widget.maxColumns;
        } else {
            maxColumns = 99999;
        }
        return maxColumns;
    };

    /**
     * Builds the configuration of the field's display.
     *
     * @param {Widget}         widget             - Widget where the report is being generated.
     * @param {Array.<String>} [columnsToUse]     - The name of the fields that will be used on the
     * report generation.
     * @param {String}         [reportType='PDF'] - The type of the report.
     * @param {Array.<String>} [groups]           - List of the field names that are grouped.
     *
     * @return {Object} Object where each propertie is a object with the configuration of its display
     * on the report.
     */
    var _buildMetaDataColumns = function(widget, columnsToUse, reportType, groups) {
        var columns = {};
        var widgetColumns = widget.fields;
        var maxVisibleColCount = getMaxVisibleColumns(widget, reportType);
        if (widgetColumns) {
            widgetColumns = filterVisibleColumns(widgetColumns, widget.reportShowOnlyVisibleFields, reportType, groups);
            if (maxVisibleColCount && widgetColumns.length > maxVisibleColCount) {
                ZhLogger.warning(ScreenService.i18n(
                    "Number of columns too big to render the report correctly. It was limited to __maxVisibleColCount__ columns.",
                    {
                        'maxVisibleColCount': maxVisibleColCount
                    }
                ));
            }

            var remainingSize = 100;
            var columnsWithoutColumnSize = 0;

            widgetColumns.forEach(function(column) {
                if (column.reportColumnSize) {
                    remainingSize -= parseInt(column.reportColumnSize);
                }
                else {
                    columnsWithoutColumnSize++;
                }
            });

            if (remainingSize < 0) {
                ZhLogger.warning(ScreenService.i18n('Sum of columns width is bigger than 100%.'));
            }

            var size = Math.max(2, Math.floor(remainingSize / columnsWithoutColumnSize));
            var sum = 0;
            widgetColumns.forEach(function(column, index) {
                if (!columnsToUse || !columnsToUse[column.name]) {
                    var columnSize;
                    if (column.reportColumnSize) {
                        columnSize = column.reportColumnSize;
                    }
                    else {
                        if (index === (widgetColumns.length - 1)) {
                            columnSize = Math.max(2, remainingSize - sum);
                        }
                        else {
                            columnSize = size;
                            sum += size;
                        }
                    }

                    if (!columnSizeHasUnity(columnSize)) {
                        columnSize += '%';
                    }

                    columns[column.valueFieldOnReport || column.name] = buildColumn(column, columnSize);
                }
            });

        }
        return columns;
    };

    /**
     * Returns an array containing only the displayed value from field.
     *
     * @param {Object} object - Object containing the dataSource.data's row.
     *
     * @return {Object} Array containing only a object as {field.descriptionField: <displayedValue>}.
     */
    function getStaticPropertyValueFromObject(row) {
        var toReturn = {};
        toReturn[row[this.valueField]] = row[this.descriptionField];
        return toReturn;
    }

    /**
     * Builds the configuration of the field's staticData.
     *
     * @param {Widget} widget - Widget where the report is being generated.
     * @param {Object} object - Object were the configuration field's display are gathered.
     *
     * @return {Object} Object where all the staticData from fields with DataSource are
     * gathered to be treated.
     */
    var _buildStaticDataColumns = function(widget, columns) {
        var widgetColumns = widget.fields;
        var staticData = {};
        if (widgetColumns) {
            widgetColumns.forEach(function(column) {
                if (columns[column.name] && column.dataSource && column.dataSource.data) {
                    staticData[column.name] = column.dataSource.data.map(getStaticPropertyValueFromObject, column);
                }
                else if (columns[column.valueFieldOnReport] && column.dataSource && column.dataSource.data) {
                    staticData[column.valueFieldOnReport] = column.dataSource.data.map(getStaticPropertyValueFromObject, column);
                }
            });

            if (Object.keys(staticData).length) {
                for (var data in staticData) {
                    staticData[data] = staticData[data].reduce(function(o1, o2) {
                        for (var key in o2) {
                            o1[key] = o2[key];
                        }
                        return o1;
                    }, {});
                }
            }
        }

        return staticData;
    };

    /**
     * Tests if the column size has a measurement unit.
     *
     * @param {String|Number} columnSize - The column size to be tested.
     *
     * @return {Boolean} Tells if the column size has a measurement unit.
     */
    function columnSizeHasUnity(columnSize) {
        return (/[\%px]/g).test(columnSize.toString());
    }

    /**
     * Build a report's group based on the given Field.
     *
     * @param {Field} column - The Field to be based on the cration of the column.
     *
     * @return {Object} Report's group.
     */
    var buildGroup = function(column) {
        return {
            name: column.name,
            field: column.name,
            isNumber: column.isNumber,
            descending: column.descending,
            format: getFormatOfColumn(column),
            internalSorts: column.internalSorts,
            header: {
                label: column.headerLabel || ScreenService.i18n(column.label),
                displayfield: column.name
            }
        };
    };

    /**
     * Build the metadata of the fields grouped.
     *
     * @param {Widget} widget - Widget used to create the grouped metadata.
     * @param {Array.<String>} [customGroups] - List of the field names that are grouped.
     *
     * @return {Array.<Object>} Metadata of grouped columns.
     */
    var _buildMetaDataGroups = function(widget, customGroups) {
        var buildedGroups = [];
        var groups = widget.groups;
        if (customGroups) {
            groups = customGroups.map(function(name) {
                return widget.getField(name);
            });
        }
        buildedGroups = groups.map(function(group) {
            return buildGroup(group);
        });
        return buildedGroups;
    };

    /**
     * Get the text related to the filter that is being used.
     *
     * @param {String} text - Text used to create the report header.
     *
     * @return {String} Text to be shown in the header.
     */
    function getFieldFilterDefaultTextWithoutValue(text) {
        return ScreenService.i18n(text) + '.';
    }

    /**
     * Get the text related to the filter that is being used.
     *
     * @param {Object} value- Value of the Filter.
     * @param {String} text - Text used to create the report header.
     *
     * @return {String} Text to be shown in the header.
     */
    function likeIFieldText(value, text) {
        return ScreenService.i18n(text) + ' \'' + value.replace(/%/g, '') + '\' case sensitive.';
    }

    /**
     * Get the text related to the filter that is being used.
     *
     * @param {Object} value- Value of the Filter.
     * @param {String} text - Text used to create the report header.
     * @param {Object} filter - Filter used to create the report.
     *
     * @return {String} Text to be shown in the header.
     */
    function valueFieldText(filter, value, text) {
        if (value[0] === "%" && value[value.length - 1] === "%") {
            value = value.substring(1, value.length - 1);
        }
        else {

            if (value[0] === "%") {
                if (filter.operator == 'LIKE') {
                    value = value.substring(1, value.length);
                    text = "ends with";
                }
                else if (filter.operator == 'NOT_LIKE') {
                    value = value.substring(1, value.length);
                    text = "does not ends with";
                }
            }
            if (value[value.length - 1] === "%") {
                if (filter.operator == 'LIKE') {
                    value = value.substring(0, (value.length - 1));
                    text = "starts with";
                }
                else if (filter.operator == 'NOT_LIKE') {
                    value = value.substring(0, (value.length - 1));
                    text = "does not starts with";
                }
            }
        }
        return ScreenService.i18n(text) + ' ' + value + '.';
    }

    /**
     * Get the text related to the filter that is being used.
     *
     * @param {Object} value- Value of the Filter.
     * @param {String} text - Text used to create the report header.
     *
     * @return {String} Text to be shown in the header.
     */
    function oneOrMoreValuesFieldText(value, text) {
        if (Array.isArray(text)) {
            return ScreenService.i18n(text[0]) + ' ' + value[0] + ' ' + ScreenService.i18n(text[1]) + ' ' + value[1] + '.';
        }

        return ScreenService.i18n(text) + ' ' + value.join(', ') + '.';
    }

    /**
     * Get the text related to the filter that is being used.
     *
     * @param {Object} filter- Filter used to create the report.
     * @param {Object} value - Value of the filter.
     * @param {String} text  - Text used to create the header of the report.
     *
     * @return {String} Text to be shown woth data related to the given filter.
     */
    var getFieldFilterDefaultText = function(filter, value, text) {
        if (Array.isArray(value)) {

            return oneOrMoreValuesFieldText(value, text);
        }

        if (filter.operator === "LIKE_I") {
            return likeIFieldText(value, text);
        }

        if (!value) {
            return getFieldFilterDefaultTextWithoutValue(text);
        }

        return valueFieldText(filter, value, text);


    };

    /**
     * Checks if the filter related to the given item should be displayed on the header of
     * the report.
     *
     * @param  {Field} field -  Field to be filter to be tested.
     *
     * @return {Boolean} Boolean telling if the filter related to the field should be displayed.
     */
    function filterIsVisibleOnHeader(field) {
        return field && field.isVisibleOnReport;
    }

    /**
     * Builds the metadata of the filter.
     *
     * @param {Widget} widget - Widget where the report is being generated.
     *
     * @return {Array.<Object>} The metadatas of each filter in the widget.
     */
    var _buildMetaDataFilter = function(widget) {
        var filterData = [];
        if (widget.dataSourceFilter) {
            widget.dataSourceFilter.forEach(function(item) {
                var field = widget.getField(item.name);
                if (filterIsVisibleOnHeader(field)) {
                    filterData.push({
                        label: field.label,
                        value: ZhUtil.evaluate(getFieldFilterValue(field, item))
                    });
                }
            });
        }

        return filterData;
    };

    /**
     * Retrieves the image from the url and converts it to base64
     *
     * @param {String}   url    - The source of the image
     * @param {Function} widget - Widget where the report is being generated.
     */
    function convertImageToB64(url, callback) {
        var xhr = new XMLHttpRequest();

        xhr.onload = function() {
            var reader = new FileReader();
            reader.onloadend = function() {
                callback(reader.result);
            };
            reader.readAsDataURL(xhr.response);
        };

        xhr.open('GET', url);
        xhr.responseType = 'blob';
        xhr.send();
    }

    /**
     * Fetches the images if they exist.
     *
     * @param {Function} callback  - The callback to be executed after all the images where fetched.
     * @param {Widget}   widget    - Widget where the report is being generated.
     */
    function getAllImages(container, callback) {
        var imgs = {};
        var imgSrc = ['reportClientLogo', 'reportProductLogo', 'reportEnterpriseLogo'];
        var index = 0;

        if(!container[imgSrc[0]] && !container[imgSrc[1]] && !container[imgSrc[2]]){
            callback({});
            return;
        }

        imgSrc.forEach(function(imgName){
            if(container[imgName]){
                index++;
                convertImageToB64(container[imgName], function(imageData){
                    imgs[imgName] = imageData;
                    index--;

                    if(index === 0){
                        callback(imgs);
                    }
                });
            }
        });
    }

    /**
     * Builds the widget metadata.
     *
     * @param {Object} [customData]       - Customization data for the generation of the report.
     * @param {Widget} sourceWidget       - Widget where the report is being generated.
     * @param {String} [reportType='PDF'] - The type of the report.
     *
     * @return {Object} The widget's metadata for the generation of the report.
     */
    var buildMetaData = function(customData, sourceWidget, reportType, callback) {
        var widget = sourceWidget;
        var columns = _buildMetaDataColumns(widget, customData.columns, reportType, customData.groups);
        var staticColumns = _buildStaticDataColumns(widget, columns);
        var widgetLabel = ScreenService.i18n(widget.label);
        var groups = _buildMetaDataGroups(widget, customData.groups);

        getAllImages(templateManager.project, function(images) {
            var widgetMetaData = {
                name: widget.name,
                title: customData.name || widgetLabel,
                reportName: customData.reportName || widget.name,
                reportClientLogo: images.reportClientLogo,
                reportProductLogo: images.reportProductLogo,
                reportEnterpriseLogo: images.reportEnterpriseLogo,
                widgetLabel: widgetLabel,
                version: '1.0',
                clientLogo: templateManager.project.reportClientLogo,
                productLogo: templateManager.project.reportProductLogo,
                enterpriseLogo: templateManager.project.reportEnterpriseLogo,
                columns: columns,
                staticData: staticColumns,
                groups: groups,
                filter: _buildMetaDataFilter(widget),
                xlsDefaultType: widget.xlsDefaultType,
                orientation: widget.reportOrientation || 'PORTRAIT'
            };

            callback(widgetMetaData);
        });
    };

    /**
     * Tells if the given field needs to have it's value decoded.
     *
     * @param {Field} field - Fild to test if it's value need to be decoded.
     *
     * @return {Boolean} Tells if the field's value need to be decoded
     */
    var shouldUseDecodeValueField = function(field) {
        var masksTypesToAvoid = ['currency', 'hour', 'float', 'percent', 'fix'];
        return !field.mask || masksTypesToAvoid.indexOf(field.mask.type) == -1;
    };

    /**
     * Get the grouped columns from the given metadata of grouped fields.
     *
     * @param {Object} groupsMetadata - Metadata of the grouped on the report.
     *
     * @return {Array.<Field>} The fields of the group.
     */
    var getGroupedColumns = function(groupsMetadata) {
        var columns = [];
        groupsMetadata.forEach(function(group) {
            columns.push(group.field);
        });

        return columns;
    };

    /**
     * Format the values of the dataset based on the field of the widget configured
     * the metaData.
     *
     * @param {Array.<Object>} dataSet  - The widget's dataset.
     * @param {Object}         metaData - Metadata of the report.
     * @param {Widget}         widget   - Widget where the report is being generated.
     *
     * @return {Array.<Object>} The given dataset formatted for be used on the report.
     */
    var formatValuesForReport = function(dataSet, metaData, widget) {
        var columns = Object.keys(metaData.columns);
        columns = columns.concat(getGroupedColumns(metaData.groups));

        return dataSet.map(function(row) {
            if(row.__groupHeader || row.__groupFooter) return row;

            var formattedRow = {};
            columns.forEach(function(column) {
                var field = widget.getField(column);
                if (field && shouldUseDecodeValueField(field)) {
                    formattedRow[column] = DecodeValueFieldService.model(field, row[column]);
                }
                else {
                    formattedRow[column] = row[column];
                }
            });

            return formattedRow;
        });
    };

    /**
     * Builds the dataSet based on the given widget,
     *
     * @param {Object} metaData   - The metadata of the report.
     * @param {Widget} widget     - Widget where the report is being generated.
     * @param {String} reportType - The report type to generate.
     *
     * @return {Array.<Object>}  Dataset from the widget formatted to the report.
     */
    var buildDataSet = function(metaData, widget, reportType) {
        return loadAllData(widget, reportType).then(function(dataSet) {
            return (isPdfOrXlsLocalFormat(reportType)) ? formatValuesForReport(dataSet, metaData, widget) : dataSet;
        });
    };

    var buildDataSetXLS = function(metaData, widget, reportType,actionControl) {
        return loadAllDataXLS(widget, reportType, metaData, actionControl).then(function(dataSet) {
            return (isPdfOrXlsLocalFormat(reportType)) ? formatValuesForReport(dataSet, metaData, widget) : dataSet;
        });
    };

    /**
     * Get the datasorce's name without the initial '/'.
     *
     * @param {DataSource} dataSource - Widget's dataSource to get the name.
     *
     * @return {String} Datasorce name without the initial '/'.
     */
    function getDataSourceName(dataSource) {
        return dataSource.name.split('/').pop();
    }

    var confirmeErroBackend = function(result, dataToReturn, metaData) {
        var variables = {
            'NAMEACTION':ScreenService.i18n(ZhReportsXLS.labelByFormat[metaData.formatXLS])
        };
        var message = 'Unable to generate the report in the format<BR>"__NAMEACTION__"<BR>Do you want to generate the report in the format<BR>"XLS (all columns - no group)",<BR> without grouping?';
        var callbackYes = function () {
            result.resolve(dataToReturn);
            metaData.formatXLS = 'F3';
        };
        var callbackYNo = function () {
            result.reject(dataToReturn);
        };
        ScreenService.confirmMessage(message,null,callbackYes,callbackYNo,null,variables);
    };

    /**
     * Load all data from the widget's dataSource.
     *
     * @param {Widget} widget     - Widget where the report is being generated.
     * @param {String} reportType - The report type to generate.
     *
     * @return {Promise.<Array>} Promise that will be resolved with the widget's datasource.
     */
    function loadAllData(widget, reportType) {
        var dataSource = widget.dataSource;
        var result;

        if (dataSource.getStorageStrategy() && !widget.useLocalDataOnReport) {
            var oldData = dataSource.data;

            result = dataSource.load(widget.getDataSourceFilter(),DataSource.LOAD_ALL,undefined,undefined,undefined,undefined,undefined,undefined,widget).then(function(dataSet) {
                if (Util.isObject(dataSet)) {
                    dataToReturn = dataSet.dataset[getDataSourceName(dataSource)];
                    return isPdfOrXlsLocalFormat(reportType) ? widget.getUpdatedGroupData(dataToReturn) : dataToReturn;
                } else {
                    dataSource.data = oldData;
                    return dataSet;
                }
            }).catch(function() {
                dataSource.data = oldData;
            });
        } else {
            result = ZHPromise.when(widget.groupedData);
        }

        return result;
    }

    var validateLoadAll = function (metaData,actionControl) {
        return !(ZhReportsXLS.isFormat3(metaData.formatXLS) && (actionControl.dataSourceName || actionControl.collectionName));
    };

    function loadAllDataXLS(widget, reportType, metaData,actionControl) {
        var dataSource = widget.dataSource;
        var result = ZHPromise.defer();

        if (dataSource.getStorageStrategy() && !widget.useLocalDataOnReport && validateLoadAll(metaData,actionControl)) {
            var oldData = dataSource.data;
            var catchFunction = function(response) {
                dataSource.data = oldData;

                if (isXlsLocalFormat(reportType)) {
                    confirmeErroBackend(result, widget.groupedData, metaData);
                } else {
                    result.reject(response);
                }
            };

            dataSource.load(widget.getDataSourceFilter(),DataSource.LOAD_ALL,undefined,undefined,undefined,undefined,undefined,undefined,widget).then(function(dataSet) {
                var dataToReturn = dataSet;
                if (Util.isObject(dataSet)) {
                    dataToReturn = dataSet.dataset[getDataSourceName(dataSource)];
                    if (dataToReturn === undefined && (actionControl.dataSourceName || actionControl.collectionName)) {
                        confirmeErroBackend(result, widget.groupedData, metaData);
                    } else {
                        dataToReturn = isPdfOrXlsLocalFormat(reportType) ? widget.getUpdatedGroupData(dataToReturn) : dataToReturn;
                        result.resolve(dataToReturn);
                    }
                } else {
                    catchFunction(dataSet);
                }
            }).catch(catchFunction);
        } else {
            result.resolve(dataSource.data);
        }

        return result;
    }

    /**
     * Build the path where the file was created.
     *
     * @param {String} fileName - Name of the created file.
     *
     * @return {Object} Object with the ful path of the created file.
     */
    var buildFilePath = function(fileName) {
        var reportsUrl = templateManager.project.reportsUrl;
        return {
            path: reportsUrl + '/reports/' + fileName
        };
    };

    /**
     * Builds a successs callback.
     *
     * @param {Function} callback - Function to be executed with the FilePath.
     *
     * @return {Function} Callback with the given callback.
     */
    var buildCallbackOfSuccess = function(callback) {
        return function(data) {
            if (callback) {
                callback(buildFilePath(data.messages[0].message));
            }
        };
    };

    /**
     * Build the file path of the generated file for the dataExporter
     *
     * @param {String} fileName - Name of the generated file.
     *
     * @return {Object} Object with the fukk path of the generated file.
     */
    var buildFilePathForDataExporter = function(exporterUrl, fileName) {
        return {
            path: exporterUrl + fileName
        };
    };

    /**
     * Builds a successs callback for the dataExporter.
     *
     * @param {Function} callback - Function to be executed with the FilePath.
     *
     * @return {Function} Callback with the given callback.
     */
    var buildCallbackOfSuccessForDataExporter = function(exporterUrl, callback) {
        return function(data) {
            if (callback) {
                callback(buildFilePathForDataExporter(exporterUrl, data.messages[0].message));
            }
        };
    };

    /**
     * Returns the uri from a given report type.
     *
     * @param {String} reportType - Report type that will be used to get the uri.
     *
     * @return {String} - Uri from the given report type.
     */
    var getReportUri = function(reportType) {
        return reportConfig[reportType].uri;
    };

    /**
     * Format the dataset for the XLS files.
     *
     * @param {Object} metaData - The metadata of each column of the report.
     * @param {Array}  dataSetFormat - The datasource's formatted like it shows on the screen.
     * @param {Array}  dataSet - The datasource's data of the widget.
     *
     * @return {Array.<Object>} The dataSet to the XLS files
     */
    var formatDataSetXLS = function (metaData, dataSetFormat, dataSet) {
            metaData.reportXLS = true;
            return ZhReportsXLS.getFormatDataSet(metaData, dataSetFormat, dataSet);
     };

    /**
     * Format the dataset for the CSV files.
     *
     * @param {Object} metaData - The metadata of each column of the report.
     * @param {Array}  dataSet - The datasource's data of the widget.
     *
     * @return {Array.<Object>} The dataSet to the  CSV files
     */
    var formatDataSet = function(metaData, dataSet) {
        var columns = metaData.columns;
        metaData.groups.forEach(function(column) {
            if (columns[column.name]) {
                columns[column.name].sequence -= 1000; // put grouped columns first
            }
        });
        var columnsName = Object.keys(columns).sort(function(a, b) {
            return columns[a].sequence - columns[b].sequence;
        });
        var rowValues = [];
        var formatedDataSet = [];

        dataSet.forEach(function(row) {
            columnsName.forEach(function(column) {
                rowValues.push(row[column]);
            });

            formatedDataSet.push(rowValues);
            rowValues = [];
        });

        return [columnsName].concat(formatedDataSet);
    };

    /**
     * Build the dataSet to be used on the backend to generate the report.
     *
     * @param {String} reportType - Defines what report type will be generate.
     * @param {Object} metaData - Defines the report's structure.
     * @param {Object} dataSet - Data used to create the reports.
     *
     * @return {Object} - Builded dataSet.
     */
    var buildDataSetToReportRow = function(reportType, metaData, dataSet) {
        if(reportType == reportConfig.PDF.type) {
            return dataSet.map(ZhUtil.clearRow);
        } else {
            return formatDataSet(metaData, dataSet);
        }
    };

    /**
     * Build the reportRow to be used on the backend to generate the report.
     *
     * @param {Object} metaData - Defines the report's structure.
     * @param {Object} reportRowDataSet - Data used to create the reports.
     * @param {Widget} widget - Widget to report.
     *
     * @return {Object} reportRow - Builded reportRow.
     */
    var buildReportRow = function(metaData, reportRowDataSet, widget) {
        var reportRow = {};
        reportRow.metaData = JSON.stringify(metaData);
        reportRow.dataSet = JSON.stringify(reportRowDataSet);
        reportRow.filter = JSON.stringify(widget.dataSourceFilter);
        return reportRow;
    };

    /**
     * Build the params to be used on the request.
     *
     * @param {Object} metaData - Defines the report's structure.
     * @param {Object} reportRowDataSet - Data used to create the reports.
     * @param {Widget} widget - Widget to report.
     *
     * @return {Object} - Builded params.
     */
    var buildParamsToRequest = function(metaData, reportRowDataSet, widget) {
        return {
            'requestType': 'Row',
            'row': buildReportRow(metaData, reportRowDataSet, widget)
        };
    };

    /**
     * Build the request to generate the report.
     *
     * @param {String} reportType         - Defines what report type will be generate.
     * @param {Object} metaData           - Defines the report's structure.
     * @param {Object} reportRowDataSet   - Data used to create the reports.
     * @param {function} callback         - Callback called after sucess.
     * @param {function} callbackError    - Callback called after error.
     * @param {Widget} widget             - Widget to report.
     *
     * @return {Promisse} Request's promisse.
     */
    var buildRequest = function(reportType, metaData, reportRowDataSet, callback, callbackError, widget) {
        var uri = getReportUri(reportType);
        var params = buildParamsToRequest(metaData, reportRowDataSet, widget);
        var callbackSuccess = buildCallbackOfSuccess(callback);
        var requestType = 'post';
        var reportsUrl = templateManager.project.reportsUrl;

        return restEngine.request(uri,params,callbackSuccess,requestType,callbackError,reportsUrl);
    };

    /**
     * Process to be executed after the request.
     *
     * @param {Object}      response        - Request result.
     * @param {Promisse}    deferred        - Promisse that defines the result of report generation.
     * @param {String}      reportType      - Defines what report type will be generated.
     *
     */
    var afterRequest = function(widget, response, deferred, reportType) {
        if (response) {
            var file = buildFilePath(response.messages[0].message);

            deferred.resolve(file);

            if(widget.afterOpenreport){
                widget.afterOpenreport();
            }
        }
        else {
            deferred.reject();
            publishErrorEvent();
        }
    };

    /**
     * Generates the report making a requests to the server to generate the file.
     *
     * @param {Object}          metaData        - Metadata for the construction of the report.
     * @param {Array.<Object>}  dataSet         - The widget's dataset.
     * @param {Function}        callback        - Callback used to create a success callback that will be executed if the request does not failed.
     * @param {Function}        callbackError   - Callback that will be executed if the request failed.
     * @param {String}          reportType      - The type of the report.
     *
     * @return {Promise} Promise resolved when the file is created of rejected if somethig went wrong.
     */
    var _generateReport = function(widget, metaData, dataSet, callback, callbackError, reportType) {
        var deferred = ZHPromise.defer();
        var reportRowDataSet = buildDataSetToReportRow(reportType, metaData, dataSet);

        buildRequest(reportType, metaData, reportRowDataSet, callback, callbackError, widget).then(function(response) {
            afterRequest(widget, response, deferred, reportType);
        }).catch(function(response) {
            deferred.reject(response);
            publishErrorEvent();
        });

        return deferred.promise;
    };

    /**
     * Removes the '__proxy_' form the order filter.
     *
     * @param {Object} filter The filter to be cleared.
     */
    function clearFilter(filter){
        return filter.map(function(currentFilter){
            if(currentFilter.operator === "ORDER_BY"){
                currentFilter.name.map( function(currentOrderFilter){
                    currentOrderFilter.name = currentOrderFilter.name.replace("__proxy_", "");
                    return currentOrderFilter;
                });
            }

            currentFilter.value = ZhUtil.evaluate(currentFilter.value);

            return currentFilter;
        });
    }

    var setDefaultParamReport = function(widget, reportType, metaData, params) {
        var reportRow = {};
        var dataSet = widget.dataSource.data;
        if (reportType === reportConfig.XLS.type) {
            dataSet = formatDataSetXLS(metaData, widget.dataSetXLS, dataSet);
        }
        reportRow.dataSet = JSON.stringify(dataSet);
        reportRow.metaData = JSON.stringify(metaData);
        reportRow.filter = JSON.stringify(widget.dataSourceFilter);

        params = {
            'requestType': 'Row',
            'row': reportRow,
        };
        return params;
    };

    /**
     * Returns the params to make the request.
     *
     * @param {Object} actionControl - The widget's actionControl.
     * @param {Widget} widget        - Widget where the report is being generated.
     * @param {Object} metaData      - Metadata for the construction of the report.
     * @param {String}   [reportType='PDF'] - The type of the report.
     *
     * @return {Object} Params to the request.
     */
    function getParams(actionControl, widget, metaData, reportType){
        var params = {
            'requestType': 'FilterData',
            'filter': clearFilter(widget.dataSourceFilter),
            'metaData': metaData
        };
        if (metaData.formatXLS !== 'F3' && widget.dataSetXLS) {
            params = setDefaultParamReport(widget, reportType, metaData, params);
        } else {
            if(actionControl.dataSourceName){
                params.dataSourceName = actionControl.dataSourceName;
            } else if(actionControl.collectionName){
                params.collectionName = actionControl.collectionName;
            } else {
                params = setDefaultParamReport(widget, reportType, metaData, params);
            }
        }
        return params;
    }

    /**
     * Generates the report making only one request to the server generate the file.
     *
     * @param {Object}   metaData           - Metadata for the construction of the report.
     * @param {Object}   actionControl      - The widget's actionControl.
     * @param {Object}   widget             - Widget where the report is being generated.
     * @param {Function} callback           - Callback used to create a success callback that will be executed if the request does not failed.
     * @param {Function} callbackError      - Callback that will be executed if the request failed.
     * @param {String}   [reportType='PDF'] - The type of the report.
     *
     * @return {Promise} Promise resolved when the file is created of rejected if somethig went wrong.
     */
    var _generateServerSideReport = function(metaData, actionControl, widget, callback, callbackError, reportType) {
        var exporterUrl = templateManager.project.exporterUrl;
        var deferred = ZHPromise.defer();
        var uri = getReportUri(reportType);
        var params = getParams(actionControl, widget, metaData, reportType);

        restEngine.request(uri, params, buildCallbackOfSuccessForDataExporter(exporterUrl, callback), 'post', callbackError, exporterUrl)
            .then(
                function(response) {
                    afterRequest(widget, response, deferred, reportType);
                })
            .catch(
                function(response) {
                    deferred.reject(response);
                    publishErrorEvent();
                }
            );

        return deferred.promise;
    };

    /**
     * Publish a new event. Lauched after the report failed.
     */
    var publishErrorEvent = function() {
        eventAggregator.publish('afterReportError');
    };

    /**
     * Creates a metaData for the translate of fixed words on the report.
     *
     * @param {Object} metaData - Metada of the report.
     *
     * @return {Object} The metadata with the configuration of the i18n
     */
    var _i18nMetaData = function(metaData) {
        var words = {
            'Page': ScreenService.i18n('Page'),
            'Report': ScreenService.i18n('Report'),
            'Version': ScreenService.i18n('Version')
        };

        metaData.words = words;
        metaData.lang = templateManager.lang;

        Object.keys(metaData.columns).forEach(function(key) {
            var column = metaData.columns[key];

            column.description = ScreenService.i18n(column.description);
        });

        metaData.groups.forEach(function(group) {
            Object.keys(group).forEach(function(key) {
                var grp = group[key];
                if (grp) {
                    grp.label = ScreenService.i18n(grp.label);
                }
            });
        });

        return metaData;
    };

    /**
     * Get the action control's configuration.
     *
     * @param  {Widget} widget     - Widget where the report is being generated.
     * @param  {String} reportType - The type of the report.
     *
     * @return {Object | Boolean} A object containing the configuration of the floating action or true.
     */
    var getActionControl = function(widget, reportType) {
        return Util.getNestedProperty(widget, ['floatingControl', reportConfig[reportType].action]);
    };

    /**
     * Generates the report.
     *
     * @param {Object}      customData      - Informations to customize the report.
     * @param {Widget}      sourceWidget    - Widget where the report is being generated.
     * @param {Function}    callback        - Function to be executed after the file be generated, reciving the name of the generated file.
     * @param {Function}    callbackError   - Function to be executed if happen a error while generating the file.
     * @param {String}      reportType      - The type of the report.
     * @param {String}      format      - The format of the report.
     *
     * @return {Promise} Promise resolved when the file is created o rejected.
     */
    this.generateReport = function generateReport(customData, sourceWidget, callback, callbackError, reportType, format) {
        if (Util.getNestedProperty(sourceWidget, ['dataSource', 'data', 'length'])) {
            customData = customData || {};
            checkConfiguration();
            var widget = sourceWidget;
            var promise;

            buildMetaData(customData, widget, reportType, function(metaDataResolved) {
                var metaDataInternationalized = _i18nMetaData(metaDataResolved);

                triggerBeforeGenerateReport(widget, metaDataInternationalized);

                var actionControl = getActionControl(widget, reportType);

                if (typeof actionControl === "object" && actionControl.runAt == 'server') {
                    if(reportType === reportConfig.XLS.type) {
                        metaDataInternationalized.formatXLS = format;
                        promise = buildDataSetXLS(metaDataInternationalized, widget, typeXLSLocal,actionControl).then(function (dataSet) {
                            widget.dataSetXLS = dataSet;
                            return _generateServerSideReport(metaDataInternationalized, actionControl, widget, callback, callbackError, reportType);
                        });
                    }else{
                        promise = _generateServerSideReport(metaDataInternationalized, actionControl, widget, callback, callbackError, reportType);
                    }
                }
                else {
                    promise = buildDataSet(metaDataInternationalized, widget, reportType).then(function(dataSet) {
                        return _generateReport(widget, metaDataInternationalized, dataSet, callback, callbackError, reportType);
                    });
                }
            });

            return promise;
        }
        else {
            ScreenService.errorNotification("Can't create a report without data!");
        }
    };

    /**
     * Returns a callback to be executed if the report is created succefully.
     *
     * @param {Function} callback - Function executed after the test.
     *
     * @return {Function} Callback that tests if the screen is able to open the popup creating a fake popup and, warning the user if the windows's popups are blocked.
     */
    var _previewCallback = function(callback) {
        return function(data) {
            var popup_window = window.open(data.path, '_blank');
            if (!popup_window) {
                ScreenService.showMessage(ScreenService.i18n('Pop-up Blocker is enabled! Please add this site to your exception list.'));
            }
            if (callback) {
                callback(data);
            }
        };
    };

    /**
     * Creates the report and open it rigth after.
     *
     * @param {Object}      customData      - Custom data for the generation of the report.
     * @param {Widget}      sourceWidget    - Widget where the report is being generated.
     * @param {Function}    callback        - Callback used to create a success callback that will be executed if the request does not failed.
     * @param {Function}    callbackError   - Callback that will be executed if the request failed.
     * @param {String}      reportType      - The type of the report.
     * @param {String}      format          - The format of the report.
     *
     * @return {Promise} Promise resolved when the file is created or rejected
     */
    this.openReport = function openReport(customData, sourceWidget, callback, callbackError, reportType, format) {
        return this.generateReport(customData, sourceWidget, _previewCallback(callback), callbackError, reportType, format);
    };
}

Configuration(function(ContextRegister) {
    ContextRegister.register('ZhReports', ZhReports);
});


// FILE: src/ZhReportsDirective.js
var ZeedhiDirectives = angular.module('ZeedhiDirectives');

function ReportsDirective(ApplicationContext){
    return {
        priority: 2,
        link: function($scope) {
            /**
             * Generate the report of the given widget.
             * @param  {Widget}   widget  Widget where the report is being generated.
             * @param  {String}   type    The type of the report.
             * @param  {String}   format  The format of the report.
             */
            $scope.generateReport = function(widget, type, format) {
                ApplicationContext.ZhReports.openReport(widget.reportCustomData, widget, undefined, undefined, type, format);
            };
        }
    };
}

ZeedhiDirectives.directive(
    'zhFloatingControl', ['ApplicationContext', ReportsDirective]
);


// FILE: ./bower_components/zh-preferences/dist/preferences.js
// FILE: src/ZhPreferences.js
/**
 * Service to handle preferences storage
 *
 * @class
 * @param {RepositoryFactory} RepositoryFactory Service to factory repositories
 * @param {RequestEngine}     requestEngine     Service to make http requests
 * @param {RequestFactory}    requestFactory    Service to factory requests
 * @param {ZHPromise}         ZHPromise         Service to manipulate promises
 * @param {Query}             Query             Service to build queries
 */
function ZhPreferences(RepositoryFactory, requestEngine, requestFactory, ZHPromise, Query){

    var repositoryMap = {};

    var userWidgetConfiguration = {};

    /**
     * Register new repository to save preferences
     *
     * @param  {String} name Repository name used to save a preference
     */
    this.registerRepository = function(name){
        var repositoryName = name.split('#').pop();
        repositoryMap[repositoryName] = RepositoryFactory.factory(name, 'MEMORY');
    };


    /**
     * Persist preferences
     *
     * @param  {String}   preferenceType Repository name
     * @param  {Object[]} preferences    Array of preferences to persist
     *
     * @return {Promise}                 Preferences saved
     */
    this.savePreferences = function(preferenceType, preferences){
        return requestEngine.doRequest(requestFactory.factory({
            'serviceName': 'zh-preferences#/' + preferenceType + '/save',
            'requestType': 'dataSource',
            'dataSource': preferences
        })).then(null, function(response){
            throw new Error(response.data.error);
        }).then(function(response){
            var returnedIds = response.dataset[preferenceType];
            return preferences.map(function(preference, index){
                preference.__is_new = false;
                preference.changed = false;
                preference.ID = returnedIds[index].ID;
                return preference;
            });
        }).then(function(preferences){
            return repositoryMap[preferenceType].save(preferences);
        });
    };

    /**
     * Delete preferences
     *
     * @param  {String}   preferenceType Repository name
     * @param  {Object[]} preferences    Array of preferences to delete
     *
     * @return {Promise}                 Preferences deleted
     */
    this.deletePreferences = function(preferenceType, preferences){
        return requestEngine.doRequest(requestFactory.factory({
            'serviceName': 'zh-preferences#/' + preferenceType + '/remove',
            'requestType': 'dataSource',
            'dataSource': preferences
        })).then(null, function(response){
            throw new Error(response.data.error);
        }).then(function(response){
            var deletedIds = response.dataset[preferenceType].map(function(preference){
                return preference.ID;
            });
            var query = Query.build().where('ID').in(deletedIds);

            return repositoryMap[preferenceType].remove(query);
        });
    };

    /**
     * Get local saved preferences from repository
     *
     * @param  {String} preferenceType Repository name
     * @param  {Query}  query          Conditions to filter the preferences
     *
     * @return {Promise}               Array of preferences
     */
    this.getPreferences = function(preferenceType, query){
        var filterRequest = requestFactory.factory({
            'serviceName': 'zh-preferences#/' + preferenceType,
            'requestType': 'filterData',
            'filter': query.where()
        });
        return requestEngine.doRequest(filterRequest)
            .then(function(response){
                var preferences = response.dataset[preferenceType];
                var removePreferences = repositoryMap[preferenceType].remove(query);
                var savePreferences = repositoryMap[preferenceType].save(preferences);
                return ZHPromise.all([removePreferences, savePreferences]).then(function(){
                    return preferences;
                });
            })
            .catch(function(response){
                throw new Error(response.data.error);
            });
    };

    /**
     * Get local saved preferences from repository filtering by widget and logged user
     *
     * @param  {String} preferenceType Repository name
     * @param  {String} widgetID       Widget identified
     *
     * @return {Promise}               Array of preferences
     */
    this.getWidgetPreferences = function(preferenceType, widgetID){
        var query = Query.build().where('WIDGET_ID').equals(widgetID);
        return this.getPreferences(preferenceType, query);
    };

    /**
     * Get default preferences for user on specified widget
     *
     * @param  {String} widgetID Widget to get default preferences
     *
     * @return {Promise}         Widget default preferences
     */
    this.getDefaultWidgetPreferences = function(widgetID){
        if(userWidgetConfiguration[widgetID] === undefined){
            var query = Query.build().where('WIDGET_ID').equals(widgetID);

            userWidgetConfiguration[widgetID] = requestEngine.doRequest(requestFactory.factory({
                'serviceName': 'zh-preferences#/default-preferences',
                'requestType': 'filterData',
                'filter': query.where()
            })).then(function(response){
                var dataset = response.dataset;
                var preference = dataset.user_widget.pop()|| {
                    '__is_new': true,
                    'ID': null,
                    'WIDGET_ID': widgetID,
                    'DEFAULT_FILTER': null,
                    'DEFAULT_LAYOUT': null,
                    'DEFAULT_VIEW': null,
                    'LAST_MODIFIED_DATE': null
                };
                if(dataset.defaultFilter && dataset.defaultFilter.length){
                    preference.defaultFilter = dataset.defaultFilter.pop();
                    preference.defaultFilter.FILTER_ROW = JSON.parse(preference.defaultFilter.FILTER_ROW);
                }
                if(dataset.defaultLayout && dataset.defaultLayout.length){
                    preference.defaultLayout = dataset.defaultLayout.pop();
                }
                if(dataset.defaultView && dataset.defaultView.length){
                    preference.defaultView = dataset.defaultView.pop();
                }
                return preference;
            });
        }

        return userWidgetConfiguration[widgetID];
    };

    /**
     * Change default preference for user on specified widget
     *
     * @param  {String}  configWidget        Preference configuration widget
     * @param  {String}  property            Property that contains the default preference ID
     * @param  {Integer} preference          Preference configuration widget changed row
     *
     * @return {Promise}                     Widget default preferences
     */
    this.changeDefaultPreferences = function(configWidget, property, preference){
        var widgetID = configWidget.listWidget.id;
        var preferenceID = preference[property] ? preference.ID : null;

        userWidgetConfiguration[widgetID] = this.getDefaultWidgetPreferences(widgetID)
            .then(function(defaultPreferences){
                defaultPreferences[property] = preferenceID;
                defaultPreferences.__is_new = defaultPreferences.__is_new || false;
                return ZHPromise.all([
                    defaultPreferences,
                    requestEngine.doRequest(requestFactory.factory({
                        'serviceName': 'zh-preferences#/default-preferences/save',
                        'requestType': 'dataSource',
                        'dataSource': [defaultPreferences]
                    }))
                ]);
            }).then(function(args){
                var defaultPreferences = args[0];
                var response = args[1];
                defaultPreferences.ID = Util.getNestedProperty(response, ['dataset', 'user_widget', '0', 'ID']);

                configWidget.dataSource.data.forEach(function(row){
                    row.__is_new = false;
                    row[property] = row.ID == defaultPreferences[property];
                });
                return defaultPreferences;
            });

        return userWidgetConfiguration[widgetID];
    };

    function isMasterDetail(template){
        return template.indexOf('master_detail/grid.html') !== -1 ||
               template.indexOf('master_detail/list.html') !== -1 ||
               template.indexOf('master_detail/tree/grid.html') !== -1;
    }

    function isMasterDetailView(widget){
        return isMasterDetail(widget.template) && widget.mode == ViewMode.VIEW;
    }

    this.validateWidget = function(widget){
        if(!widget.id){
            throw new Error('Widget\'s must have "id" to use Preferences. '+
                'Widget with name "'+widget.name+'" does not have an id.');
        }
        if(!widget.container.id){
            throw new Error('Container\'s must have "id" to use Preferences.');
        }

        return !isMasterDetailView(widget);
    };

    var userPromise = ZHPromise.defer();

    /**
     * Invalidate logged user and clear preferences loaded
     */
    this.unsetUser = function(){
        userPromise = ZHPromise.defer();
        userWidgetConfiguration = {};

        Object.keys(repositoryMap).forEach(function(repositoryName){
            repositoryMap[repositoryName].clearAll();
        });
    };

    /**
     * Set logged user
     *
     * @param {String} userID Logged user
     */
    this.setUserID = function(userID){
        userPromise.resolve(userID);
    };

    /**
     * Get logged user ID
     *
     * @return {Promise} User identifier
     */
    this.getUserID = function(){
        return userPromise.promise;
    };


    /**
     * Generate preference file to download
     *
     * @param {Object} preference       Preference to be exported
     * @param {String} fileName         File name
     *
     * @return {Promise<Object>}        Preference exported
     */
    this.downloadPreferenceFile = function(preference, fileName){
        var dataStr = "data:text/json;charset=utf-8," + encodeURIComponent(JSON.stringify(preference,false,4));

        var linkElement = document.createElement('a');
        linkElement.setAttribute("href",     dataStr);
        linkElement.setAttribute("download", fileName);
        linkElement.click();
        linkElement.remove();

        return ZHPromise.when(preference);
    };

}

Configuration(function(ContextRegister){
    ContextRegister.register('ZhPreferences', ZhPreferences);
});


// FILE: src/ZhPreferenceFloatingControl.js
var ZeedhiDirectives = angular.module('ZeedhiDirectives');

ZeedhiDirectives.directive('zhPreferenceFloatingControl', [zhPreferenceFloatingControl]);

function zhPreferenceFloatingControl(){
    return {
        priority: 10,
        link: function($scope){
            function checkFloatingCardOverflow(e){
                var actionElement = $(e.target).closest('.float-action');
                var floatingControl = actionElement.parents('.zh-floating-control');
                var widgetContainer = actionElement.closest('.container');
                var actionTop, actionBottom;
                var widgetTop, widgetBottom;

                if(!actionElement.hasClass('opened')){
                    actionElement.removeClass('fix-position-top');
                    actionElement.removeClass('fix-position-bottom');

                    actionTop = actionElement.offset().top;
                    widgetTop = widgetContainer.offset().top;
                    widgetBottom = widgetTop + widgetContainer.height();
                    if(floatingControl.hasClass('pos-top')){
                        actionTop = actionTop - 200 + actionElement.height();
                        if(actionTop < widgetTop){
                            actionElement.addClass('fix-position-top');
                        }
                    } else {
                        actionBottom = actionTop + 200;
                        if(actionBottom > widgetBottom){
                            actionElement.addClass('fix-position-bottom');
                        }
                    }
                }
            }

            $scope.togglePreferencesCard = function(e){
                checkFloatingCardOverflow(e);
                $scope.toggleAction(e);
            };
        }
    };
}

// FILE: src/Config.js
(function(){

window.metadataUrls = window.metadataUrls || [];
window.serviceUrls = window.serviceUrls || [];

var PACKAGE_NAME = 'zh-preferences';

var hasMetaData = window.metadataUrls.some(function(metadataUrl){
    return metadataUrl.package === PACKAGE_NAME;
});

var hasServiceUrl = window.serviceUrls.some(function(serviceUrl){
    return serviceUrl.package === PACKAGE_NAME;
});

if(!hasMetaData){
    window.metadataUrls.push({
        package: PACKAGE_NAME,
        baseUrl: 'bower_components/zh-preferences/dist/assets/'
    });
}

if(!hasServiceUrl){
    window.serviceUrls.push({
        package: PACKAGE_NAME,
        baseUrl: '../backend/service/index.php/zh-preferences'
    });
}

})();


// FILE: ./bower_components/zh-layout-preferences/dist/layout-preferences.js
// FILE: src/utilities/LayoutUtilities.js
var LayoutUtilities = {};
LayoutUtilities.createDiffDataStructure = function createDiffDataStructure(container, widget, clearFields){
    var containerDiff = {};
    var createWidgetsDataStructure = function createWidgetsDataStructure(widgetID, widgets, containerDiff){
        containerDiff.widgets = [];
        createWidgetsObjects(containerDiff.widgets, widgets, widgetID);
        if(Util.isArray(widgets) && widgets.length > 0){
            widgets.forEach(function(eachWidget){
                createWidgetsDataStructure(widgetID, eachWidget.widgets, getWidgetObjectByID(containerDiff.widgets, eachWidget.id));
            });
        }
    };

    var createWidgetsObjects = function createWidgetsObjects(widgetsDiff, widgetsArray, widgetID){
        if(Util.isArray(widgetsArray) && widgetsArray.length > 0){
            widgetsArray.forEach(function(eachWidget){
                var properties = {
                    "id": eachWidget.id
                };
                if(eachWidget.id == widgetID){
                    properties.fields = clearFields ? [] : eachWidget.fields;
                }
                widgetsDiff.push(properties);
            });
        }
    };

    var getWidgetObjectByID = function getWidgetObjectByID(widgets, widgetId){
        return widgets.filter(function(eachWidgetObject){
            return eachWidgetObject.id == widgetId;
        }).shift();
    };

    createWidgetsDataStructure(widget.id, container.widgets, containerDiff);
    return containerDiff;
};


// FILE: src/services/ZhLayoutPreferences.js
/**
 * Layout
 * @typedef {Object} Layout
 *
 * @since 3.0.0
 *
 * @property {String} ID                  Layout unique identifier
 * @property {String} USER_ID             User identifier that created the layout
 * @property {String} ORGANIZATION_ID     Organization the user belongs to
 * @property {String} LABEL_TO_PREFERENCE Layout label
 * @property {String} WIDGET_ID           Widget identifier what the layout belongs to
 * @property {String} LAYOUT_CHANGES      Widget changes saved on the layout
 * @property {String} LAST_MODIFIED_DATE  Last date the layout was modified
 */

/**
 * Service to handle preferences storage
 *
 * @class
 * @since 3.0.0
 *
 * @param {ZhPreferences}              ZhPreferences   Service to handle preferences storage
 * @param {TemplateManager}            templateManager Service to handle template
 * @param {EventAggregator}            eventAggregator Service to use project events
 * @param {ContainerMerger}            containerMerger Service to handle layout changes
 * @param {ZHPromise}                  ZHPromise       Service to handle promises
 * @param {EventEngine}                eventEngine     Service to use models events
 * @param {ZhUtil}                     ZhUtil          Service to provice utilities methods
 * @param {MessageService}             MessageService  Service to handle messages
 */
function ZhLayoutPreferences(ZhPreferences, templateManager, eventAggregator, containerMerger, ZHPromise, eventEngine, ZhUtil, MessageService){

    var defaultOriginalLayout = {
        'ID': 'ORIGINAL',
        'USER_ID': 0,
        'ORGANIZATION_ID': 0,
        'LAYOUT_CHANGES': '{}',
        'LABEL_TO_PREFERENCE': 'Original'
    };

    function shouldShowLayoutAction(widget){
        return Util.get(widget, ['floatingControl', 'customizationAction', 'layout']) !== false;
    }

    eventAggregator.subscribe('beforeProjectStartup', function(){
        ZhPreferences.registerRepository('zh-layout-preferences#layout');

        templateManager.project.customFloatingActions.push({
            'name': 'Layout Action',
            'label': 'Layout',
            'type': 'layout',
            'order': 20,
            'icon': 'layout',
            'template': 'zh-layout-preferences#floating-layout-card.html',
            'expandable': true,
            'isVisible': shouldShowLayoutAction
        });
    });

    eventEngine.registerEvent('LayoutBeforeApply', 'beforeLayoutApply');
    eventEngine.registerEvent('LayoutAfterApply', 'afterLayoutApply');

    var layoutRegisteredDataSources = {};

    /**
     * Register layouts datasource
     *
     * @since 3.0.0
     *
     * @param {String} widgetID         Widget identifier
     * @param {Object} datasource       Datasource that contains the layouts
     *
     */
    this.registerLayoutDataSource = function(widgetID, dataSource){
        if(widgetID){
            layoutRegisteredDataSources[widgetID] = dataSource;
        }

        return layoutRegisteredDataSources;
    };

    /**
     * Update dataSource with local saved layouts
     *
     * @since 3.0.0
     *
     * @param  {String}     widgetID   Widget identifier
     * @param  {DataSource} dataSource DataSource that contains the loaded layouts
     *
     * @return {Promise}               Promise resolved after the layouts are loaded into the dataSource
     */
    this.updateLayouts = function(widgetID, dataSource){
        if(!dataSource){
            dataSource = layoutRegisteredDataSources[widgetID];
        }

        return this.getWidgetLayouts(widgetID).then(function(layouts){
            return layouts;
        }).then(function(layouts){
            return this.addIsDefaultLayoutToLayouts(layouts, widgetID).then(function(layouts){
                dataSource.data = layouts;
            });
        }.bind(this));
    };

    /**
     * Add property to identify if the layout is selected as default
     *
     * @since 3.0.0
     *
     * @param {Layout[]} layouts  List of layouts to update the default layout property
     * @param {String}   widgetID Widget to get the default properties
     */
    this.addIsDefaultLayoutToLayouts = function(layouts, widgetID){
        return ZhPreferences.getDefaultWidgetPreferences(widgetID).then(function(defaultPreferences){
            var defaultLayout = defaultPreferences.DEFAULT_LAYOUT;
            return layouts.map(addIsDefaultLayoutToLayout.bind(this, defaultLayout));
        });
    };

    function addIsDefaultLayoutToLayout(defaultLayout, layout){
        layout.DEFAULT_LAYOUT = layout.ID === defaultLayout;
        return layout;
    }

    /**
     * Retrieve local cached layouts for specified widget
     *
     * @since 3.0.0
     *
     * @param  {String} widgetID   Widget identifier
     *
     * @return {Promise<Layout[]>} Layout preferences
     */
    this.getWidgetLayouts = function(widgetID){
        return ZhPreferences.getWidgetPreferences('layout', widgetID);
    };

    /**
     * Retrieve local cached layouts
     *
     * @since 3.0.0
     *
     * @param  {Query} query       Conditions to filter the preferences
     *
     * @return {Promise<Layout[]>} Layout preferences
     */
    this.getLayouts = function(query){
        return ZhPreferences.getPreferences('layout', query);
    };

    /**
     * Persist layouts
     *
     * @since 3.0.0
     *
     * @param  {Layout[]} layouts  Layouts to persist
     *
     * @return {Promise<Layout[]>} List of persisted layouts
     */
    this.saveLayouts = function(layouts){
        var cloneLayouts = layouts.map(function(layout){ return ZhUtil.clearRow(layout); });
        return ZhPreferences.savePreferences('layout', cloneLayouts).then(function(response){
            cloneLayouts.forEach(function(clone, index){
                layouts[index].ID = clone.ID;
                layouts[index].__is_new = clone.__is_new;
                layouts[index].changes = clone.changed;
            });

            return ZHPromise.when(response);
        });
    };

    /**
     * Delete layouts
     *
     * @since 3.0.0
     *
     * @param  {Layout[]} layouts Layouts to delete
     *
     * @return {Promise<Layout[]>} List of deleted layouts
     */
    this.deleteLayouts = function(layouts){
        var cloneLayouts = layouts.map(function(layout){ return ZhUtil.clearRow(layout); });
        return ZhPreferences.deletePreferences('layout', cloneLayouts);
    };

    function triggerBeforeLayoutApplyEvent(widget, layout){
        if(widget.beforeLayoutApply){
            widget.beforeLayoutApply({
                'layout': layout
            });
        }
    }

    function triggerAfterLayoutApplyEvent(widget, layout){
        if(widget.afterLayoutApply){
            widget.afterLayoutApply({
                'layout': layout
            });
        }
    }

    var appliedPreference = {ID: 'ORIGINAL'};

    /**
     * Apply original layout
     *
     * @since 3.0.0
     *
     * @param  {Widget} widget Widget to apply the original layout on
     *
     * @return {Promise}       Promise resolved after the original layout is applied
     */
    this.applyOriginalLayout = function(widget){
        triggerBeforeLayoutApplyEvent(widget, defaultOriginalLayout);

        containerMerger.restore(widget, 'ORIGINAL');
        widget.redraw();
        widget.setAppliedLayout(defaultOriginalLayout);
        appliedPreference = defaultOriginalLayout;

        triggerAfterLayoutApplyEvent(widget, defaultOriginalLayout);

        return ZHPromise.when();
    };

    /**
     * Apply layout
     *
     * @since 3.0.0
     *
     * @param  {Widget} widget     Widget to apply the layout on
     * @param  {Layout} preference Layout preference to be applied
     *
     * @return {Promise}           Promise that is resolved after the layout is applied
     */
    this.applyLayout = function(widget, preference){
        triggerBeforeLayoutApplyEvent(widget, preference);

        if(widget.backupPDFOrientation === undefined){
            widget.backupPDFOrientation = widget.reportOrientation || 'PORTRAIT';
        }
        widget.reportOrientation = preference.PDF_REPORT_ORIENTATION;

        var layoutChanges = prepareLayout(JSON.parse(preference.LAYOUT_CHANGES));
        containerMerger.merge(templateManager.container, layoutChanges, appliedPreference.ID);

        widget.redraw(true);

        widget.setAppliedLayout(preference);
        appliedPreference = preference;

        triggerAfterLayoutApplyEvent(widget, preference);

        return ZHPromise.when();
    };

    var propertyToBeVerified = {
        container: ['widgets'],
        widget: ['widgets', 'fields']
    };

    function prepareLayout(objToBeMerged, baseObject){
        baseObject = baseObject || templateManager.container;
        var childProperties = [];

        if(baseObject instanceof Container){
            childProperties = propertyToBeVerified.container;
        } else if(baseObject instanceof Widget){
            childProperties = propertyToBeVerified.widget;
        }

        childProperties.forEach(function prepareChildLayout(propertyName){
            var childBaseObj = baseObject[propertyName];
            var childObjToBeMerged = objToBeMerged[propertyName];
            if(childObjToBeMerged){
                if(childBaseObj && childBaseObj.length){
                    var existentIds = childBaseObj.map(function returnObjId(obj){
                        return obj.id;
                    });
                    objToBeMerged[propertyName] = childObjToBeMerged.filter(function filterChilds(obj){
                        var objIndex = existentIds.indexOf(obj.id);
                        if(objIndex != -1){
                            prepareLayout(obj, childBaseObj[objIndex]);
                        }
                        return ~objIndex;
                    });
                } else {
                    objToBeMerged[propertyName] = [];
                }
            }
        });

        return objToBeMerged;
    }

    /**
     * Export layout file
     *
     * @since 3.0.0
     *
     * @param  {Layout} layout  Layout to export
     *
     * @return {Promise<Layout>} Layout exported
     */
    this.downloadPreferenceFile = function(layout){
        var fileName = layout.LABEL_TO_PREFERENCE.latinise().replace(/[^a-z,0-9 ]/ig,'').replace(/(?:^\w|[A-Z]|\b\w|\s+)/g, function(match, index){
            if(+match === 0) return "";
            return index == 0 ? match.toLowerCase() : match.toUpperCase();
        }) + '.layout';

        var layoutToExport = {
            'ID': layout.ID,
            'LABEL_TO_PREFERENCE': layout.LABEL_TO_PREFERENCE,
            'WIDGET_ID': layout.WIDGET_ID,
            'PDF_REPORT_ORIENTATION': layout.PDF_REPORT_ORIENTATION,
            'LAYOUT_CHANGES': JSON.parse(layout.LAYOUT_CHANGES),
            'LAST_MODIFIED_DATE': layout.LAST_MODIFIED_DATE
        };

        return ZhPreferences.downloadPreferenceFile(layoutToExport, fileName);
    };

    /**
     * Validade layout to import
     *
     * @since 3.0.0
     *
     * @param  {Layout} layout              Layout to import
     * @param  {Widget} configWidget        Widget to validate
     * @param  {Object[]} layoutDataSource  Existing layouts data (optional)
     *
     * @return {Boolean} Layout valid
     */
    this.validateLayoutImport = function(layout, configWidget, layoutDataSource){
        layoutDataSource = layoutDataSource || configWidget.dataSource.data;

        if(configWidget.listWidget.id != layout.WIDGET_ID){
            MessageService.showMessageByCode('zh-layout-preferences#import_error_widget_id');
            return false;
        }

        var layoutsWithSameId = layoutDataSource.filter(function(row){
            return row.ID == layout.ID;
        });

        if(layoutsWithSameId.length > 0){
            MessageService.showMessageByCode('zh-layout-preferences#import_error_id_violation');
            return false;
        }

        var layoutsWithSameLabel = layoutDataSource.filter(function(row){
            return row.LABEL_TO_PREFERENCE == layout.LABEL_TO_PREFERENCE;
        });

        if(layoutsWithSameLabel.length > 0){
            MessageService.showMessageByCode('zh-layout-preferences#import_error_name_violation');
            return false;
        }

        return true;
    };
}

Configuration(function(ContextRegister){
    ContextRegister.register('ZhLayoutPreferences', ZhLayoutPreferences);
});

// FILE: src/controllers/ZhLayoutWidgetsBuilder.js
/**
 * Service to create widgets to handle layout
 *
 * @class
 * @since 3.0.0
 *
 * @param {RestEngine}      restEngine      Service to make http requests
 * @param {TemplateManager} templateManager Service to handle templates
 * @param {MetaDataFactory} metaDataFactory Service to factory models from metadata
 */
var ZhLayoutWidgetsBuilder = function(restEngine, templateManager, metaDataFactory){

    function getWidgetJSON(widgetName){
        var widgetPath = 'zh-layout-preferences#json/widgets/'+widgetName+'.json';
        return restEngine.requestMetaData(widgetPath).then(function(response){
            return response.data;
        });
    }

    /**
     * Retrieve a factored widget
     *
     * @since 3.0.0
     *
     * @param  {String} widgetName Widget name
     *
     * @return {Widget}            Factored widget
     */
    this.factoryWidget = function(widgetName){
        return getWidgetJSON(widgetName).then(function(widget){
            return metaDataFactory.widgetFactory(widget, templateManager.container);
        });
    };

    /**
     * Retrieve factored layout configuration widget
     *
     * @since 3.0.0
     *
     * @return {Widget} Layout configuration widget
     */
    this.factoryLayoutConfigurationWidget = function(){
        return this.factoryWidget('config');
    };

    /**
     * Retrieve factored create layout widget
     *
     * @since 3.0.0
     *
     * @return {Widget} Create layout widget
     */
    this.factoryCreateLayoutWidget = function(){
        return this.factoryWidget('createLayout');
    };

    /**
     * Retrieve factored import layout widget
     *
     * @since 3.0.0
     *
     * @return {Widget} Import layout widget
     */
    this.factoryImportLayoutWidget = function(){
        return this.factoryWidget('importLayout');
    };

    /**
     * Retrieve factored build layout options widget
     *
     * @since 3.0.0
     *
     * @return {Widget} Build layout options widget
     */
    this.factoryBuildLayoutOptionsWidget = function(){
        return this.factoryWidget('createLayoutOptions');
    };

    /**
     * Retrieve factored build layout field options widget
     *
     * @since 3.0.0
     *
     * @return {Widget} Build layout field options widget
     */
    this.factoryBuildLayoutFieldOptionsWidget = function(){
        return this.factoryWidget('createLayoutFieldOptions');
    };

};

ZeedhiController.controller('ZhLayoutWidgetsBuilder', ZhLayoutWidgetsBuilder);

Configuration(function(ContextRegister){
    ContextRegister.register('ZhLayoutWidgetsBuilder', ZhLayoutWidgetsBuilder);
});

// FILE: src/controllers/ZhLayoutCreateLayoutOptionsController.js
/**
 * Controller to manipulate create layout options widget
 *
 * @class
 * @since 3.0.0
 *
 * @param {MessageService}                             MessageService                             Service to show messages
 * @param {ZhLayoutPreferences}                        ZhLayoutPreferences                        Service to handle layout preferences methods
 * @param {ScreenService}                              ScreenService                              Service to manipulate screen
 * @param {ZhLayoutWidgetsBuilder}                     ZhLayoutWidgetsBuilder                     Service to create widgets to handle layouts
 * @param {ZHPromise}                                  ZHPromise              Service to handle promises
 */
var ZhLayoutCreateLayoutOptionsController = function(MessageService, ZhLayoutPreferences, ScreenService, ZhLayoutWidgetsBuilder, metaDataFactory, ZHPromise){

    var fieldDefaultProperties = {
        isVisible: true,
        showOnList: true,
        visibility: true,
        grouped: false,
        fixed: false
    };

    var createLayoutOptionsWidgetPromise = null;

    function removeConflictingProperties(field){
        var conflictingProperties = ['selectWidget', 'inlineEditable'];
        conflictingProperties.forEach(function(property){
            delete field[property];
        });
    }

    function factoryFields(parentWidget, gridFields){
        return gridFields.filter(function(field){
            return !field.skipLayout;
        }).map(function(field){
            var factoredField = metaDataFactory.fieldFactory(field, parentWidget);
            removeConflictingProperties(factoredField);
            return factoredField;
        });
    }

    /**
     * Retrieve widget that handles create layout options
     *
     * @since 3.0.0
     *
     * @param  {Layout} preference   Layout to be changed
     * @param  {Widget} configWidget Widget that handles layouts configuration
     *
     * @return {Widget}              Widget that handles create layout options
     */
    this.getCreateLayoutOptionsWidget = function(preference, configWidget){
        if(createLayoutOptionsWidgetPromise === null){
            createLayoutOptionsWidgetPromise = ZhLayoutWidgetsBuilder.factoryBuildLayoutOptionsWidget();
        }

        return createLayoutOptionsWidgetPromise.then(function(layoutOptionsWidget){
            var label = preference.LABEL_TO_PREFERENCE;

            var listWidget = configWidget.listWidget;

            layoutOptionsWidget.preference = preference;
            layoutOptionsWidget.label = ScreenService.i18n('Layout');
            if(label){
                layoutOptionsWidget.label = layoutOptionsWidget.label + ' - ' + label;
            }
            layoutOptionsWidget.layoutName = label;
            layoutOptionsWidget.reportTitle = listWidget.label;
            layoutOptionsWidget.reportOrientation = preference.PDF_REPORT_ORIENTATION;

            // get only the first two rows from listWidget
            layoutOptionsWidget.dataSource.data = Util.clone(listWidget.dataSource.data.slice(0,2));

            // get fields from listWidget
            layoutOptionsWidget.fields = factoryFields(layoutOptionsWidget, listWidget.fields);

            var layoutChanges = JSON.parse(preference.LAYOUT_CHANGES);
            var widgetDifferences = getEditingWidgetPath(layoutChanges.widgets, listWidget);

            layoutOptionsWidget.fields = layoutOptionsWidget.fields.map(function(field, index){
                delete field.__isSelected;
                delete field.__leftActions;
                delete field.__notSelectable;
                delete field.__rightActions;

                if(!Util.isEmptyOrBlank(widgetDifferences.fields)){
                    var fieldPreference = filterObject(widgetDifferences.fields, field.id, "id");
                    if(fieldPreference.obj && Object.keys(fieldPreference.obj).length){
                        return Util.extend(field, fieldPreference.obj);
                    }
                }

                return Util.extend(fieldDefaultProperties, field, true);
            });

            return layoutOptionsWidget;
        });
    };

    /**
     * Save and apply layout
     *
     * @since 3.0.0
     *
     * @param  {Widget} createLayoutOptionsWidget Widget that handles layout options
     *
     * @return {Promise}                          Promise resolved when the layout is applied
     */
    this.saveAndApplyLayout = function(createLayoutOptionsWidget){
        if(createLayoutOptionsWidget.gridConfigWidget.isValid()){
            var configWidget = createLayoutOptionsWidget.createNewLayoutWidget.configWidget;
            var listWidget = configWidget.listWidget;

            var fields = getFieldEditingWidgetAsDataSource(createLayoutOptionsWidget);
            var layout = createLayoutOptionsWidget.preference;

            var layoutChanges = JSON.parse(layout.LAYOUT_CHANGES);
            var editingWidget = getEditingWidgetPath(layoutChanges.widgets, listWidget);
            editingWidget.fields = fields;

            layout.PDF_REPORT_ORIENTATION = createLayoutOptionsWidget.reportOrientation;
            layout.LABEL_TO_PREFERENCE = createLayoutOptionsWidget.layoutName;
            layout.LAYOUT_CHANGES = JSON.stringify(layoutChanges);

            return ZhLayoutPreferences.saveLayouts([layout]).then(function(layouts){
                return ZhLayoutPreferences.applyLayout(listWidget, layouts[0]);
            }).then(function(){
                ScreenService.closePopup(true);
                ZhLayoutPreferences.updateLayouts(listWidget.id, configWidget.dataSource);
                listWidget.activate();
            }).catch(function(error){
                MessageService.showMessageByCode('zh-layout-preferences#save_error', {
                    'ERROR': error.message
                });
            });
        } else {
            return ZHPromise.reject("Invalid params");
        }
    };

    /**
     * Change field visibility
     *
     * @since 3.0.0
     *
     * @param {Field} field Field to change the visibility
     */
    this.updateFieldVisibility = function(field){
        field.isVisible = true;
        field.showOnList = field.isVisibleOnReport = field.visibility;
    };

    function getFieldEditingWidgetAsDataSource(listWidget){
        return listWidget.fields.map(function(field){
            var data = {
                'id': field.id,
                'name': field.name,
                'label': field.label,
                'labelOnReport': field.labelOnReport || null,
                'expression': field.expression || null,
                'align': field.align || null,
                'isVisible': field.isVisible,
                'showOnList': field.showOnList,
                'minWidth': field.gridColumnSize || null,
                'maxWidth': field.gridColumnSize || null,
                'gridColumnSize': field.gridColumnSize || null,
                'reportColumnSize': field.reportColumnSize || null,
                'isVisibleOnReport': field.isVisibleOnReport,
                'sequenceInList': field.sequenceInList,
                'visibility': field.isVisible && field.showOnList,
                'grouped': field.grouped || false,
                'groupOpened': field.groupOpened,
                'fixed': field.fixed || false,
                'skipLayout': field.skipLayout || false
            };
            return data;
        }).filter(function(field){
            return !field.skipLayout;
        });
    }

    function getEditingWidgetPath(widgetsArray, listWidget){
        var foundWidget = getWidgetObjectByID(widgetsArray, listWidget.id);
        if(!foundWidget){
            widgetsArray.some(function(eachWidget){
                foundWidget = getEditingWidgetPath(eachWidget.widgets, listWidget);
                return foundWidget;
            });
        }
        return foundWidget;
    }

    function filterObject(obj, value, key){
        var filtered = obj.filter(function(preference){
            return preference[key] == value;
        });

        var toReturn = {};
        toReturn.index = obj.indexOf(filtered[0]);
        toReturn.obj = filtered[0];
        return toReturn;
    }

    function getWidgetObjectByID(widgets, widgetID){
        return widgets.filter(function(eachWidgetObject){
            return eachWidgetObject.id == widgetID;
        }).shift();
    }

};

ZeedhiController.controller('ZhLayoutCreateLayoutOptionsController', ZhLayoutCreateLayoutOptionsController);

Configuration(function(ContextRegister){
    ContextRegister.register('ZhLayoutCreateLayoutOptionsController', ZhLayoutCreateLayoutOptionsController);
});

// FILE: src/controllers/ZhLayoutImportLayoutController.js
/**
 * Import layout widget controller
 *
 * @class
 * @since 3.0.0
 *
 * @param {MessageService}                        MessageService                           Service to show messages
 * @param {ZhLayoutPreferences}                   ZhLayoutPreferences                      Service to handle layout preferences methods
 * @param {ZhPreferences}                         ZhPreferences                            Service to handle preferences persistance
 * @param {ZhLayoutWidgetsBuilder}                ZhLayoutWidgetsBuilder Service to create widgets to handle layouts
 * @param {ZHPromise}                             ZHPromise                                Service to handle promises
 * @param {ScreenService}                         ScreenService                            Service to manipulate screen
 */
var ZhLayoutImportLayoutController = function(MessageService, ZhLayoutPreferences, ZhPreferences, ZhLayoutWidgetsBuilder, ZHPromise, ScreenService){

    var importLayoutWidgetPromise = null;

    /**
     * Retrieve widget to import layout
     *
     * @since 3.0.0
     *
     * @return {Promise<Widget>}
     */
    this.getImportLayoutWidget = function(){
        if(importLayoutWidgetPromise === null){
            importLayoutWidgetPromise = ZhLayoutWidgetsBuilder.factoryImportLayoutWidget();
        }

        return importLayoutWidgetPromise;
    };

    /**
     * Import layout
     *
     * @since 3.0.0
     *
     * @param  {Widget} importLayoutWidget Widget with the layout configuration
     *
     * @return {Promise}                      Promise resolved after the layout is imported
     */
    this.importPreference = function(importLayoutWidget){
        if(!importLayoutWidget.isValid()){
            return ZHPromise.reject({err: 'WIDGET_INVALID'});
        }

        var layoutFileData = importLayoutWidget.fields[0].value()[0].b64File;
        layoutFileData = layoutFileData.split('base64,')[1];
        layoutFileData = window.atob(layoutFileData);
        layoutFileData = decodeURIComponent(escape(layoutFileData));

        var layout = JSON.parse(layoutFileData);

        var configWidget = importLayoutWidget.configWidget;
        var listWidget = configWidget.listWidget;

        if(!ZhLayoutPreferences.validateLayoutImport(layout, configWidget)){
            return ZHPromise.reject({err: 'LAYOUT_FILE_INVALID'});
        }

        layout.__is_new = true;
        layout.__generate_id = false;
        layout.LAYOUT_CHANGES = JSON.stringify(layout.LAYOUT_CHANGES);

        return ZhPreferences.getUserID().then(function(userID){
            layout.USER_ID = userID;

            return ZhLayoutPreferences.saveLayouts([layout]).then(function(){
                ScreenService.closePopup();
                ZhLayoutPreferences.updateLayouts(listWidget.id, configWidget.dataSource);
                configWidget.refreshWidget();
            }).catch(function(error){
                MessageService.showMessageByCode('zh-layout-preferences#save_error', {
                    'ERROR': error.message
                });
            });
        });
    };
};

ZeedhiController.controller('ZhLayoutImportLayoutController', ZhLayoutImportLayoutController);

Configuration(function(ContextRegister){
    ContextRegister.register('ZhLayoutImportLayoutController', ZhLayoutImportLayoutController);
});

// FILE: src/controllers/ZhLayoutConfigController.js
/**
 * Layout configuration widget controller
 *
 * @class
 * @since 3.0.0
 *
 * @param {ZhPreferences}                         ZhPreferences                         Service to handle preferences persistance
 * @param {ZhLayoutPreferences}                   ZhLayoutPreferences                   Service to handle layout preferences methods
 * @param {ZhLayoutWidgetsBuilder}                ZhLayoutWidgetsBuilder                Service to create widgets to handle layouts
 * @param {ScreenService}                         ScreenService                         Service to manipulate screen
 * @param {MessageService}                        MessageService                        Service to show messages
 * @param {ZHPromise}                             ZHPromise                             Service to handle promises
 * @param {$timeout}                              $timeout                              Service to handle timeouts
 * @param {ZhLayoutCreateLayoutOptionsController} ZhLayoutCreateLayoutOptionsController Controller to manipulate create layout options widget
 * @param {ZhLayoutImportLayoutController}        ZhLayoutImportLayoutController        Controller to manipulate import layout widget
 */
var ZhLayoutConfigController = function(ZhPreferences, ZhLayoutPreferences, ZhLayoutWidgetsBuilder, ScreenService, MessageService, ZHPromise, $timeout, ZhLayoutCreateLayoutOptionsController, ZhLayoutImportLayoutController){

    var configWidgetPromise = null;

    /**
     * Retrieve widget that handles layouts configuration
     *
     * @since 3.0.0
     *
     * @param  {Widget}     listWidget Widget that is being used to create layouts for
     * @param  {DataSource} dataSource DataSource to use on config widget
     *
     * @return {Promise<Widget>}       Widget that handles layouts configuration
     */
    this.getConfigWidget = function(listWidget, dataSource){
        if(configWidgetPromise === null){
            configWidgetPromise = ZhLayoutWidgetsBuilder.factoryLayoutConfigurationWidget();
        }

        var userID = ZhPreferences.getUserID();

        return ZHPromise.all([userID, configWidgetPromise]).then(function(args){
            var configWidget = args[1];

            configWidget.listWidget = listWidget;
            configWidget.dataSourceFilter = [
                {'name': 'WIDGET_ID', 'operator': '=', 'value': listWidget.id}
            ];
            dataSource.data.forEach(function(row){
                row.APPLIED = row.ID == (listWidget.appliedLayout ? listWidget.appliedLayout.ID : 'ORIGINAL');
            });
            configWidget.dataSource = dataSource;

            return configWidget;
        });
    };

    /**
     * Open widget to create a new layout
     *
     * @since 3.0.0
     *
     * @param  {Widget} configWidget Widget that handles layout configuration
     *
     * @return {Promise}             Promise that is resolved when the widget is opened
     */
    this.openCreateLayoutWidget = function(configWidget){
        var listWidget = configWidget.listWidget;
        var pdfReportOrientation = listWidget.reportOrientation || "PORTRAIT";

        return ZhPreferences.getUserID().then(function(userID){
            return {
                '__is_new': true,
                'ID': null,
                'WIDGET_ID': listWidget.id,
                'USER_ID': userID,
                'LAYOUT_CHANGES': JSON.stringify(LayoutUtilities.createDiffDataStructure(listWidget.container, listWidget, true)),
                'PDF_REPORT_ORIENTATION': pdfReportOrientation,
                'LAST_MODIFIED_DATE': null
            };
        }).then(function(preference){
            return ZhLayoutCreateLayoutOptionsController.getCreateLayoutOptionsWidget(preference, configWidget).then(function(createLayoutOptionsWidget){
                createLayoutOptionsWidget.createNewLayoutWidget = {'configWidget': configWidget};

                $timeout(function(){
                    ScreenService.openPopup(createLayoutOptionsWidget);
                });
            });
        });

    };

    /**
     * Open popup to edit a saved layout
     *
     * @since 3.0.0
     *
     * @param  {Layout} layout   Layout to edit
     *
     * @return {Promise<Widget>} Widget used to edit the layout
     */
    this.editLayout = function(configWidget, layout){
        if(layout.TYPE === 'F'){
            MessageService.alertNotificationByCode('zh-layout-preferences#cannot_edit_fixed_layout');
            return ZHPromise.when();
        }
        return ZhLayoutCreateLayoutOptionsController.getCreateLayoutOptionsWidget(layout, configWidget).then(function(createLayoutOptionsWidget){
            createLayoutOptionsWidget.createNewLayoutWidget = {'configWidget': configWidget};

            $timeout(function(){
                ScreenService.openPopup(createLayoutOptionsWidget);
            });
        });
    };

    /**
     * Delete layouts
     *
     * @since 3.0.0
     *
     * @param  {Widget} configWidget Widget that contains the layouts to delete
     *
     * @return {Promise}             Promise resolved after layouts are deleted
     */
    this.deleteLayouts = function(configWidget){
        var layoutsToDelete = configWidget.getCheckedRows();

        var defaultLayout = layoutsToDelete.filter(function(layout){
            return layout.DEFAULT_LAYOUT;
        });
        if(defaultLayout.length){
            MessageService.showMessageByCode('zh-layout-preferences#delete_error_default');

            return;
        }

        return MessageService.confirmMessageByCode('zh-layout-preferences#delete', {
            'NR_OF_LAYOUTS': layoutsToDelete.length
        }).then(function(){
            return ZhLayoutPreferences.deleteLayouts(layoutsToDelete).then(function(){
                configWidget.dataSource.clearCheckedRows();
                return ZhLayoutPreferences.updateLayouts(configWidget.listWidget.id, configWidget.dataSource);
            }).catch(function(error){
                return MessageService.getMessageByCode('zh-layout-preferences#'+error.message).then(function(errorMessage) {
                    return MessageService.showMessageByCode('zh-layout-preferences#delete_error', {
                        'ERROR': ScreenService.i18n(errorMessage)
                    });
                });
            });
        });
    };

    /**
     * Set a layout as the default preference
     *
     * @since 3.0.0
     *
     * @param  {Widget} configWidget Widget that handles layouts configuration
     * @param  {Layout} layout       Layout that it's default value has changed
     *
     * @return {Promise<Object>}     Widget default preferences
     */
    this.updateDefaultLayout = function(configWidget, layout){
        return ZhPreferences.changeDefaultPreferences(configWidget, 'DEFAULT_LAYOUT', layout);
    };

    /**
     * Apply Layout
     *
     * @since 3.0.0
     *
     * @param  {Widget} configWidget Widget that handles layouts configuration
     * @param  {Layout} layout       Layout to be applied
     *
     * @return {Promise<Object>}     Widget default preferences
     */
    this.updateAppliedLayout = function(configWidget, layout){
        var listWidget = configWidget.listWidget;

        return ZhLayoutPreferences.applyLayout(listWidget, layout).then(function(){
            configWidget.dataSource.data.forEach(function(row){
                row.APPLIED = row.ID == layout.ID;
            });
        });
    };

    /**
     * Download preference as file
     *
     * @since 3.0.0
     *
     * @param  {Layout} layout       Layout to export
     *
     * @return {Promise<Layout>}     Layout exportado
     */
    this.downloadPreferenceFile = function(layout){
        return ZhLayoutPreferences.downloadPreferenceFile(layout);
    };

    /**
     * Open widget to import a new layout from file
     *
     * @since 3.0.0
     *
     * @param  {Widget} configWidget Widget that handles layout configuration
     *
     * @return {Promise}             Promise that is resolved when the widget is opened
     */
    this.importPreferenceFile = function(configWidget){
        return ZhLayoutImportLayoutController.getImportLayoutWidget().then(function(importLayoutWidget){
            importLayoutWidget.newRow();
            importLayoutWidget.configWidget = configWidget;
            return ScreenService.openPopup(importLayoutWidget);
        });
    };

};

ZeedhiController.controller('ZhLayoutConfigController', ZhLayoutConfigController);

Configuration(function(ContextRegister){
    ContextRegister.register('ZhLayoutConfigController', ZhLayoutConfigController);
});

// FILE: src/controllers/ZhLayoutFloatingCardController.js
/**
 * Floating window controller
 *
 * @class
 * @since 3.0.0
 *
 * @param {$scope}              $scope              Floating window scope
 * @param {ApplicationContext}  ApplicationContext  Service to retrieve Zeedhi services
 * @param {Query}               Query               Service to build queries
 * @param {ScreenService}       ScreenService       Service to handle screen
 * @param {metaDataFactory}     metaDataFactory     Service to factory models from metadata
 */
var ZhLayoutFloatingCardController = function($scope, ApplicationContext, Query, ScreenService, metaDataFactory){

    var widget = $scope.widget;
    $scope.appliedPreference = null;

    var ZhLayoutPreferences = ApplicationContext.ZhLayoutPreferences;
    var ZhPreferences = ApplicationContext.ZhPreferences;
    var ZhLayoutConfigController = ApplicationContext.ZhLayoutConfigController;

    var fieldDefaultProperties = {
        isVisible: true,
        showOnList: true,
        visibility: true,
        grouped: false,
        fixed: false
    };

    var dataSource = metaDataFactory.factoryDataSource({
        'name': 'zh-layout-preferences#/layout',
        'localStorage': false,
        'lazyLoad': true,
        'rest': true,
        'data': []
    });

    dataSource.afterLoadDataSource(function(){
        return ZhLayoutPreferences.addIsDefaultLayoutToLayouts(dataSource.data, widget.id).then(function(layouts){
            dataSource.data = layouts;
        });
    });

    $scope.customizationCard = {
        'label': 'Layouts',
        'type': 'layout',
        'openLayoutConfiguration': openLayoutConfiguration,
        'refreshLayouts': refreshLayouts,
        'applyOriginalLayout': applyOriginalLayout,
        'applyLayout': applyPreference,
        'dataSource': dataSource
    };

    ZhLayoutPreferences.registerLayoutDataSource(widget.id, $scope.customizationCard.dataSource);

    widget.setAppliedLayout = setAppliedLayout;

    $scope.$on('$destroy', function() {
        delete dataSource.afterLoadDataSourcelistener;
    });

    function setAppliedLayout(layout){
        $scope.appliedPreference = layout;
        widget.appliedLayout = layout;
    }

    function openLayoutConfiguration(){
        var dataSource = $scope.customizationCard.dataSource;
        return ZhLayoutConfigController.getConfigWidget(widget, dataSource).then(function(configWidget){
            return ScreenService.openPopup(configWidget);
        });
    }

    function refreshLayouts(){
        return ZhPreferences.getUserID().then(function(){
            var query = Query.build()
                .where('WIDGET_ID').equals(widget.id);

            return $scope.customizationCard.dataSource.load(query.where());
        });
    }

    function applyOriginalLayout(){
        return ZhLayoutPreferences.applyOriginalLayout(widget);
    }

    function applyPreference(layout){
        return ZhLayoutPreferences.applyLayout(widget, layout);
    }

    function applyDefaultLayout(){
        ZhPreferences.getDefaultWidgetPreferences(widget.id).then(function(defaultPreference){
            if(defaultPreference.defaultLayout){
                applyPreference(defaultPreference.defaultLayout);
            } else {
                applyOriginalLayout();
            }
        });
    }

    (function initLayoutPreferences(){
        if(ZhPreferences.validateWidget(widget)){
            if(Util.isUndefinedOrNull(widget.appliedLayout)){
                applyDefaultLayout();
            } else {
                applyPreference(widget.appliedLayout);
            }
        }
    })();

};

ZeedhiController.controller('ZhLayoutFloatingCardController', ZhLayoutFloatingCardController);

// FILE: src/directives/ZhLayoutFloatingControl.js
var ZeedhiDirectives = angular.module('ZeedhiDirectives');

ZeedhiDirectives.directive('zhLayoutFloatingControl', [ZhLayoutFloatingControl]);

function ZhLayoutFloatingControl(){

    return {
        priority: 10,
        link: function($scope){
            $scope.toggleLayoutPreferencesCard = function(e){
                var actionElement = $(e.target).closest('.float-action');
                if(!actionElement.hasClass('opened')){
                    $scope.customizationCard.refreshLayouts();
                }
                $scope.togglePreferencesCard(e);
            };
        }
    };

}

// FILE: src/Config.js
(function(){

window.templateUrls = window.templateUrls || [];
window.metadataUrls = window.metadataUrls || [];
window.serviceUrls = window.serviceUrls || [];

var PACKAGE_NAME = 'zh-layout-preferences';

var hasTemplateUrl = Boolean(window.templateUrls.find(function(value){
    return value.package === PACKAGE_NAME;
}));

var hasMetadataUrl = Boolean(window.metadataUrls.find(function(value){
    return value.package === PACKAGE_NAME;
}));

var hasServiceUrl = Boolean(window.serviceUrls.find(function(value){
    return value.package === PACKAGE_NAME;
}));

if(!hasTemplateUrl){
    window.templateUrls.push({
        package: PACKAGE_NAME,
        baseUrl: 'bower_components/zh-layout-preferences/dist/templates/'
    });
}

if(!hasMetadataUrl){
    window.metadataUrls.push({
        package: PACKAGE_NAME,
        baseUrl: 'bower_components/zh-layout-preferences/dist/assets/'
    });
}

if(!hasServiceUrl){
    window.serviceUrls.push({
        package: PACKAGE_NAME,
        baseUrl: '../backend/service/index.php/zh-preferences'
    });
}

})();


// FILE: ./bower_components/zh-filter-preferences/dist/filter-preferences.js
// FILE: src/services/ZhFilterBuilder.js
/**
 * Service to create the filter conditions
 *
 * @class
 * @since 3.0.0
 *
 * @param {QueryBuilder} Query Service to build the query conditions
 */
function ZhFilterBuilder(Query){

    var defaultOperators = {
        'field/between-dates.html': Query.BETWEEN,
        'field/calendar.html': Query.EQ,
        'field/date.html': Query.EQ,
        'field/datetime.html': Query.EQ,
        'field/interval.html': {
            'default': Query.BETWEEN,
            'start': Query.GTE,
            'end': Query.LTE
        },
        'field/number-edit.html': Query.EQ,
        'field/number-keyboard.html': Query.EQ,
        'field/number.html': Query.EQ,
        'field/radio.html': Query.EQ,
        'field/select.html': Query.EQ,
        'field/select-simple.html': Query.EQ,
        'field/select-native.html': Query.EQ,
        'field/select-autocomplete.html': Query.EQ,
        'field/select-multiple.html': Query.IN,
        'default': Query.LIKE_INSENSITIVE
    };

    var buildFilterByTemplate = {
        'field/select.html': buildSelectFilter,
        'field/select-autocomplete.html': buildSelectFilter,
        'field/select-native.html': buildSelectNativeFilter,
        'field/select-multiple.html': buildSelectMultipleFilter,
        'field/interval.html':buildIntervalFilter,
        'default': buildDefaultFilter
    };

    /**
     * Register the default operator for a field
     *
     * @since 3.0.0
     *
     * @param {String} template Template of the field
     * @param {String} operator Operator to use on template
     */
    this.setDefaultOperator = function(template, operator){
        defaultOperators[template] = operator;
    };

    /**
     * Register the method used to create condition for a field
     *
     * @since 3.0.0
     *
     * @param {String}   template Template of the field
     * @param {Function} callback Method to be used to create the condition
     */
    this.setBuildFilterByTemplate = function(template, callback){
        buildFilterByTemplate[template] = callback;
    };

    function getFieldTemplate(field){
        return field.template.split('#').pop();
    }

    function getFilterBuilderByTemplate(template){
        if(!buildFilterByTemplate[template]){
            template = 'default';
        }

        return buildFilterByTemplate[template];
    }

    /**
     * Clear filter with same filter name
     *
     * @since 3.10.0
     *
     * @param  {Object[]} List of filters
     *
     * @return {Object[]} List of filters with unique name
     */
    function clearFilters(filters){
        var clearedFilters = [];
        filters.forEach(function(filter){
            var repeated = clearedFilters.some(function(_filter){
                return _filter.name === filter.name;
            });

            if(!repeated){
                clearedFilters.push(filter);
            }
        });
        return clearedFilters;
    }

    /**
     * Build filter conditions
     *
     * @since 3.0.0
     *
     * @param  {Field[]} fields List of fields to get the filter values
     * @param  {Object}  row    Row to get the values from
     *
     * @return {Object[]}       List of conditions
     */
    this.buildFilter = function (fields, row){
        var query = Query.build();

        fields.forEach(function(field){
            if(!field.skipSearch){
                var template = getFieldTemplate(field);
                getFilterBuilderByTemplate(template)(query, field, row);
            }
        });

        return clearFilters(query.where());
    };

    var operatorFlow = {
        "BETWEEN": function (query, value){
            query.between([value.start, value.end]);
        },
        "NOT BETWEEN": function (query, value){
            query.notBetween([value.start, value.end]);
        },
        "LIKE": function (query, value){
            query.like('%' + value + '%');
        },
        "LIKE_I": function (query, value){
            query.likeInsensitive('%' + value + '%');
        },
        "LIKE_BEGINNING": function (query, value){
            query.likeInsensitive( value + '%');
        },
        "NOT LIKE": function (query, value){
            query.notLike('%' + value + '%');
        },
        "LIKE ALL": function (query, value){
            query.likeAll('%' + value + '%');
        },
        "<>": function (query, value){
            query.notEquals(value);
        },
        "=": function (query, value){
            query.equals(value);
        },
        ">": function (query, value){
            query.greater(value);
        },
        "<": function (query, value){
            query.lower(value);
        },
        ">=": function (query, value){
            query.greaterOrEqual(value);
        },
        "<=": function (query, value){
            query.lowerOrEqual(value);
        },
        "IN": function (query, value){
            query.in(value);
        },
        "NOT IN": function (query, value){
            query.notIn(value);
        }
    };

    function buildFilter(query, fieldName, operator, value){
        query.where(fieldName);
        operatorFlow[operator](query, value);
    }

    function isEmptyArrayOrObject(obj){
        var name;
        for(name in obj){
            return false;
        }
        return true;
    }

    function existValue(value){
        var isObject = typeof value == 'object';
        return isObject ? !isEmptyArrayOrObject(value) : !Util.isEmptyOrBlank(value);
    }

    function buildDefaultFilter(query, field, currentRow){
        var fieldName = field.name;
        var value = currentRow[fieldName];

        if(existValue(value)){
            var operator = getFieldOperator(field);
            buildFilter(query, fieldName, operator, value);
        }
    }

    function buildIntervalFilter(query, field, currentRow){
        var fieldName = field.name;
        var value = currentRow[fieldName];
        value = existValue(value) ? Util.clone(value) : {};

        var existStartValue = !Util.isEmptyOrBlank(value.start);
        var existEndValue = !Util.isEmptyOrBlank(value.end);

        if(existStartValue || existEndValue){
            var operator = getFieldOperator(field);
            if(existStartValue && existEndValue){
                operator = operator.default;
            } else if(existStartValue){
                operator = operator.start;
                value = value.start;
            } else {
                operator = operator.end;
                value = value.end;
            }
            buildFilter(query, fieldName, operator, value);
        }
    }

    function buildSelectWithValueFieldFilter(query, field, currentRow, operator){
        var fieldName = field.valueField;
        var value = currentRow[fieldName];
        if(existValue(value)){
            buildFilter(query, fieldName, operator, value);
        }
    }

    function buildSelectWithValueFieldsFilter(query, field, currentRow, operator){
        var fieldName = field.name;
        var value = currentRow[fieldName];

        if(existValue(value)){
            buildFilter(query, fieldName, operator, value);
        }
    }

    function buildSelectWithOutDataFilter(query, field, currentRow, operator){
        var outData = field.outData;
        Object.keys(outData).forEach(function(outDataKey){
            var fieldName = outData[outDataKey];
            var value = currentRow[fieldName];
            if(existValue(value)){
                buildFilter(query, fieldName, operator, value);
            }
        });
    }

    function buildSelectFilter(query, field, currentRow){
        var operator = getFieldOperator(field);
        if(field.valueField){
            buildSelectWithValueFieldFilter(query, field, currentRow, operator);
        } else if(field.valueFields){
            buildSelectWithValueFieldsFilter(query, field, currentRow, operator);
        } else if(field.outData){
            buildSelectWithOutDataFilter(query, field, currentRow, operator);
        } else {
            throw new Error('Invalid select configuration on field ' + field.name);
        }
    }

    function buildSelectNativeWithValueFieldFilter(query, field, currentRow, operator){
        var fieldName = field.name;
        var value = currentRow[fieldName];
        if(existValue(value)){
            buildFilter(query, fieldName, operator, value);
        }
    }

    function buildSelectNativeFilter(query, field, currentRow){
        var operator = getFieldOperator(field);

        if(field.valueField){
            buildSelectNativeWithValueFieldFilter(query, field, currentRow, operator);
        } else {
            throw new Error('Invalid select-native configuration on field ' + field.name);
        }

    }

    function buildSelectMultipleWithValueFieldFilter(query, field, currentRow, operator){
        var fieldName = field.name;
        var value = currentRow[fieldName];
        if(currentRow[fieldName + '_EXCEPT']){
            value = currentRow[fieldName + '_EXCEPT'];
            operator = 'NOT IN';
        }

        if(existValue(value)){
            buildFilter(query, fieldName, operator, value);
        }
    }

    function buildSelectMultipleWithValueFieldsFilter(query, field, currentRow, operator){
        throw new Error('Filter on field select-multiple with property valuesFields is not supported yet. ' +
            'Field "'+field.name+'"');
    }

    function buildSelectMultipleFilter(query, field, currentRow){
        var operator = getFieldOperator(field);

        if(field.valueField){
            buildSelectMultipleWithValueFieldFilter(query, field, currentRow, operator);
        } else if(field.valueFields){
            buildSelectMultipleWithValueFieldsFilter(query, field, currentRow, operator);
        } else {
            throw new Error('Invalid select-multiple configuration on field ' + field.name);
        }
    }

    function getFieldOperator(field){
        var template = getFieldTemplate(field);
        if (template === 'field/interval.html' && typeof field.operator === 'string') {
            field.operator = defaultOperators[template];
        }
        return field.operator || defaultOperators[template] || defaultOperators['default'];
    }

}

Configuration(function(ContextRegister){
    ContextRegister.register('ZhFilterBuilder', ZhFilterBuilder);
});

// FILE: src/services/ZhFilterDescriptionBuilder.js
/**
 * Service to create the applied filter description
 *
 * @class
 * @since 3.0.0
 *
 * @param {DecodeValueFieldService} DecodeValueFieldService Service to retrieve field value
 */
function ZhFilterDescriptionBuilder(DecodeValueFieldService, ZhUtil, templateManager){

    /**
     * Build filter description for a filter preference
     *
     * @since 3.0.0
     *
     * @param  {String} preferenceName Filter preference label
     *
     * @return {Object[]}              List containing the applied preference description
     */
    this.buildFilterAppliedInfo = function(preferenceName){
        return [{
            'label': 'Filter',
            'filterName': preferenceName
        }];
    };

    function getFilterWidget(id){
        return templateManager.container.factoredWidgets.filter(function(widget){ return widget._filteredWidgetId == id; })[0];
    }

    /**
     * Build filter description for a list of filter conditions
     *
     * @since 3.0.0
     *
     * @param  {Field[]} fields         List of fields on the list widget
     * @param  {Object}  currentRow     Row of the applied filter
     * @param  {Object}  searchCriteria Search criteria currently applied
     *
     * @return {Object[]}               List of descriptions for the applied conditions
     */
    this.buildFilterInfo = function(fields, currentRow, searchCriteria, widget){
        var filterInfo = [];

        var filterWidget = getFilterWidget(widget && widget.id);

        fields.forEach(function(field){
            buildDefaultFilterInfo(filterInfo, field, currentRow, filterWidget);
        });

        buildFilterInfoForSearchCriteria(fields, filterInfo, searchCriteria);

        return filterInfo;
    };

    function buildFilterInfoForSearchCriteria(fields, filterInfo, searchCriteria){
        if(searchCriteria){
            Object.keys(searchCriteria).forEach(function(fieldName){
                if(searchCriteria[fieldName] !== ''){
                    var fieldLabel;
                    if(fieldName == '_ALL_MAP'){
                        fieldLabel = 'All fields';
                    } else {
                        fieldLabel = getFieldByName(fields, fieldName).label;
                    }

                    filterInfo.push(buildFilterInfo(fieldLabel, searchCriteria[fieldName]));
                }
            });
        }
    }

    function getFieldByName(fields, fieldName){
        return fields.filter(function(field){
            return field.name === fieldName;
        }).shift();
    }

    function buildFilterInfo(label, value){
        return {
            'label': label,
            'value': value
        };
    }

    function buildDefaultFilterInfo(filterInfo, field, currentRow, widget){
        var condition = !Util.isEmptyOrBlank(currentRow[field.name]);
        var filterField = widget && widget.getField(field.name);
        var showInfo = filterField && filterField.isVisible;

        if(condition && showInfo){
            var value = DecodeValueFieldService.model(field, currentRow[field.name]);
            value = ZhUtil.evaluate(value);
            filterInfo.push(buildFilterInfo(field.label, value));
        }
    }

}

Configuration(function(ContextRegister){
    ContextRegister.register('ZhFilterDescriptionBuilder', ZhFilterDescriptionBuilder);
});

// FILE: src/services/ZhFilterPreferences.js
/**
 * A filter preference
 * @typedef {Object} Filter
 * @property {String} ID                  Filter unique identifier
 * @property {String} USER_ID             User identifier that created the filter
 * @property {String} ORGANIZATION_ID     Organization the user belongs to
 * @property {String} LABEL_TO_PREFERENCE Filter label
 * @property {String} WIDGET_ID           Widget identifier the filter belongs to
 * @property {String} FILTER_ROW          Row indicating the filter settings
 * @property {String} LAST_MODIFIED_DATE  Last date the filter was modified
 */

/**
 * Service to handle filters storage
 *
 * @class
 * @since 3.0.0
 *
 * @param {ZhPreferences}              ZhPreferences              Service to handle preferences storage
 * @param {ZhFilterBuilder}            ZhFilterBuilder            Service to create filters conditions
 * @param {ZhFilterDescriptionBuilder} ZhFilterDescriptionBuilder Service to conditions description
 * @param {TemplateManager}            templateManager            Service to handle template
 * @param {EventAggregator}            eventAggregator            Service to use project events
 * @param {ZhUtil}                     ZhUtil                     Service to provice utilities methods
 * @param {EventEngine}                eventEngine                Service to use models events
 * @param {MetaDataFactory}            metaDataFactory            Service to factory models from metadata
 * @param {ZHPromise}                  ZHPromise                  Service to handle promises
 * @param {MessageService}             MessageService             Service to handle messages
 * @param {ScreenService}              ScreenService              Service to handle screen
 * @param {ZhKeyboardService}          ZhKeyboardService          Service to handle keyboard binds
 * @param {ApplicationContext}         ApplicationContext         Service to retrieve Zeedhi services
 */
function ZhFilterPreferences(ZhPreferences, ZhFilterBuilder, ZhFilterDescriptionBuilder, templateManager, eventAggregator, ZhUtil, eventEngine, metaDataFactory, ZHPromise, MessageService, ScreenService, ZhKeyboardService, ApplicationContext, $timeout) {
    var self = this;
    var originalFilterRows = {};

    var originalFilter = {
        'ID': 'ORIGINAL',
        'USER_ID': 0,
        'ORGANIZATION_ID': 0,
        'LABEL_TO_PREFERENCE': 'Original'
    };

    function shouldShowFilterAction(widget){
        return Util.get(widget, ['floatingControl', 'searchAction']) !== false ||
            Util.get(widget, ['floatingControl', 'customizationAction', 'filter']) !== false;
    }

    eventAggregator.subscribe('beforeProjectStartup', function(){
        ZhPreferences.registerRepository('zh-filter-preferences#filter');

        templateManager.project.customFloatingActions.push({
            'name': 'Filter Action',
            'label': 'Search',
            'type': 'filter',
            'order': 20,
            'icon': 'search',
            'template': 'zh-filter-preferences#floating-filter-card.html',
            'expandable': true,
            'isVisible': shouldShowFilterAction
        });
    });

    eventEngine.registerEvent('FilterBeforeApply', 'beforeFilterApply');
    eventEngine.registerEvent('FilterAfterApply', 'afterFilterApply');

    var filterRegisteredDataSources = {};

    /**
     * Register filters datasource
     *
     * @since 3.0.0
     *
     * @param {String} widgetID         Widget identifier
     * @param {Object} datasource       Datasource that contains the filters
     *
     */
    this.registerFilterDataSource = function(widgetID, dataSource){
        if(widgetID){
            filterRegisteredDataSources[widgetID] = dataSource;
        }

        return filterRegisteredDataSources;
    };

    /**
     * Update dataSource with local saved filters
     *
     * @since 3.0.0
     *
     * @param  {String}     widgetID   Widget identifier
     * @param  {DataSource} dataSource DataSource that contains the loaded filters
     *
     * @return {Promise}               Promise resolved after the filters are loaded into the dataSource
     */
    this.updateFilters = function(widgetID, dataSource){
        if(!dataSource){
            dataSource = filterRegisteredDataSources[widgetID];
        }

        return this.getWidgetFilters(widgetID).then(function(filters){
            return this.addIsDefaultFilterToFilters(filters, widgetID).then(function(filters){
                dataSource.data = filters;
            });
        }.bind(this));
    };

    function addIsDefaultFilterToFilter(defaultFilter, filter){
        filter.DEFAULT_FILTER = filter.ID === defaultFilter;
        return filter;
    }

    /**
     * Add property to identify if the filter is selected as default
     *
     * @since 3.0.0
     *
     * @param {Filter[]} filters  List of filters to update the default filter property
     * @param {String}   widgetID Widget to get the default properties
     */
    this.addIsDefaultFilterToFilters = function(filters, widgetID){
        return ZhPreferences.getDefaultWidgetPreferences(widgetID).then(function(defaultPreferences){
            var defaultFilter = defaultPreferences.DEFAULT_FILTER;
            return filters.map(addIsDefaultFilterToFilter.bind(this, defaultFilter));
        });
    };

    /**
     * Retrieve local cached filters for specified widget
     *
     * @since 3.0.0
     *
     * @param  {String} widgetID   Widget identifier
     *
     * @return {Promise<Filter[]>} Filter preferences
     */
    this.getWidgetFilters = function(widgetID){
        return ZhPreferences.getWidgetPreferences('filter', widgetID).then(function parseFilterRow(preferences){
            preferences.forEach(function(preference){
                preference.FILTER_ROW = JSON.parse(preference.FILTER_ROW);
            });
            return preferences;
        });
    };

    /**
     * Retrieve local cached filters
     *
     * @since 3.0.0
     *
     * @param  {Query} query       Conditions to filter the preferences
     *
     * @return {Promise<Filter[]>} Filter preferences
     */
    this.getFilters = function(query){
        return ZhPreferences.getPreferences('filter', query);
    };

    /**
     * Persist filters
     *
     * @since 3.0.0
     *
     * @param  {Filter[]} filters  Filters to persist
     *
     * @return {Promise<Filter[]>} List of persisted filters
     */
    this.saveFilters = function(filters){
        var cloneFilters = filters.map(function(filter){ return ZhUtil.clearRow(filter); });
        return ZhPreferences.savePreferences('filter', cloneFilters).then(function(response){
            cloneFilters.forEach(function(clone, index){
                filters[index].ID = clone.ID;
                filters[index].__is_new = clone.__is_new;
                filters[index].changes = clone.changed;
            });

            return ZHPromise.when(response);
        });
    };

    /**
     * Delete filters
     *
     * @since 3.0.0
     *
     * @param  {Filter[]} filters  Filters to delete
     *
     * @return {Promise<Filter[]>} List of deleted filters
     */
    this.deleteFilters = function(filters){
        var cloneFilters = filters.map(function(filter){ return ZhUtil.clearRow(filter); });
        return ZhPreferences.deletePreferences('filter', cloneFilters);
    };

    function applyOriginalFilterRow(widget, filter){
        filter.FILTER_ROW = Util.clone(originalFilterRows[widget.id] || {});
    }

    /**
     * Apply original filter
     *
     * @since 3.0.0
     *
     * @param  {Widget} widget Widget to apply the original filter on
     *
     * @return {Object[]}      Rows returned using the filter
     */
    this.applyOriginalFilter = function(widget){
        applyOriginalFilterRow(widget, originalFilter);
        return this.applyFilter(widget, originalFilter);
    };

    /**
     * Set the filter row used when applying the Original filter
     *
     * @since 3.4.0
     *
     * @param {String} widgetId Widget identifier to set the original filter row
     * @param {Object} filter   Filter row to create the original filter
     */
    this.setOriginalFilter = function(widgetId, filter){
        originalFilterRows[widgetId] = Util.clone(filter);
    };

    /**
     * Get the filter row used when applying the Original filter
     *
     * @since 3.4.0
     *
     * @return {Object} filter  Filter row used to create the original filter
     */
    this.getOriginalFilter = function(widgetId, widget){
        var clearedFilter = ZhUtil.clearRow(originalFilterRows[widgetId] || {});
        var originalFilter = {
            ID: 'ORIGINAL',
            LABEL_TO_PREFERENCE: 'Original',
            FILTER_ROW: Util.clone(clearedFilter)
        };
        return originalFilter;
    };

    function getFilterConditions(filters){
        return filters.filter(function(filter){
            return filter.name.indexOf('SEARCHLIST_') === -1;
        }).map(function(filter){
            filter.isCustomFilter = true;
            return filter;
        });
    }

    function getSearchConditions(filters){
        var searchFields = Util.clone(filters);
        searchFields = searchFields.filter(function(filter){
            return ~filter.name.indexOf('SEARCHLIST_');
        });

        return searchFields.map(function(filter){
            filter.name = filter.name.replace('SEARCHLIST_', '');
            return filter;
        });
    }

    function triggerBeforeFilterApplyEvent(widget, preference){
        if(widget.beforeFilterApply){
            return widget.beforeFilterApply({
                'preference': preference
            });
        }
    }

    function triggerAfterFilterApplyEvent(widget, preference, filters){
        if(widget.afterFilterApply){
            widget.afterFilterApply({
                'preference': preference,
                'filters': filters
            });
        }
    }

    function prepareFilterRow(preference){
        var filterRow = preference.FILTER_ROW || {};
        filterRow = typeof preference.FILTER_ROW === 'string'?
            JSON.parse(preference.FILTER_ROW) : preference.FILTER_ROW;
        preference.FILTER_ROW = filterRow;
    }

    function applyFilterInFilterPopup(widget, filterRow){
        self.createFilterWidget(widget, filterRow);
    }

    function mergeFilters(baseFilters, newFilters){
        var result = baseFilters.concat(newFilters).reduce(function(prev, current, index){
            var fieldName = current.name;
            if(fieldName in prev.keys){
                var replaceIndex = prev.keys[fieldName];
                prev.filters[replaceIndex] = current;
            } else {
                prev.keys[fieldName] = index;
                prev.filters.push(current);
            }
            return prev;
        }, {
            filters: [],
            keys: {}
        });
        return result.filters;
    }

    function buildDataSourceFilter(widget, filters){
        var filterConditions = getFilterConditions(filters);
        var originalFilters = getOriginalDataSourceFilters(widget.dataSourceFilter);
        return mergeFilters(originalFilters, filterConditions);
    }

    function applyFilterInDataSource(widget, filters){
        widget.dataSourceFilter = buildDataSourceFilter(widget, filters);

        var searchConditions = getSearchConditions(filters);
        if(widget.setSearchCriteria){
            widget.setSearchCriteria(searchConditions);
        }
        return searchConditions;
    }

    function setAppliedFilter(widget, preference){
        widget.appliedFilter = preference;
    }

    function applyFilterInWidget(widget, fields, filterRow, preference){
        self.updateFilterInfo(widget, fields, filterRow, preference, {});
        setAppliedFilter(widget, preference);
    }

    /**
     * Apply filter
     *
     * @since 3.0.0
     *
     * @param  {Widget}  widget              Widget to apply the original filter on
     * @param  {Filter}  preference          Preference to be applied on widget
     * @param  {Boolean} [reloadWidget=true] Flag to cancel reload in widget
     *
     * @return {Object[]}          Rows returned using the filter
     */
    this.applyFilter = function(widget, preference, reloadWidget){
        reloadWidget = reloadWidget !== false;
        prepareFilterRow(preference);
        var event;

        if(reloadWidget){
            event = triggerBeforeFilterApplyEvent(widget, preference);
        }

        var filterRow = preference.CUSTOM_FILTER_ROW || preference.FILTER_ROW;

        var fields = self.factoryFields(null, widget.fields).filter(function removeInvisibleFields(field){
            return field.isVisible;
        });
        var filters = ZhFilterBuilder.buildFilter(fields, filterRow);

        if(reloadWidget){
            if(!event || !event.isDefaultPrevented()){
                var searchConditions = applyFilterInDataSource(widget, filters);
                var searchCriteria = buildSearchCriteria(searchConditions);

                return widget.reload(ZhUtil.getLikeAllFilter(widget, searchCriteria)).then(function(){
                    if (widget.dataSource) {
                        widget.dataSource.clearCheckedRows();
                    }
                    applyFilterInWidget(widget, fields, filterRow, preference);
                    triggerAfterFilterApplyEvent(widget, preference, filters);
                    applyFilterInFilterPopup(widget, preference.FILTER_ROW);

                    return ZHPromise.when();
                }.bind(this));
            } else {
                return ZHPromise.reject();
            }
        } else {
            applyFilterInDataSource(widget, filters);
            applyFilterInWidget(widget, fields, filterRow, preference);
            applyFilterInFilterPopup(widget, preference.FILTER_ROW);
            return ZHPromise.when();
        }
    };

    /**
     * Update the applied filter information
     *
     * @since 3.0.0
     *
     * @param  {Widget}  widget         Widget to update the filter information
     * @param  {Field[]} fields         List of fields used to create the filter
     * @param  {Object}  filterRow      Row representing the filter configuration
     * @param  {Filter}  preference     Filter currently applied
     * @param  {Object}  searchCriteria Search criteria currently applied
     */
    this.updateFilterInfo = function(widget, fields, filterRow, preference, searchCriteria){
        var filterInfo;
        var filterName = preference.LABEL_TO_PREFERENCE;

        if(((preference.ID === 'ORIGINAL' || preference.ID === 'EDITED') && !filterName) || preference.forceBuild){
            filterInfo = ZhFilterDescriptionBuilder.buildFilterInfo(fields, filterRow, searchCriteria, widget);
        } else {
            filterInfo = ZhFilterDescriptionBuilder.buildFilterAppliedInfo(filterName);
        }

        widget._filterInfo = filterInfo;
    };

    function trimPercentageSymbol(value){
        if(value.charAt(0) === '%'){
            value = value.substr(1);
        }

        if(value.charAt(value.length - 1) === '%'){
            value = value.substr(0, value.length - 1);
        }

        return value;
    }

    function buildSearchCriteria(conditions){
        var searchCriteria = {};
        conditions.forEach(function(condition){
            searchCriteria[condition.name] = trimPercentageSymbol(condition.value);
        });

        return searchCriteria;
    }

    function getOriginalDataSourceFilters(dataSourceFilter){
        return dataSourceFilter.filter(function(filter){
            return !filter.isCustomFilter;
        });
    }

    function removeConflictingProperties(field){
        var conflictingProperties = ['selectWidget', 'bindedEvents'];
        conflictingProperties.forEach(function(property){
            delete field[property];
        });
    }

    function factoryFields(gridFields, editing){
        var cloneField = function(field){
            var fieldClone = self.cloneObj(field);
            if(editing){
                fieldClone.fieldGroup = 'FILTER_FIELDS';
            }
            fieldClone.dataSource = field.dataSource;
            fieldClone.dataSourceFilter = field.dataSourceFilter;
            return fieldClone;
        };
        return gridFields.filter(function(field){
            return !Util.isUndefined(field.template);
        }).map(cloneField);
    }

    function factorySearchFields(gridFields){
        var factoredFields = [
            {
                'id': 'SEARCHLIST__ALL_MAP',
                'label': 'All fields',
                'name': 'SEARCHLIST__ALL_MAP',
                'class': 12,
                'template': 'field/text-edit.html',
                'isVisible': true,
                'showOnList': true,
                'descending': true,
                'fieldGroup': 'MORE_FIELDS'
            }
        ];

        var buildSearchListField = function(field){
            var fieldClone = self.cloneObj(field);
            fieldClone.id = 'SEARCHLIST_' + fieldClone.id;
            fieldClone.name = 'SEARCHLIST_' + fieldClone.name;
            fieldClone.class = 6;
            fieldClone.isVisible = true;
            fieldClone.readOnly = false;
            fieldClone.validations = {};
            fieldClone.template = 'field/text-edit.html';
            fieldClone.fieldGroup = 'MORE_FIELDS';
            return fieldClone;
        };

        return factoredFields.concat(gridFields.filter(function(field){
            return !field.skipSearch && Util.isUndefined(field.template);
        }).map(buildSearchListField));
    }

    function mergeFieldNewProperties(field, filterProperties){
        var keys = Object.keys(filterProperties);
        keys.forEach(function(property){
            field[property] = filterProperties[property];
        });
        if(field.dataSource && !(field.dataSource instanceof DataSource)){
            field.dataSource = metaDataFactory.factoryDataSource(field.dataSource, field.dataSourceFilter, field);
        }
        delete field.filterProperties;
        return field;
    }

    function removeEventListener(field, eventName, eventIndex){
        eventIndex = eventEngine.bindEvent(field, eventName);
        eventEngine.unbindEvent(field, eventName, eventIndex);
        eventIndex--;
        eventEngine.unbindEvent(field, eventName, eventIndex);
    }

    /**
     * Factory fields used on filter widget
     *
     * @since 3.0.0
     *
     * @param  {Widget}   parentWidget Widget to be the parent of the fields
     * @param  {Fields[]} gridFields   Fields from the widget to use the filter
     * @param  {Boolean}  editing      Filter configuration being edited
     *
     * @return {Fields[]}              Factored fields
     */
    this.factoryFields = function(parentWidget, gridFields, editing){
        var fields = factoryFields(gridFields, editing);
        var searchFields = factorySearchFields(gridFields);
        var buildFilterProperties = function(field){
            if(field.filterProperties){
                field = mergeFieldNewProperties(field, field.filterProperties);
            }
            removeConflictingProperties(field);
            removeEventListener(field, "FieldOnChange");
            return metaDataFactory.fieldFactory(field, parentWidget);
        };

        return fields.concat(searchFields).map(buildFilterProperties);
    };

    /**
     * Export filter file
     *
     * @since 3.0.0
     *
     * @param  {Filter} filter  Filter to export
     *
     * @return {Promise<Filter>} Filter exported
     */
    this.downloadPreferenceFile = function(filter){
        var fileName = filter.LABEL_TO_PREFERENCE.latinise().replace(/[^a-z,0-9 ]/ig,'').replace(/(?:^\w|[A-Z]|\b\w|\s+)/g, function(match, index){
            if(+match === 0) return "";
            return index == 0 ? match.toLowerCase() : match.toUpperCase();
        }) + '.filter';

        var filterToExport = {
            'ID': filter.ID,
            'LABEL_TO_PREFERENCE': filter.LABEL_TO_PREFERENCE,
            'WIDGET_ID': filter.WIDGET_ID,
            'FILTER_ROW': ZhUtil.clearRow(filter.FILTER_ROW),
            'LAST_MODIFIED_DATE': filter.LAST_MODIFIED_DATE
        };

        return ZhPreferences.downloadPreferenceFile(filterToExport, fileName);
    };

    /**
     * Validade filter to import
     *
     * @since 3.0.0
     *
     * @param  {Filter} filter              Filter to import
     * @param  {Widget} configWidget        Widget to validate
     * @param  {Object[]} filterDataSource  Existing filters data (optional)
     *
     * @return {Boolean} Filter valid
     */
    this.validateFilterImport = function(filter, configWidget, filterDataSource){
        filterDataSource = filterDataSource || configWidget.dataSource.data;

        if(configWidget.listWidget.id != filter.WIDGET_ID){
            MessageService.showMessageByCode('zh-filter-preferences#import_error_widget_id');
            return false;
        }

        var filtersWithSameId = filterDataSource.filter(function(row){
            return row.ID == filter.ID;
        });

        if(filtersWithSameId.length > 0){
            MessageService.showMessageByCode('zh-filter-preferences#import_error_id_violation');
            return false;
        }

        var filtersWithSameLabel = filterDataSource.filter(function(row){
            return row.LABEL_TO_PREFERENCE == filter.LABEL_TO_PREFERENCE;
        });

        if(filtersWithSameLabel.length > 0){
            MessageService.showMessageByCode('zh-filter-preferences#import_error_name_violation');
            return false;
        }

        return true;
    };

    function openFilterWidget(widget, rowToBeSet) {
        return createFilterWidget(widget, rowToBeSet).then(function(widgetToBeShown) {
            widget.activate();
            ScreenService.openPopup(widgetToBeShown);
        });
    }
    this.openFilterWidget = openFilterWidget;

    var filterWidgets = {};

    function forceSelectDataSourceToLoad(field, row) {
        var data = Util.getNestedProperty(field, ['dataSource', 'data', 'length']);

        var fieldName = field.valueField || field.name;
        var currentRow;

        var template = field.template.split('#').pop();
        if (template === 'field/select-autocomplete.html') {
            currentRow = row[fieldName];
        } else {
            currentRow = row[field.name];
        }

        if (field.dataSource && !data && currentRow) {
            field.dataSource.load([{ name: fieldName, value: currentRow, operator: "IN" }]);
        }
    }

    function forceFieldDataSourceToLoad(widget){
        widget.fields.forEach(function(field){
            forceSelectDataSourceToLoad(field, widget.currentRow);
        });
    }

    function createFilterWidget(widget, rowToBeSet) {
        return ApplicationContext.ZhFilterCreateFilterConditionsController.getCreateFilterConditionsWidgetForFilterPopup(widget).then(function(filterWidget) {
            if (!widget.filterInitialized){
                filterWidget.listWidget = widget;
                widget.filterInitialized = true;
            }

            filterWidget.label = ScreenService.i18n('Filter');

            var currentRow = rowToBeSet || widget.filterRowData;
            if(!currentRow) {
                currentRow = widget.appliedFilter ? widget.appliedFilter.FILTER_ROW : {};
            }

            filterWidget.currentRow = filterWidget.currentRow || {};
            Object.keys(currentRow).forEach(function(fieldName){
                filterWidget.currentRow[fieldName] = ZhUtil.evaluate(currentRow[fieldName]);
            });

            if (rowToBeSet) {
                if (!widget.appliedFilter) {
                    widget.appliedFilter = {
                        ID: 'CREATED'
                    };
                }
                
                widget.appliedFilter.FILTER_ROW = filterWidget.currentRow;
            }

            forceFieldDataSourceToLoad(filterWidget);

            filterWidget.actions[0].isVisible = true;
            filterWidget.actions[1].isVisible = true;
            filterWidget.actions[2].isVisible = false;
            filterWidget.actions[3].isVisible = false;

            filterWidgets[widget.id] = filterWidget;
            return ZHPromise.when(filterWidget);
        }.bind(this));
    }
    this.createFilterWidget = createFilterWidget;

    function isCopiable(object){
        var isCopiable = Util.isUndefinedOrNull(object);
        if(!isCopiable){
            var constr = object.constructor;
            var types = [String, Number, Array, Object, Boolean];
            isCopiable = types.some(function(type){
                return type().constructor === constr;
            });
        }
        return isCopiable;
    }

    /**
     * Clone the object avoiding first level non JavaScript basic and undefined types.
     *
     * @since ^3.14
     *
     * @param {Object} object The object to be copied.
     *
     * @return {Object} Returns the new object.
     */
    this.cloneObj = function(object){
        var clone = {};
        Object.keys(object).forEach(function(property){
            if(isCopiable(object[property])){
                clone[property] = ZhUtil.clearRow(object[property]);
            }
        });
        return clone;
    };

    function hasPopupOpened(){
        var isMobiScrollOpen = $('.mbsc-mobiscroll').length > 0;
        return !ScreenService.isSideMenuOpen() && !isMobiScrollOpen && !ScreenService.isAlertShown();
    }

    function isFilterPreferencesActive(widget){
        return Util.get(widget, ['floatingControl', 'customizationAction', 'filter']) !== false;
    }

    function isSearchActionActive(widget){
        return Util.get(widget, ['floatingControl', 'searchAction']) !== false;
    }

    function openWidgetFilter(){
        var activeWidget = templateManager.container.getActiveWidget();
        if(hasPopupOpened() && isFilterPreferencesActive(activeWidget) && ZhPreferences.validateWidget(activeWidget)){
            openFilterWidget(activeWidget);
        }

        return false;
    }

    function openWidgetSearch(){
        var activeWidget = templateManager.container.getActiveWidget();
        var searchIsEnabled = isFilterPreferencesActive(activeWidget) || isSearchActionActive(activeWidget);
        if(searchIsEnabled && hasPopupOpened() && ZhPreferences.validateWidget(activeWidget)){
            activeWidget.openSearchAction();
        }

        return false;
    }

    templateManager.projectPromise.then(function(){
        templateManager.project.shortcutKeys = templateManager.project.shortcutKeys || {};
        var openFilterKey = templateManager.project.shortcutKeys.openWidgetFilter || 'mod+l';
        var openSearchKey = templateManager.project.shortcutKeys.openWidgetSearch || 'mod+f';

        ZhKeyboardService.unbind(openFilterKey);
        ZhKeyboardService.unbind(openSearchKey);

        ZhKeyboardService.bind(openFilterKey, openWidgetFilter);
        ZhKeyboardService.bind(openSearchKey, openWidgetSearch);
    });
}

Configuration(function(ContextRegister){
    ContextRegister.register('ZhFilterPreferences', ZhFilterPreferences);
});

// FILE: src/controllers/ZhFilterWidgetsBuilder.js
/**
 * Service to create widgets to handle filters
 *
 * @class
 * @since 3.0.0
 *
 * @param {RestEngine}      restEngine      Service to make http requests
 * @param {TemplateManager} templateManager Service to handle templates
 * @param {MetaDataFactory} metaDataFactory Service to factory models from metadata
 */
var ZhFilterWidgetsBuilder = function(restEngine, templateManager, metaDataFactory, ZhFilterPreferences){
    var widgetsJson = {};

    function getWidgetJSON(widgetName){
        var widgetPath = 'zh-filter-preferences#json/widgets/'+widgetName+'.json';
        if(!widgetsJson[widgetPath]){
            widgetsJson[widgetPath] = restEngine.requestMetaData(widgetPath).then(function(response){
                return response.data;
            });
        }
        return widgetsJson[widgetPath];
    }

    /**
     * Retrieve a factored widget
     *
     * @since 3.0.0
     *
     * @param  {String} widgetName Widget name
     *
     * @return {Widget}            Factored widget
     */
    this.factoryWidget = function(widgetName){
        return getWidgetJSON(widgetName).then(function(widget){
            widget = Util.clone(widget);
            return metaDataFactory.widgetFactory(widget, templateManager.container);
        });
    };

    /**
     * Retrieve factored filter configuration widget
     *
     * @since 3.0.0
     *
     * @return {Widget} Filter configuration widget
     */
    this.factoryFilterConfigurationWidget = function(){
        return this.factoryWidget('config');
    };

    /**
     * Retrieve factored create filter widget
     *
     * @since 3.0.0
     *
     * @return {Widget} Create filter widget
     */
    this.factoryCreateFilterWidget = function(){
        return this.factoryWidget('createFilter');
    };

    /**
     * Retrieve factored import filter widget
     *
     * @since 3.0.0
     *
     * @return {Widget} Import filter widget
     */
    this.factoryImportFilterWidget = function(){
        return this.factoryWidget('importFilter');
    };

    function copyFieldGroups(fieldGroups){
        var copiedObj = (fieldGroups || []).map(function(fieldGroup){
            return Util.clone(fieldGroup, ['__proto__', 'rows', 'widget']);
        });
        return copiedObj;
    }

    function buildFilterWidgetFieldGroups(filterWidget, widget){
        var fieldGroups = (filterWidget.fieldGroups || []).concat(copyFieldGroups(widget.fieldGroups));
        var moreFieldsFieldGroup = [];
        fieldGroups = fieldGroups.filter(function(fieldGroup){
            var isMoreFieldFieldGroup = fieldGroup.name === 'MORE_FIELDS';
            if(isMoreFieldFieldGroup){
                moreFieldsFieldGroup = fieldGroup;
                moreFieldsFieldGroup.isVisible = !widget.hideMoreFieldsOnFilter;
            }
            return !isMoreFieldFieldGroup;
        });
        filterWidget.fieldGroups = fieldGroups.concat(moreFieldsFieldGroup);
    }

    /**
     * Retrieve factored build filters conditions widget
     *
     * @since 3.0.0
     *
     * @return {Widget} Build filters conditions widget
     */
    this.factoryBuildFiltersConditionsWidget = function(baseWidget){
        return getWidgetJSON('createFilterConditions').then(function(widgetJson){
            widgetJson = Util.clone(widgetJson);
            widgetJson.id = baseWidget.id + '_filter';
            widgetJson.actions.forEach(function(action) {
                action.id = baseWidget.id + '_filter_action_' + action.name;
            });
            buildFilterWidgetFieldGroups(widgetJson, baseWidget);
            var widget = metaDataFactory.widgetFactory(widgetJson, templateManager.container);
            widget.fields = widget.fields.concat(ZhFilterPreferences.factoryFields(widget, baseWidget.fields));
            widget._filteredWidgetId = baseWidget.id;
            return widget;
        });
    };

};

ZeedhiController.controller('ZhFilterWidgetsBuilder', ZhFilterWidgetsBuilder);

Configuration(function(ContextRegister){
    ContextRegister.register('ZhFilterWidgetsBuilder', ZhFilterWidgetsBuilder);
});

// FILE: src/controllers/ZhFilterCreateFilterConditionsController.js
/**
 * Create filter conditions widget controller
 *
 * @class
 * @since 3.0.0
 *
 * @param {ZhFilterPreferences}    ZhFilterPreferences    Service to handle filter preferences methods
 * @param {ZhFilterWidgetsBuilder} ZhFilterWidgetsBuilder Service to create widgets to handle filters
 * @param {MessageService}         MessageService         Service to show messages
 * @param {ScreenService}          ScreenService          Service to manipulate screen
 * @param {ZHPromise}              ZHPromise              Service to handle promises
 * @param {ZhUtil}                 ZhUtil                 Service that contains utilities methods
 */
var ZhFilterCreateFilterConditionsController = function(ZhFilterPreferences, ZhFilterWidgetsBuilder, MessageService, ScreenService, ZHPromise, ZhUtil, templateManager, $timeout){

    var createFilterConditionsWidgetPromise = {};

    /**
     * Clear cached widgets
     *
     * @since 3.21.2
     *
     * @param {Widget} widget Widget to be removed from cache.
     */
    this.clearCachedFilterConditionsWidget = function(widget){
        if(widget && widget.id){
            widget.filterInitialized = false;
            delete createFilterConditionsWidgetPromise[widget.id];
        }
    };

    /**
     * Retrieve widget to create filter conditions
     *
     * @since 3.0.0
     *
     * @return {Widget} Widget to create filter conditions
     */
    this.getCreateFilterConditionsWidget = function(widget){
        var widgetId = widget.id;
        if(!createFilterConditionsWidgetPromise[widgetId]){
            createFilterConditionsWidgetPromise[widgetId] = ZhFilterWidgetsBuilder.factoryBuildFiltersConditionsWidget(widget);
        }

        return createFilterConditionsWidgetPromise[widgetId];
    };

    function saveFilterFields(widget){
        var allowedFields = widget.fields.map(function(field){
            return ZhFilterPreferences.cloneObj(field);
        });

        widget.__originalFilterStatus = allowedFields;
        widget.__originalCurrentRow = ZhFilterPreferences.cloneObj(ZhUtil.clearRow(widget.currentRow));
    }

    /**
     * Retrieve widget to create filter conditions with filter popup configuration
     *
     * @since 3.0.0
     *
     * @return {Widget} Widget to create filter conditions
     */
    this.getCreateFilterConditionsWidgetForFilterPopup = function(widget){
        return this.getCreateFilterConditionsWidget(widget).then(function(createFilterConditionsWidget){
            createFilterConditionsWidget.actions[0].isVisible = true;
            createFilterConditionsWidget.actions[1].isVisible = true;
            createFilterConditionsWidget.actions[2].isVisible = false;
            createFilterConditionsWidget.actions[3].isVisible = false;
            var labelField = createFilterConditionsWidget.getField('LABEL_TO_PREFERENCE');

            if(labelField){
                labelField.isVisible = false;
                if(createFilterConditionsWidget.fields[1]){
                    createFilterConditionsWidget.fields[1].focused = true;
                }
            }

            saveFilterFields(createFilterConditionsWidget);

            return createFilterConditionsWidget;
        });
    };


    /**
     * Retrieve widget to create filter conditions with edit preference configuration
     *
     * @since 3.0.0
     *
     * @return {Widget} Widget to create filter conditions
     */
    this.getCreateFilterConditionsWidgetForEditPreference = function(widget){
        return this.getCreateFilterConditionsWidget(widget).then(function(createFilterConditionsWidget){
            createFilterConditionsWidget.actions[0].isVisible = false;
            createFilterConditionsWidget.actions[1].isVisible = false;
            createFilterConditionsWidget.actions[2].isVisible = true;
            createFilterConditionsWidget.actions[3].isVisible = true;

            var labelField = createFilterConditionsWidget.getField('LABEL_TO_PREFERENCE');

            if(labelField){
                labelField.isVisible = true;
            }

            saveFilterFields(createFilterConditionsWidget);

            return createFilterConditionsWidget;
        });
    };

    /**
     * Save filter and apply
     *
     * @since 3.0.0
     *
     * @param  {Widget} createFilterConditionsWidget Widget that has the filter conditions to be saved
     *
     * @return {Promise}                             Promise resolved when saved filter is applied
     */
    this.saveAndApplyFilter = function(createFilterConditionsWidget){

        var clearRequiredFieldErrors = function(invalidFields){
            invalidFields.shift();
            invalidFields.forEach(function(invalidField){
                var fieldName;
                invalidField = invalidField.filter(function(invalidItem){
                    fieldName = invalidItem.fieldName;
                    return invalidItem.errorMessage != "Required field";
                });
                if(!invalidField.length){
                    delete createFilterConditionsWidget.currentRow.$error[fieldName];
                }
            });
        };

        if(createFilterConditionsWidget.isValid(clearRequiredFieldErrors)){
            var currentRow = createFilterConditionsWidget.currentRow;
            var filter = createFilterConditionsWidget.preference;

            filter.LABEL_TO_PREFERENCE = currentRow.LABEL_TO_PREFERENCE;
            filter.FILTER_ROW = ZhUtil.clearRow(currentRow);
            delete filter.FILTER_ROW.LABEL_TO_PREFERENCE;
            filter.FILTER_ROW = JSON.stringify(filter.FILTER_ROW);

            var configWidget = createFilterConditionsWidget.configWidget;
            var listWidget = configWidget.listWidget;

            return ZhFilterPreferences.saveFilters([filter]).then(function(){
                filter.FILTER_ROW = JSON.parse(filter.FILTER_ROW);
                MessageService.successNotificationByCode('zh-filter-preferences#save_success');
                ScreenService.closePopup(true);

                if(createFilterConditionsWidget.isValid()){
                    filter.forceBuild = true;
                    listWidget.filterRowData = currentRow;
                    ZhFilterPreferences.applyFilter(listWidget, filter);
                    listWidget.activate();
                } else {
                    listWidget.openFilterWidget(createFilterConditionsWidget.currentRow);
                }

                ZhFilterPreferences.updateFilters(listWidget.id, configWidget.dataSource);
            }).catch(function(error){
                MessageService.showMessageByCode('zh-filter-preferences#save_error', {
                    'ERROR': error.message
                });
            });
        } else {
            return ZHPromise.reject("Invalid params");
        }
    };

    function getRowToApply(appliedFilter, currentRow){
        var appliedRow = (appliedFilter && appliedFilter.FILTER_ROW) || {};
        var row = ZhUtil.clearRow(currentRow);
        Object.keys(appliedRow).forEach(function(key){
            // Do not replace evaluated values
            if(Util.isString(appliedRow[key]) && appliedRow[key].indexOf('@') === 0){
                row[key] = appliedRow[key];
            }
        });
        return row;
    }

    this.clearFilter = function(widget){
        widget.fields
            .filter(function(field){
                return !field.readOnly;
            })
            .forEach(function(field){
                var template = field.template || '';
                field.clearValue(field);

                if(template.indexOf('field/checkbox.html') !== -1){
                    widget.currentRow[field.name] = field.valueToFalse;
                    field.checked = false;
                    templateManager.updateTemplate();
                } else if(template.indexOf('field/select-native.html') !== -1){
                    $timeout(function(){
                        if(field.element){
                            var dropdown = field.element.next();
                            dropdown.find('.selected').removeClass('selected');
                            dropdown.find('.current').text('');
                        }
                    });
                }

                if(field.change){
                    field.change();
                }
            });
    };

    /**
     * Apply filter
     *
     * @since 3.0.0
     *
     * @param  {Widget} createFilterConditionsWidget Widget that has the filter conditions to be saved
     * @param  {String} [filterName] - The name of the filter being applied
     *
     * @return {Promise}                             Promise resolved when saved filter is applied
     */
    this.applyFilter = function(createFilterConditionsWidget, filterName){
        if(createFilterConditionsWidget.isValid()){
            var currentRow = createFilterConditionsWidget.currentRow;
            var listWidget = createFilterConditionsWidget.listWidget;
            delete currentRow.LABEL_TO_PREFERENCE;

            var filter = {
                'ID': 'EDITED',
                'FILTER_ROW': getRowToApply(listWidget.appliedFilter, currentRow)
            };

            if(filterName){
                filter.LABEL_TO_PREFERENCE = filterName;
            }

            var applyFilterPromise = ZhFilterPreferences.applyFilter(listWidget, filter).catch(function(){
                ScreenService.openPopup(createFilterConditionsWidget);
                return ZHPromise.reject();
            });
            if(ScreenService.getPopupOpen() == createFilterConditionsWidget){
                ScreenService.closePopup(true);
                listWidget.activate();
            }
            return applyFilterPromise;
        } else {
            if(ScreenService.getPopupOpen() != createFilterConditionsWidget){
                ScreenService.openPopup(createFilterConditionsWidget);
            }
            return ZHPromise.reject();
        }
    };

    function restoreFilterFields(widget){
        if(widget.__originalFilterStatus){
            widget.fields.forEach(function(field, index){
                var __field = widget.__originalFilterStatus.filter(function(fieldOriginal){
                    return fieldOriginal.name === field.name;
                })[0];
                Object.keys(__field).forEach(function(key){
                    widget.fields[index][key] = __field[key];
                });
            });
            widget.currentRow = widget.__originalCurrentRow;

            delete widget.__originalCurrentRow;
            delete widget.__originalFilterStatus;
        }
    }

    /**
     * Close widget popup and restore original status of filter widget
     *
     * @since 3.14.x
     *
     * @param  {Widget} createFilterConditionsWidget Widget that has the filter conditions to be restored
     *
     * @return {undefined}
     */
    this.closePopup = function(widget){
        restoreFilterFields(widget);
        ScreenService.closePopup();
        widget.listWidget.activate();
    };

};

ZeedhiController.controller('ZhFilterCreateFilterConditionsController', ZhFilterCreateFilterConditionsController);

Configuration(function(ContextRegister){
    ContextRegister.register('ZhFilterCreateFilterConditionsController', ZhFilterCreateFilterConditionsController);
});

// FILE: src/controllers/ZhFilterImportFilterController.js
/**
 * Import filter widget controller
 *
 * @class
 * @since 3.0.0
 *
 * @param {MessageService}                        MessageService                           Service to show messages
 * @param {ZhFilterPreferences}                   ZhFilterPreferences                      Service to handle filter preferences methods
 * @param {ZhPreferences}                         ZhPreferences                            Service to handle preferences persistance
 * @param {ZhFilterWidgetsBuilder}                ZhFilterWidgetsBuilder Service to create widgets to handle filters
 * @param {ZHPromise}                             ZHPromise                                Service to handle promises
 * @param {ScreenService}                         ScreenService                            Service to manipulate screen
 */
var ZhFilterImportFilterController = function(MessageService, ZhFilterPreferences, ZhPreferences, ZhFilterWidgetsBuilder, ZHPromise, ScreenService){

    var importFilterWidgetPromise = null;

    /**
     * Retrieve widget to import filter
     *
     * @since 3.0.0
     *
     * @return {Promise<Widget>}
     */
    this.getImportFilterWidget = function(){
        if(importFilterWidgetPromise === null){
            importFilterWidgetPromise = ZhFilterWidgetsBuilder.factoryImportFilterWidget();
        }

        return importFilterWidgetPromise;
    };

    /**
     * Import filter
     *
     * @since 3.0.0
     *
     * @param  {Widget} importFilterWidget Widget with the filter configuration
     *
     * @return {Promise}                      Promise resolved after the filter is imported
     */
    this.importPreference = function(importFilterWidget){
        if(!importFilterWidget.isValid()){
            return ZHPromise.reject({err: 'WIDGET_INVALID'});
        }

        var filterFileData = importFilterWidget.fields[0].value()[0].b64File;
        filterFileData = filterFileData.split('base64,')[1];
        filterFileData = window.atob(filterFileData);
        filterFileData = decodeURIComponent(escape(filterFileData));

        var filter = JSON.parse(filterFileData);

        var configWidget = importFilterWidget.configWidget;
        var listWidget = configWidget.listWidget;

        if(!ZhFilterPreferences.validateFilterImport(filter, configWidget)){
            return ZHPromise.reject({err: 'FILTER_FILE_INVALID'});
        }

        filter.__is_new = true;
        filter.__generate_id = false;
        filter.FILTER_ROW = JSON.stringify(filter.FILTER_ROW);

        return ZhPreferences.getUserID().then(function(userID){
            filter.USER_ID = userID;

            return ZhFilterPreferences.saveFilters([filter]).then(function(){
                filter.FILTER_ROW = JSON.parse(filter.FILTER_ROW);
                ScreenService.closePopup();
                ZhFilterPreferences.updateFilters(listWidget.id, configWidget.dataSource);
                configWidget.refreshWidget();
            }).catch(function(error){
                MessageService.showMessageByCode('zh-filter-preferences#save_error', {
                    'ERROR': error.message
                });
            });
        });
    };
};

ZeedhiController.controller('ZhFilterImportFilterController', ZhFilterImportFilterController);

Configuration(function(ContextRegister){
    ContextRegister.register('ZhFilterImportFilterController', ZhFilterImportFilterController);
});

// FILE: src/controllers/ZhFilterConfigWidgetController.js
/**
 * Filter configuration widget controller
 *
 * @class
 * @since 3.0.0
 *
 * @param {ZhPreferences}                            ZhPreferences                            Service to handle preferences persistance
 * @param {ZhFilterPreferences}                      ZhFilterPreferences                      Service to handle filter preferences methods
 * @param {ZhFilterWidgetsBuilder}                   ZhFilterWidgetsBuilder                   Service to create widgets to handle filters
 * @param {ScreenService}                            ScreenService                            Service to manipulate screen
 * @param {MessageService}                           MessageService                           Service to show messages
 * @param {ZHPromise}                                ZHPromise                                Service to handle promises
 * @param {ZhFilterCreateFilterConditionsController} ZhFilterCreateFilterConditionsController Controller to manipulate create filter conditions widget
 * @param {ZhFilterImportFilterController}           ZhFilterImportFilterController           Controller to manipulate import filter widget
 */
var ZhFilterConfigWidgetController = function(ZhPreferences, ZhFilterPreferences, ZhFilterWidgetsBuilder, ScreenService, MessageService, ZHPromise, ZhFilterCreateFilterConditionsController, ZhFilterImportFilterController){

    var configWidgetPromise = null;

    /**
     * Retrieve widget that handles filters configuration
     *
     * @since 3.0.0
     *
     * @param  {Widget}     listWidget Widget that is being used to create filters for
     * @param  {DataSource} dataSource DataSource to use on config widget
     *
     * @return {Promise<Widget>}       Widget that handles filters configuration
     */
    this.getConfigWidget = function(listWidget, dataSource){
        if(configWidgetPromise === null){
            configWidgetPromise = ZhFilterWidgetsBuilder.factoryFilterConfigurationWidget();
        }

        var userID = ZhPreferences.getUserID();

        return ZHPromise.all([userID, configWidgetPromise]).then(function(args){
            var userID = args[0];
            var configWidget = args[1];

            configWidget.listWidget = listWidget;
            configWidget.dataSourceFilter = [
                {'name': 'WIDGET_ID', 'operator': '=', 'value': listWidget.id}
            ];
            dataSource.data.forEach(function(row){
                row.APPLIED = row.ID == (listWidget.appliedFilter ? listWidget.appliedFilter.ID : 'ORIGINAL');
            });
            configWidget.dataSource = dataSource;

            return configWidget;
        });
    };

    var hideMoreFields = function(groups, hide){
        var moreFieldsFieldGroup= [];
        return groups.filter(function(fieldGroup){
            delete fieldGroup.rows;
            var isMoreFieldFieldGroup = fieldGroup.name === 'MORE_FIELDS';
            if(isMoreFieldFieldGroup){
                moreFieldsFieldGroup = fieldGroup;
                moreFieldsFieldGroup.isVisible = !hide;
            }
            return !isMoreFieldFieldGroup;
        }).concat(moreFieldsFieldGroup);
    };

    /**
     * Open widget to create a new filter
     *
     * @since 3.0.0
     *
     * @param  {Widget} configWidget Widget that handles filters configuration
     *
     * @return {Promise}             Promise that is resolved when the widget is opened
     */
    this.openCreateFilterWidget = function(configWidget){
        var label = configWidget.currentRow.LABEL_TO_PREFERENCE;
        return ZhFilterCreateFilterConditionsController.getCreateFilterConditionsWidgetForEditPreference(configWidget.listWidget).then(function(createFilterConditionsWidget){
            var listWidget = configWidget.listWidget;

            createFilterConditionsWidget.label = ScreenService.i18n('Filter');
            createFilterConditionsWidget.configWidget = configWidget;

            if(!listWidget.filterInitialized){
                var fieldGroups = (createFilterConditionsWidget.fieldGroups || []).concat((listWidget.fieldGroups || []));
                createFilterConditionsWidget.fieldGroups = fieldGroups;
                listWidget.filterInitialized = true;
            }
            createFilterConditionsWidget.fieldGroups = hideMoreFields(createFilterConditionsWidget.fieldGroups, listWidget.hideMoreFieldsOnFilter);

            return ZhPreferences.getUserID().then(function(userID){
                var preference = {
                    '__is_new': true,
                    'ID': null,
                    'USER_ID': userID,
                    'LABEL_TO_PREFERENCE': label,
                    'WIDGET_ID': listWidget.id,
                    'LAST_MODIFIED_DATE': null
                };

                createFilterConditionsWidget.preference = preference;

                var labelField = createFilterConditionsWidget.getField('LABEL_TO_PREFERENCE');
                var fields = ZhFilterPreferences.factoryFields(createFilterConditionsWidget, listWidget.fields, true);
                createFilterConditionsWidget.fields = [labelField].concat(fields);
                labelField.isVisible = true;
                createFilterConditionsWidget.newRow();
                return ScreenService.openPopup(createFilterConditionsWidget);
            });
        });
    };


    /**
     * Open popup to edit a saved filter
     *
     * @since 3.0.0
     *
     * @param  {Filter} filter   Filter to edit
     *
     * @return {Promise<Widget>} Widget used to edit the filter
     */
    this.editFilter = function(configWidget, filter){
        if(filter.TYPE === 'F'){
            MessageService.alertNotificationByCode('zh-filter-preferences#cannot_edit_fixed_filter');
            return ZHPromise.when();
        }
        var listWidget = configWidget.listWidget;
        return ZhFilterCreateFilterConditionsController.getCreateFilterConditionsWidgetForEditPreference(configWidget.listWidget)
            .then(function(createFilterConditionsWidget){
                createFilterConditionsWidget.preference = filter;
                createFilterConditionsWidget.label = ScreenService.i18n('Filter') + ' - ' + filter.LABEL_TO_PREFERENCE;
                createFilterConditionsWidget.configWidget = configWidget;
                createFilterConditionsWidget.fieldGroups= hideMoreFields(createFilterConditionsWidget.fieldGroups || [], listWidget.hideMoreFieldsOnFilter);

                var labelField = createFilterConditionsWidget.getField('LABEL_TO_PREFERENCE');
                var fields = ZhFilterPreferences.factoryFields(createFilterConditionsWidget, listWidget.fields, true);
                createFilterConditionsWidget.fields = [labelField].concat(fields);
                labelField.isVisible = true;

                createFilterConditionsWidget.currentRow = filter.FILTER_ROW;
                createFilterConditionsWidget.currentRow.LABEL_TO_PREFERENCE = filter.LABEL_TO_PREFERENCE;
                return ScreenService.openPopup(createFilterConditionsWidget);
            });
    };

    /**
     * Delete filters
     *
     * @since 3.0.0
     *
     * @param  {Widget} configWidget Widget that contains the filters to delete
     *
     * @return {Promise}             Promise resolved after filters are deleted
     */
    this.deleteFilters = function(configWidget){
        var filtersToDelete = configWidget.getCheckedRows();

        var defaultFilter = filtersToDelete.filter(function(filter){
            return filter.DEFAULT_FILTER;
        });
        if(defaultFilter.length){
            MessageService.showMessageByCode('zh-filter-preferences#delete_error_default');

            return;
        }

        return MessageService.confirmMessageByCode('zh-filter-preferences#delete', {
            'NR_OF_FILTERS': filtersToDelete.length
        }).then(function(){
            return ZhFilterPreferences.deleteFilters(filtersToDelete).then(function(){
                configWidget.dataSource.clearCheckedRows();
                return ZhFilterPreferences.updateFilters(configWidget.listWidget.id, configWidget.dataSource);
            }).catch(function(error){
                return MessageService.getMessageByCode('zh-filter-preferences#'+error.message).then(function(errorMessage) {
                    return MessageService.showMessageByCode('zh-filter-preferences#delete_error', {
                        'ERROR': ScreenService.i18n(errorMessage)
                    });
                });
            });
        });
    };

    /**
     * Set a filter as the default preference
     *
     * @since 3.0.0
     *
     * @param  {Widget} configWidget Widget that handles filters configuration
     * @param  {Filter} filter       Filter that it's default value has changed
     *
     * @return {Promise<Object>}     Widget default preferences
     */
    this.updateDefaultFilter = function(configWidget, filter){
        return ZhPreferences.changeDefaultPreferences(configWidget, 'DEFAULT_FILTER', filter);
    };

    /**
     * Apply Filter
     *
     * @since 3.0.0
     *
     * @param  {Widget} configWidget Widget that handles filters configuration
     * @param  {Filter} filter       Filter to be applied
     *
     * @return {Promise<Object>}     Widget default preferences
     */
    this.updateAppliedFilter = function(configWidget, filter){
        var listWidget = configWidget.listWidget;

        return ZhFilterPreferences.applyFilter(listWidget, filter).then(function(){
            configWidget.dataSource.data.forEach(function(row){
                row.APPLIED = row.ID == filter.ID;
            });
        });
    };

    /**
     * Download preference as file
     *
     * @since 3.0.0
     *
     * @param  {Filter} filter       Filter to export
     *
     * @return {Promise<Filter>}     Filter exportado
     */
    this.downloadPreferenceFile = function(filter){
        return ZhFilterPreferences.downloadPreferenceFile(filter);
    };

    /**
     * Open widget to import a new filter from file
     *
     * @since 3.0.0
     *
     * @param  {Widget} configWidget Widget that handles filter configuration
     *
     * @return {Promise}             Promise that is resolved when the widget is opened
     */
    this.importPreferenceFile = function(configWidget){
        return ZhFilterImportFilterController.getImportFilterWidget().then(function(importFilterWidget){
            importFilterWidget.newRow();
            importFilterWidget.configWidget = configWidget;
            return ScreenService.openPopup(importFilterWidget);
        });
    };

};

ZeedhiController.controller('ZhFilterConfigWidgetController', ZhFilterConfigWidgetController);

Configuration(function(ContextRegister){
    ContextRegister.register('ZhFilterConfigWidgetController', ZhFilterConfigWidgetController);
});

// FILE: src/controllers/ZhFilterFloatingCardController.js
/**
 * Floating window controller
 *
 * @class
 * @since 3.0.0
 *
 * @param {$scope}              $scope              Floating window scope
 * @param {$timeout}            $timeout            AngularJS's wrapper for window.setTimeout
 * @param {ApplicationContext}  ApplicationContext  Service to retrieve Zeedhi services
 * @param {templateManager}     templateManager     Service to handle templates
 * @param {metaDataFactory}     metaDataFactory     Service to factory models from metadata
 * @param {ScreenService}       ScreenService       Service to handle screen
 * @param {Query}               Query               Service to build queries
 * @param {eventEngine}         eventEngine         Service to handle events
 * @param {ZHPromise}           ZHPromise           Service to handle promises
 * @param {ZhUtil}              ZhUtil              Service to provice utilities methods
 */
var ZhFilterFloatingCardController = function($scope, ApplicationContext, templateManager, metaDataFactory, ScreenService, Query, eventEngine, ZHPromise, ZhUtil){

    var widget = $scope.widget;
    var ZhFilterPreferences = ApplicationContext.ZhFilterPreferences;
    var ZhPreferences = ApplicationContext.ZhPreferences;
    var ZhFilterConfigWidgetController = ApplicationContext.ZhFilterConfigWidgetController;
    var ZhFilterCreateFilterConditionsController = ApplicationContext.ZhFilterCreateFilterConditionsController;
    var filterWidget;

    var dataSource = metaDataFactory.factoryDataSource({
        'name': 'zh-filter-preferences#/filter',
        'localStorage': false,
        'lazyLoad': true,
        'rest': true,
        'data': []
    });

    dataSource.afterLoadDataSource(function(){
        return ZhFilterPreferences.addIsDefaultFilterToFilters(dataSource.data, widget.id).then(function(filters){
            dataSource.data = filters.map(function(filter){
                filter.FILTER_ROW = JSON.parse(filter.FILTER_ROW);
                return filter;
            });

        });
    });

    $scope.customizationCard = {
        'label': 'Filters',
        'type': 'filter',
        'openFilterConfiguration': openFilterConfiguration,
        'refreshFilters': refreshFilters,
        'openFilterWidget': openFilterWidget,
        'applyOriginalFilter': applyOriginalFilter,
        'applyFilter': applyPreference,
        'dataSource': dataSource
    };

    ZhFilterPreferences.registerFilterDataSource(widget.id, $scope.customizationCard.dataSource);

    widget.openFilterWidget = openFilterWidget;
    widget.refreshFilters = refreshFilters;

    function updateFilterRow(filterRow, searchCriteria){
        var changed = false;
        filterRow = filterRow || {};
        Object.keys(searchCriteria).forEach(function(key){
            var name = 'SEARCHLIST_' + key;
            var filterValue = filterRow[name];
            if(!Util.isEmptyOrBlank(filterValue) && searchCriteria[key] !== filterValue){
                changed = true;
            }
            filterRow[name] = searchCriteria[key];
        });

        filterRow.changed = changed;
        return filterRow;
    }

    $scope.$watchCollection('widget.searchCriteria', function(searchCriteria){
        if(ZhPreferences.validateWidget(widget)){
            var filterRow = widget.appliedFilter && widget.appliedFilter.FILTER_ROW;
            filterRow = updateFilterRow(filterRow, searchCriteria || {});

            if(filterRow.changed){
                widget.appliedFilter = {
                    ID: 'EDITED',
                    FILTER_ROW: filterRow
                };
            }
            delete filterRow.changed;

            if(widget.appliedFilter){
                ZhFilterPreferences.updateFilterInfo(widget, widget.fields, filterRow, widget.appliedFilter, searchCriteria);
            }
        }
    });

    function openFilterConfiguration(){
        var dataSource = $scope.customizationCard.dataSource;
        return ZhFilterConfigWidgetController.getConfigWidget(widget, dataSource).then(function(configWidget){
            return ScreenService.openPopup(configWidget);
        });
    }

    function refreshFilters(){
        return ZhPreferences.getUserID().then(function(){
            var query = Query.build()
                .where('WIDGET_ID').equals(widget.id);

            return dataSource.load(query.where());
        });
    }

    function openFilterWidget(rowToBeSet){
        return ZhFilterPreferences.openFilterWidget(widget, rowToBeSet);
    }

    function applyOriginalFilter(){
        return ZhFilterPreferences.applyOriginalFilter(widget);
    }

    function applyPreference(filter, reloadWidget){
        ZhFilterPreferences.applyFilter(widget, filter, reloadWidget);
    }

    function applyDefaultFilter(){
        var isLazyLoad = Util.getNestedProperty(widget, ['dataSource', 'lazyLoad']);
        ZhPreferences.getDefaultWidgetPreferences(widget.id).then(function(defaultPreference){
            var filter = defaultPreference.defaultFilter || ZhFilterPreferences.getOriginalFilter(widget.id);
            applyPreference(filter, !isLazyLoad);
        });
    }

    function getDataSourceFilterRow(){
        var filterRow = {};
        (widget.dataSourceFilter || [])
            .filter(function removeCustoms(filter){
                return !filter.isCustomFilter;
            })
            .forEach(function parseToFilterRow(filter){
                filterRow[filter.name] = filter.value;
            });
        return filterRow;
    }

    function initOriginalFilter(){
        var widgetId = widget.id;
        var filter = ZhFilterPreferences.getOriginalFilter(widgetId);
        if(Util.isEmptyObject(filter.FILTER_ROW)){
            var filterRow = getDataSourceFilterRow();
            widget.fields.forEach(function(field){
                var hasFilterDefaultValue = field.filterProperties && field.filterProperties.hasOwnProperty('defaultValue');
                var defaultValue = hasFilterDefaultValue ? field.filterProperties.defaultValue : field.defaultValue;
                if(!Util.isUndefinedOrNull(defaultValue)){
                    filterRow[field.name] = defaultValue;
                }
            });
            ZhFilterPreferences.setOriginalFilter(widgetId, filterRow);
        }

    }

    function isFilterPreferencesActive(activeWidget){
        return Util.get(activeWidget || widget, ['floatingControl', 'customizationAction', 'filter']) !== false;
    }

    $scope.$on('$destroy', function() {
        delete widget.openFilterWidget;
        delete widget.refreshFilters;
        delete dataSource.afterLoadDataSourcelistener;
    });

    (function initFilterPreferences(){
        var filterIsActive = isFilterPreferencesActive();
        if(filterIsActive && ZhPreferences.validateWidget(widget) && Util.isUndefinedOrNull(widget.appliedFilter) && widget.filterInitialized !== true && widget.preventDefaultFilter !== true){
            initOriginalFilter();
            applyDefaultFilter();
        }
    })();

};

ZeedhiController.controller('ZhFilterFloatingCardController', ZhFilterFloatingCardController);

// FILE: src/directives/ZhFilterFloatingControl.js
var ZeedhiDirectives = angular.module('ZeedhiDirectives');

ZeedhiDirectives.directive('zhFloatingControl', ['$timeout', 'templateManager', ZhSearchFloatingControl]);

function ZhSearchFloatingControl($timeout, templateManager){

    return {
        priority: 10,
        link: function($scope, element, attrs, controller){
            var widget = $scope.widget;
            if(widget.floatingControl === false){
                return;
            }

            var isFilterApplied = function(){
                return widget && widget.appliedFilter && (Object.keys(widget.appliedFilter.FILTER_ROW).length > 0);
            };

            var defaultOptions = {
                searchAction: Util.isUndefined(element.parent().attr('data-hide-search')) && Util.isUndefined(element.parent().attr('hide-search')),
                openSearch: false
            };
            widget.floatingControl = Util.extend(defaultOptions, widget.floatingControl);

            var isFilterAppliedWithoutOriginal = function(){
                return widget._filterInfo && widget._filterInfo.length > 0 && widget.appliedFilter && (widget.appliedFilter.ID != 'ORIGINAL');
            };

            widget.floatingControl.addStatus({
                priority: 20,
                classString: 'searching',
                icon: 'more',
                conditionFunction: function(){
                    return isFilterAppliedWithoutOriginal();
                },
                infoTemplate: function(){
                    var hideFilterValue = templateManager.project.hideFilterValue || widget.hideFilterValue;
                    var filterInfoValue = hideFilterValue ? '</b> {{info.filterName}}': ':</b> {{info.value}}';
                    if(isFilterApplied()){
                        widget.floatingControl.statuses[1].icon = 'search';
                        if(widget.floatingControl.customizationAction && widget.floatingControl.customizationAction.filter){
                            icon = 'filter';
                            method = 'openFilter';
                        } else {
                            icon = 'close-x';
                            method = 'clearFilter';
                        }
                        return '<div data-zh-touchstart="'+method+'()"> <div class="searching-control-info"><span data-zh-icon="'+icon+' no-border icon-white"></span><div class="searching-control-info-details"><span ng-repeat="info in widget._filterInfo"><b>{{info.label|i18n}}'+filterInfoValue+'</span></div></div><div class="searching-control-info-text" data-zh-bind-translate="\'Filter applied\'"></div></div>';
                    }
                    widget.floatingControl.statuses[1].icon = 'more';
                },
                scope: $scope
            });

            if(templateManager.project.showEmptyFilter){
                widget.floatingControl.addStatus({
                    priority: 30,
                    classString: 'emptyFilter',
                    icon: 'more',
                    conditionFunction: function(){
                        return !isFilterAppliedWithoutOriginal();
                    },
                    infoTemplate: '<div data-zh-touchstart="openFilter()"> <div class="searching-control-info"><span data-zh-icon="filter no-border icon-white"></span></div><div class="searching-control-info-text"></div></div>',
                    scope: $scope
                });
            }

            $scope.openSearchAction = function(){
                $timeout.cancel($scope._closeTimeout);
                if(!element.hasClass('opened')){
                    $scope.toggleActionMenu();
                }
                $scope.closeOpenedActions();
                var searchAction = element.find('.search-action').closest('.float-action');
                if(searchAction && searchAction.length > 0){
                    searchAction.find("span.search-action-icon").click();
                    Util.selectElement(searchAction.find('input'));
                }
            };
            widget.openSearchAction = $scope.openSearchAction;

            $scope.$on('$destroy', function() {
               delete widget.openSearchAction;
               widget.floatingControl.statuses = [];
            });

            $scope.openFilter = function(){
                $scope.widget.openFilterWidget();
            };

            $scope.clearFilter = function(){
                $scope.widget.searchCriteria = {};
            };

            $scope.clearSearch = function(event, fieldName){
                var filterRow = (widget.appliedFilter && widget.appliedFilter.FILTER_ROW) || {};
                if(!fieldName){
                    widget.searchCriteria = {};
                } else {
                    delete filterRow['SEARCHLIST_'+fieldName];
                    delete widget.searchCriteria[fieldName];
                }

                if(event){
                    Util.selectElement($(event.target).closest(".floating-card-input").find("input"));
                }
            };

            $scope.toggleSearchFieldsList = function(event){
                if(!widget.floatingControl.customizationAction || !widget.floatingControl.customizationAction.filter){
                    var el = $(event.target).closest(".floating-card").find('.floating-card-search-field-select');
                    el.toggleClass("opened");

                    if(el.hasClass("opened")){
                        $(event.target).closest(".floating-card").find('.floating-card-select-field-options').removeClass("opened");
                        $(event.target).closest(".floating-card").find('.zh-select-search-floating').removeClass("opened");
                    }
                }
            };

            $scope.selectSearchField = function(field){
                $scope.searchField = field;
                element.find('.floating-card-search-field-select').removeClass('opened');
                element.find('input.zh-input-search-floating').focus();
            };

            $scope.filterFields = function(field){
                return field.aclIsVisible && !field.skipSearch && ((field.isVisible && field.showOnList) || field.showOnFilter);
            };

            $scope.getFields = function(widget) {
                return (widget.fields || []).filter($scope.filterFields);
            };

            if(widget.floatingControl.defaultSearchField){
                $scope.searchField = widget.getField(widget.floatingControl.defaultSearchField);
            }

            if (widget.floatingControl.openSearch) {
                $timeout(widget.openSearchAction, 0, false);
            }
        }
    };

}

ZeedhiDirectives.directive('zhFilterFloatingControl', [ZhFilterFloatingControl]);

function ZhFilterFloatingControl(){

    return {
        priority: 10,
        link: function($scope){
            $scope.toggleFilterPreferencesCard = function(e){
                var actionElement = $(e.target).closest('.float-action');
                if(!actionElement.hasClass('opened')){
                    $scope.widget.refreshFilters();
                }
                $scope.togglePreferencesCard(e);
            };
        }
    };

}

// FILE: src/Config.js
(function(){

window.templateUrls = window.templateUrls || [];
window.metadataUrls = window.metadataUrls || [];
window.serviceUrls = window.serviceUrls || [];

var PACKAGE_NAME = 'zh-filter-preferences';

var hasTemplateUrl = Boolean(window.templateUrls.find(function(value){
    return value.package === PACKAGE_NAME;
}));

var hasMetadataUrl = Boolean(window.metadataUrls.find(function(value){
    return value.package === PACKAGE_NAME;
}));

var hasServiceUrl = Boolean(window.serviceUrls.find(function(value){
    return value.package === PACKAGE_NAME;
}));

if(!hasTemplateUrl){
    window.templateUrls.push({
        package: PACKAGE_NAME,
        baseUrl: 'bower_components/zh-filter-preferences/dist/templates/'
    });
}

if(!hasMetadataUrl){
    window.metadataUrls.push({
        package: PACKAGE_NAME,
        baseUrl: 'bower_components/zh-filter-preferences/dist/assets/'
    });
}

if(!hasServiceUrl){
    window.serviceUrls.push({
        package: PACKAGE_NAME,
        baseUrl: '../backend/service/index.php/zh-preferences'
    });
}

})();


// FILE: ./bower_components/zh-grid-configuration/dist/zh-grid-configuration.js

// FILE: bower_components/sortablejs/Sortable.js
/**!
 * Sortable 1.15.0
 * @author	RubaXa   <trash@rubaxa.org>
 * @author	owenm    <owen23355@gmail.com>
 * @license MIT
 */
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
  typeof define === 'function' && define.amd ? define(factory) :
  (global = global || self, global.Sortable = factory());
}(this, (function () { 'use strict';

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);

    if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);

      if (enumerableOnly) {
        symbols = symbols.filter(function (sym) {
          return Object.getOwnPropertyDescriptor(object, sym).enumerable;
        });
      }

      keys.push.apply(keys, symbols);
    }

    return keys;
  }

  function _objectSpread2(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};

      if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }

    return target;
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";

    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function (obj) {
        return typeof obj;
      };
    } else {
      _typeof = function (obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }

    return _typeof(obj);
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
    } else {
      obj[key] = value;
    }

    return obj;
  }

  function _extends() {
    _extends = Object.assign || function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];

        for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }

      return target;
    };

    return _extends.apply(this, arguments);
  }

  function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};
    var target = {};
    var sourceKeys = Object.keys(source);
    var key, i;

    for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      target[key] = source[key];
    }

    return target;
  }

  function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};

    var target = _objectWithoutPropertiesLoose(source, excluded);

    var key, i;

    if (Object.getOwnPropertySymbols) {
      var sourceSymbolKeys = Object.getOwnPropertySymbols(source);

      for (i = 0; i < sourceSymbolKeys.length; i++) {
        key = sourceSymbolKeys[i];
        if (excluded.indexOf(key) >= 0) continue;
        if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
        target[key] = source[key];
      }
    }

    return target;
  }

  function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread();
  }

  function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) return _arrayLikeToArray(arr);
  }

  function _iterableToArray(iter) {
    if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter);
  }

  function _unsupportedIterableToArray(o, minLen) {
    if (!o) return;
    if (typeof o === "string") return _arrayLikeToArray(o, minLen);
    var n = Object.prototype.toString.call(o).slice(8, -1);
    if (n === "Object" && o.constructor) n = o.constructor.name;
    if (n === "Map" || n === "Set") return Array.from(o);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
  }

  function _arrayLikeToArray(arr, len) {
    if (len == null || len > arr.length) len = arr.length;

    for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

    return arr2;
  }

  function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }

  var version = "1.15.0";

  function userAgent(pattern) {
    if (typeof window !== 'undefined' && window.navigator) {
      return !! /*@__PURE__*/navigator.userAgent.match(pattern);
    }
  }

  var IE11OrLess = userAgent(/(?:Trident.*rv[ :]?11\.|msie|iemobile|Windows Phone)/i);
  var Edge = userAgent(/Edge/i);
  var FireFox = userAgent(/firefox/i);
  var Safari = userAgent(/safari/i) && !userAgent(/chrome/i) && !userAgent(/android/i);
  var IOS = userAgent(/iP(ad|od|hone)/i);
  var ChromeForAndroid = userAgent(/chrome/i) && userAgent(/android/i);

  var captureMode = {
    capture: false,
    passive: false
  };

  function on(el, event, fn) {
    el.addEventListener(event, fn, !IE11OrLess && captureMode);
  }

  function off(el, event, fn) {
    el.removeEventListener(event, fn, !IE11OrLess && captureMode);
  }

  function matches(
  /**HTMLElement*/
  el,
  /**String*/
  selector) {
    if (!selector) return;
    selector[0] === '>' && (selector = selector.substring(1));

    if (el) {
      try {
        if (el.matches) {
          return el.matches(selector);
        } else if (el.msMatchesSelector) {
          return el.msMatchesSelector(selector);
        } else if (el.webkitMatchesSelector) {
          return el.webkitMatchesSelector(selector);
        }
      } catch (_) {
        return false;
      }
    }

    return false;
  }

  function getParentOrHost(el) {
    return el.host && el !== document && el.host.nodeType ? el.host : el.parentNode;
  }

  function closest(
  /**HTMLElement*/
  el,
  /**String*/
  selector,
  /**HTMLElement*/
  ctx, includeCTX) {
    if (el) {
      ctx = ctx || document;

      do {
        if (selector != null && (selector[0] === '>' ? el.parentNode === ctx && matches(el, selector) : matches(el, selector)) || includeCTX && el === ctx) {
          return el;
        }

        if (el === ctx) break;
        /* jshint boss:true */
      } while (el = getParentOrHost(el));
    }

    return null;
  }

  var R_SPACE = /\s+/g;

  function toggleClass(el, name, state) {
    if (el && name) {
      if (el.classList) {
        el.classList[state ? 'add' : 'remove'](name);
      } else {
        var className = (' ' + el.className + ' ').replace(R_SPACE, ' ').replace(' ' + name + ' ', ' ');
        el.className = (className + (state ? ' ' + name : '')).replace(R_SPACE, ' ');
      }
    }
  }

  function css(el, prop, val) {
    var style = el && el.style;

    if (style) {
      if (val === void 0) {
        if (document.defaultView && document.defaultView.getComputedStyle) {
          val = document.defaultView.getComputedStyle(el, '');
        } else if (el.currentStyle) {
          val = el.currentStyle;
        }

        return prop === void 0 ? val : val[prop];
      } else {
        if (!(prop in style) && prop.indexOf('webkit') === -1) {
          prop = '-webkit-' + prop;
        }

        style[prop] = val + (typeof val === 'string' ? '' : 'px');
      }
    }
  }

  function matrix(el, selfOnly) {
    var appliedTransforms = '';

    if (typeof el === 'string') {
      appliedTransforms = el;
    } else {
      do {
        var transform = css(el, 'transform');

        if (transform && transform !== 'none') {
          appliedTransforms = transform + ' ' + appliedTransforms;
        }
        /* jshint boss:true */

      } while (!selfOnly && (el = el.parentNode));
    }

    var matrixFn = window.DOMMatrix || window.WebKitCSSMatrix || window.CSSMatrix || window.MSCSSMatrix;
    /*jshint -W056 */

    return matrixFn && new matrixFn(appliedTransforms);
  }

  function find(ctx, tagName, iterator) {
    if (ctx) {
      var list = ctx.getElementsByTagName(tagName),
          i = 0,
          n = list.length;

      if (iterator) {
        for (; i < n; i++) {
          iterator(list[i], i);
        }
      }

      return list;
    }

    return [];
  }

  function getWindowScrollingElement() {
    var scrollingElement = document.scrollingElement;

    if (scrollingElement) {
      return scrollingElement;
    } else {
      return document.documentElement;
    }
  }
  /**
   * Returns the "bounding client rect" of given element
   * @param  {HTMLElement} el                       The element whose boundingClientRect is wanted
   * @param  {[Boolean]} relativeToContainingBlock  Whether the rect should be relative to the containing block of (including) the container
   * @param  {[Boolean]} relativeToNonStaticParent  Whether the rect should be relative to the relative parent of (including) the contaienr
   * @param  {[Boolean]} undoScale                  Whether the container's scale() should be undone
   * @param  {[HTMLElement]} container              The parent the element will be placed in
   * @return {Object}                               The boundingClientRect of el, with specified adjustments
   */


  function getRect(el, relativeToContainingBlock, relativeToNonStaticParent, undoScale, container) {
    if (!el.getBoundingClientRect && el !== window) return;
    var elRect, top, left, bottom, right, height, width;

    if (el !== window && el.parentNode && el !== getWindowScrollingElement()) {
      elRect = el.getBoundingClientRect();
      top = elRect.top;
      left = elRect.left;
      bottom = elRect.bottom;
      right = elRect.right;
      height = elRect.height;
      width = elRect.width;
    } else {
      top = 0;
      left = 0;
      bottom = window.innerHeight;
      right = window.innerWidth;
      height = window.innerHeight;
      width = window.innerWidth;
    }

    if ((relativeToContainingBlock || relativeToNonStaticParent) && el !== window) {
      // Adjust for translate()
      container = container || el.parentNode; // solves #1123 (see: https://stackoverflow.com/a/37953806/6088312)
      // Not needed on <= IE11

      if (!IE11OrLess) {
        do {
          if (container && container.getBoundingClientRect && (css(container, 'transform') !== 'none' || relativeToNonStaticParent && css(container, 'position') !== 'static')) {
            var containerRect = container.getBoundingClientRect(); // Set relative to edges of padding box of container

            top -= containerRect.top + parseInt(css(container, 'border-top-width'));
            left -= containerRect.left + parseInt(css(container, 'border-left-width'));
            bottom = top + elRect.height;
            right = left + elRect.width;
            break;
          }
          /* jshint boss:true */

        } while (container = container.parentNode);
      }
    }

    if (undoScale && el !== window) {
      // Adjust for scale()
      var elMatrix = matrix(container || el),
          scaleX = elMatrix && elMatrix.a,
          scaleY = elMatrix && elMatrix.d;

      if (elMatrix) {
        top /= scaleY;
        left /= scaleX;
        width /= scaleX;
        height /= scaleY;
        bottom = top + height;
        right = left + width;
      }
    }

    return {
      top: top,
      left: left,
      bottom: bottom,
      right: right,
      width: width,
      height: height
    };
  }
  /**
   * Checks if a side of an element is scrolled past a side of its parents
   * @param  {HTMLElement}  el           The element who's side being scrolled out of view is in question
   * @param  {String}       elSide       Side of the element in question ('top', 'left', 'right', 'bottom')
   * @param  {String}       parentSide   Side of the parent in question ('top', 'left', 'right', 'bottom')
   * @return {HTMLElement}               The parent scroll element that the el's side is scrolled past, or null if there is no such element
   */


  function isScrolledPast(el, elSide, parentSide) {
    var parent = getParentAutoScrollElement(el, true),
        elSideVal = getRect(el)[elSide];
    /* jshint boss:true */

    while (parent) {
      var parentSideVal = getRect(parent)[parentSide],
          visible = void 0;

      if (parentSide === 'top' || parentSide === 'left') {
        visible = elSideVal >= parentSideVal;
      } else {
        visible = elSideVal <= parentSideVal;
      }

      if (!visible) return parent;
      if (parent === getWindowScrollingElement()) break;
      parent = getParentAutoScrollElement(parent, false);
    }

    return false;
  }
  /**
   * Gets nth child of el, ignoring hidden children, sortable's elements (does not ignore clone if it's visible)
   * and non-draggable elements
   * @param  {HTMLElement} el       The parent element
   * @param  {Number} childNum      The index of the child
   * @param  {Object} options       Parent Sortable's options
   * @return {HTMLElement}          The child at index childNum, or null if not found
   */


  function getChild(el, childNum, options, includeDragEl) {
    var currentChild = 0,
        i = 0,
        children = el.children;

    while (i < children.length) {
      if (children[i].style.display !== 'none' && children[i] !== Sortable.ghost && (includeDragEl || children[i] !== Sortable.dragged) && closest(children[i], options.draggable, el, false)) {
        if (currentChild === childNum) {
          return children[i];
        }

        currentChild++;
      }

      i++;
    }

    return null;
  }
  /**
   * Gets the last child in the el, ignoring ghostEl or invisible elements (clones)
   * @param  {HTMLElement} el       Parent element
   * @param  {selector} selector    Any other elements that should be ignored
   * @return {HTMLElement}          The last child, ignoring ghostEl
   */


  function lastChild(el, selector) {
    var last = el.lastElementChild;

    while (last && (last === Sortable.ghost || css(last, 'display') === 'none' || selector && !matches(last, selector))) {
      last = last.previousElementSibling;
    }

    return last || null;
  }
  /**
   * Returns the index of an element within its parent for a selected set of
   * elements
   * @param  {HTMLElement} el
   * @param  {selector} selector
   * @return {number}
   */


  function index(el, selector) {
    var index = 0;

    if (!el || !el.parentNode) {
      return -1;
    }
    /* jshint boss:true */


    while (el = el.previousElementSibling) {
      if (el.nodeName.toUpperCase() !== 'TEMPLATE' && el !== Sortable.clone && (!selector || matches(el, selector))) {
        index++;
      }
    }

    return index;
  }
  /**
   * Returns the scroll offset of the given element, added with all the scroll offsets of parent elements.
   * The value is returned in real pixels.
   * @param  {HTMLElement} el
   * @return {Array}             Offsets in the format of [left, top]
   */


  function getRelativeScrollOffset(el) {
    var offsetLeft = 0,
        offsetTop = 0,
        winScroller = getWindowScrollingElement();

    if (el) {
      do {
        var elMatrix = matrix(el),
            scaleX = elMatrix.a,
            scaleY = elMatrix.d;
        offsetLeft += el.scrollLeft * scaleX;
        offsetTop += el.scrollTop * scaleY;
      } while (el !== winScroller && (el = el.parentNode));
    }

    return [offsetLeft, offsetTop];
  }
  /**
   * Returns the index of the object within the given array
   * @param  {Array} arr   Array that may or may not hold the object
   * @param  {Object} obj  An object that has a key-value pair unique to and identical to a key-value pair in the object you want to find
   * @return {Number}      The index of the object in the array, or -1
   */


  function indexOfObject(arr, obj) {
    for (var i in arr) {
      if (!arr.hasOwnProperty(i)) continue;

      for (var key in obj) {
        if (obj.hasOwnProperty(key) && obj[key] === arr[i][key]) return Number(i);
      }
    }

    return -1;
  }

  function getParentAutoScrollElement(el, includeSelf) {
    // skip to window
    if (!el || !el.getBoundingClientRect) return getWindowScrollingElement();
    var elem = el;
    var gotSelf = false;

    do {
      // we don't need to get elem css if it isn't even overflowing in the first place (performance)
      if (elem.clientWidth < elem.scrollWidth || elem.clientHeight < elem.scrollHeight) {
        var elemCSS = css(elem);

        if (elem.clientWidth < elem.scrollWidth && (elemCSS.overflowX == 'auto' || elemCSS.overflowX == 'scroll') || elem.clientHeight < elem.scrollHeight && (elemCSS.overflowY == 'auto' || elemCSS.overflowY == 'scroll')) {
          if (!elem.getBoundingClientRect || elem === document.body) return getWindowScrollingElement();
          if (gotSelf || includeSelf) return elem;
          gotSelf = true;
        }
      }
      /* jshint boss:true */

    } while (elem = elem.parentNode);

    return getWindowScrollingElement();
  }

  function extend(dst, src) {
    if (dst && src) {
      for (var key in src) {
        if (src.hasOwnProperty(key)) {
          dst[key] = src[key];
        }
      }
    }

    return dst;
  }

  function isRectEqual(rect1, rect2) {
    return Math.round(rect1.top) === Math.round(rect2.top) && Math.round(rect1.left) === Math.round(rect2.left) && Math.round(rect1.height) === Math.round(rect2.height) && Math.round(rect1.width) === Math.round(rect2.width);
  }

  var _throttleTimeout;

  function throttle(callback, ms) {
    return function () {
      if (!_throttleTimeout) {
        var args = arguments,
            _this = this;

        if (args.length === 1) {
          callback.call(_this, args[0]);
        } else {
          callback.apply(_this, args);
        }

        _throttleTimeout = setTimeout(function () {
          _throttleTimeout = void 0;
        }, ms);
      }
    };
  }

  function cancelThrottle() {
    clearTimeout(_throttleTimeout);
    _throttleTimeout = void 0;
  }

  function scrollBy(el, x, y) {
    el.scrollLeft += x;
    el.scrollTop += y;
  }

  function clone(el) {
    var Polymer = window.Polymer;
    var $ = window.jQuery || window.Zepto;

    if (Polymer && Polymer.dom) {
      return Polymer.dom(el).cloneNode(true);
    } else if ($) {
      return $(el).clone(true)[0];
    } else {
      return el.cloneNode(true);
    }
  }

  function setRect(el, rect) {
    css(el, 'position', 'absolute');
    css(el, 'top', rect.top);
    css(el, 'left', rect.left);
    css(el, 'width', rect.width);
    css(el, 'height', rect.height);
  }

  function unsetRect(el) {
    css(el, 'position', '');
    css(el, 'top', '');
    css(el, 'left', '');
    css(el, 'width', '');
    css(el, 'height', '');
  }

  var expando = 'Sortable' + new Date().getTime();

  function AnimationStateManager() {
    var animationStates = [],
        animationCallbackId;
    return {
      captureAnimationState: function captureAnimationState() {
        animationStates = [];
        if (!this.options.animation) return;
        var children = [].slice.call(this.el.children);
        children.forEach(function (child) {
          if (css(child, 'display') === 'none' || child === Sortable.ghost) return;
          animationStates.push({
            target: child,
            rect: getRect(child)
          });

          var fromRect = _objectSpread2({}, animationStates[animationStates.length - 1].rect); // If animating: compensate for current animation


          if (child.thisAnimationDuration) {
            var childMatrix = matrix(child, true);

            if (childMatrix) {
              fromRect.top -= childMatrix.f;
              fromRect.left -= childMatrix.e;
            }
          }

          child.fromRect = fromRect;
        });
      },
      addAnimationState: function addAnimationState(state) {
        animationStates.push(state);
      },
      removeAnimationState: function removeAnimationState(target) {
        animationStates.splice(indexOfObject(animationStates, {
          target: target
        }), 1);
      },
      animateAll: function animateAll(callback) {
        var _this = this;

        if (!this.options.animation) {
          clearTimeout(animationCallbackId);
          if (typeof callback === 'function') callback();
          return;
        }

        var animating = false,
            animationTime = 0;
        animationStates.forEach(function (state) {
          var time = 0,
              target = state.target,
              fromRect = target.fromRect,
              toRect = getRect(target),
              prevFromRect = target.prevFromRect,
              prevToRect = target.prevToRect,
              animatingRect = state.rect,
              targetMatrix = matrix(target, true);

          if (targetMatrix) {
            // Compensate for current animation
            toRect.top -= targetMatrix.f;
            toRect.left -= targetMatrix.e;
          }

          target.toRect = toRect;

          if (target.thisAnimationDuration) {
            // Could also check if animatingRect is between fromRect and toRect
            if (isRectEqual(prevFromRect, toRect) && !isRectEqual(fromRect, toRect) && // Make sure animatingRect is on line between toRect & fromRect
            (animatingRect.top - toRect.top) / (animatingRect.left - toRect.left) === (fromRect.top - toRect.top) / (fromRect.left - toRect.left)) {
              // If returning to same place as started from animation and on same axis
              time = calculateRealTime(animatingRect, prevFromRect, prevToRect, _this.options);
            }
          } // if fromRect != toRect: animate


          if (!isRectEqual(toRect, fromRect)) {
            target.prevFromRect = fromRect;
            target.prevToRect = toRect;

            if (!time) {
              time = _this.options.animation;
            }

            _this.animate(target, animatingRect, toRect, time);
          }

          if (time) {
            animating = true;
            animationTime = Math.max(animationTime, time);
            clearTimeout(target.animationResetTimer);
            target.animationResetTimer = setTimeout(function () {
              target.animationTime = 0;
              target.prevFromRect = null;
              target.fromRect = null;
              target.prevToRect = null;
              target.thisAnimationDuration = null;
            }, time);
            target.thisAnimationDuration = time;
          }
        });
        clearTimeout(animationCallbackId);

        if (!animating) {
          if (typeof callback === 'function') callback();
        } else {
          animationCallbackId = setTimeout(function () {
            if (typeof callback === 'function') callback();
          }, animationTime);
        }

        animationStates = [];
      },
      animate: function animate(target, currentRect, toRect, duration) {
        if (duration) {
          css(target, 'transition', '');
          css(target, 'transform', '');
          var elMatrix = matrix(this.el),
              scaleX = elMatrix && elMatrix.a,
              scaleY = elMatrix && elMatrix.d,
              translateX = (currentRect.left - toRect.left) / (scaleX || 1),
              translateY = (currentRect.top - toRect.top) / (scaleY || 1);
          target.animatingX = !!translateX;
          target.animatingY = !!translateY;
          css(target, 'transform', 'translate3d(' + translateX + 'px,' + translateY + 'px,0)');
          this.forRepaintDummy = repaint(target); // repaint

          css(target, 'transition', 'transform ' + duration + 'ms' + (this.options.easing ? ' ' + this.options.easing : ''));
          css(target, 'transform', 'translate3d(0,0,0)');
          typeof target.animated === 'number' && clearTimeout(target.animated);
          target.animated = setTimeout(function () {
            css(target, 'transition', '');
            css(target, 'transform', '');
            target.animated = false;
            target.animatingX = false;
            target.animatingY = false;
          }, duration);
        }
      }
    };
  }

  function repaint(target) {
    return target.offsetWidth;
  }

  function calculateRealTime(animatingRect, fromRect, toRect, options) {
    return Math.sqrt(Math.pow(fromRect.top - animatingRect.top, 2) + Math.pow(fromRect.left - animatingRect.left, 2)) / Math.sqrt(Math.pow(fromRect.top - toRect.top, 2) + Math.pow(fromRect.left - toRect.left, 2)) * options.animation;
  }

  var plugins = [];
  var defaults = {
    initializeByDefault: true
  };
  var PluginManager = {
    mount: function mount(plugin) {
      // Set default static properties
      for (var option in defaults) {
        if (defaults.hasOwnProperty(option) && !(option in plugin)) {
          plugin[option] = defaults[option];
        }
      }

      plugins.forEach(function (p) {
        if (p.pluginName === plugin.pluginName) {
          throw "Sortable: Cannot mount plugin ".concat(plugin.pluginName, " more than once");
        }
      });
      plugins.push(plugin);
    },
    pluginEvent: function pluginEvent(eventName, sortable, evt) {
      var _this = this;

      this.eventCanceled = false;

      evt.cancel = function () {
        _this.eventCanceled = true;
      };

      var eventNameGlobal = eventName + 'Global';
      plugins.forEach(function (plugin) {
        if (!sortable[plugin.pluginName]) return; // Fire global events if it exists in this sortable

        if (sortable[plugin.pluginName][eventNameGlobal]) {
          sortable[plugin.pluginName][eventNameGlobal](_objectSpread2({
            sortable: sortable
          }, evt));
        } // Only fire plugin event if plugin is enabled in this sortable,
        // and plugin has event defined


        if (sortable.options[plugin.pluginName] && sortable[plugin.pluginName][eventName]) {
          sortable[plugin.pluginName][eventName](_objectSpread2({
            sortable: sortable
          }, evt));
        }
      });
    },
    initializePlugins: function initializePlugins(sortable, el, defaults, options) {
      plugins.forEach(function (plugin) {
        var pluginName = plugin.pluginName;
        if (!sortable.options[pluginName] && !plugin.initializeByDefault) return;
        var initialized = new plugin(sortable, el, sortable.options);
        initialized.sortable = sortable;
        initialized.options = sortable.options;
        sortable[pluginName] = initialized; // Add default options from plugin

        _extends(defaults, initialized.defaults);
      });

      for (var option in sortable.options) {
        if (!sortable.options.hasOwnProperty(option)) continue;
        var modified = this.modifyOption(sortable, option, sortable.options[option]);

        if (typeof modified !== 'undefined') {
          sortable.options[option] = modified;
        }
      }
    },
    getEventProperties: function getEventProperties(name, sortable) {
      var eventProperties = {};
      plugins.forEach(function (plugin) {
        if (typeof plugin.eventProperties !== 'function') return;

        _extends(eventProperties, plugin.eventProperties.call(sortable[plugin.pluginName], name));
      });
      return eventProperties;
    },
    modifyOption: function modifyOption(sortable, name, value) {
      var modifiedValue;
      plugins.forEach(function (plugin) {
        // Plugin must exist on the Sortable
        if (!sortable[plugin.pluginName]) return; // If static option listener exists for this option, call in the context of the Sortable's instance of this plugin

        if (plugin.optionListeners && typeof plugin.optionListeners[name] === 'function') {
          modifiedValue = plugin.optionListeners[name].call(sortable[plugin.pluginName], value);
        }
      });
      return modifiedValue;
    }
  };

  function dispatchEvent(_ref) {
    var sortable = _ref.sortable,
        rootEl = _ref.rootEl,
        name = _ref.name,
        targetEl = _ref.targetEl,
        cloneEl = _ref.cloneEl,
        toEl = _ref.toEl,
        fromEl = _ref.fromEl,
        oldIndex = _ref.oldIndex,
        newIndex = _ref.newIndex,
        oldDraggableIndex = _ref.oldDraggableIndex,
        newDraggableIndex = _ref.newDraggableIndex,
        originalEvent = _ref.originalEvent,
        putSortable = _ref.putSortable,
        extraEventProperties = _ref.extraEventProperties;
    sortable = sortable || rootEl && rootEl[expando];
    if (!sortable) return;
    var evt,
        options = sortable.options,
        onName = 'on' + name.charAt(0).toUpperCase() + name.substr(1); // Support for new CustomEvent feature

    if (window.CustomEvent && !IE11OrLess && !Edge) {
      evt = new CustomEvent(name, {
        bubbles: true,
        cancelable: true
      });
    } else {
      evt = document.createEvent('Event');
      evt.initEvent(name, true, true);
    }

    evt.to = toEl || rootEl;
    evt.from = fromEl || rootEl;
    evt.item = targetEl || rootEl;
    evt.clone = cloneEl;
    evt.oldIndex = oldIndex;
    evt.newIndex = newIndex;
    evt.oldDraggableIndex = oldDraggableIndex;
    evt.newDraggableIndex = newDraggableIndex;
    evt.originalEvent = originalEvent;
    evt.pullMode = putSortable ? putSortable.lastPutMode : undefined;

    var allEventProperties = _objectSpread2(_objectSpread2({}, extraEventProperties), PluginManager.getEventProperties(name, sortable));

    for (var option in allEventProperties) {
      evt[option] = allEventProperties[option];
    }

    if (rootEl) {
      rootEl.dispatchEvent(evt);
    }

    if (options[onName]) {
      options[onName].call(sortable, evt);
    }
  }

  var _excluded = ["evt"];

  var pluginEvent = function pluginEvent(eventName, sortable) {
    var _ref = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {},
        originalEvent = _ref.evt,
        data = _objectWithoutProperties(_ref, _excluded);

    PluginManager.pluginEvent.bind(Sortable)(eventName, sortable, _objectSpread2({
      dragEl: dragEl,
      parentEl: parentEl,
      ghostEl: ghostEl,
      rootEl: rootEl,
      nextEl: nextEl,
      lastDownEl: lastDownEl,
      cloneEl: cloneEl,
      cloneHidden: cloneHidden,
      dragStarted: moved,
      putSortable: putSortable,
      activeSortable: Sortable.active,
      originalEvent: originalEvent,
      oldIndex: oldIndex,
      oldDraggableIndex: oldDraggableIndex,
      newIndex: newIndex,
      newDraggableIndex: newDraggableIndex,
      hideGhostForTarget: _hideGhostForTarget,
      unhideGhostForTarget: _unhideGhostForTarget,
      cloneNowHidden: function cloneNowHidden() {
        cloneHidden = true;
      },
      cloneNowShown: function cloneNowShown() {
        cloneHidden = false;
      },
      dispatchSortableEvent: function dispatchSortableEvent(name) {
        _dispatchEvent({
          sortable: sortable,
          name: name,
          originalEvent: originalEvent
        });
      }
    }, data));
  };

  function _dispatchEvent(info) {
    dispatchEvent(_objectSpread2({
      putSortable: putSortable,
      cloneEl: cloneEl,
      targetEl: dragEl,
      rootEl: rootEl,
      oldIndex: oldIndex,
      oldDraggableIndex: oldDraggableIndex,
      newIndex: newIndex,
      newDraggableIndex: newDraggableIndex
    }, info));
  }

  var dragEl,
      parentEl,
      ghostEl,
      rootEl,
      nextEl,
      lastDownEl,
      cloneEl,
      cloneHidden,
      oldIndex,
      newIndex,
      oldDraggableIndex,
      newDraggableIndex,
      activeGroup,
      putSortable,
      awaitingDragStarted = false,
      ignoreNextClick = false,
      sortables = [],
      tapEvt,
      touchEvt,
      lastDx,
      lastDy,
      tapDistanceLeft,
      tapDistanceTop,
      moved,
      lastTarget,
      lastDirection,
      pastFirstInvertThresh = false,
      isCircumstantialInvert = false,
      targetMoveDistance,
      // For positioning ghost absolutely
  ghostRelativeParent,
      ghostRelativeParentInitialScroll = [],
      // (left, top)
  _silent = false,
      savedInputChecked = [];
  /** @const */

  var documentExists = typeof document !== 'undefined',
      PositionGhostAbsolutely = IOS,
      CSSFloatProperty = Edge || IE11OrLess ? 'cssFloat' : 'float',
      // This will not pass for IE9, because IE9 DnD only works on anchors
  supportDraggable = documentExists && !ChromeForAndroid && !IOS && 'draggable' in document.createElement('div'),
      supportCssPointerEvents = function () {
    if (!documentExists) return; // false when <= IE11

    if (IE11OrLess) {
      return false;
    }

    var el = document.createElement('x');
    el.style.cssText = 'pointer-events:auto';
    return el.style.pointerEvents === 'auto';
  }(),
      _detectDirection = function _detectDirection(el, options) {
    var elCSS = css(el),
        elWidth = parseInt(elCSS.width) - parseInt(elCSS.paddingLeft) - parseInt(elCSS.paddingRight) - parseInt(elCSS.borderLeftWidth) - parseInt(elCSS.borderRightWidth),
        child1 = getChild(el, 0, options),
        child2 = getChild(el, 1, options),
        firstChildCSS = child1 && css(child1),
        secondChildCSS = child2 && css(child2),
        firstChildWidth = firstChildCSS && parseInt(firstChildCSS.marginLeft) + parseInt(firstChildCSS.marginRight) + getRect(child1).width,
        secondChildWidth = secondChildCSS && parseInt(secondChildCSS.marginLeft) + parseInt(secondChildCSS.marginRight) + getRect(child2).width;

    if (elCSS.display === 'flex') {
      return elCSS.flexDirection === 'column' || elCSS.flexDirection === 'column-reverse' ? 'vertical' : 'horizontal';
    }

    if (elCSS.display === 'grid') {
      return elCSS.gridTemplateColumns.split(' ').length <= 1 ? 'vertical' : 'horizontal';
    }

    if (child1 && firstChildCSS["float"] && firstChildCSS["float"] !== 'none') {
      var touchingSideChild2 = firstChildCSS["float"] === 'left' ? 'left' : 'right';
      return child2 && (secondChildCSS.clear === 'both' || secondChildCSS.clear === touchingSideChild2) ? 'vertical' : 'horizontal';
    }

    return child1 && (firstChildCSS.display === 'block' || firstChildCSS.display === 'flex' || firstChildCSS.display === 'table' || firstChildCSS.display === 'grid' || firstChildWidth >= elWidth && elCSS[CSSFloatProperty] === 'none' || child2 && elCSS[CSSFloatProperty] === 'none' && firstChildWidth + secondChildWidth > elWidth) ? 'vertical' : 'horizontal';
  },
      _dragElInRowColumn = function _dragElInRowColumn(dragRect, targetRect, vertical) {
    var dragElS1Opp = vertical ? dragRect.left : dragRect.top,
        dragElS2Opp = vertical ? dragRect.right : dragRect.bottom,
        dragElOppLength = vertical ? dragRect.width : dragRect.height,
        targetS1Opp = vertical ? targetRect.left : targetRect.top,
        targetS2Opp = vertical ? targetRect.right : targetRect.bottom,
        targetOppLength = vertical ? targetRect.width : targetRect.height;
    return dragElS1Opp === targetS1Opp || dragElS2Opp === targetS2Opp || dragElS1Opp + dragElOppLength / 2 === targetS1Opp + targetOppLength / 2;
  },

  /**
   * Detects first nearest empty sortable to X and Y position using emptyInsertThreshold.
   * @param  {Number} x      X position
   * @param  {Number} y      Y position
   * @return {HTMLElement}   Element of the first found nearest Sortable
   */
  _detectNearestEmptySortable = function _detectNearestEmptySortable(x, y) {
    var ret;
    sortables.some(function (sortable) {
      var threshold = sortable[expando].options.emptyInsertThreshold;
      if (!threshold || lastChild(sortable)) return;
      var rect = getRect(sortable),
          insideHorizontally = x >= rect.left - threshold && x <= rect.right + threshold,
          insideVertically = y >= rect.top - threshold && y <= rect.bottom + threshold;

      if (insideHorizontally && insideVertically) {
        return ret = sortable;
      }
    });
    return ret;
  },
      _prepareGroup = function _prepareGroup(options) {
    function toFn(value, pull) {
      return function (to, from, dragEl, evt) {
        var sameGroup = to.options.group.name && from.options.group.name && to.options.group.name === from.options.group.name;

        if (value == null && (pull || sameGroup)) {
          // Default pull value
          // Default pull and put value if same group
          return true;
        } else if (value == null || value === false) {
          return false;
        } else if (pull && value === 'clone') {
          return value;
        } else if (typeof value === 'function') {
          return toFn(value(to, from, dragEl, evt), pull)(to, from, dragEl, evt);
        } else {
          var otherGroup = (pull ? to : from).options.group.name;
          return value === true || typeof value === 'string' && value === otherGroup || value.join && value.indexOf(otherGroup) > -1;
        }
      };
    }

    var group = {};
    var originalGroup = options.group;

    if (!originalGroup || _typeof(originalGroup) != 'object') {
      originalGroup = {
        name: originalGroup
      };
    }

    group.name = originalGroup.name;
    group.checkPull = toFn(originalGroup.pull, true);
    group.checkPut = toFn(originalGroup.put);
    group.revertClone = originalGroup.revertClone;
    options.group = group;
  },
      _hideGhostForTarget = function _hideGhostForTarget() {
    if (!supportCssPointerEvents && ghostEl) {
      css(ghostEl, 'display', 'none');
    }
  },
      _unhideGhostForTarget = function _unhideGhostForTarget() {
    if (!supportCssPointerEvents && ghostEl) {
      css(ghostEl, 'display', '');
    }
  }; // #1184 fix - Prevent click event on fallback if dragged but item not changed position


  if (documentExists && !ChromeForAndroid) {
    document.addEventListener('click', function (evt) {
      if (ignoreNextClick) {
        evt.preventDefault();
        evt.stopPropagation && evt.stopPropagation();
        evt.stopImmediatePropagation && evt.stopImmediatePropagation();
        ignoreNextClick = false;
        return false;
      }
    }, true);
  }

  var nearestEmptyInsertDetectEvent = function nearestEmptyInsertDetectEvent(evt) {
    if (dragEl) {
      evt = evt.touches ? evt.touches[0] : evt;

      var nearest = _detectNearestEmptySortable(evt.clientX, evt.clientY);

      if (nearest) {
        // Create imitation event
        var event = {};

        for (var i in evt) {
          if (evt.hasOwnProperty(i)) {
            event[i] = evt[i];
          }
        }

        event.target = event.rootEl = nearest;
        event.preventDefault = void 0;
        event.stopPropagation = void 0;

        nearest[expando]._onDragOver(event);
      }
    }
  };

  var _checkOutsideTargetEl = function _checkOutsideTargetEl(evt) {
    if (dragEl) {
      dragEl.parentNode[expando]._isOutsideThisEl(evt.target);
    }
  };
  /**
   * @class  Sortable
   * @param  {HTMLElement}  el
   * @param  {Object}       [options]
   */


  function Sortable(el, options) {
    if (!(el && el.nodeType && el.nodeType === 1)) {
      throw "Sortable: `el` must be an HTMLElement, not ".concat({}.toString.call(el));
    }

    this.el = el; // root element

    this.options = options = _extends({}, options); // Export instance

    el[expando] = this;
    var defaults = {
      group: null,
      sort: true,
      disabled: false,
      store: null,
      handle: null,
      draggable: /^[uo]l$/i.test(el.nodeName) ? '>li' : '>*',
      swapThreshold: 1,
      // percentage; 0 <= x <= 1
      invertSwap: false,
      // invert always
      invertedSwapThreshold: null,
      // will be set to same as swapThreshold if default
      removeCloneOnHide: true,
      direction: function direction() {
        return _detectDirection(el, this.options);
      },
      ghostClass: 'sortable-ghost',
      chosenClass: 'sortable-chosen',
      dragClass: 'sortable-drag',
      ignore: 'a, img',
      filter: null,
      preventOnFilter: true,
      animation: 0,
      easing: null,
      setData: function setData(dataTransfer, dragEl) {
        dataTransfer.setData('Text', dragEl.textContent);
      },
      dropBubble: false,
      dragoverBubble: false,
      dataIdAttr: 'data-id',
      delay: 0,
      delayOnTouchOnly: false,
      touchStartThreshold: (Number.parseInt ? Number : window).parseInt(window.devicePixelRatio, 10) || 1,
      forceFallback: false,
      fallbackClass: 'sortable-fallback',
      fallbackOnBody: false,
      fallbackTolerance: 0,
      fallbackOffset: {
        x: 0,
        y: 0
      },
      supportPointer: Sortable.supportPointer !== false && 'PointerEvent' in window && !Safari,
      emptyInsertThreshold: 5
    };
    PluginManager.initializePlugins(this, el, defaults); // Set default options

    for (var name in defaults) {
      !(name in options) && (options[name] = defaults[name]);
    }

    _prepareGroup(options); // Bind all private methods


    for (var fn in this) {
      if (fn.charAt(0) === '_' && typeof this[fn] === 'function') {
        this[fn] = this[fn].bind(this);
      }
    } // Setup drag mode


    this.nativeDraggable = options.forceFallback ? false : supportDraggable;

    if (this.nativeDraggable) {
      // Touch start threshold cannot be greater than the native dragstart threshold
      this.options.touchStartThreshold = 1;
    } // Bind events


    if (options.supportPointer) {
      on(el, 'pointerdown', this._onTapStart);
    } else {
      on(el, 'mousedown', this._onTapStart);
      on(el, 'touchstart', this._onTapStart);
    }

    if (this.nativeDraggable) {
      on(el, 'dragover', this);
      on(el, 'dragenter', this);
    }

    sortables.push(this.el); // Restore sorting

    options.store && options.store.get && this.sort(options.store.get(this) || []); // Add animation state manager

    _extends(this, AnimationStateManager());
  }

  Sortable.prototype =
  /** @lends Sortable.prototype */
  {
    constructor: Sortable,
    _isOutsideThisEl: function _isOutsideThisEl(target) {
      if (!this.el.contains(target) && target !== this.el) {
        lastTarget = null;
      }
    },
    _getDirection: function _getDirection(evt, target) {
      return typeof this.options.direction === 'function' ? this.options.direction.call(this, evt, target, dragEl) : this.options.direction;
    },
    _onTapStart: function _onTapStart(
    /** Event|TouchEvent */
    evt) {
      if (!evt.cancelable) return;

      var _this = this,
          el = this.el,
          options = this.options,
          preventOnFilter = options.preventOnFilter,
          type = evt.type,
          touch = evt.touches && evt.touches[0] || evt.pointerType && evt.pointerType === 'touch' && evt,
          target = (touch || evt).target,
          originalTarget = evt.target.shadowRoot && (evt.path && evt.path[0] || evt.composedPath && evt.composedPath()[0]) || target,
          filter = options.filter;

      _saveInputCheckedState(el); // Don't trigger start event when an element is been dragged, otherwise the evt.oldindex always wrong when set option.group.


      if (dragEl) {
        return;
      }

      if (/mousedown|pointerdown/.test(type) && evt.button !== 0 || options.disabled) {
        return; // only left button and enabled
      } // cancel dnd if original target is content editable


      if (originalTarget.isContentEditable) {
        return;
      } // Safari ignores further event handling after mousedown


      if (!this.nativeDraggable && Safari && target && target.tagName.toUpperCase() === 'SELECT') {
        return;
      }

      target = closest(target, options.draggable, el, false);

      if (target && target.animated) {
        return;
      }

      if (lastDownEl === target) {
        // Ignoring duplicate `down`
        return;
      } // Get the index of the dragged element within its parent


      oldIndex = index(target);
      oldDraggableIndex = index(target, options.draggable); // Check filter

      if (typeof filter === 'function') {
        if (filter.call(this, evt, target, this)) {
          _dispatchEvent({
            sortable: _this,
            rootEl: originalTarget,
            name: 'filter',
            targetEl: target,
            toEl: el,
            fromEl: el
          });

          pluginEvent('filter', _this, {
            evt: evt
          });
          preventOnFilter && evt.cancelable && evt.preventDefault();
          return; // cancel dnd
        }
      } else if (filter) {
        filter = filter.split(',').some(function (criteria) {
          criteria = closest(originalTarget, criteria.trim(), el, false);

          if (criteria) {
            _dispatchEvent({
              sortable: _this,
              rootEl: criteria,
              name: 'filter',
              targetEl: target,
              fromEl: el,
              toEl: el
            });

            pluginEvent('filter', _this, {
              evt: evt
            });
            return true;
          }
        });

        if (filter) {
          preventOnFilter && evt.cancelable && evt.preventDefault();
          return; // cancel dnd
        }
      }

      if (options.handle && !closest(originalTarget, options.handle, el, false)) {
        return;
      } // Prepare `dragstart`


      this._prepareDragStart(evt, touch, target);
    },
    _prepareDragStart: function _prepareDragStart(
    /** Event */
    evt,
    /** Touch */
    touch,
    /** HTMLElement */
    target) {
      var _this = this,
          el = _this.el,
          options = _this.options,
          ownerDocument = el.ownerDocument,
          dragStartFn;

      if (target && !dragEl && target.parentNode === el) {
        var dragRect = getRect(target);
        rootEl = el;
        dragEl = target;
        parentEl = dragEl.parentNode;
        nextEl = dragEl.nextSibling;
        lastDownEl = target;
        activeGroup = options.group;
        Sortable.dragged = dragEl;
        tapEvt = {
          target: dragEl,
          clientX: (touch || evt).clientX,
          clientY: (touch || evt).clientY
        };
        tapDistanceLeft = tapEvt.clientX - dragRect.left;
        tapDistanceTop = tapEvt.clientY - dragRect.top;
        this._lastX = (touch || evt).clientX;
        this._lastY = (touch || evt).clientY;
        dragEl.style['will-change'] = 'all';

        dragStartFn = function dragStartFn() {
          pluginEvent('delayEnded', _this, {
            evt: evt
          });

          if (Sortable.eventCanceled) {
            _this._onDrop();

            return;
          } // Delayed drag has been triggered
          // we can re-enable the events: touchmove/mousemove


          _this._disableDelayedDragEvents();

          if (!FireFox && _this.nativeDraggable) {
            dragEl.draggable = true;
          } // Bind the events: dragstart/dragend


          _this._triggerDragStart(evt, touch); // Drag start event


          _dispatchEvent({
            sortable: _this,
            name: 'choose',
            originalEvent: evt
          }); // Chosen item


          toggleClass(dragEl, options.chosenClass, true);
        }; // Disable "draggable"


        options.ignore.split(',').forEach(function (criteria) {
          find(dragEl, criteria.trim(), _disableDraggable);
        });
        on(ownerDocument, 'dragover', nearestEmptyInsertDetectEvent);
        on(ownerDocument, 'mousemove', nearestEmptyInsertDetectEvent);
        on(ownerDocument, 'touchmove', nearestEmptyInsertDetectEvent);
        on(ownerDocument, 'mouseup', _this._onDrop);
        on(ownerDocument, 'touchend', _this._onDrop);
        on(ownerDocument, 'touchcancel', _this._onDrop); // Make dragEl draggable (must be before delay for FireFox)

        if (FireFox && this.nativeDraggable) {
          this.options.touchStartThreshold = 4;
          dragEl.draggable = true;
        }

        pluginEvent('delayStart', this, {
          evt: evt
        }); // Delay is impossible for native DnD in Edge or IE

        if (options.delay && (!options.delayOnTouchOnly || touch) && (!this.nativeDraggable || !(Edge || IE11OrLess))) {
          if (Sortable.eventCanceled) {
            this._onDrop();

            return;
          } // If the user moves the pointer or let go the click or touch
          // before the delay has been reached:
          // disable the delayed drag


          on(ownerDocument, 'mouseup', _this._disableDelayedDrag);
          on(ownerDocument, 'touchend', _this._disableDelayedDrag);
          on(ownerDocument, 'touchcancel', _this._disableDelayedDrag);
          on(ownerDocument, 'mousemove', _this._delayedDragTouchMoveHandler);
          on(ownerDocument, 'touchmove', _this._delayedDragTouchMoveHandler);
          options.supportPointer && on(ownerDocument, 'pointermove', _this._delayedDragTouchMoveHandler);
          _this._dragStartTimer = setTimeout(dragStartFn, options.delay);
        } else {
          dragStartFn();
        }
      }
    },
    _delayedDragTouchMoveHandler: function _delayedDragTouchMoveHandler(
    /** TouchEvent|PointerEvent **/
    e) {
      var touch = e.touches ? e.touches[0] : e;

      if (Math.max(Math.abs(touch.clientX - this._lastX), Math.abs(touch.clientY - this._lastY)) >= Math.floor(this.options.touchStartThreshold / (this.nativeDraggable && window.devicePixelRatio || 1))) {
        this._disableDelayedDrag();
      }
    },
    _disableDelayedDrag: function _disableDelayedDrag() {
      dragEl && _disableDraggable(dragEl);
      clearTimeout(this._dragStartTimer);

      this._disableDelayedDragEvents();
    },
    _disableDelayedDragEvents: function _disableDelayedDragEvents() {
      var ownerDocument = this.el.ownerDocument;
      off(ownerDocument, 'mouseup', this._disableDelayedDrag);
      off(ownerDocument, 'touchend', this._disableDelayedDrag);
      off(ownerDocument, 'touchcancel', this._disableDelayedDrag);
      off(ownerDocument, 'mousemove', this._delayedDragTouchMoveHandler);
      off(ownerDocument, 'touchmove', this._delayedDragTouchMoveHandler);
      off(ownerDocument, 'pointermove', this._delayedDragTouchMoveHandler);
    },
    _triggerDragStart: function _triggerDragStart(
    /** Event */
    evt,
    /** Touch */
    touch) {
      touch = touch || evt.pointerType == 'touch' && evt;

      if (!this.nativeDraggable || touch) {
        if (this.options.supportPointer) {
          on(document, 'pointermove', this._onTouchMove);
        } else if (touch) {
          on(document, 'touchmove', this._onTouchMove);
        } else {
          on(document, 'mousemove', this._onTouchMove);
        }
      } else {
        on(dragEl, 'dragend', this);
        on(rootEl, 'dragstart', this._onDragStart);
      }

      try {
        if (document.selection) {
          // Timeout neccessary for IE9
          _nextTick(function () {
            document.selection.empty();
          });
        } else {
          window.getSelection().removeAllRanges();
        }
      } catch (err) {}
    },
    _dragStarted: function _dragStarted(fallback, evt) {

      awaitingDragStarted = false;

      if (rootEl && dragEl) {
        pluginEvent('dragStarted', this, {
          evt: evt
        });

        if (this.nativeDraggable) {
          on(document, 'dragover', _checkOutsideTargetEl);
        }

        var options = this.options; // Apply effect

        !fallback && toggleClass(dragEl, options.dragClass, false);
        toggleClass(dragEl, options.ghostClass, true);
        Sortable.active = this;
        fallback && this._appendGhost(); // Drag start event

        _dispatchEvent({
          sortable: this,
          name: 'start',
          originalEvent: evt
        });
      } else {
        this._nulling();
      }
    },
    _emulateDragOver: function _emulateDragOver() {
      if (touchEvt) {
        this._lastX = touchEvt.clientX;
        this._lastY = touchEvt.clientY;

        _hideGhostForTarget();

        var target = document.elementFromPoint(touchEvt.clientX, touchEvt.clientY);
        var parent = target;

        while (target && target.shadowRoot) {
          target = target.shadowRoot.elementFromPoint(touchEvt.clientX, touchEvt.clientY);
          if (target === parent) break;
          parent = target;
        }

        dragEl.parentNode[expando]._isOutsideThisEl(target);

        if (parent) {
          do {
            if (parent[expando]) {
              var inserted = void 0;
              inserted = parent[expando]._onDragOver({
                clientX: touchEvt.clientX,
                clientY: touchEvt.clientY,
                target: target,
                rootEl: parent
              });

              if (inserted && !this.options.dragoverBubble) {
                break;
              }
            }

            target = parent; // store last element
          }
          /* jshint boss:true */
          while (parent = parent.parentNode);
        }

        _unhideGhostForTarget();
      }
    },
    _onTouchMove: function _onTouchMove(
    /**TouchEvent*/
    evt) {
      if (tapEvt) {
        var options = this.options,
            fallbackTolerance = options.fallbackTolerance,
            fallbackOffset = options.fallbackOffset,
            touch = evt.touches ? evt.touches[0] : evt,
            ghostMatrix = ghostEl && matrix(ghostEl, true),
            scaleX = ghostEl && ghostMatrix && ghostMatrix.a,
            scaleY = ghostEl && ghostMatrix && ghostMatrix.d,
            relativeScrollOffset = PositionGhostAbsolutely && ghostRelativeParent && getRelativeScrollOffset(ghostRelativeParent),
            dx = (touch.clientX - tapEvt.clientX + fallbackOffset.x) / (scaleX || 1) + (relativeScrollOffset ? relativeScrollOffset[0] - ghostRelativeParentInitialScroll[0] : 0) / (scaleX || 1),
            dy = (touch.clientY - tapEvt.clientY + fallbackOffset.y) / (scaleY || 1) + (relativeScrollOffset ? relativeScrollOffset[1] - ghostRelativeParentInitialScroll[1] : 0) / (scaleY || 1); // only set the status to dragging, when we are actually dragging

        if (!Sortable.active && !awaitingDragStarted) {
          if (fallbackTolerance && Math.max(Math.abs(touch.clientX - this._lastX), Math.abs(touch.clientY - this._lastY)) < fallbackTolerance) {
            return;
          }

          this._onDragStart(evt, true);
        }

        if (ghostEl) {
          if (ghostMatrix) {
            ghostMatrix.e += dx - (lastDx || 0);
            ghostMatrix.f += dy - (lastDy || 0);
          } else {
            ghostMatrix = {
              a: 1,
              b: 0,
              c: 0,
              d: 1,
              e: dx,
              f: dy
            };
          }

          var cssMatrix = "matrix(".concat(ghostMatrix.a, ",").concat(ghostMatrix.b, ",").concat(ghostMatrix.c, ",").concat(ghostMatrix.d, ",").concat(ghostMatrix.e, ",").concat(ghostMatrix.f, ")");
          css(ghostEl, 'webkitTransform', cssMatrix);
          css(ghostEl, 'mozTransform', cssMatrix);
          css(ghostEl, 'msTransform', cssMatrix);
          css(ghostEl, 'transform', cssMatrix);
          lastDx = dx;
          lastDy = dy;
          touchEvt = touch;
        }

        evt.cancelable && evt.preventDefault();
      }
    },
    _appendGhost: function _appendGhost() {
      // Bug if using scale(): https://stackoverflow.com/questions/2637058
      // Not being adjusted for
      if (!ghostEl) {
        var container = this.options.fallbackOnBody ? document.body : rootEl,
            rect = getRect(dragEl, true, PositionGhostAbsolutely, true, container),
            options = this.options; // Position absolutely

        if (PositionGhostAbsolutely) {
          // Get relatively positioned parent
          ghostRelativeParent = container;

          while (css(ghostRelativeParent, 'position') === 'static' && css(ghostRelativeParent, 'transform') === 'none' && ghostRelativeParent !== document) {
            ghostRelativeParent = ghostRelativeParent.parentNode;
          }

          if (ghostRelativeParent !== document.body && ghostRelativeParent !== document.documentElement) {
            if (ghostRelativeParent === document) ghostRelativeParent = getWindowScrollingElement();
            rect.top += ghostRelativeParent.scrollTop;
            rect.left += ghostRelativeParent.scrollLeft;
          } else {
            ghostRelativeParent = getWindowScrollingElement();
          }

          ghostRelativeParentInitialScroll = getRelativeScrollOffset(ghostRelativeParent);
        }

        ghostEl = dragEl.cloneNode(true);
        toggleClass(ghostEl, options.ghostClass, false);
        toggleClass(ghostEl, options.fallbackClass, true);
        toggleClass(ghostEl, options.dragClass, true);
        css(ghostEl, 'transition', '');
        css(ghostEl, 'transform', '');
        css(ghostEl, 'box-sizing', 'border-box');
        css(ghostEl, 'margin', 0);
        css(ghostEl, 'top', rect.top);
        css(ghostEl, 'left', rect.left);
        css(ghostEl, 'width', rect.width);
        css(ghostEl, 'height', rect.height);
        css(ghostEl, 'opacity', '0.8');
        css(ghostEl, 'position', PositionGhostAbsolutely ? 'absolute' : 'fixed');
        css(ghostEl, 'zIndex', '100000');
        css(ghostEl, 'pointerEvents', 'none');
        Sortable.ghost = ghostEl;
        container.appendChild(ghostEl); // Set transform-origin

        css(ghostEl, 'transform-origin', tapDistanceLeft / parseInt(ghostEl.style.width) * 100 + '% ' + tapDistanceTop / parseInt(ghostEl.style.height) * 100 + '%');
      }
    },
    _onDragStart: function _onDragStart(
    /**Event*/
    evt,
    /**boolean*/
    fallback) {
      var _this = this;

      var dataTransfer = evt.dataTransfer;
      var options = _this.options;
      pluginEvent('dragStart', this, {
        evt: evt
      });

      if (Sortable.eventCanceled) {
        this._onDrop();

        return;
      }

      pluginEvent('setupClone', this);

      if (!Sortable.eventCanceled) {
        cloneEl = clone(dragEl);
        cloneEl.removeAttribute("id");
        cloneEl.draggable = false;
        cloneEl.style['will-change'] = '';

        this._hideClone();

        toggleClass(cloneEl, this.options.chosenClass, false);
        Sortable.clone = cloneEl;
      } // #1143: IFrame support workaround


      _this.cloneId = _nextTick(function () {
        pluginEvent('clone', _this);
        if (Sortable.eventCanceled) return;

        if (!_this.options.removeCloneOnHide) {
          rootEl.insertBefore(cloneEl, dragEl);
        }

        _this._hideClone();

        _dispatchEvent({
          sortable: _this,
          name: 'clone'
        });
      });
      !fallback && toggleClass(dragEl, options.dragClass, true); // Set proper drop events

      if (fallback) {
        ignoreNextClick = true;
        _this._loopId = setInterval(_this._emulateDragOver, 50);
      } else {
        // Undo what was set in _prepareDragStart before drag started
        off(document, 'mouseup', _this._onDrop);
        off(document, 'touchend', _this._onDrop);
        off(document, 'touchcancel', _this._onDrop);

        if (dataTransfer) {
          dataTransfer.effectAllowed = 'move';
          options.setData && options.setData.call(_this, dataTransfer, dragEl);
        }

        on(document, 'drop', _this); // #1276 fix:

        css(dragEl, 'transform', 'translateZ(0)');
      }

      awaitingDragStarted = true;
      _this._dragStartId = _nextTick(_this._dragStarted.bind(_this, fallback, evt));
      on(document, 'selectstart', _this);
      moved = true;

      if (Safari) {
        css(document.body, 'user-select', 'none');
      }
    },
    // Returns true - if no further action is needed (either inserted or another condition)
    _onDragOver: function _onDragOver(
    /**Event*/
    evt) {
      var el = this.el,
          target = evt.target,
          dragRect,
          targetRect,
          revert,
          options = this.options,
          group = options.group,
          activeSortable = Sortable.active,
          isOwner = activeGroup === group,
          canSort = options.sort,
          fromSortable = putSortable || activeSortable,
          vertical,
          _this = this,
          completedFired = false;

      if (_silent) return;

      function dragOverEvent(name, extra) {
        pluginEvent(name, _this, _objectSpread2({
          evt: evt,
          isOwner: isOwner,
          axis: vertical ? 'vertical' : 'horizontal',
          revert: revert,
          dragRect: dragRect,
          targetRect: targetRect,
          canSort: canSort,
          fromSortable: fromSortable,
          target: target,
          completed: completed,
          onMove: function onMove(target, after) {
            return _onMove(rootEl, el, dragEl, dragRect, target, getRect(target), evt, after);
          },
          changed: changed
        }, extra));
      } // Capture animation state


      function capture() {
        dragOverEvent('dragOverAnimationCapture');

        _this.captureAnimationState();

        if (_this !== fromSortable) {
          fromSortable.captureAnimationState();
        }
      } // Return invocation when dragEl is inserted (or completed)


      function completed(insertion) {
        dragOverEvent('dragOverCompleted', {
          insertion: insertion
        });

        if (insertion) {
          // Clones must be hidden before folding animation to capture dragRectAbsolute properly
          if (isOwner) {
            activeSortable._hideClone();
          } else {
            activeSortable._showClone(_this);
          }

          if (_this !== fromSortable) {
            // Set ghost class to new sortable's ghost class
            toggleClass(dragEl, putSortable ? putSortable.options.ghostClass : activeSortable.options.ghostClass, false);
            toggleClass(dragEl, options.ghostClass, true);
          }

          if (putSortable !== _this && _this !== Sortable.active) {
            putSortable = _this;
          } else if (_this === Sortable.active && putSortable) {
            putSortable = null;
          } // Animation


          if (fromSortable === _this) {
            _this._ignoreWhileAnimating = target;
          }

          _this.animateAll(function () {
            dragOverEvent('dragOverAnimationComplete');
            _this._ignoreWhileAnimating = null;
          });

          if (_this !== fromSortable) {
            fromSortable.animateAll();
            fromSortable._ignoreWhileAnimating = null;
          }
        } // Null lastTarget if it is not inside a previously swapped element


        if (target === dragEl && !dragEl.animated || target === el && !target.animated) {
          lastTarget = null;
        } // no bubbling and not fallback


        if (!options.dragoverBubble && !evt.rootEl && target !== document) {
          dragEl.parentNode[expando]._isOutsideThisEl(evt.target); // Do not detect for empty insert if already inserted


          !insertion && nearestEmptyInsertDetectEvent(evt);
        }

        !options.dragoverBubble && evt.stopPropagation && evt.stopPropagation();
        return completedFired = true;
      } // Call when dragEl has been inserted


      function changed() {
        newIndex = index(dragEl);
        newDraggableIndex = index(dragEl, options.draggable);

        _dispatchEvent({
          sortable: _this,
          name: 'change',
          toEl: el,
          newIndex: newIndex,
          newDraggableIndex: newDraggableIndex,
          originalEvent: evt
        });
      }

      if (evt.preventDefault !== void 0) {
        evt.cancelable && evt.preventDefault();
      }

      target = closest(target, options.draggable, el, true);
      dragOverEvent('dragOver');
      if (Sortable.eventCanceled) return completedFired;

      if (dragEl.contains(evt.target) || target.animated && target.animatingX && target.animatingY || _this._ignoreWhileAnimating === target) {
        return completed(false);
      }

      ignoreNextClick = false;

      if (activeSortable && !options.disabled && (isOwner ? canSort || (revert = parentEl !== rootEl) // Reverting item into the original list
      : putSortable === this || (this.lastPutMode = activeGroup.checkPull(this, activeSortable, dragEl, evt)) && group.checkPut(this, activeSortable, dragEl, evt))) {
        vertical = this._getDirection(evt, target) === 'vertical';
        dragRect = getRect(dragEl);
        dragOverEvent('dragOverValid');
        if (Sortable.eventCanceled) return completedFired;

        if (revert) {
          parentEl = rootEl; // actualization

          capture();

          this._hideClone();

          dragOverEvent('revert');

          if (!Sortable.eventCanceled) {
            if (nextEl) {
              rootEl.insertBefore(dragEl, nextEl);
            } else {
              rootEl.appendChild(dragEl);
            }
          }

          return completed(true);
        }

        var elLastChild = lastChild(el, options.draggable);

        if (!elLastChild || _ghostIsLast(evt, vertical, this) && !elLastChild.animated) {
          // Insert to end of list
          // If already at end of list: Do not insert
          if (elLastChild === dragEl) {
            return completed(false);
          } // if there is a last element, it is the target


          if (elLastChild && el === evt.target) {
            target = elLastChild;
          }

          if (target) {
            targetRect = getRect(target);
          }

          if (_onMove(rootEl, el, dragEl, dragRect, target, targetRect, evt, !!target) !== false) {
            capture();

            if (elLastChild && elLastChild.nextSibling) {
              // the last draggable element is not the last node
              el.insertBefore(dragEl, elLastChild.nextSibling);
            } else {
              el.appendChild(dragEl);
            }

            parentEl = el; // actualization

            changed();
            return completed(true);
          }
        } else if (elLastChild && _ghostIsFirst(evt, vertical, this)) {
          // Insert to start of list
          var firstChild = getChild(el, 0, options, true);

          if (firstChild === dragEl) {
            return completed(false);
          }

          target = firstChild;
          targetRect = getRect(target);

          if (_onMove(rootEl, el, dragEl, dragRect, target, targetRect, evt, false) !== false) {
            capture();
            el.insertBefore(dragEl, firstChild);
            parentEl = el; // actualization

            changed();
            return completed(true);
          }
        } else if (target.parentNode === el) {
          targetRect = getRect(target);
          var direction = 0,
              targetBeforeFirstSwap,
              differentLevel = dragEl.parentNode !== el,
              differentRowCol = !_dragElInRowColumn(dragEl.animated && dragEl.toRect || dragRect, target.animated && target.toRect || targetRect, vertical),
              side1 = vertical ? 'top' : 'left',
              scrolledPastTop = isScrolledPast(target, 'top', 'top') || isScrolledPast(dragEl, 'top', 'top'),
              scrollBefore = scrolledPastTop ? scrolledPastTop.scrollTop : void 0;

          if (lastTarget !== target) {
            targetBeforeFirstSwap = targetRect[side1];
            pastFirstInvertThresh = false;
            isCircumstantialInvert = !differentRowCol && options.invertSwap || differentLevel;
          }

          direction = _getSwapDirection(evt, target, targetRect, vertical, differentRowCol ? 1 : options.swapThreshold, options.invertedSwapThreshold == null ? options.swapThreshold : options.invertedSwapThreshold, isCircumstantialInvert, lastTarget === target);
          var sibling;

          if (direction !== 0) {
            // Check if target is beside dragEl in respective direction (ignoring hidden elements)
            var dragIndex = index(dragEl);

            do {
              dragIndex -= direction;
              sibling = parentEl.children[dragIndex];
            } while (sibling && (css(sibling, 'display') === 'none' || sibling === ghostEl));
          } // If dragEl is already beside target: Do not insert


          if (direction === 0 || sibling === target) {
            return completed(false);
          }

          lastTarget = target;
          lastDirection = direction;
          var nextSibling = target.nextElementSibling,
              after = false;
          after = direction === 1;

          var moveVector = _onMove(rootEl, el, dragEl, dragRect, target, targetRect, evt, after);

          if (moveVector !== false) {
            if (moveVector === 1 || moveVector === -1) {
              after = moveVector === 1;
            }

            _silent = true;
            setTimeout(_unsilent, 30);
            capture();

            if (after && !nextSibling) {
              el.appendChild(dragEl);
            } else {
              target.parentNode.insertBefore(dragEl, after ? nextSibling : target);
            } // Undo chrome's scroll adjustment (has no effect on other browsers)


            if (scrolledPastTop) {
              scrollBy(scrolledPastTop, 0, scrollBefore - scrolledPastTop.scrollTop);
            }

            parentEl = dragEl.parentNode; // actualization
            // must be done before animation

            if (targetBeforeFirstSwap !== undefined && !isCircumstantialInvert) {
              targetMoveDistance = Math.abs(targetBeforeFirstSwap - getRect(target)[side1]);
            }

            changed();
            return completed(true);
          }
        }

        if (el.contains(dragEl)) {
          return completed(false);
        }
      }

      return false;
    },
    _ignoreWhileAnimating: null,
    _offMoveEvents: function _offMoveEvents() {
      off(document, 'mousemove', this._onTouchMove);
      off(document, 'touchmove', this._onTouchMove);
      off(document, 'pointermove', this._onTouchMove);
      off(document, 'dragover', nearestEmptyInsertDetectEvent);
      off(document, 'mousemove', nearestEmptyInsertDetectEvent);
      off(document, 'touchmove', nearestEmptyInsertDetectEvent);
    },
    _offUpEvents: function _offUpEvents() {
      var ownerDocument = this.el.ownerDocument;
      off(ownerDocument, 'mouseup', this._onDrop);
      off(ownerDocument, 'touchend', this._onDrop);
      off(ownerDocument, 'pointerup', this._onDrop);
      off(ownerDocument, 'touchcancel', this._onDrop);
      off(document, 'selectstart', this);
    },
    _onDrop: function _onDrop(
    /**Event*/
    evt) {
      var el = this.el,
          options = this.options; // Get the index of the dragged element within its parent

      newIndex = index(dragEl);
      newDraggableIndex = index(dragEl, options.draggable);
      pluginEvent('drop', this, {
        evt: evt
      });
      parentEl = dragEl && dragEl.parentNode; // Get again after plugin event

      newIndex = index(dragEl);
      newDraggableIndex = index(dragEl, options.draggable);

      if (Sortable.eventCanceled) {
        this._nulling();

        return;
      }

      awaitingDragStarted = false;
      isCircumstantialInvert = false;
      pastFirstInvertThresh = false;
      clearInterval(this._loopId);
      clearTimeout(this._dragStartTimer);

      _cancelNextTick(this.cloneId);

      _cancelNextTick(this._dragStartId); // Unbind events


      if (this.nativeDraggable) {
        off(document, 'drop', this);
        off(el, 'dragstart', this._onDragStart);
      }

      this._offMoveEvents();

      this._offUpEvents();

      if (Safari) {
        css(document.body, 'user-select', '');
      }

      css(dragEl, 'transform', '');

      if (evt) {
        if (moved) {
          evt.cancelable && evt.preventDefault();
          !options.dropBubble && evt.stopPropagation();
        }

        ghostEl && ghostEl.parentNode && ghostEl.parentNode.removeChild(ghostEl);

        if (rootEl === parentEl || putSortable && putSortable.lastPutMode !== 'clone') {
          // Remove clone(s)
          cloneEl && cloneEl.parentNode && cloneEl.parentNode.removeChild(cloneEl);
        }

        if (dragEl) {
          if (this.nativeDraggable) {
            off(dragEl, 'dragend', this);
          }

          _disableDraggable(dragEl);

          dragEl.style['will-change'] = ''; // Remove classes
          // ghostClass is added in dragStarted

          if (moved && !awaitingDragStarted) {
            toggleClass(dragEl, putSortable ? putSortable.options.ghostClass : this.options.ghostClass, false);
          }

          toggleClass(dragEl, this.options.chosenClass, false); // Drag stop event

          _dispatchEvent({
            sortable: this,
            name: 'unchoose',
            toEl: parentEl,
            newIndex: null,
            newDraggableIndex: null,
            originalEvent: evt
          });

          if (rootEl !== parentEl) {
            if (newIndex >= 0) {
              // Add event
              _dispatchEvent({
                rootEl: parentEl,
                name: 'add',
                toEl: parentEl,
                fromEl: rootEl,
                originalEvent: evt
              }); // Remove event


              _dispatchEvent({
                sortable: this,
                name: 'remove',
                toEl: parentEl,
                originalEvent: evt
              }); // drag from one list and drop into another


              _dispatchEvent({
                rootEl: parentEl,
                name: 'sort',
                toEl: parentEl,
                fromEl: rootEl,
                originalEvent: evt
              });

              _dispatchEvent({
                sortable: this,
                name: 'sort',
                toEl: parentEl,
                originalEvent: evt
              });
            }

            putSortable && putSortable.save();
          } else {
            if (newIndex !== oldIndex) {
              if (newIndex >= 0) {
                // drag & drop within the same list
                _dispatchEvent({
                  sortable: this,
                  name: 'update',
                  toEl: parentEl,
                  originalEvent: evt
                });

                _dispatchEvent({
                  sortable: this,
                  name: 'sort',
                  toEl: parentEl,
                  originalEvent: evt
                });
              }
            }
          }

          if (Sortable.active) {
            /* jshint eqnull:true */
            if (newIndex == null || newIndex === -1) {
              newIndex = oldIndex;
              newDraggableIndex = oldDraggableIndex;
            }

            _dispatchEvent({
              sortable: this,
              name: 'end',
              toEl: parentEl,
              originalEvent: evt
            }); // Save sorting


            this.save();
          }
        }
      }

      this._nulling();
    },
    _nulling: function _nulling() {
      pluginEvent('nulling', this);
      rootEl = dragEl = parentEl = ghostEl = nextEl = cloneEl = lastDownEl = cloneHidden = tapEvt = touchEvt = moved = newIndex = newDraggableIndex = oldIndex = oldDraggableIndex = lastTarget = lastDirection = putSortable = activeGroup = Sortable.dragged = Sortable.ghost = Sortable.clone = Sortable.active = null;
      savedInputChecked.forEach(function (el) {
        el.checked = true;
      });
      savedInputChecked.length = lastDx = lastDy = 0;
    },
    handleEvent: function handleEvent(
    /**Event*/
    evt) {
      switch (evt.type) {
        case 'drop':
        case 'dragend':
          this._onDrop(evt);

          break;

        case 'dragenter':
        case 'dragover':
          if (dragEl) {
            this._onDragOver(evt);

            _globalDragOver(evt);
          }

          break;

        case 'selectstart':
          evt.preventDefault();
          break;
      }
    },

    /**
     * Serializes the item into an array of string.
     * @returns {String[]}
     */
    toArray: function toArray() {
      var order = [],
          el,
          children = this.el.children,
          i = 0,
          n = children.length,
          options = this.options;

      for (; i < n; i++) {
        el = children[i];

        if (closest(el, options.draggable, this.el, false)) {
          order.push(el.getAttribute(options.dataIdAttr) || _generateId(el));
        }
      }

      return order;
    },

    /**
     * Sorts the elements according to the array.
     * @param  {String[]}  order  order of the items
     */
    sort: function sort(order, useAnimation) {
      var items = {},
          rootEl = this.el;
      this.toArray().forEach(function (id, i) {
        var el = rootEl.children[i];

        if (closest(el, this.options.draggable, rootEl, false)) {
          items[id] = el;
        }
      }, this);
      useAnimation && this.captureAnimationState();
      order.forEach(function (id) {
        if (items[id]) {
          rootEl.removeChild(items[id]);
          rootEl.appendChild(items[id]);
        }
      });
      useAnimation && this.animateAll();
    },

    /**
     * Save the current sorting
     */
    save: function save() {
      var store = this.options.store;
      store && store.set && store.set(this);
    },

    /**
     * For each element in the set, get the first element that matches the selector by testing the element itself and traversing up through its ancestors in the DOM tree.
     * @param   {HTMLElement}  el
     * @param   {String}       [selector]  default: `options.draggable`
     * @returns {HTMLElement|null}
     */
    closest: function closest$1(el, selector) {
      return closest(el, selector || this.options.draggable, this.el, false);
    },

    /**
     * Set/get option
     * @param   {string} name
     * @param   {*}      [value]
     * @returns {*}
     */
    option: function option(name, value) {
      var options = this.options;

      if (value === void 0) {
        return options[name];
      } else {
        var modifiedValue = PluginManager.modifyOption(this, name, value);

        if (typeof modifiedValue !== 'undefined') {
          options[name] = modifiedValue;
        } else {
          options[name] = value;
        }

        if (name === 'group') {
          _prepareGroup(options);
        }
      }
    },

    /**
     * Destroy
     */
    destroy: function destroy() {
      pluginEvent('destroy', this);
      var el = this.el;
      el[expando] = null;
      off(el, 'mousedown', this._onTapStart);
      off(el, 'touchstart', this._onTapStart);
      off(el, 'pointerdown', this._onTapStart);

      if (this.nativeDraggable) {
        off(el, 'dragover', this);
        off(el, 'dragenter', this);
      } // Remove draggable attributes


      Array.prototype.forEach.call(el.querySelectorAll('[draggable]'), function (el) {
        el.removeAttribute('draggable');
      });

      this._onDrop();

      this._disableDelayedDragEvents();

      sortables.splice(sortables.indexOf(this.el), 1);
      this.el = el = null;
    },
    _hideClone: function _hideClone() {
      if (!cloneHidden) {
        pluginEvent('hideClone', this);
        if (Sortable.eventCanceled) return;
        css(cloneEl, 'display', 'none');

        if (this.options.removeCloneOnHide && cloneEl.parentNode) {
          cloneEl.parentNode.removeChild(cloneEl);
        }

        cloneHidden = true;
      }
    },
    _showClone: function _showClone(putSortable) {
      if (putSortable.lastPutMode !== 'clone') {
        this._hideClone();

        return;
      }

      if (cloneHidden) {
        pluginEvent('showClone', this);
        if (Sortable.eventCanceled) return; // show clone at dragEl or original position

        if (dragEl.parentNode == rootEl && !this.options.group.revertClone) {
          rootEl.insertBefore(cloneEl, dragEl);
        } else if (nextEl) {
          rootEl.insertBefore(cloneEl, nextEl);
        } else {
          rootEl.appendChild(cloneEl);
        }

        if (this.options.group.revertClone) {
          this.animate(dragEl, cloneEl);
        }

        css(cloneEl, 'display', '');
        cloneHidden = false;
      }
    }
  };

  function _globalDragOver(
  /**Event*/
  evt) {
    if (evt.dataTransfer) {
      evt.dataTransfer.dropEffect = 'move';
    }

    evt.cancelable && evt.preventDefault();
  }

  function _onMove(fromEl, toEl, dragEl, dragRect, targetEl, targetRect, originalEvent, willInsertAfter) {
    var evt,
        sortable = fromEl[expando],
        onMoveFn = sortable.options.onMove,
        retVal; // Support for new CustomEvent feature

    if (window.CustomEvent && !IE11OrLess && !Edge) {
      evt = new CustomEvent('move', {
        bubbles: true,
        cancelable: true
      });
    } else {
      evt = document.createEvent('Event');
      evt.initEvent('move', true, true);
    }

    evt.to = toEl;
    evt.from = fromEl;
    evt.dragged = dragEl;
    evt.draggedRect = dragRect;
    evt.related = targetEl || toEl;
    evt.relatedRect = targetRect || getRect(toEl);
    evt.willInsertAfter = willInsertAfter;
    evt.originalEvent = originalEvent;
    fromEl.dispatchEvent(evt);

    if (onMoveFn) {
      retVal = onMoveFn.call(sortable, evt, originalEvent);
    }

    return retVal;
  }

  function _disableDraggable(el) {
    el.draggable = false;
  }

  function _unsilent() {
    _silent = false;
  }

  function _ghostIsFirst(evt, vertical, sortable) {
    var rect = getRect(getChild(sortable.el, 0, sortable.options, true));
    var spacer = 10;
    return vertical ? evt.clientX < rect.left - spacer || evt.clientY < rect.top && evt.clientX < rect.right : evt.clientY < rect.top - spacer || evt.clientY < rect.bottom && evt.clientX < rect.left;
  }

  function _ghostIsLast(evt, vertical, sortable) {
    var rect = getRect(lastChild(sortable.el, sortable.options.draggable));
    var spacer = 10;
    return vertical ? evt.clientX > rect.right + spacer || evt.clientX <= rect.right && evt.clientY > rect.bottom && evt.clientX >= rect.left : evt.clientX > rect.right && evt.clientY > rect.top || evt.clientX <= rect.right && evt.clientY > rect.bottom + spacer;
  }

  function _getSwapDirection(evt, target, targetRect, vertical, swapThreshold, invertedSwapThreshold, invertSwap, isLastTarget) {
    var mouseOnAxis = vertical ? evt.clientY : evt.clientX,
        targetLength = vertical ? targetRect.height : targetRect.width,
        targetS1 = vertical ? targetRect.top : targetRect.left,
        targetS2 = vertical ? targetRect.bottom : targetRect.right,
        invert = false;

    if (!invertSwap) {
      // Never invert or create dragEl shadow when target movemenet causes mouse to move past the end of regular swapThreshold
      if (isLastTarget && targetMoveDistance < targetLength * swapThreshold) {
        // multiplied only by swapThreshold because mouse will already be inside target by (1 - threshold) * targetLength / 2
        // check if past first invert threshold on side opposite of lastDirection
        if (!pastFirstInvertThresh && (lastDirection === 1 ? mouseOnAxis > targetS1 + targetLength * invertedSwapThreshold / 2 : mouseOnAxis < targetS2 - targetLength * invertedSwapThreshold / 2)) {
          // past first invert threshold, do not restrict inverted threshold to dragEl shadow
          pastFirstInvertThresh = true;
        }

        if (!pastFirstInvertThresh) {
          // dragEl shadow (target move distance shadow)
          if (lastDirection === 1 ? mouseOnAxis < targetS1 + targetMoveDistance // over dragEl shadow
          : mouseOnAxis > targetS2 - targetMoveDistance) {
            return -lastDirection;
          }
        } else {
          invert = true;
        }
      } else {
        // Regular
        if (mouseOnAxis > targetS1 + targetLength * (1 - swapThreshold) / 2 && mouseOnAxis < targetS2 - targetLength * (1 - swapThreshold) / 2) {
          return _getInsertDirection(target);
        }
      }
    }

    invert = invert || invertSwap;

    if (invert) {
      // Invert of regular
      if (mouseOnAxis < targetS1 + targetLength * invertedSwapThreshold / 2 || mouseOnAxis > targetS2 - targetLength * invertedSwapThreshold / 2) {
        return mouseOnAxis > targetS1 + targetLength / 2 ? 1 : -1;
      }
    }

    return 0;
  }
  /**
   * Gets the direction dragEl must be swapped relative to target in order to make it
   * seem that dragEl has been "inserted" into that element's position
   * @param  {HTMLElement} target       The target whose position dragEl is being inserted at
   * @return {Number}                   Direction dragEl must be swapped
   */


  function _getInsertDirection(target) {
    if (index(dragEl) < index(target)) {
      return 1;
    } else {
      return -1;
    }
  }
  /**
   * Generate id
   * @param   {HTMLElement} el
   * @returns {String}
   * @private
   */


  function _generateId(el) {
    var str = el.tagName + el.className + el.src + el.href + el.textContent,
        i = str.length,
        sum = 0;

    while (i--) {
      sum += str.charCodeAt(i);
    }

    return sum.toString(36);
  }

  function _saveInputCheckedState(root) {
    savedInputChecked.length = 0;
    var inputs = root.getElementsByTagName('input');
    var idx = inputs.length;

    while (idx--) {
      var el = inputs[idx];
      el.checked && savedInputChecked.push(el);
    }
  }

  function _nextTick(fn) {
    return setTimeout(fn, 0);
  }

  function _cancelNextTick(id) {
    return clearTimeout(id);
  } // Fixed #973:


  if (documentExists) {
    on(document, 'touchmove', function (evt) {
      if ((Sortable.active || awaitingDragStarted) && evt.cancelable) {
        evt.preventDefault();
      }
    });
  } // Export utils


  Sortable.utils = {
    on: on,
    off: off,
    css: css,
    find: find,
    is: function is(el, selector) {
      return !!closest(el, selector, el, false);
    },
    extend: extend,
    throttle: throttle,
    closest: closest,
    toggleClass: toggleClass,
    clone: clone,
    index: index,
    nextTick: _nextTick,
    cancelNextTick: _cancelNextTick,
    detectDirection: _detectDirection,
    getChild: getChild
  };
  /**
   * Get the Sortable instance of an element
   * @param  {HTMLElement} element The element
   * @return {Sortable|undefined}         The instance of Sortable
   */

  Sortable.get = function (element) {
    return element[expando];
  };
  /**
   * Mount a plugin to Sortable
   * @param  {...SortablePlugin|SortablePlugin[]} plugins       Plugins being mounted
   */


  Sortable.mount = function () {
    for (var _len = arguments.length, plugins = new Array(_len), _key = 0; _key < _len; _key++) {
      plugins[_key] = arguments[_key];
    }

    if (plugins[0].constructor === Array) plugins = plugins[0];
    plugins.forEach(function (plugin) {
      if (!plugin.prototype || !plugin.prototype.constructor) {
        throw "Sortable: Mounted plugin must be a constructor function, not ".concat({}.toString.call(plugin));
      }

      if (plugin.utils) Sortable.utils = _objectSpread2(_objectSpread2({}, Sortable.utils), plugin.utils);
      PluginManager.mount(plugin);
    });
  };
  /**
   * Create sortable instance
   * @param {HTMLElement}  el
   * @param {Object}      [options]
   */


  Sortable.create = function (el, options) {
    return new Sortable(el, options);
  }; // Export


  Sortable.version = version;

  var autoScrolls = [],
      scrollEl,
      scrollRootEl,
      scrolling = false,
      lastAutoScrollX,
      lastAutoScrollY,
      touchEvt$1,
      pointerElemChangedInterval;

  function AutoScrollPlugin() {
    function AutoScroll() {
      this.defaults = {
        scroll: true,
        forceAutoScrollFallback: false,
        scrollSensitivity: 30,
        scrollSpeed: 10,
        bubbleScroll: true
      }; // Bind all private methods

      for (var fn in this) {
        if (fn.charAt(0) === '_' && typeof this[fn] === 'function') {
          this[fn] = this[fn].bind(this);
        }
      }
    }

    AutoScroll.prototype = {
      dragStarted: function dragStarted(_ref) {
        var originalEvent = _ref.originalEvent;

        if (this.sortable.nativeDraggable) {
          on(document, 'dragover', this._handleAutoScroll);
        } else {
          if (this.options.supportPointer) {
            on(document, 'pointermove', this._handleFallbackAutoScroll);
          } else if (originalEvent.touches) {
            on(document, 'touchmove', this._handleFallbackAutoScroll);
          } else {
            on(document, 'mousemove', this._handleFallbackAutoScroll);
          }
        }
      },
      dragOverCompleted: function dragOverCompleted(_ref2) {
        var originalEvent = _ref2.originalEvent;

        // For when bubbling is canceled and using fallback (fallback 'touchmove' always reached)
        if (!this.options.dragOverBubble && !originalEvent.rootEl) {
          this._handleAutoScroll(originalEvent);
        }
      },
      drop: function drop() {
        if (this.sortable.nativeDraggable) {
          off(document, 'dragover', this._handleAutoScroll);
        } else {
          off(document, 'pointermove', this._handleFallbackAutoScroll);
          off(document, 'touchmove', this._handleFallbackAutoScroll);
          off(document, 'mousemove', this._handleFallbackAutoScroll);
        }

        clearPointerElemChangedInterval();
        clearAutoScrolls();
        cancelThrottle();
      },
      nulling: function nulling() {
        touchEvt$1 = scrollRootEl = scrollEl = scrolling = pointerElemChangedInterval = lastAutoScrollX = lastAutoScrollY = null;
        autoScrolls.length = 0;
      },
      _handleFallbackAutoScroll: function _handleFallbackAutoScroll(evt) {
        this._handleAutoScroll(evt, true);
      },
      _handleAutoScroll: function _handleAutoScroll(evt, fallback) {
        var _this = this;

        var x = (evt.touches ? evt.touches[0] : evt).clientX,
            y = (evt.touches ? evt.touches[0] : evt).clientY,
            elem = document.elementFromPoint(x, y);
        touchEvt$1 = evt; // IE does not seem to have native autoscroll,
        // Edge's autoscroll seems too conditional,
        // MACOS Safari does not have autoscroll,
        // Firefox and Chrome are good

        if (fallback || this.options.forceAutoScrollFallback || Edge || IE11OrLess || Safari) {
          autoScroll(evt, this.options, elem, fallback); // Listener for pointer element change

          var ogElemScroller = getParentAutoScrollElement(elem, true);

          if (scrolling && (!pointerElemChangedInterval || x !== lastAutoScrollX || y !== lastAutoScrollY)) {
            pointerElemChangedInterval && clearPointerElemChangedInterval(); // Detect for pointer elem change, emulating native DnD behaviour

            pointerElemChangedInterval = setInterval(function () {
              var newElem = getParentAutoScrollElement(document.elementFromPoint(x, y), true);

              if (newElem !== ogElemScroller) {
                ogElemScroller = newElem;
                clearAutoScrolls();
              }

              autoScroll(evt, _this.options, newElem, fallback);
            }, 10);
            lastAutoScrollX = x;
            lastAutoScrollY = y;
          }
        } else {
          // if DnD is enabled (and browser has good autoscrolling), first autoscroll will already scroll, so get parent autoscroll of first autoscroll
          if (!this.options.bubbleScroll || getParentAutoScrollElement(elem, true) === getWindowScrollingElement()) {
            clearAutoScrolls();
            return;
          }

          autoScroll(evt, this.options, getParentAutoScrollElement(elem, false), false);
        }
      }
    };
    return _extends(AutoScroll, {
      pluginName: 'scroll',
      initializeByDefault: true
    });
  }

  function clearAutoScrolls() {
    autoScrolls.forEach(function (autoScroll) {
      clearInterval(autoScroll.pid);
    });
    autoScrolls = [];
  }

  function clearPointerElemChangedInterval() {
    clearInterval(pointerElemChangedInterval);
  }

  var autoScroll = throttle(function (evt, options, rootEl, isFallback) {
    // Bug: https://bugzilla.mozilla.org/show_bug.cgi?id=505521
    if (!options.scroll) return;
    var x = (evt.touches ? evt.touches[0] : evt).clientX,
        y = (evt.touches ? evt.touches[0] : evt).clientY,
        sens = options.scrollSensitivity,
        speed = options.scrollSpeed,
        winScroller = getWindowScrollingElement();
    var scrollThisInstance = false,
        scrollCustomFn; // New scroll root, set scrollEl

    if (scrollRootEl !== rootEl) {
      scrollRootEl = rootEl;
      clearAutoScrolls();
      scrollEl = options.scroll;
      scrollCustomFn = options.scrollFn;

      if (scrollEl === true) {
        scrollEl = getParentAutoScrollElement(rootEl, true);
      }
    }

    var layersOut = 0;
    var currentParent = scrollEl;

    do {
      var el = currentParent,
          rect = getRect(el),
          top = rect.top,
          bottom = rect.bottom,
          left = rect.left,
          right = rect.right,
          width = rect.width,
          height = rect.height,
          canScrollX = void 0,
          canScrollY = void 0,
          scrollWidth = el.scrollWidth,
          scrollHeight = el.scrollHeight,
          elCSS = css(el),
          scrollPosX = el.scrollLeft,
          scrollPosY = el.scrollTop;

      if (el === winScroller) {
        canScrollX = width < scrollWidth && (elCSS.overflowX === 'auto' || elCSS.overflowX === 'scroll' || elCSS.overflowX === 'visible');
        canScrollY = height < scrollHeight && (elCSS.overflowY === 'auto' || elCSS.overflowY === 'scroll' || elCSS.overflowY === 'visible');
      } else {
        canScrollX = width < scrollWidth && (elCSS.overflowX === 'auto' || elCSS.overflowX === 'scroll');
        canScrollY = height < scrollHeight && (elCSS.overflowY === 'auto' || elCSS.overflowY === 'scroll');
      }

      var vx = canScrollX && (Math.abs(right - x) <= sens && scrollPosX + width < scrollWidth) - (Math.abs(left - x) <= sens && !!scrollPosX);
      var vy = canScrollY && (Math.abs(bottom - y) <= sens && scrollPosY + height < scrollHeight) - (Math.abs(top - y) <= sens && !!scrollPosY);

      if (!autoScrolls[layersOut]) {
        for (var i = 0; i <= layersOut; i++) {
          if (!autoScrolls[i]) {
            autoScrolls[i] = {};
          }
        }
      }

      if (autoScrolls[layersOut].vx != vx || autoScrolls[layersOut].vy != vy || autoScrolls[layersOut].el !== el) {
        autoScrolls[layersOut].el = el;
        autoScrolls[layersOut].vx = vx;
        autoScrolls[layersOut].vy = vy;
        clearInterval(autoScrolls[layersOut].pid);

        if (vx != 0 || vy != 0) {
          scrollThisInstance = true;
          /* jshint loopfunc:true */

          autoScrolls[layersOut].pid = setInterval(function () {
            // emulate drag over during autoscroll (fallback), emulating native DnD behaviour
            if (isFallback && this.layer === 0) {
              Sortable.active._onTouchMove(touchEvt$1); // To move ghost if it is positioned absolutely

            }

            var scrollOffsetY = autoScrolls[this.layer].vy ? autoScrolls[this.layer].vy * speed : 0;
            var scrollOffsetX = autoScrolls[this.layer].vx ? autoScrolls[this.layer].vx * speed : 0;

            if (typeof scrollCustomFn === 'function') {
              if (scrollCustomFn.call(Sortable.dragged.parentNode[expando], scrollOffsetX, scrollOffsetY, evt, touchEvt$1, autoScrolls[this.layer].el) !== 'continue') {
                return;
              }
            }

            scrollBy(autoScrolls[this.layer].el, scrollOffsetX, scrollOffsetY);
          }.bind({
            layer: layersOut
          }), 24);
        }
      }

      layersOut++;
    } while (options.bubbleScroll && currentParent !== winScroller && (currentParent = getParentAutoScrollElement(currentParent, false)));

    scrolling = scrollThisInstance; // in case another function catches scrolling as false in between when it is not
  }, 30);

  var drop = function drop(_ref) {
    var originalEvent = _ref.originalEvent,
        putSortable = _ref.putSortable,
        dragEl = _ref.dragEl,
        activeSortable = _ref.activeSortable,
        dispatchSortableEvent = _ref.dispatchSortableEvent,
        hideGhostForTarget = _ref.hideGhostForTarget,
        unhideGhostForTarget = _ref.unhideGhostForTarget;
    if (!originalEvent) return;
    var toSortable = putSortable || activeSortable;
    hideGhostForTarget();
    var touch = originalEvent.changedTouches && originalEvent.changedTouches.length ? originalEvent.changedTouches[0] : originalEvent;
    var target = document.elementFromPoint(touch.clientX, touch.clientY);
    unhideGhostForTarget();

    if (toSortable && !toSortable.el.contains(target)) {
      dispatchSortableEvent('spill');
      this.onSpill({
        dragEl: dragEl,
        putSortable: putSortable
      });
    }
  };

  function Revert() {}

  Revert.prototype = {
    startIndex: null,
    dragStart: function dragStart(_ref2) {
      var oldDraggableIndex = _ref2.oldDraggableIndex;
      this.startIndex = oldDraggableIndex;
    },
    onSpill: function onSpill(_ref3) {
      var dragEl = _ref3.dragEl,
          putSortable = _ref3.putSortable;
      this.sortable.captureAnimationState();

      if (putSortable) {
        putSortable.captureAnimationState();
      }

      var nextSibling = getChild(this.sortable.el, this.startIndex, this.options);

      if (nextSibling) {
        this.sortable.el.insertBefore(dragEl, nextSibling);
      } else {
        this.sortable.el.appendChild(dragEl);
      }

      this.sortable.animateAll();

      if (putSortable) {
        putSortable.animateAll();
      }
    },
    drop: drop
  };

  _extends(Revert, {
    pluginName: 'revertOnSpill'
  });

  function Remove() {}

  Remove.prototype = {
    onSpill: function onSpill(_ref4) {
      var dragEl = _ref4.dragEl,
          putSortable = _ref4.putSortable;
      var parentSortable = putSortable || this.sortable;
      parentSortable.captureAnimationState();
      dragEl.parentNode && dragEl.parentNode.removeChild(dragEl);
      parentSortable.animateAll();
    },
    drop: drop
  };

  _extends(Remove, {
    pluginName: 'removeOnSpill'
  });

  var lastSwapEl;

  function SwapPlugin() {
    function Swap() {
      this.defaults = {
        swapClass: 'sortable-swap-highlight'
      };
    }

    Swap.prototype = {
      dragStart: function dragStart(_ref) {
        var dragEl = _ref.dragEl;
        lastSwapEl = dragEl;
      },
      dragOverValid: function dragOverValid(_ref2) {
        var completed = _ref2.completed,
            target = _ref2.target,
            onMove = _ref2.onMove,
            activeSortable = _ref2.activeSortable,
            changed = _ref2.changed,
            cancel = _ref2.cancel;
        if (!activeSortable.options.swap) return;
        var el = this.sortable.el,
            options = this.options;

        if (target && target !== el) {
          var prevSwapEl = lastSwapEl;

          if (onMove(target) !== false) {
            toggleClass(target, options.swapClass, true);
            lastSwapEl = target;
          } else {
            lastSwapEl = null;
          }

          if (prevSwapEl && prevSwapEl !== lastSwapEl) {
            toggleClass(prevSwapEl, options.swapClass, false);
          }
        }

        changed();
        completed(true);
        cancel();
      },
      drop: function drop(_ref3) {
        var activeSortable = _ref3.activeSortable,
            putSortable = _ref3.putSortable,
            dragEl = _ref3.dragEl;
        var toSortable = putSortable || this.sortable;
        var options = this.options;
        lastSwapEl && toggleClass(lastSwapEl, options.swapClass, false);

        if (lastSwapEl && (options.swap || putSortable && putSortable.options.swap)) {
          if (dragEl !== lastSwapEl) {
            toSortable.captureAnimationState();
            if (toSortable !== activeSortable) activeSortable.captureAnimationState();
            swapNodes(dragEl, lastSwapEl);
            toSortable.animateAll();
            if (toSortable !== activeSortable) activeSortable.animateAll();
          }
        }
      },
      nulling: function nulling() {
        lastSwapEl = null;
      }
    };
    return _extends(Swap, {
      pluginName: 'swap',
      eventProperties: function eventProperties() {
        return {
          swapItem: lastSwapEl
        };
      }
    });
  }

  function swapNodes(n1, n2) {
    var p1 = n1.parentNode,
        p2 = n2.parentNode,
        i1,
        i2;
    if (!p1 || !p2 || p1.isEqualNode(n2) || p2.isEqualNode(n1)) return;
    i1 = index(n1);
    i2 = index(n2);

    if (p1.isEqualNode(p2) && i1 < i2) {
      i2++;
    }

    p1.insertBefore(n2, p1.children[i1]);
    p2.insertBefore(n1, p2.children[i2]);
  }

  var multiDragElements = [],
      multiDragClones = [],
      lastMultiDragSelect,
      // for selection with modifier key down (SHIFT)
  multiDragSortable,
      initialFolding = false,
      // Initial multi-drag fold when drag started
  folding = false,
      // Folding any other time
  dragStarted = false,
      dragEl$1,
      clonesFromRect,
      clonesHidden;

  function MultiDragPlugin() {
    function MultiDrag(sortable) {
      // Bind all private methods
      for (var fn in this) {
        if (fn.charAt(0) === '_' && typeof this[fn] === 'function') {
          this[fn] = this[fn].bind(this);
        }
      }

      if (!sortable.options.avoidImplicitDeselect) {
        if (sortable.options.supportPointer) {
          on(document, 'pointerup', this._deselectMultiDrag);
        } else {
          on(document, 'mouseup', this._deselectMultiDrag);
          on(document, 'touchend', this._deselectMultiDrag);
        }
      }

      on(document, 'keydown', this._checkKeyDown);
      on(document, 'keyup', this._checkKeyUp);
      this.defaults = {
        selectedClass: 'sortable-selected',
        multiDragKey: null,
        avoidImplicitDeselect: false,
        setData: function setData(dataTransfer, dragEl) {
          var data = '';

          if (multiDragElements.length && multiDragSortable === sortable) {
            multiDragElements.forEach(function (multiDragElement, i) {
              data += (!i ? '' : ', ') + multiDragElement.textContent;
            });
          } else {
            data = dragEl.textContent;
          }

          dataTransfer.setData('Text', data);
        }
      };
    }

    MultiDrag.prototype = {
      multiDragKeyDown: false,
      isMultiDrag: false,
      delayStartGlobal: function delayStartGlobal(_ref) {
        var dragged = _ref.dragEl;
        dragEl$1 = dragged;
      },
      delayEnded: function delayEnded() {
        this.isMultiDrag = ~multiDragElements.indexOf(dragEl$1);
      },
      setupClone: function setupClone(_ref2) {
        var sortable = _ref2.sortable,
            cancel = _ref2.cancel;
        if (!this.isMultiDrag) return;

        for (var i = 0; i < multiDragElements.length; i++) {
          multiDragClones.push(clone(multiDragElements[i]));
          multiDragClones[i].sortableIndex = multiDragElements[i].sortableIndex;
          multiDragClones[i].draggable = false;
          multiDragClones[i].style['will-change'] = '';
          toggleClass(multiDragClones[i], this.options.selectedClass, false);
          multiDragElements[i] === dragEl$1 && toggleClass(multiDragClones[i], this.options.chosenClass, false);
        }

        sortable._hideClone();

        cancel();
      },
      clone: function clone(_ref3) {
        var sortable = _ref3.sortable,
            rootEl = _ref3.rootEl,
            dispatchSortableEvent = _ref3.dispatchSortableEvent,
            cancel = _ref3.cancel;
        if (!this.isMultiDrag) return;

        if (!this.options.removeCloneOnHide) {
          if (multiDragElements.length && multiDragSortable === sortable) {
            insertMultiDragClones(true, rootEl);
            dispatchSortableEvent('clone');
            cancel();
          }
        }
      },
      showClone: function showClone(_ref4) {
        var cloneNowShown = _ref4.cloneNowShown,
            rootEl = _ref4.rootEl,
            cancel = _ref4.cancel;
        if (!this.isMultiDrag) return;
        insertMultiDragClones(false, rootEl);
        multiDragClones.forEach(function (clone) {
          css(clone, 'display', '');
        });
        cloneNowShown();
        clonesHidden = false;
        cancel();
      },
      hideClone: function hideClone(_ref5) {
        var _this = this;

        var sortable = _ref5.sortable,
            cloneNowHidden = _ref5.cloneNowHidden,
            cancel = _ref5.cancel;
        if (!this.isMultiDrag) return;
        multiDragClones.forEach(function (clone) {
          css(clone, 'display', 'none');

          if (_this.options.removeCloneOnHide && clone.parentNode) {
            clone.parentNode.removeChild(clone);
          }
        });
        cloneNowHidden();
        clonesHidden = true;
        cancel();
      },
      dragStartGlobal: function dragStartGlobal(_ref6) {
        var sortable = _ref6.sortable;

        if (!this.isMultiDrag && multiDragSortable) {
          multiDragSortable.multiDrag._deselectMultiDrag();
        }

        multiDragElements.forEach(function (multiDragElement) {
          multiDragElement.sortableIndex = index(multiDragElement);
        }); // Sort multi-drag elements

        multiDragElements = multiDragElements.sort(function (a, b) {
          return a.sortableIndex - b.sortableIndex;
        });
        dragStarted = true;
      },
      dragStarted: function dragStarted(_ref7) {
        var _this2 = this;

        var sortable = _ref7.sortable;
        if (!this.isMultiDrag) return;

        if (this.options.sort) {
          // Capture rects,
          // hide multi drag elements (by positioning them absolute),
          // set multi drag elements rects to dragRect,
          // show multi drag elements,
          // animate to rects,
          // unset rects & remove from DOM
          sortable.captureAnimationState();

          if (this.options.animation) {
            multiDragElements.forEach(function (multiDragElement) {
              if (multiDragElement === dragEl$1) return;
              css(multiDragElement, 'position', 'absolute');
            });
            var dragRect = getRect(dragEl$1, false, true, true);
            multiDragElements.forEach(function (multiDragElement) {
              if (multiDragElement === dragEl$1) return;
              setRect(multiDragElement, dragRect);
            });
            folding = true;
            initialFolding = true;
          }
        }

        sortable.animateAll(function () {
          folding = false;
          initialFolding = false;

          if (_this2.options.animation) {
            multiDragElements.forEach(function (multiDragElement) {
              unsetRect(multiDragElement);
            });
          } // Remove all auxiliary multidrag items from el, if sorting enabled


          if (_this2.options.sort) {
            removeMultiDragElements();
          }
        });
      },
      dragOver: function dragOver(_ref8) {
        var target = _ref8.target,
            completed = _ref8.completed,
            cancel = _ref8.cancel;

        if (folding && ~multiDragElements.indexOf(target)) {
          completed(false);
          cancel();
        }
      },
      revert: function revert(_ref9) {
        var fromSortable = _ref9.fromSortable,
            rootEl = _ref9.rootEl,
            sortable = _ref9.sortable,
            dragRect = _ref9.dragRect;

        if (multiDragElements.length > 1) {
          // Setup unfold animation
          multiDragElements.forEach(function (multiDragElement) {
            sortable.addAnimationState({
              target: multiDragElement,
              rect: folding ? getRect(multiDragElement) : dragRect
            });
            unsetRect(multiDragElement);
            multiDragElement.fromRect = dragRect;
            fromSortable.removeAnimationState(multiDragElement);
          });
          folding = false;
          insertMultiDragElements(!this.options.removeCloneOnHide, rootEl);
        }
      },
      dragOverCompleted: function dragOverCompleted(_ref10) {
        var sortable = _ref10.sortable,
            isOwner = _ref10.isOwner,
            insertion = _ref10.insertion,
            activeSortable = _ref10.activeSortable,
            parentEl = _ref10.parentEl,
            putSortable = _ref10.putSortable;
        var options = this.options;

        if (insertion) {
          // Clones must be hidden before folding animation to capture dragRectAbsolute properly
          if (isOwner) {
            activeSortable._hideClone();
          }

          initialFolding = false; // If leaving sort:false root, or already folding - Fold to new location

          if (options.animation && multiDragElements.length > 1 && (folding || !isOwner && !activeSortable.options.sort && !putSortable)) {
            // Fold: Set all multi drag elements's rects to dragEl's rect when multi-drag elements are invisible
            var dragRectAbsolute = getRect(dragEl$1, false, true, true);
            multiDragElements.forEach(function (multiDragElement) {
              if (multiDragElement === dragEl$1) return;
              setRect(multiDragElement, dragRectAbsolute); // Move element(s) to end of parentEl so that it does not interfere with multi-drag clones insertion if they are inserted
              // while folding, and so that we can capture them again because old sortable will no longer be fromSortable

              parentEl.appendChild(multiDragElement);
            });
            folding = true;
          } // Clones must be shown (and check to remove multi drags) after folding when interfering multiDragElements are moved out


          if (!isOwner) {
            // Only remove if not folding (folding will remove them anyways)
            if (!folding) {
              removeMultiDragElements();
            }

            if (multiDragElements.length > 1) {
              var clonesHiddenBefore = clonesHidden;

              activeSortable._showClone(sortable); // Unfold animation for clones if showing from hidden


              if (activeSortable.options.animation && !clonesHidden && clonesHiddenBefore) {
                multiDragClones.forEach(function (clone) {
                  activeSortable.addAnimationState({
                    target: clone,
                    rect: clonesFromRect
                  });
                  clone.fromRect = clonesFromRect;
                  clone.thisAnimationDuration = null;
                });
              }
            } else {
              activeSortable._showClone(sortable);
            }
          }
        }
      },
      dragOverAnimationCapture: function dragOverAnimationCapture(_ref11) {
        var dragRect = _ref11.dragRect,
            isOwner = _ref11.isOwner,
            activeSortable = _ref11.activeSortable;
        multiDragElements.forEach(function (multiDragElement) {
          multiDragElement.thisAnimationDuration = null;
        });

        if (activeSortable.options.animation && !isOwner && activeSortable.multiDrag.isMultiDrag) {
          clonesFromRect = _extends({}, dragRect);
          var dragMatrix = matrix(dragEl$1, true);
          clonesFromRect.top -= dragMatrix.f;
          clonesFromRect.left -= dragMatrix.e;
        }
      },
      dragOverAnimationComplete: function dragOverAnimationComplete() {
        if (folding) {
          folding = false;
          removeMultiDragElements();
        }
      },
      drop: function drop(_ref12) {
        var evt = _ref12.originalEvent,
            rootEl = _ref12.rootEl,
            parentEl = _ref12.parentEl,
            sortable = _ref12.sortable,
            dispatchSortableEvent = _ref12.dispatchSortableEvent,
            oldIndex = _ref12.oldIndex,
            putSortable = _ref12.putSortable;
        var toSortable = putSortable || this.sortable;
        if (!evt) return;
        var options = this.options,
            children = parentEl.children; // Multi-drag selection

        if (!dragStarted) {
          if (options.multiDragKey && !this.multiDragKeyDown) {
            this._deselectMultiDrag();
          }

          toggleClass(dragEl$1, options.selectedClass, !~multiDragElements.indexOf(dragEl$1));

          if (!~multiDragElements.indexOf(dragEl$1)) {
            multiDragElements.push(dragEl$1);
            dispatchEvent({
              sortable: sortable,
              rootEl: rootEl,
              name: 'select',
              targetEl: dragEl$1,
              originalEvent: evt
            }); // Modifier activated, select from last to dragEl

            if (evt.shiftKey && lastMultiDragSelect && sortable.el.contains(lastMultiDragSelect)) {
              var lastIndex = index(lastMultiDragSelect),
                  currentIndex = index(dragEl$1);

              if (~lastIndex && ~currentIndex && lastIndex !== currentIndex) {
                // Must include lastMultiDragSelect (select it), in case modified selection from no selection
                // (but previous selection existed)
                var n, i;

                if (currentIndex > lastIndex) {
                  i = lastIndex;
                  n = currentIndex;
                } else {
                  i = currentIndex;
                  n = lastIndex + 1;
                }

                for (; i < n; i++) {
                  if (~multiDragElements.indexOf(children[i])) continue;
                  toggleClass(children[i], options.selectedClass, true);
                  multiDragElements.push(children[i]);
                  dispatchEvent({
                    sortable: sortable,
                    rootEl: rootEl,
                    name: 'select',
                    targetEl: children[i],
                    originalEvent: evt
                  });
                }
              }
            } else {
              lastMultiDragSelect = dragEl$1;
            }

            multiDragSortable = toSortable;
          } else {
            multiDragElements.splice(multiDragElements.indexOf(dragEl$1), 1);
            lastMultiDragSelect = null;
            dispatchEvent({
              sortable: sortable,
              rootEl: rootEl,
              name: 'deselect',
              targetEl: dragEl$1,
              originalEvent: evt
            });
          }
        } // Multi-drag drop


        if (dragStarted && this.isMultiDrag) {
          folding = false; // Do not "unfold" after around dragEl if reverted

          if ((parentEl[expando].options.sort || parentEl !== rootEl) && multiDragElements.length > 1) {
            var dragRect = getRect(dragEl$1),
                multiDragIndex = index(dragEl$1, ':not(.' + this.options.selectedClass + ')');
            if (!initialFolding && options.animation) dragEl$1.thisAnimationDuration = null;
            toSortable.captureAnimationState();

            if (!initialFolding) {
              if (options.animation) {
                dragEl$1.fromRect = dragRect;
                multiDragElements.forEach(function (multiDragElement) {
                  multiDragElement.thisAnimationDuration = null;

                  if (multiDragElement !== dragEl$1) {
                    var rect = folding ? getRect(multiDragElement) : dragRect;
                    multiDragElement.fromRect = rect; // Prepare unfold animation

                    toSortable.addAnimationState({
                      target: multiDragElement,
                      rect: rect
                    });
                  }
                });
              } // Multi drag elements are not necessarily removed from the DOM on drop, so to reinsert
              // properly they must all be removed


              removeMultiDragElements();
              multiDragElements.forEach(function (multiDragElement) {
                if (children[multiDragIndex]) {
                  parentEl.insertBefore(multiDragElement, children[multiDragIndex]);
                } else {
                  parentEl.appendChild(multiDragElement);
                }

                multiDragIndex++;
              }); // If initial folding is done, the elements may have changed position because they are now
              // unfolding around dragEl, even though dragEl may not have his index changed, so update event
              // must be fired here as Sortable will not.

              if (oldIndex === index(dragEl$1)) {
                var update = false;
                multiDragElements.forEach(function (multiDragElement) {
                  if (multiDragElement.sortableIndex !== index(multiDragElement)) {
                    update = true;
                    return;
                  }
                });

                if (update) {
                  dispatchSortableEvent('update');
                }
              }
            } // Must be done after capturing individual rects (scroll bar)


            multiDragElements.forEach(function (multiDragElement) {
              unsetRect(multiDragElement);
            });
            toSortable.animateAll();
          }

          multiDragSortable = toSortable;
        } // Remove clones if necessary


        if (rootEl === parentEl || putSortable && putSortable.lastPutMode !== 'clone') {
          multiDragClones.forEach(function (clone) {
            clone.parentNode && clone.parentNode.removeChild(clone);
          });
        }
      },
      nullingGlobal: function nullingGlobal() {
        this.isMultiDrag = dragStarted = false;
        multiDragClones.length = 0;
      },
      destroyGlobal: function destroyGlobal() {
        this._deselectMultiDrag();

        off(document, 'pointerup', this._deselectMultiDrag);
        off(document, 'mouseup', this._deselectMultiDrag);
        off(document, 'touchend', this._deselectMultiDrag);
        off(document, 'keydown', this._checkKeyDown);
        off(document, 'keyup', this._checkKeyUp);
      },
      _deselectMultiDrag: function _deselectMultiDrag(evt) {
        if (typeof dragStarted !== "undefined" && dragStarted) return; // Only deselect if selection is in this sortable

        if (multiDragSortable !== this.sortable) return; // Only deselect if target is not item in this sortable

        if (evt && closest(evt.target, this.options.draggable, this.sortable.el, false)) return; // Only deselect if left click

        if (evt && evt.button !== 0) return;

        while (multiDragElements.length) {
          var el = multiDragElements[0];
          toggleClass(el, this.options.selectedClass, false);
          multiDragElements.shift();
          dispatchEvent({
            sortable: this.sortable,
            rootEl: this.sortable.el,
            name: 'deselect',
            targetEl: el,
            originalEvent: evt
          });
        }
      },
      _checkKeyDown: function _checkKeyDown(evt) {
        if (evt.key === this.options.multiDragKey) {
          this.multiDragKeyDown = true;
        }
      },
      _checkKeyUp: function _checkKeyUp(evt) {
        if (evt.key === this.options.multiDragKey) {
          this.multiDragKeyDown = false;
        }
      }
    };
    return _extends(MultiDrag, {
      // Static methods & properties
      pluginName: 'multiDrag',
      utils: {
        /**
         * Selects the provided multi-drag item
         * @param  {HTMLElement} el    The element to be selected
         */
        select: function select(el) {
          var sortable = el.parentNode[expando];
          if (!sortable || !sortable.options.multiDrag || ~multiDragElements.indexOf(el)) return;

          if (multiDragSortable && multiDragSortable !== sortable) {
            multiDragSortable.multiDrag._deselectMultiDrag();

            multiDragSortable = sortable;
          }

          toggleClass(el, sortable.options.selectedClass, true);
          multiDragElements.push(el);
        },

        /**
         * Deselects the provided multi-drag item
         * @param  {HTMLElement} el    The element to be deselected
         */
        deselect: function deselect(el) {
          var sortable = el.parentNode[expando],
              index = multiDragElements.indexOf(el);
          if (!sortable || !sortable.options.multiDrag || !~index) return;
          toggleClass(el, sortable.options.selectedClass, false);
          multiDragElements.splice(index, 1);
        }
      },
      eventProperties: function eventProperties() {
        var _this3 = this;

        var oldIndicies = [],
            newIndicies = [];
        multiDragElements.forEach(function (multiDragElement) {
          oldIndicies.push({
            multiDragElement: multiDragElement,
            index: multiDragElement.sortableIndex
          }); // multiDragElements will already be sorted if folding

          var newIndex;

          if (folding && multiDragElement !== dragEl$1) {
            newIndex = -1;
          } else if (folding) {
            newIndex = index(multiDragElement, ':not(.' + _this3.options.selectedClass + ')');
          } else {
            newIndex = index(multiDragElement);
          }

          newIndicies.push({
            multiDragElement: multiDragElement,
            index: newIndex
          });
        });
        return {
          items: _toConsumableArray(multiDragElements),
          clones: [].concat(multiDragClones),
          oldIndicies: oldIndicies,
          newIndicies: newIndicies
        };
      },
      optionListeners: {
        multiDragKey: function multiDragKey(key) {
          key = key.toLowerCase();

          if (key === 'ctrl') {
            key = 'Control';
          } else if (key.length > 1) {
            key = key.charAt(0).toUpperCase() + key.substr(1);
          }

          return key;
        }
      }
    });
  }

  function insertMultiDragElements(clonesInserted, rootEl) {
    multiDragElements.forEach(function (multiDragElement, i) {
      var target = rootEl.children[multiDragElement.sortableIndex + (clonesInserted ? Number(i) : 0)];

      if (target) {
        rootEl.insertBefore(multiDragElement, target);
      } else {
        rootEl.appendChild(multiDragElement);
      }
    });
  }
  /**
   * Insert multi-drag clones
   * @param  {[Boolean]} elementsInserted  Whether the multi-drag elements are inserted
   * @param  {HTMLElement} rootEl
   */


  function insertMultiDragClones(elementsInserted, rootEl) {
    multiDragClones.forEach(function (clone, i) {
      var target = rootEl.children[clone.sortableIndex + (elementsInserted ? Number(i) : 0)];

      if (target) {
        rootEl.insertBefore(clone, target);
      } else {
        rootEl.appendChild(clone);
      }
    });
  }

  function removeMultiDragElements() {
    multiDragElements.forEach(function (multiDragElement) {
      if (multiDragElement === dragEl$1) return;
      multiDragElement.parentNode && multiDragElement.parentNode.removeChild(multiDragElement);
    });
  }

  Sortable.mount(new AutoScrollPlugin());
  Sortable.mount(Remove, Revert);

  Sortable.mount(new SwapPlugin());
  Sortable.mount(new MultiDragPlugin());

  return Sortable;

})));


// FILE: src/config/config.js
(function () {

	window.templateUrls = window.templateUrls || [];
	var packageName = 'zh-grid-configuration';

	var hasPackageRegistered = window.templateUrls.some(function (templateUrl) {
		return templateUrl.package === packageName;
	});

	if (!hasPackageRegistered) {
		window.templateUrls.push({
			'package': packageName,
			'baseUrl': './bower_components/' + packageName + '/dist/templates/'
		});
	}
})();

// FILE: src/controllers/ZhGridConfigController.js
var ZhGridConfigController = function($scope, $timeout, $filter, ApplicationContext, ScreenService, metaDataFactory) {
	var self = this;
	var widget = $scope.widget;
	var widgetShowCheckbox = widget.showCheckbox;
	var GRID_MODE = 'grid';
	var REPORT_MODE = 'report';

	widget.reportShowOnlyVisibleFields = false;
	widget._selectedColumn = undefined;

	self.configMode = GRID_MODE;

	self.inGridMode = function(){
		return self.configMode == GRID_MODE;
	};
	$scope.inGridMode = self.inGridMode;

	self.inReportMode = function(){
		return self.configMode == REPORT_MODE;
	};
	$scope.inReportMode = self.inReportMode;

	self.setConfigMode = function(mode) {
		self.configMode = mode;
		widget.showCheckbox = self.inGridMode() && widgetShowCheckbox;
		widget._selectedColumn = undefined;

		$timeout(function() {
			$scope.updateFields(false);
		});
	};

	$scope.getConfigMode = function() {
		return self.configMode;
	};

	self.setReportOrientation = function(orientation) {
		widget.reportOrientation = orientation;

		$timeout(function() {
			$scope.calcColumnSize();
			widget.resizeGridColumns(true);
		});
	};

	self.getPageInfo = function() {
		return ScreenService.i18n("Page")+": 1<br />"+(new Date()).toLocaleString();
	};

	$scope.selectColumn = function(column) {
		if (widget._selectedColumn == column) {
			widget._selectedColumn = undefined;
		} else {
			widget._selectedColumn = column;
			if (Util.isUndefined(column.fixed)) {
				column.fixed = false;
			}

			$scope.updateFieldDetailsData(column);
		}
	};

	$scope.updateFieldDetailsData = function(column) {
		self.fieldDetailsWidget.dataSource.data[0] = {
			"LABEL": (self.inReportMode() && column.labelOnReport) || column.label,
			"ALIGNMENT": column.align,
			"EXPRESSION": column.expression
		};
		self.fieldDetailsWidget.moveToFirst();
		self.fieldDetailsWidget.getField("FIXED").setValue(column.fixed);
		self.fieldDetailsWidget.getField("OPENED").setValue(Util.isUndefinedOrNull(column.groupOpened) ? true : column.groupOpened);
		self.fieldDetailsWidget.getField("VISIBLE").setValue(self.inReportMode() ? column.isVisibleOnReport : column.showOnList);

		if (self.inReportMode()) {
			self.fieldDetailsWidget.getField("COLUMNSIZE").label = "Column Width (%)";
			if (!Util.isUndefinedOrNull(column.reportColumnSize)) {
				self.fieldDetailsWidget.getField("COLUMNSIZE").setValue(parseInt(column.reportColumnSize));
			}

			self.fieldDetailsWidget.getField("FIXED").isVisible = false;
		} else {
			self.fieldDetailsWidget.getField("COLUMNSIZE").label = "Column Width (px)";
			self.fieldDetailsWidget.getField("COLUMNSIZE").setValue(column.gridColumnSize);

			self.fieldDetailsWidget.getField("FIXED").isVisible = true;
		}

		self.fieldDetailsWidget.getField('ALIGNMENT').isVisible = !column.grouped;
		self.fieldDetailsWidget.getField('EXPRESSION').isVisible = !column.grouped;
		self.fieldDetailsWidget.getField('COLUMNSIZE').isVisible = !column.grouped;
		self.fieldDetailsWidget.getField('FIXED').isVisible = !column.grouped;
		self.fieldDetailsWidget.getField('VISIBLE').isVisible = !column.grouped;
		self.fieldDetailsWidget.getField('OPENED').isVisible = column.grouped && !self.inReportMode();
		self.fieldDetailsWidget.getField('LABEL').class = column.grouped && !self.inReportMode() ? 10 : 12;
	};

	$scope.calcColumnSize = function() {
		var totalWidth = $scope.getTotalWidth();

		widget._filteredFields.forEach(function(field) {
			field.minWidth = field.maxWidth = undefined;

			if (self.inReportMode()) {
				if (field.reportColumnSize) {
					field.minWidth = field.maxWidth = totalWidth * parseInt(field.reportColumnSize) / 100;
				}
			} else if (field.gridColumnSize) {
				field.minWidth = field.maxWidth = field.gridColumnSize;
			}
		});
	};

	$scope.calcColumnWidthProperties = function() {
		var totalWidth = $scope.getTotalWidth();

		widget._filteredFields.forEach(function(field) {
			if (field.minWidth) {
				if (self.inReportMode()) {
					field.reportColumnSize = Math.round(field.minWidth * 100 / totalWidth) + "%";
				} else {
					field.gridColumnSize = field.minWidth;
				}
			}
		});
	};

	$scope.updateFields = function(apply) {
		function _updateFields() {
			widget.updateFilteredFields();
			self.updateGroupedColumns();
			self.updateNotVisibleColumns();
			$scope.calcColumnSize();
		}

		if (apply !== false) {
			$scope.$apply(_updateFields);
		} else {
			_updateFields();
		}
	};

	widget.updateFilteredFields = function() {
		widget._filteredFields = $filter('orderBy')(widget.fields, $scope.fieldOrder);
		widget._filteredFields = widget._filteredFields.filter(function(field) {
			return (self.inReportMode() ? field.isVisibleOnReport !== false : field.showOnList) && field.aclIsVisible && !field.grouped;
		});
	};

	self._groupedColumns = [];
	self.updateGroupedColumns = function() {
		self._groupedColumns = $filter('orderBy')(widget.fields, $scope.fieldOrder);
		self._groupedColumns = self._groupedColumns.filter(function(field) {
			return field.grouped && field.aclIsVisible;
		});
	};

	self._notVisibleColumns = [];
	self.updateNotVisibleColumns = function() {
		self._notVisibleColumns = $filter('orderBy')(widget.fields, $scope.fieldOrder);
		self._notVisibleColumns = self._notVisibleColumns.filter(function(field) {
			return !~widget._filteredFields.indexOf(field) && !~self._groupedColumns.indexOf(field) && field.aclIsVisible;
		});
	};

	$timeout(function() { $scope.updateFields(false); });

	self.layoutNameWidget = metaDataFactory.widgetFactory({
		"id": "grid-config-layout-name",
		"name": "grid-config-layout-name",
		"template": "widget/form-structure.html",
		"container": widget.container,
		"isVisible": true,
		"popupNoBlock": false,
		"showDescriptionOrder": false,
		"floatingControl": false,
		"dataSource": { "data": [] },
		"actions": [],
		"events": [],
		"fields": [
			{
				"label": "Layout name",
				"name": "LABEL",
				"class": "12",
				"showOnForm": true,
				"template": "field/text-edit.html",
				"events": [],
				"validations": {
					"required": {}
				}
			}
		]
	});
	self.layoutNameWidget.dataSource.data.push({ LABEL: widget.layoutName });
	self.layoutNameWidget.currentRow = self.layoutNameWidget.dataSource.data[0];

	$scope.$watch(function() { return self.layoutNameWidget.dataSource.data[0].LABEL; }, function(newValue) {
		if (!Util.isUndefinedOrNull(newValue)) {
			widget.layoutName = newValue;
		}
	});

	self.fieldDetailsWidget = metaDataFactory.widgetFactory({
		"id": "grid-config-field-details",
		"name": "grid-config-field-details",
		"label": "Field Details",
		"template": 'widget/form-structure.html',
		"container": widget.container,
		"isVisible": true,
		"popupNoBlock": false,
		"showDescriptionOrder": false,
		"floatingControl": false,
		"fieldGroups": [{
			"name": "FIELDGROUP",
			"opened": true,
			"collapsible": false,
			"label": "Column properties"
		}],
		"fields": [{
			"label": "Label",
			"name": "LABEL",
			"showLabel": true,
			"showOnList": true,
			"showOnForm": true,
			"fieldGroup": "FIELDGROUP",
			"class": 12,
			"template": "field/text-edit.html"
		},{
			"label": "Alignment",
			"name": "ALIGNMENT",
			"showLabel": true,
			"showOnList": true,
			"showOnForm": true,
			"fieldGroup": "FIELDGROUP",
			"class": 3,
			"template": "field/select-native.html",
			"dataSource": {
				"data": [
					{"value": "left"},
					{"value": "center"},
					{"value": "right"}
				]
			},
			"valueField": "value",
			"hideEmptyValue": true,
			"descriptionField": "value"
		},{
			"label": "Group expression",
			"name": "EXPRESSION",
			"showLabel": true,
			"showOnList": true,
			"showOnForm": true,
			"fieldGroup": "FIELDGROUP",
			"class": 3,
			"template": "field/select-native.html",
			"dataSource": {
				"data": [
					{"value": "SUM"},
					{"value": "AVG"},
					{"value": "COUNT"},
					{"value": "MAX"},
					{"value": "MIN"}
				]
			},
			"valueField": "value",
			"hideEmptyValue": false,
			"descriptionField": "value"
		},{
			"label": "Column Width (%)",
			"name": "COLUMNSIZE",
			"showLabel": true,
			"showOnList": true,
			"showOnForm": true,
			"fieldGroup": "FIELDGROUP",
			"class": 3,
			"template": "field/number.html",
			"spin": true
		},{
			"label": "Fixed",
			"name": "FIXED",
			"showLabel": true,
			"showOnList": true,
			"showOnForm": true,
			"fieldGroup": "FIELDGROUP",
			"class": 1,
			"template": "field/checkbox.html",
			"valueToTrue": true,
			"valueToFalse": false,
		},{
			"label": "Visible",
			"name": "VISIBLE",
			"showLabel": true,
			"showOnList": true,
			"showOnForm": true,
			"fieldGroup": "FIELDGROUP",
			"class": 2,
			"template": "field/checkbox.html",
			"valueToTrue": true,
			"valueToFalse": false,
		},{
			"label": "Opened",
			"name": "OPENED",
			"showLabel": true,
			"showOnList": true,
			"showOnForm": true,
			"fieldGroup": "FIELDGROUP",
			"class": 2,
			"template": "field/checkbox.html",
			"valueToTrue": true,
			"valueToFalse": false,
		}],
		"dataSource": { "data": [] },
		"actions": [],
		"events": []
	});

	var lastSelectedColumn;
	$scope.$watch(function() { return self.fieldDetailsWidget.dataSource.data[0]; }, function(newValue) {
		if (newValue && widget._selectedColumn && lastSelectedColumn == widget._selectedColumn) {
			var forceResize = false;

			if (self.inReportMode()) {
				widget._selectedColumn.labelOnReport = newValue.LABEL;

				widget._selectedColumn.reportColumnSize = undefined;
				if (!Util.isUndefinedOrNull(newValue.COLUMNSIZE) && widget._selectedColumn.reportColumnSize != newValue.COLUMNSIZE+"%") {
					widget._selectedColumn.reportColumnSize = newValue.COLUMNSIZE+"%";

					$scope.calcColumnSize();
					$scope.setFieldWidthFromElementWidth();
					$scope.calcColumnWidthProperties();
					forceResize = true;
				}

				if (widget._selectedColumn.isVisibleOnReport != newValue.VISIBLE) {
					widget._selectedColumn.isVisibleOnReport = newValue.VISIBLE;

					widget._selectedColumn = undefined;
					widget.updateFilteredFields();
					self.updateNotVisibleColumns();
					$scope.removeInvisibleColumns();
					forceResize = true;
				}
			} else {
				widget._selectedColumn.label = newValue.LABEL;

				widget._selectedColumn.gridColumnSize = undefined;
				if (!Util.isUndefinedOrNull(newValue.COLUMNSIZE) && widget._selectedColumn.gridColumnSize != newValue.COLUMNSIZE) {
					widget._selectedColumn.gridColumnSize = newValue.COLUMNSIZE;

					$scope.calcColumnSize();
					$scope.setFieldWidthFromElementWidth();
					$scope.calcColumnWidthProperties();
					forceResize = true;
				}

				if (widget._selectedColumn.showOnList != newValue.VISIBLE) {
					widget._selectedColumn.showOnList = newValue.VISIBLE;

					widget._selectedColumn = undefined;
					widget.updateFilteredFields();
					self.updateNotVisibleColumns();
					$scope.removeInvisibleColumns();
					forceResize = true;
				}
			}

			if (widget._selectedColumn) {
				widget._selectedColumn.align = newValue.ALIGNMENT;
				widget._selectedColumn.expression = newValue.EXPRESSION;
				widget._selectedColumn.groupOpened = newValue.OPENED;

				if (widget._selectedColumn.fixed != newValue.FIXED) {
					widget._selectedColumn.fixed = newValue.FIXED;

					widget.updateFilteredFields();
					var fixed = true;
					widget._filteredFields.forEach(function(field, idx) {
						field.sequenceInList = idx;
						fixed = fixed && field.fixed;
						field.fixed = fixed;
					});

					forceResize = true;
				}
			}

			if (forceResize) {
				widget.resizeGridColumns(true);
			}
		}
		lastSelectedColumn = widget._selectedColumn;
	}, true);

	self.previewPDF = function() {
		ApplicationContext.ZhReports.openReport(undefined, widget, undefined, undefined, 'PDF');
	};

	self.openSearch = function() {
		self.searchOpened = !self.searchOpened;
		if (self.searchOpened) {
			$('#zh-grid-config-not-visible-search input').focus();
		}
	};

	self.clearSearch = function() {
		delete self.notVisibleSearch;
	};

	self.getNotVisibleColumns = function() {
		return self._notVisibleColumns.filter(function(item) {
			return !self.notVisibleSearch || item.label.indexOfLatin(self.notVisibleSearch) > -1;
		}).sort(function(a, b) {
			a.label = a.label || "";
			b.label = b.label || "";
			var labelA = a.label.toUpperCase();
			var labelB = b.label.toUpperCase();
			if (labelA < labelB) {
				return -1;
			}
			if (labelA > labelB) {
				return 1;
			}
			return 0;
		});
	};

	widget.gridConfigWidget = self.layoutNameWidget;
};

ZeedhiController.controller('ZhGridConfigController', ZhGridConfigController);

// FILE: src/directives/ZhGridConfigDirective.js

(function () {
	var ZeedhiDirectives = angular.module('ZeedhiDirectives');
	ZeedhiDirectives.directive('zhGridConfig', zhGridConfig);

	function zhGridConfig(ApplicationContext) {
		return {
			restrict: 'A',
			link: function($scope, element) {
				var widget = $scope.widget;

				if (Util.isUndefinedOrNull(ApplicationContext.ZhReports)) {
					element.find('span.config-buttons').hide();
				}

				$scope.getTotalWidth = function() {
					return element.find('.header-content').outerWidth() - element.find('.header-content .th.grid-checkbox-column').outerWidth() - 10;
				};

				element.find('.body-content').off('mousewheel wheel DOMMouseScroll');

				var groupedColumns = element.find('.zh-grid-config-groups .sortable-columns')[0];
				var visibleColumns = element.find('.zh-grid-container .sortable-columns')[0];
				var notVisibleColumns = element.find('.zh-grid-config-not-visible .sortable-columns')[0];

				$scope.onStartSortable = function(evt) {
					var el = $(evt.item);
					var fieldName = el.attr('data-zh-field-name');
					var field = widget.getField(fieldName);

					if (field == widget._selectedColumn) {
						delete widget._selectedColumn;
					}
				};

				$scope.onAddSortable = function(evt) {
					var fieldName = $(evt.item).attr('data-zh-field-name');
					var field = widget.getField(fieldName);
					if (field) {
						if ($(evt.to).parent().hasClass('zh-grid-config-groups')) {
							field.showOnList = false;
							field.grouped = true;
							field.groupOpened = Util.isUndefinedOrNull(field.groupOpened) ? true : field.groupOpened;
						} else if ($(evt.to).parent().hasClass('zh-grid-config-not-visible')) {
							if ($scope.inReportMode()) {
								field.isVisibleOnReport = false;
							} else {
								field.showOnList = false;
							}
							field.grouped = false;
						} else {
							if ($scope.inReportMode()) {
								field.isVisibleOnReport = true;
							} else {
								field.showOnList = true;
							}
							field.isVisible = true;
							field.grouped = false;
						}
					}

					$scope.onUpdateSortable(evt);
				};

				$scope.onUpdateSortable = function(evt) {
					var fixed = true;
					$(evt.to).parent().find('.th').each(function(idx, item) {
						var fieldName = $(item).attr('data-zh-field-name');
						var field = widget.getField(fieldName);
						if (field) {
							if (!$(evt.to).parent().hasClass('zh-grid-config-not-visible')) {
								field.sequenceInList = idx;
							}

							if ($(evt.to).parent().hasClass('tr')) {
								fixed = fixed && field.fixed;
								field.fixed = fixed;
							}
						}
					});

					if (evt.type == "add") {
						$(evt.item).remove();
					}

					$scope.updateFields();
				};

				var sortableOptions = {
					group: "sortableList",
					onUpdate: $scope.onUpdateSortable,
					onAdd: $scope.onAddSortable,
					onStart: $scope.onStartSortable,
					animation: 100,
					handle: ".label-text",
					scroll: element.find('.body-scroll-control')[0]
				};

				var sortableItems = [];
				[groupedColumns, visibleColumns, notVisibleColumns].forEach(function(el) {
					sortableItems.push(Sortable.create(el, sortableOptions));
				});

				$scope.$on('$destroy', function() {
					sortableItems.forEach(function(item) {
						item.destroy();
					});
					sortableItems = [];

					delete $scope.onUpdateSortable;
					delete $scope.onAddSortable;
					delete $scope.onStartSortable;
				});

				element.on('touchend touchcancel mouseup pointercancel', function() {
					delete element[0]._tapEvt;
				});

				$scope.setFieldWidthFromElementWidth = function(force) {
					element.find('.header-content .sortable-columns .th').each(function(idx, item) {
						item = $(item);
						var itemField = widget.getField(item.attr('data-zh-field-name'));
						if (Util.isUndefinedOrNull(itemField.minWidth) || force) {
							itemField.minWidth = item.width();
							itemField.maxWidth = item.outerWidth();
						}
					});
				};

				element.on('touchmove mousemove', function(evt) {
					if (element[0]._tapEvt) {
						var tapElement = $(element[0]._tapEvt.target);
						var thElement = tapElement.closest('.th');
						var deltaX = evt.clientX - element[0]._tapEvt.clientX;

						if (deltaX === 0) {
							return;
						}

						if (thElement.offset().left + thElement.outerWidth() + deltaX > thElement.offsetParent().offset().left + thElement.offsetParent().outerWidth()) {
							return;
						}

						var field = widget.getField(thElement.attr('data-zh-field-name'));
						var width = thElement.width();
						var outerWidth = thElement.outerWidth();

						$scope.setFieldWidthFromElementWidth(true);

						if (tapElement.hasClass('resize-handle-left')) {
							if (thElement.prev().length) {
								thElement.width(width - deltaX);

								if (field) {
									field.minWidth = field.maxWidth = outerWidth - deltaX;
								}

								var prevElement = thElement.prev();
								if (prevElement) {
									var prevWidth = prevElement.width();
									var prevOuterWidth = prevElement.outerWidth();

									prevElement.width(prevWidth + deltaX);

									var prevField = widget.getField(prevElement.attr('data-zh-field-name'));
									if (prevField) {
										prevField.minWidth = prevField.maxWidth = prevOuterWidth + deltaX;
									}
								}
							}
						} else {
							thElement.width(width + deltaX);

							if (field) {
								field.minWidth = width + deltaX;
								field.maxWidth = outerWidth + deltaX;
							}
						}

						element[0]._tapEvt.clientX += deltaX;

						$scope.calcColumnWidthProperties();
						$scope.updateFieldDetailsData(field);

						widget.resizeGridColumns(true);
					}
				});

				$scope.removeInvisibleColumns = function() {
					var thItems = element.find('.header-content .sortable-columns .th');
					thItems.each(function(idx, th) {
						th = $(th);
						var fieldName = th.attr('data-zh-field-name');
						var field = widget.getField(fieldName);
						if (!field || widget._filteredFields.indexOf(field) == -1) {
							th.remove();
						}
					});
				};
			}
		};
	}

	ZeedhiDirectives.directive('zhGridConfigResizeHandle', zhGridConfigResizeHandle);

	function zhGridConfigResizeHandle() {
		return {
			restrict: 'A',
			link: function($scope, element) {
				var widget = $scope.widget;

				element.on('touchStart mousedown', function(evt) {
					element.closest('.zh-grid-config-container')[0]._tapEvt = evt;
				});

				element.on('touchend touchcancel mouseup pointercancel', function(evt) {
					delete element.closest('.zh-grid-config-container')[0]._tapEvt;
				});
			}
		};
	}
})();

// FILE: ./bower_components/zh-select-autocomplete/dist/zh-select-autocomplete.js

// FILE: src/config/config.js
window.templateUrls = window.templateUrls || [];
var packageName = 'zh-select-autocomplete';

var hasPackageRegistered = window.templateUrls.some(function(templateUrl){
    return templateUrl.package === packageName;
});

if(!hasPackageRegistered){
    window.templateUrls.push({
        'package': packageName,
        'baseUrl': './bower_components/' + packageName + '/dist/templates/'
    });
}

// FILE: src/controllers/zh-select-autocomplete.controller.js
var ZhSelectAutoCompleteController = function($scope, $rootScope, templateManager, ScreenService, ZhUtil, SelectService, ZHPromise, EventChildPropagation, DecodeValueFieldService, $filter, metaDataFactory, $timeout, eventAggregator) {

	var self = this;
    var lastSearch = "";
    var propertyToSearch = [];
	var isMakingRequest = false;
	var parentReload = $scope.field.reload.bind($scope.field);
	$scope.field.dataInitialized = !!($scope.field.dataSource && (!$scope.field.dataSource.lazyLoad || ($scope.field.dataSource.data && $scope.field.dataSource.data.length > 0)));
	$scope.field.searchUpdate = false;

	$scope.field.filteredData = $scope.field.dataSource.data;
	if (!$scope.field.dataSource.rest || !$scope.field.searchWithPagination) $scope.originalData = $scope.field.filteredData;

	// Save old event to be triggered
	if (!$scope.field.oldAfterLoadDataSource) $scope.field.oldAfterLoadDataSource = $scope.field.dataSource.afterLoadDataSource;
	$scope.field.dataSource.afterLoadDataSource = function(){
		if ($scope.field.oldAfterLoadDataSource) $scope.field.oldAfterLoadDataSource.apply(null, arguments);
		$scope.field.filteredData = $scope.field.dataSource.data;
		if (!$scope.field.dataSource.rest || !$scope.field.searchWithPagination) $scope.originalData = $scope.field.filteredData;
		$scope.field.dataInitialized = !!($scope.field.searchUpdate || !$scope.field.dataSource.lazyLoad || ($scope.field.dataSource.data && $scope.field.dataSource.data.length > 0));
		$scope.field.searchUpdate = false; // don't de-initialize field if searching return no data
	};

	$scope.$on('$destroy', function(event) {
        event.currentScope.field.dataSource.afterLoadDataSource = event.currentScope.oldAfterLoadDataSource;
    });

	$scope.field.lazyLoadEvent = $scope.field.lazyLoadEvent || templateManager.project.lazyLoadEvent;
	$scope.viewMore = ScreenService.i18n("View more...");
	$scope.showDropdown = true;
	$scope.itemSearch = "";

	/**
	 * Extends the behavior of it's parent (ListController).
	 *
	 * @function extendBehavior
	 * @private
	 */
	function extendBehavior() {
		Util.extend(self, new ListTemplatable());
	}
	extendBehavior();


	/**
	 * Return isMakingRequest.
	 */
	$scope.isRequestBeingMade = function() {
		return isMakingRequest;
	};

	/**
	 * Override toggleDropdown to be controlled by showDropdown variable.
	 */
	var oldFieldToggleDropdown = $scope.field.toggleDropdown;
    $scope.field.toggleDropdown = function(){
        $scope.showDropdown = !$scope.showDropdown;
	};

	/**
	 * Override initialize field to change field
	 */
	var oldFieldInitializeField = $scope.field.initializeField;
	$scope.field.initializeField = function() {
		if(!$scope.field.dataInitialized) {
			setDataInitialized();
			$scope.field.reload();
		}
	};

	/**
	 * Set dataInitialized as true.
	 *
	 * @function setDataInitialized
	 * @private
	 */
	function setDataInitialized(){
		$scope.field.dataInitialized = true;
	}

	/**
	 * Override the field function reload to initialize the field when called.
	 * @param {Object[]} [additionalFilters] - An object of filters to be applied when reloading the field
	 * @returns {Promise.<Array>} Field data with the given fields.
	 */
	$scope.field.reload = function(additionalFilters){
		$scope.field.initializeField();

		return updateDatasource($scope.itemSearch, true, additionalFilters);
	};

	/**
	 * Get a row from dataSets
	 *
	 * @function getNewData
	 * @private
	 * @param   {Object} dataSets - DataSets returned by request
	 * @returns {Array} Returns a data array.
	 */
	function getNewData(dataSets){
		var data;
		result = dataSets.dataset;
		var keys = Object.keys(result);

		if (keys && keys.length > 0 && keys[0] !== '0') {
			var dataSetName = $scope.field.dataSource.name.split('/').pop();
			if (result[dataSetName]) {
				data = result[dataSetName];
			}
		} else {
			data = result;
		}

		return data;
	}

	/**
	 * Make a request to get an specific value.
	 *
	 * @function findNewValue
	 * @private
	 * @param   {Array} keys - CurrentRow's keys.
	 * @param   {Field} field - Field to change it's value.
	 * @param   {Object} value - Value to be searched.
	 * @returns {Array} Returns a row.
	 */
	function findNewValue(keys, field, value){
		var filter = [];
		keys.forEach(function(key){
			filter.push({
				"name": key,
				"operator": '=',
				"value": value[key]
			});
		});
		var storageStrategy = field.dataSource.getStorageStrategy();
		return storageStrategy.getDataSource(field.dataSource.name, function(){}, filter, 1, 2, undefined, 0);
	}

	/**
	 * Prepares the value.
	 *
	 * @function findNewValue
	 * @private
	 * @param   {Array} valueFields - The field's valueFields
	 * @param   {String|Object} value - the value to be inserted.
	 * @returns {Object} The prepared value.
	 */
	function prepareValue(valueFields, value) {
		var valueBuilt = {};

		if(valueFields.length === 1 && typeof value !== 'object'){
			valueBuilt[valueFields[0]] =  value;
		} else {
			valueBuilt = value;
		}

		return valueBuilt;
	}

	/**
	 * Override the field function value to use valueFields.
	 * @param {Object} value - The value to be set.
	 */
	var oldFieldValue = $scope.field.value;
	$scope.field.value = function(value){
		if(value){
			var shouldMakeRequest = $scope.field.dataSource.rest && $scope.field.hasPagination;
			currentRow = $scope.field.widget.currentRow;
			valueFields = $scope.field.valueFields;

			value = prepareValue(valueFields, value);

			if(shouldMakeRequest){
				findNewValue(valueFields, $scope.field, value).then(function(result){
					result = getNewData(result);
					if(result.length === 1){
						self.addItemAsSelected(result[0], $scope.field);
					} else {
						currentRow[$scope.field.name] = "";
					}
				});
			} else {
				var row = $scope.field.dataSource.data.filter(function(row){
					var result = true;

					valueFields.forEach(function(key){
						if(row[key] !== value[key]){
							result = false;
						}
					});

					return result;
				});

				if(row.length === 1){
					self.addItemAsSelected(row[0], $scope.field);
				} else {
					currentRow[$scope.field.name] = "";
				}
			}
		} else {
			return this.widget.currentRow[this.name];
		}
	};

    /**
     * Retrieves the code to be executed on FieldOnAdd event.
	 *
	 * @function getOnAddCode
	 * @returns {String} The code to be executed on the FieldOnAdd event.
     */
	function getOnAddCode(){
		var onAddEventCode = $scope.field.events.filter(function(event) {
			return event.name === "FieldOnAdd";
		});

		if(onAddEventCode.length > 0){
			return onAddEventCode[0].code;
		} else {
			return "args.owner.widget.onAdd()";
		}
	}

	var onAddCode = getOnAddCode();

	/**
	 * Build all actions of the widget that appears when the field's popup is opened.
	 *
	 * @function buildActions
	 * @private
	 * @param   {Field} field - Widget owner
	 * @returns {Array} - Actions of the widget
	 */
	function buildActions(field) {
		var actions = [{
			"label": ScreenService.i18n("Cancel"),
			"showAsAction": "back",
			"isVisible": true,
			"showOnForm": true,
			"showOnList": true,
			"hideIcon": true,
			"events": [{
				"name": "ActionEvent",
				"code": "ScreenService.closePopup(); args.owner.widget.afterClosePopup(args.owner.widget.selectField);",
				"id": 9998
			}]
		}];

		if (field.showAddButtonAs == 'action') {
			actions.push({
				"icon": "plus",
				"showAsAction": "always|edit|checked_rows|view",
				"isVisible": true,
				"showOnForm": true,
				"showOnList": true,
				"events": [{
					"name": "ActionEvent",
					"code": onAddCode,
					"id": 9999
				}]
			});
		}

		return actions;
	}

    /**
     * Initialize the field.
     *
     * @function initialize
     */
    (function initialize() {
        initializeValuesOnCurrentRow();
        initializeFieldProperties();
    })();

    /**
     * Prepares the new clearValue function for the select-autocomplete's field.
     */
    $scope.field.clearValue = function() {
        clearFieldValue(this);
    };

    /**
     * Clears the select-autocomplete value and it's dependents.
     * @param {Field} field The select autocomplete.
     */
    function clearFieldValue(field) {
        if (!field.isReadOnly()) {
            field.clearByOutData();
            field.clearByName();
            field.clearByOutDescription();
            field.dataSource.clearCheckedRows();
            setChanged(field);
            if (field.change) {
                field.change();
            }
            $scope.clearAutoCompleteListData();
            $scope.removeFocusOfInput();
        }
    }

	/**
     * Config which template of widget will appear when the field's popup is opened.
     *
     * @function configTemplate
     * @private
     * @param   {Field} field - Widget owner
     * @returns {String} template - Widget template
     */
	function configTemplate(field){
		var template;
		if (!field.showSelectAs) {
			template = "widget/list.html";
		}
		else if (field.showSelectAs === "tree") {
			template = "widget/tree/grid.html";
		}
		else {
			template = "widget/" + field.showSelectAs + ".html";
		}

		return template;
	}

	/**
     * Create the fields to be inserted
     *
     * @function buildFields
     * @private
     * @param   {descriptionField} displayedField - Used to create the fields
     * @param   {Number} key - Array position
     */
	function buildFields(displayedField, key){
        this[key] = {
            "name": displayedField,
            "showLabel": false,
            "showOnList": true,
            "mask": this.mask
        };
    }

    /**
     * Insert labels on the fields.
     *
     * @function insertLabels
     * @private
     * @param   {String} label - label to be inserted
     * @param   {Number} key - Array position
     */
    function insertLabels(label, key){
        this[key].label = label;
        this[key].showLabel = true;
    }

	/**
     * Build all fields of the widget that appears when the field's popup is opened.
     *
     * @function buildSelectWidgetFields
     * @private
     * @param   {Field} field - Widget owner
     */
	function buildSelectWidgetFields(field) {
        var fields = [];

        if (field.fields && field.fields.length) {
            fields = field.fields;
        } else {
            field.descriptionFields.forEach(buildFields, fields);
        }

        if(field.displayedFieldsLabels){
            field.displayedFieldsLabels.forEach(insertLabels, fields);
        }

        fields.forEach(function(currentElement) {
            metaDataFactory.fieldFactory(currentElement, field.selectWidget, true);
        });
	}

	/**
     * Build all events of the widget that appears when the field's popup is opened.
     *
     * @function buildEvents
     * @private
     * @returns {Array} - Events of the widget
     */
	function buildEvents(){
		return [
			{
				"name": "WidgetAfterMoveRow",
				"code": "args.owner.setSelected(args);",
				"id": 9999
			},
			{
				"name": "WidgetAfterLoadDataSource",
				"code": "args.owner.setDataInitialized()",
				"id": 9999
			}
		];
	}

	/**
	 * Set the args' row as selected.
	 *
	 * @function setSelected
	 * @private
	 * @param {Object} args - The window args.
	 */
	function setSelected(args) {
		if (!$scope.field.allowSelectOnlyLastChild || ($scope.field.allowSelectOnlyLastChild && this.isTree($scope.field.selectWidget) && isLastChild(args.row))) {
			ScreenService.closePopup();
			self.onAutoCompleteItemClick(args.row);
		}
	}

	/**
	 * Routine executed after the field's popup be closed.
	 *
	 * @function afterClosePopup
	 * @private
	 * @param {Field} field - The field that had it's popup closed.
	 */
	function afterClosePopup(field) {
		if (field.element) {
			field.element.focus();
		}
	}

	/**
	 * Build the widget that appears when the field's popup is opened.
	 *
	 * @function buildSelectWidget
	 * @private
	 * @param {Field} args - Widget owner.
	 * @param {Object} widgetConfig - Widget's propertys
	 */
	function buildSelectWidget(field, widgetConfig) {
		if (!field.selectWidget){
			field.selectWidget = metaDataFactory.widgetFactory({
				"id": 9000,
				"name": "Widget",
				"label": field.label,
				"template": widgetConfig.template,
				"container": field.widget.container,
				"isVisible": true,
				"popupNoBlock": false,
				"showDescriptionOrder": false,
				"floatingControl": {
					"openSearch": !Util.isMobile(),
					"defaultSearchField": field.defaultSearchField,
					"customizationAction": {
						"layout": false,
						"filter": false,
						"view": false
					},
					"xlsAction": false,
					"pdfAction": false,
					"csvAction": false
				},
				"parentProperty": field.parentProperty,
				"primaryProperty": field.primaryProperty,
				"expandingProperty": field.expandingProperty,
				"breadcrumbProperty": field.breadcrumbProperty,
				"order": field.order,
				"reverse": field.reverse,
				"bringGroupsCollapsed": field.bringGroupsCollapsed,
				"orderFromGroups": field.orderFromGroups,
				"selectField": field,
				"showCheckbox": false,
				"onAdd": field.onAdd,
				"showAddButtonAs": field.showAddButtonAs,
				"addButtonText": field.addButtonText,
				"noMatchText": field.noMatchText,
				"searchNoMatchText": field.searchNoMatchText,
				"fields": [],
				"dataSource": field.dataSource,
				"dataSourceFilter": field.dataSourceFilter,
				"itemsPerPage": field.itemsPerPage || 30,
				"searchWithPagination": Util.isUndefinedOrNull(field.searchWithPagination) ? true : field.searchWithPagination,
				"hasPagination": Util.isUndefinedOrNull(field.hasPagination) ? true : field.hasPagination,
				"onDemand": field.onDemand,
				"allowSelectOnlyLastChild": field.allowSelectOnlyLastChild,
				"actions": widgetConfig.actions,
				"events": EventChildPropagation.propagate(widgetConfig.widgetEvents, field),
				"searchCriteria": field.searchCriteria
			});
			
			buildSelectWidgetFields(field);
		}

		var unregisterWatcher = $scope.$watchCollection(function() {
			return field.selectWidget.searchCriteria;
		}, function(current, old) {
			if (!angular.equals(current || {}, old || {})) {
				$scope.field.searchUpdate = true;
			}
		});
		
		$scope.$on('$destroy', function() {
		   unregisterWatcher(); 
		});

		field.selectWidget.setSelected = setSelected;
		field.selectWidget.updateDatasource = updateDatasource;
		field.selectWidget.afterClosePopup = afterClosePopup;
	}

	/**
     * Reload the field
     *
     * @function processReload
     * @private
     * @param   {boolean} isToReload
     * @param   {Field} field
     * @returns {Promise} - A resolved promise
     */
	function processReload(isToReload, field){
		var defer = ZHPromise.defer();

		if (isToReload) {
			field.selectWidget.searchCriteria = {};
			field.reload().then(defer.resolve, defer.resolve);
		}
		else {
			defer.resolve();
		}

		return defer.promise;
	}

	/**
     * Change the dataSource's data to the filtered by the given value.
     *
     * @function innerSearch
     * @private
     * @param {String} selectListSearch - The value to be searched on the field.
     * @param {Field} field - The field where will be searched the values and changed the data of the dataSource.
     */
    function innerSearch(selectListSearch, field) {
        if (Util.isArray(field.filterDefinitions) && field.filterDefinitions.length) {
            var dataSource = field.dataSource;
            var filter = ZhUtil.buildFiltersInField(field, selectListSearch);
            dataSource.filter(filter, function(data) {
                dataSource.data = data;
                templateManager.updateTemplate();
            });
        }
    }

    /**
     * Removes all filters from the dataSource's data
     *
     * @function  cleanFieldSearch
     * @private
     * @param {Field} field - The field where will be removed the filters of the dataSource's data.
     */
    function cleanFieldSearch(field) {
        innerSearch("", field);
    }

	/**
     * Build the Widget to be open
     *
     * @function buildFieldWidget
     * @private
     * @param   {Field} field - Widget owner
     * @returns {Promise} - A resolved promise
     */
	function buildFieldWidget(field) {
		cleanFieldSearch(field);

		var isToReload = !!(field.selectWidget && Util.objectHasAnyValue(field.selectWidget.searchCriteria));

		if (!field.selectWidget) {
			initializeSelectWidget(field);
			isToReload = !!(field.dataSource && field.dataSource.lazyLoad);
		}

		return processReload(isToReload, field);
	}

	/**
     * Build configs to be used on the widget
     *
     * @function buildwidgetConfig
     * @private
     * @param   {Field} field - field used to build the configs
     * @returns {Object} Object with the configs
     */
	function buildWidgetConfig(field) {
		var widgetConfig = {};
		widgetConfig.template = configTemplate(field);
		widgetConfig.actions = buildActions(field);
		widgetConfig.widgetEvents = buildEvents();
		return widgetConfig;
	}

	/**
     * Initialize the field's SelectWidget propertys
     *
     * @function initializeSelectWidget
     * @private
     * @param   {Field} field - SelectWidget owner
     */
	function initializeSelectWidget(field) {
		buildSelectWidget(field, buildWidgetConfig(field));
		overrideReload(field);
	}

	var oldReload;
	function overrideReload(field) {
		oldReload = field.selectWidget.reload;
		field.selectWidget.reload = function() {
			if($scope.field.dataInitialized){
				return oldReload.call(field.selectWidget);
			} else {
				return ZHPromise.when();
			}
		};
	}

	/**
	 * Call the beforeSelectOpen event if defined
	 *
	 * @function processBeforeSelectOpenEvent
	 * @private
	 * @param   {Field} field - Widget owner
	 */
	$scope.processBeforeSelectOpenEvent = function(field){
		if (field.beforeSelectOpen) {
			field.beforeSelectOpen();
		}
	};

	/**
     * Call the afterSelectOpen event if defined
     *
     * @function processAfterSelectOpenEvent
     * @param   {Field} field - Widget owner
     */
	$scope.processAfterSelectOpenEvent = function(field){
		if (field.afterSelectOpen) {
			field.afterSelectOpen();
		}
	};

	/**
     * Open the popup of the field
     *
     * @function openField
     *
     * @param   {Field} field - Popup owner
     */
	$scope.openField = function(field, $event) {
		$event.stopPropagation();
		if (!field.isReadOnly()) {
			$scope.inputWithEditableContent.blur();
			$scope.processBeforeSelectOpenEvent(field);
			buildFieldWidget(field).then(function() {
				field.initializeField();
				$scope.clearSearchFilter();
				ScreenService.openPopup(field.selectWidget);
				$scope.processAfterSelectOpenEvent(field);
			});
		}
	};

	/**
	 * Open the popup of the field on the scope.
	 */
	var oldFieldOpenField = $scope.field.openField;
	$scope.field.openField = function() {
		$scope.openField($scope.field);
	};

    /**
     * Config the property valueField because the controller works only with valueFields.
     *
     * @function configValueFields
     * @private
     */
    function configValueFields(){
        var field = $scope.field;

        if(!field.valueFields){
            field.valueFields = [field.valueField];
        }
    }

    /**
     * Set the property descriptionField to avoid component break if not defined and config the property
     * descriptionField because the controller works only with descriptionFields.
     *
     * @function configDescriptionFields
     * @private
     */
    function configDescriptionFields() {
        var field = $scope.field;
        field.descriptionFields = field.descriptionFields ? field.descriptionFields : [field.descriptionField || field.name];
    }

	/**
	 * Clear the outdata related to the component.
	 */
	var oldFieldClearByOutData = $scope.field.clearByOutData;
	$scope.field.clearByOutData = (function() {
		for (var prop in this.outData) {
			this.widget.currentRow[this.outData[prop]] = "";
		}
	}).bind($scope.field);

	/**
	 * Clear the value of the selected row by the component from the current row.
	 *
	 * @function clearByName
	 * @public
	 */
	var oldFieldClearByName = $scope.field.clearByName;
	$scope.field.clearByName = (function () {
		this.widget.currentRow[this.name] = "";
	}).bind($scope.field);

	/**
	 * Clear the outDescription related to the component
	 *
	 * @function clearByOutDescription
	 * @public
	 */
	var oldFieldClearByOutDescription = $scope.field.clearByOutDescription;
	$scope.field.clearByOutDescription = (function() {
		this.widget.currentRow[this.outDescription] = "";
	}).bind($scope.field);

	if ($scope.selectField) {
		var oldSelectFieldOpenField = $scope.selectField.openField;
		$scope.selectField.openField = function() {
			$scope.openField($scope.selectField);
		};
	}

	/**
	 * Set the widget of the component as changed.
	 *
	 * @function setChanged
	 * @private
	 * @param {Field} field - The field to have it's current row set as changed.
	 */
	var setChanged = function(field) {
		field.widget.currentRow.changed = true;
	};

    /**
     * Clear the filter of the component, and the values related to him from the current row.
     *
     * @function clearField
     * @public
     * @param {Field} field - The field to have it's values cleared.
     */
    $scope.clearField = function(field, $event) {
        $event.stopPropagation();
        clearFieldValue(field);
	};

	$scope.hasValueSet = function() {
		var field = $scope.field;
		var currentRow = field.widget.currentRow;
		return !!currentRow[field.name];
	};

    $scope.$watch($scope.hasValueSet, function(newVal){
    	$scope.showSpan = newVal;
    });

    /**
     * Searches for the given value if the value is valid.
     *
     * @function search
     * @public
     * @param {String} selectListSearch - The value to be searched. Should be bigger than 0.
     * @param {Field} field - The field that will have the data that will be searched.
     */
    $rootScope.search = function(selectListSearch, field) {
        var minLength = field.minimumInputLength || 0;
        if (selectListSearch.length > minLength) {
            innerSearch(selectListSearch, field);
        }
    };

	/**
	 * Add the given item as selected
	 *
	 * @function addItemAsSelected
	 * @public
	 * @param {Object} item - The selected item.
	 * @param {Field} field - The item's field, where the item will be set as selected.
	 */
	this.addItemAsSelected = function(item, field) {
		self.clearEditableInput();
		(field.outData ? changeByOut : changeByName)(field, item);
		if(field.outDescription){
			changeByDescription(field, item);
		}
		item.__isSelected = true;
		field.dataSource.checkedRows = [item];
		setChanged(field);

		if (field._afterSelected) {
			field._afterSelected(item);
		}
		if (field.change) field.change();
		$scope.removeFocusOfInput();
	};

	/**
	 * Returns the mounted description of the selected value.
	 *
	 * @function getDescriptionFromSelectedValue
	 * @public
	 * @returns {String} The value that should be displayed of the selected row.
	 */
	$scope.getDescriptionFromSelectedValue = function() {
		var fieldName = $scope.field.name;
		var currentRow = $scope.field.widget.currentRow;

		return DecodeValueFieldService.model($scope.field, currentRow[fieldName]);
	};

	/**
	 * Returns the item's identifier.
	 *
	 * @function getItemIdentifier
	 * @public
	 * @param   {Object} item - The item to get it's identifier.
	 * @returns {String} The item's identifier.
	 */
	this.getItemIdentifier = function(item) {
		var identifier = [];
		var field = $scope.field;
		var valueFields = field.valueFields;

		for(var valueField in valueFields){
			identifier.push(item[valueFields[valueField]]);
		}

		return identifier.join(" | ");
	};

	/**
	 * Return the ordered data.
	 *
	 * @function orderDropdown
	 * @private
	 * @param {Object} data - The data to be ordered.
	 * @param {String} order - The selectWidget's order.
	 * @returns {Object} The ordered data.
	 */
	function orderDropdown(data, order){
		return $filter('orderBy')(data, order);
	}

	function insertFieldFilter(itemSearch){
		var filterSet = false;
		var name = $scope.field.searchableFields.join("|");

		if(!$scope.field.filterToAdd){
			$scope.field.filterToAdd = {};
			filterSet = true;
		}
		$scope.field.filterToAdd.name = name;
		$scope.field.filterToAdd.operator = "LIKE_ALL";
		$scope.field.filterToAdd.value = buildSearchValue(itemSearch);

		if(filterSet){
			$scope.field.dataSourceFilter = $scope.field.dataSourceFilter || [];
			$scope.field.dataSourceFilter.push($scope.field.filterToAdd);
		}
	}

    /**
     * Updates the dataSource, applying any typed filter.
     *
     * @function updateDatasourceRemote
     * @private
     * @param {DataSourceFilter} itemSearch - The field's input value, used to filter the dataSource.
     */
    function updateDatasourceRemote(itemSearch, isToReload, additionalFilters){
        if($scope.field.dataSource.rest){
            if((itemSearch !== undefined) || isToReload){
                if($scope.field.searchableFields){
					isMakingRequest = true;
					if($scope.field.dataSource.disableLoader && $scope.showLoader){
						$scope.showLoader();
					}
					var filters = $scope.field.dataSourceFilter.slice();
					if(additionalFilters)
						additionalFilters.forEach(function(filter) {
							filters.push(filter);
						});
					return $scope.field.dataSource.load(filters, 1, $scope.field.selectWidget.itemsPerPage).then(function(response){
						$scope.originalData = $scope.field.dataSource.data;
						if ($scope.field.selectWidget.order) {
							$scope.field.dataSource.data = orderDropdown($scope.field.dataSource.data, $scope.field.selectWidget.order);
							$scope.field.filteredData = $scope.field.dataSource.data;
						}

						isMakingRequest = false;
						if($scope.field.dataSource.disableLoader && $scope.hideLoader){
							$scope.hideLoader();
						}
						return response;
					});
                } else {
                    throw new Error('Field ' + $scope.field.name + ' must have searchableFields. ');
                }
            }
        }
	}

	/**
	 * Select next field
	 *
	 * @param {Field} field - The current field
	 */
	function selectNextField(field) {
		var form = field.getParent();
		var fields = form.fields.slice(form.fields.indexOf(field) + 1).filter(function(item) {
			return item.isVisible &&
				item.aclIsVisible &&
				!item.isReadOnly() &&
				item.element;
		});

		if (fields.length) {
			fields[0].element.find('input, button, textarea').focus();
		}
	}

	/**
	 * Deletes the filter add by searching in selectAutocomplete
	 */
	$scope.$on("$destroy", function(){
		if($scope.field.dataSourceFilter){
			$scope.field.dataSourceFilter.forEach(function(filter){
				if(angular.equals(filter, $scope.field.filterToAdd)){
					$scope.field.dataSourceFilter.splice($scope.field.dataSourceFilter.indexOf(filter), 1);
			        delete $scope.field.filterToAdd;
				}
			});
		}

		if ($scope.field.selectWidget) {
			if (oldReload) {
				$scope.field.selectWidget.reload = oldReload;
			}
		}

	    $scope.field.toggleDropdown = oldFieldToggleDropdown;
		$scope.field.initializeField = oldFieldInitializeField;
		$scope.field.value = oldFieldValue;
		$scope.field.openField = oldFieldOpenField;
		$scope.field.clearByOutData = oldFieldClearByOutData;
		$scope.field.clearByName = oldFieldClearByName;
		$scope.field.clearByOutDescription = oldFieldClearByOutDescription;
		$scope.field.reload = parentReload;
		if ($scope.selectField) {
			$scope.selectField.openField = oldSelectFieldOpenField;
		}
	});


    /**
     * Creates a filtered local copy of the Datasource.
     *
     * @function updateDatasourceLocal
     * @private
     * @param {DataSourceFilter} itemSearch - The field's input value, used to filter the dataSource copy.
     */
    function updateDatasourceLocal(itemSearch) {
        var expression = function(row) {
            var result = false;
            $scope.field.searchableFields.forEach(function(fieldName) {
				var rowValue = String(row[fieldName]).toLowerCase();
				var localItemSearch = itemSearch.slice().toLowerCase();
				if(localItemSearch.charAt(0) === "%")
					localItemSearch = localItemSearch.slice(1);
				if(localItemSearch.charAt(localItemSearch.length-1) === "%")
					localItemSearch = localItemSearch.slice(-1);
                switch ($scope.field.searchIn){
                    case 'beginning':
                        result = rowValue.startsWith(localItemSearch) ? true : result;
                        break;
                    case 'end':
                        result = rowValue.endsWith(localItemSearch) ? true : result;
                        break;
                    default:
                        result = rowValue.indexOf(localItemSearch) !== -1 ? true : result;
                        break;
                }
            });

            return result;
        };

		$scope.field.dataSource.data = $filter('filter')($scope.originalData, expression);
		$scope.field.filteredData = $scope.field.dataSource.data;
		if($scope.field.selectWidget.order){
			$scope.field.filteredData = orderDropdown($scope.field.filteredData, $scope.field.selectWidget.order);
		}
	}

    /**
     * Chose which method will be used to filter the data according with
     * the searchWithPagination property
     *
     * @function    updateDatasource
     * @private
     * @param {String} itemSearch - value used to filter the data
     */
    function updateDatasource(itemSearch, isToReload, additionalFilters){
		var promise;
		itemSearch = itemSearch || $scope.itemSearch || "";

		if($scope.shouldMakeRequest(itemSearch, isToReload)){
			promise = ZHPromise.when(updateDatasourceRemote(itemSearch, isToReload, additionalFilters));
		} else {
			updateDatasourceLocal(itemSearch);
			promise = ZHPromise.when({});
		}
		resetDropdown();
		lastSearch = itemSearch;
		return promise;
	}

    /**
     * Verifies if the request should be made.
     *
     * @function shouldMakeRequest
     * @private
     * @param {String} itemSearch - value used to filter the data
     */
	$scope.shouldMakeRequest = function(itemSearch, isToReload) {
		if(isToReload) return true;
		if(!$scope.field.dataSource.rest) return false;

		/* Checks if datasource is currently making requests */
		if(!isMakingRequest && $scope.field.searchWithPagination && $scope.field.dataInitialized &&
			itemSearch !== lastSearch){
			var itemsPerPage = $scope.field.itemsPerPage || 30;
			var pageSize = 30 < itemsPerPage ? 30 : itemsPerPage;

			/* Checks if the request is a more specific version of last request.
			 *  If so, checks if the last request has already found all the data.
			 */
			var data = self.getData() || [];
			return lastSearch === '' || itemSearch.indexOf(lastSearch) === -1 || (data.length >= pageSize);
		} else {
			return false;
		}
	};

	insertFieldFilter($scope.itemSearch);

	$scope.$watch(function() {
		return $scope.field.dataSourceFilter;
	}, onDatasourceUpdate, true);

	$scope.$watch(function() {
		return $scope.itemSearch;
	}, onItemSearchUpdate);

	var filterChanged = false;

    /**
     * Propagate the field's DataSourceFilter to the selectWidget.
     *
     * @function onDatasourceUpdate
     * @private
     * @param {DataSourceFilter} fieldDataSourceFilter - The field's DataSourceFilter to be propagated.
     */
    function onDatasourceUpdate(fieldDataSourceFilter) {
		if(filterChanged) {
			if ($scope.field.selectWidget) {
				$scope.field.selectWidget.dataSourceFilter = fieldDataSourceFilter;
			}
			if(fieldDataSourceFilter === undefined || (fieldDataSourceFilter && fieldDataSourceFilter.length === 0))	return;

			update(true);
		} else {
			filterChanged = true;
		}
	}

	var timeout = $timeout(function(){});

	function onItemSearchUpdate(){
		$timeout.cancel(timeout);
		timeout = $timeout(function() {
			if($scope.itemSearch == lastSearch || $scope.itemSearch === undefined) return;
			filterChanged = false;
			$scope.field.searchUpdate = true;

			insertFieldFilter($scope.itemSearch);
			if ($scope.field.dataInitialized) updateDatasource($scope.itemSearch);
		}, 500);
	}

	function update(isToReload){
		updateDatasource($scope.itemSearch, isToReload);
	}

    /**
     * Defines the operator that will be used by filter.
     *
     * @function setOperator
     */
    function setOperator() {
        $scope.field.operator = $scope.field.operator || "=";
    }


    /**
     * Set hasPagination's default value if not set
     */
    function configHasPagination() {
        var field = $scope.field;
		if(field.hasPagination === undefined){
			field.hasPagination = true;
		}
    }

    /**
     * Initialize the field properties.
     *
     * @function initializeFieldProperties
     */
    function initializeFieldProperties() {
        configValueFields();
        configDescriptionFields();
        configHasPagination();
        buildPropertiesToSearch();
        setOperator();
        initializeSelectWidget($scope.field);
    }

    /**
     * Test the row to check if it should be displayed on the field's dropdown.
     *
     * @function searchFilter
     * @public
     * @param   {Object} row - The row to be tested.
     * @returns {Boolean} Result telling if the field should be displayed.
     */
    $scope.searchFilter = function(row) {
        return Util.isUndefinedOrNull($scope.itemSearch) || propertyToSearch.some(function(data) {
            return ~row[data].indexOfLatin($scope.itemSearch);
        });
    };

	/**
	 * Get the item with the given identifier.
	 *
	 * @function searchItem
	 * @private
	 * @param   {String} itemIdentifier - The desired item's identifier.
	 * @returns {Object} The item with the given identifier.
	 */
	function searchItem(itemIdentifier){
		var field = $scope.field;
		var data = field.dataSource.data;
		var valueFields = field.valueFields;
		var itemIdentifierArr = itemIdentifier.split(" | ");

		function findItem(item){
			var result = true;
			for(var valueField in valueFields){
				result &= item[valueFields[valueField]] == itemIdentifierArr[valueField];
			}
			return result;
		}

		item = data.find(findItem);
		return item;
	}

	/**
	 * Field's routine executed after one row be selected.
	 *
	 * @function onAutoCompleteItemSelect
	 * @public
	 * @param {String} selectedItemIdentifier - The identifier of the selected row.
	 */
	$scope.onAutoCompleteItemSelect = function(selectedItemIdentifier) {
		var item = searchItem(selectedItemIdentifier);
		if(!Util.isUndefinedOrNull(item))
			self.addItemAsSelected(item, $scope.field);
	};

	/**
	 * Set the item passed as clicked, clearing the component's last input and hiding it's list.
	 *
	 * @function onAutoCompleteItemClick
	 * @public
	 * @param {Object} clickedItem - The clicked item, with it's data.
	 */
	this.onAutoCompleteItemClick = function(clickedItem) {
		self.addItemAsSelected(clickedItem, $scope.field);
	};

	/**
	 * Tells if the given row is the last child.
	 *
	 * @function isLastChild
	 * @private
	 * @param   {Object} row - The row to be tested.
	 * @returns {Boolean} Result of the test of the row being the last child.
	 */
	var isLastChild = function(row) {
		return row._childCount === 0;
	};

	/**
	 * Change the values on the current row used to identify the selected row and, print the fields value on the screen.
	 *
	 * @function changeByName
	 * @private
	 * @param {Field} field - The field to have it's values changed.
	 * @param {Object} row - The selected row.
	 */
	function changeByName(field, row) {
		var valueFields = field.valueFields;
		var currentRow = field.widget.currentRow;
		var fieldName = field.name;
		currentRow[fieldName] = "";

		function buildCurrentRowValueFields(value, key){
			currentRow[value] = row[value];
		}

		valueFields.forEach(buildCurrentRowValueFields);
		currentRow[fieldName] = self.getItemDescription(row);
	}

	/**
	 * Change the given field current row value based on the configured outdata.
	 *
	 * @function changeByOut
	 * @private
	 * @param {Field} field - The field to have it's values changed.
	 * @param {Object} row - The selected row.
	 */
	function changeByOut(field, row) {
		if (field.widget.currentRow) {
			var outData = field.outData || {};

			Object.keys(outData).forEach(function(key) {
				if (Array.isArray(outData[key])) {
					outData[key].forEach(function(valueKey) {
						field.widget.currentRow[valueKey] = row[key];
					});
				}
				else {
					field.widget.currentRow[outData[key]] = row[key];
				}
			});
		}
	}

	/**
	 * Change the given field current row value based on the configured outDescription.
	 *
	 * @function changeByDescription
	 * @private
	 * @param {Field} field - The field to have it's values changed.
	 * @param {Object} row - The selected row.
	 */
	function changeByDescription(field, row) {
		field.widget.currentRow[field.outDescription] = self.getItemDescription(row);
	}

	/**
	 * Get the component's actual value, on it's placeholder, returning the fieldRow, if it is passed.
	 *
	 * @function getSelectionText
	 * @public
	 * @param {Object} [fieldRow] - The clicked item, with it's data.
	 */
	this.getSelectionText = function getSelectionText(fieldRow) {
		return fieldRow || ScreenService.i18n("Search");
	};

	/**
	 * Open a new window.
	 *
	 * @param  {Field} field - The field with the container's name that will be opened.
	 */
	$scope.maintainWindow = function(field) {
		if (field.maintainWindow) {
			var maintainWindowFilter = SelectService.buildMaintainFilter(field);
			ScreenService.openWindow(field.maintainWindow, maintainWindowFilter);
		}
	};

	/**
	 * Build the value to be used as filter.
	 *
	 * @function buildSearchValue
	 * @private
	 * @param {String} itemSearch - The field's input value, used to build the filter.
	 */
	function buildSearchValue(itemSearch) {
		switch ($scope.field.searchIn){
			case 'beginning':
				return itemSearch + "%";
			case 'end':
				return "%" + itemSearch;
			default:
				return "%" + itemSearch + "%";
		}
	}

	/**
	 * Clear the variables related to the filter.
	 *
	 * @function clearSearchFilter
	 * @public
	 * @param   {Object} row - The row to be tested.
	 * @returns {Boolean} Result telling if the field should be displayed.
	 */
	$scope.clearSearchFilter = function(){
		$scope.itemSearch = '';
	};

	/**
	 * Insert into the propertysToSearch the fields that the user can search on the field's dropdown.
	 *
	 * @function addFieldNamesToPropertyToSearch
	 * @private
	 * @param {Array.<Fields>} fields - The fields that should be avaible to search.
	 */
	function addFieldNamesToPropertyToSearch(fields) {
		fields.forEach(function(field){
			propertyToSearch.push(field);
		});
	}

	/**
	 * Build the properties that the user can search on the field's  dropdown.
	 *
	 * @function buildPropertiesToSearch
	 * @private
	 */
	function buildPropertiesToSearch(){
		var field = $scope.field;
		$scope.field.searchWithPagination = Util.isUndefinedOrNull($scope.field.searchWithPagination) ? true : $scope.field.searchWithPagination;
		var propertyToAdd = null;
		if (!Util.isUndefined(field.searchableFields)) {
			propertyToAdd = (field.searchableFields);
		} else if (!Util.isUndefined(field.displayedFields)) {
			propertyToAdd = (field.displayedFields);
		} else {
			propertyToAdd = (field.descriptionFields);
		}

		addFieldNamesToPropertyToSearch(propertyToAdd);
	}

	/**
	 * Initilize the field.name value on it's currentRow.
	 *
	 * @function initializeValuesOnCurrentRow
	 * @private
	 */
	function initializeValuesOnCurrentRow() {
		var currentRow = $scope.field.widget.currentRow;
		var fieldName = $scope.field.name;
		currentRow[fieldName] = currentRow[fieldName] || "";
	}

	/**
	 * Remove the item from the current row by it's index.
	 *
	 * @function removeSelectedItemByIndex
	 * @private
	 */
	function removeSelectedItemByIndex(index) {
		var widgetParent = $scope.field.widget;
		var fieldName = $scope.field.name;
		widgetParent.currentRow[fieldName].splice(index, 1);
	}

	/**
	 * Functions used by template
	 **/

	/**
	 * Get the component's label.
	 *
	 * @function getFieldLabel
	 * @public
	 * @returns {String} The component's label.
	 */
	this.getFieldLabel = function() {
		return $scope.field.label;
	};

	/**
	 * Get the selected item's values.
	 *
	 * @function getSelectedValues
	 * @public
	 * @returns {Object} The values of the selected item.
	 */
	this.getSelectedValues = function() {
		return $scope.field.widget.currentRow[$scope.field.name];
	};

	/**
	 * Get the selected item's description field.
	 *
	 * @function getSelectedItemDescription
	 * @public
	 * @returns {String} The component's data.
	 */
	this.getSelectedItemDescription = function(item) {
		return item[$scope.field.descriptionField];
	};

	/**
	 * Get the component's data.
	 *
	 * @function getData
	 * @public
	 * @returns {Array<Object>} The component's data.
	 */
	this.getData = function() {
		return $scope.field.filteredData;
	};

	$scope.$watchCollection(function() {
		return self.getData();
	}, function(newValues, oldValues) {
		if (newValues !== oldValues) {
			$timeout(function() {
				if($scope.changeDropdownListPosition)
					$scope.changeDropdownListPosition();
			}, 0, false);
		}
	});

	$scope.dropDownLimit = 10;

	/**
	 * Updates the number of items in the dropdown.
	 *
	 * @function loadMore
	 * @public
	 */
	$scope.loadMore = function($event){
		if($scope.dropDownLimit > 29){
			resetDropdown();
			$scope.openField($scope.field, $event);
			return;
		} else if($scope.dropDownLimit > 19){
			$scope.viewMore = ScreenService.i18n("Open search widget");
		}
		$scope.dropDownLimit += 10;
		$event.preventDefault();
		$event.stopPropagation();
		$scope.focusOnInput();
	};

	/**
	 * Set the dropdown to it's initial state.
	 *
	 * @function resetDropdown
	 * @private
	 */
	function resetDropdown() {
		$scope.dropDownLimit = 10;
		$scope.viewMore = ScreenService.i18n("View more...");
	}

	/**
	 * Verify if the LoadMore should be shown on dropDown.
	 *
	 * @function shouldShowLoadMore
	 * @public
	 */
	$scope.shouldShowLoadMore = function(){
		if($scope.field.hasPagination) {
			return $scope.field.filteredData && $scope.field.filteredData.length >= $scope.dropDownLimit;
		} else {
			return false;
		}
	};

	/**
	 * Translate the text of the item according to field's option and i18n.
	 *
	 * @param  {Field}  field The field with the options.
	 * @param  {Object} item  The item With the text to be translated.
	 * @return {String}       The translated text.
	 */
	function translateText(field, item){
		if(!field.getTemplateSimpleName){
			Util.extend(field, new Templatable());
		}
		var text = item[field.name];
		return DecodeValueFieldService.model(field, text);
	}

	/**
	 * Returns the given item's text to be shown on the dropdown.
	 *
	 * @function getItemText
	 * @public
	 * @param   {Object} item - An item from the autocomplete field.
	 * @returns {String}        The item's description field if both have one, or an empty string.
	 */
	this.getItemText = function(item) {
		var itemDescription = [];
		var descriptionFields = $scope.field.descriptionFields;
		var displayedFields = $scope.field.displayedFields;
		var textSpacer = $scope.field.textSpacer || " | ";
		var fields = $scope.field.fields;

		function buildTranslatedItemDescription(description, key){
			var field = fields.filter(function(field){
				return field.name === description;
			})[0];
			itemDescription[key] = translateText(field, item);
		}

		function buildItemDescription(description, key){
			itemDescription[key] = item[description];
		}

		if(displayedFields){
			if(fields){
				displayedFields.forEach(buildTranslatedItemDescription);
			}
			else {
				displayedFields.forEach(buildItemDescription);
			}
		}
		else {
			if(fields){
				descriptionFields.forEach(buildTranslatedItemDescription);
			}
			else {
				descriptionFields.forEach(buildItemDescription);
			}
		}
		return itemDescription.join(textSpacer);
	};


	/**
	 * Returns the given item's descriptionField if the field has an descriptionField.
	 *
	 * @function getItemDescription
	 * @public
	 * @param   {Object} item - An item from the autocomplete field.
	 * @returns {String}        The item's description field if both have one, or an empty string.
	 */
	this.getItemDescription = function(item){
		var itemDescription = [];
		var descriptionFields = $scope.field.descriptionFields;
		var textSpacer = $scope.field.textSpacer || " | ";
		var fields = $scope.field.fields;

		function buildTranslatedItemDescription(description, key){
			var field = fields.filter(function(field){
				return field.name === description;
			})[0];
			itemDescription[key] = translateText(field, item);
		}

		function buildItemDescription(description, key){
			itemDescription[key] = item[description];
		}

		if(fields){
			descriptionFields.forEach(buildTranslatedItemDescription);
		}
		else {
			descriptionFields.forEach(buildItemDescription);
		}
		itemDescription = itemDescription.join(textSpacer);

		return itemDescription;
	};

	/**
	 * Remove the item with the given index from the parent field's current row.
	 *
	 * @function onRemoveSelectedItem
	 * @public
	 * @param {Integer} item - The index of the item to be removed.
	 */
	this.onRemoveSelectedItem = function(removedItemIndex) {
		removeSelectedItemByIndex(removedItemIndex);
	};

	/**
	 * Clear the field's search parameter and it's list data.
	 *
	 * @function clearAutoCompleteListData
	 */
	$scope.clearAutoCompleteListData = function() {
		$scope.itemSearch = '';
		$scope.clearInputFieldText();
		$scope.autoCompleteListData = [];
		$scope.clearSelectedItem();
		$scope.showSpan = true;
	};

	/**
	 * Clear the value on the field's input.
	 *
	 * @function clearEditableInput
	 * @public
	 */
	this.clearEditableInput = function() {
		$scope.inputWithEditableContent.val('');
	};

	/**
	 * Tells if the component should display the span with the currentRow value.
	 *
	 * @function shouldShowSpan
	 * @public
	 * @returns {Boolean} Value telling if the span should be displayed.
	 */
	this.shouldShowSpan = function() {
		var isReadOnly = $scope.field.isReadOnly();
		return isReadOnly || $scope.showSpan;
	};
};

ZeedhiController.controller('ZhSelectAutoCompleteController', ZhSelectAutoCompleteController);

// FILE: src/directives/zh-select-autocomplete.directive.js
// register jQuery extension to select by TAB and Navation by press TAB
jQuery.extend(jQuery.expr[':'], {
    focusable: function(el) {
        return $(el).is('a, button, :input, [tabindex]');
    }
});

/**
 *
 */
(function() {

    var ZeedhiDirectives = angular.module('ZeedhiDirectives');
    ZeedhiDirectives.directive('zhSelectAutocomplete', ['$timeout', 'eventEngine', zhSelectAutocomplete]);

    function zhSelectAutocomplete($timeout, eventEngine) {

        var ENTER = 13;
        var DOWN = 40;
        var ESC = 27;
        var TAB = 9;
        var UP = 38;


        var linkFunction = function(theScope, theElement) {

            var $scope = theScope;
            var element = theElement;
            var selectedList = '';
            var loaderElement = $('img.autocomplete-loading-icon');
            var lazyLoadEventIndex;

            $scope.hideLoader = function() {
                loaderElement.hide();
            };
            $scope.showLoader = function() {
                loaderElement.css('display', 'initial');
            };

            $scope.itemSearch = $scope.itemSearch || "";
            $scope.selectAutoCompleteElement = $(element);
            $scope.inputWithEditableContent = $(element).find('.editable');

            if($scope.field.lazyLoadEvent){
                lazyLoadEventIndex = eventEngine.bindEvent($scope.inputWithEditableContent, $scope.field.lazyLoadEvent, function(){
                    $scope.field.initializeField();
                });
            }

            /**
             * Creates the input focus, change and blur events listeners.
             *
             * @function createInputListeners
             * @private
             */
            function createInputListeners() {
                $scope.inputWithEditableContent.change(function(evt) {
                    evt.stopPropagation();
                });
                
                $scope.inputWithEditableContent.blur(function(evt) {
                    var hasSelected = $('.show-select span:hover')[0];
                    if (!hasSelected) {
                        $scope.removeFocusOfInput();
                    }
                    if ($scope.field.blur) $scope.field.blur();
                    $scope.showLoading = false;
                });
                
                $scope.inputWithEditableContent.on('click', function(evt) {
                    evt.stopPropagation();
                    if ($scope.field.click) $scope.field.click();
                    $scope.inputWithEditableContent.focus();
                });

                $scope.inputWithEditableContent.focus(function(evt) {
                    if ($scope.field.isReadOnly()) return;
                    $scope.showLoading = true;
                    $timeout(function() {
                        $scope.inputWithEditableContent.val($scope.itemSearch);
                        $scope.inputWithEditableContent.select();
                        $scope.inputWithEditableContent.parent().scrollTop(0);
                        $scope.showSpan = false;
                        $scope.changeDropdownListPosition();
                        $timeout(function() {
                            $scope.$apply();
                            $scope.processBeforeSelectOpenEvent($scope.field);
                            $scope.field.initializeField();
                            $scope.openList();
                            $scope.processAfterSelectOpenEvent($scope.field);
                            $scope.selectAutoCompleteElement.closest("[zh-scroller]").on("scroll." + $scope.$id, function() {
                                $scope.hideList();
                            });
                        }, 0, false);
                    });
                });
            }

            createInputListeners();
            keyPressNavegationListener();

            /**
             * Creates the key press navigation listener.
             *
             * @function keyPressNavegationListener
             * @private
             */
            function keyPressNavegationListener() {
                var next;
                var navegationKeyPress = $scope.selectAutoCompleteElement;
                navegationKeyPress.on('keydown', 'input,select', function(event) {

                    var EVENTKEY = event;
                    var spanList = $scope.selectAutoCompleteElement.find('.show-select span');

                    if(EVENTKEY.which === DOWN || EVENTKEY.which === UP ) {
                        EVENTKEY.preventDefault();
                    }

                    if (EVENTKEY.which === ENTER || EVENTKEY.which === TAB) {
                        EVENTKEY.preventDefault();

                        var selected = $(event.target.parentNode.nextElementSibling).find('.selected');

                        if (isShowMore(selected)) {
                            $scope.loadMore(event);
                        } else {
                            if(canSelect(selected)){
                                $scope.selectItem(selected);
                                $scope.inputWithEditableContent.val("");
                            }
                            if (getFocusableItems().length > 1) {
                                $scope.removeFocusOfInput();
                                $scope.focusOnNextItem(EVENTKEY.which === TAB && EVENTKEY.shiftKey);
                            }
                        }

                    } else if (EVENTKEY.which === DOWN) {
                        if (selectedList) {
                            selectedList.removeClass('selected');
                            next = selectedList.next();
                            if (next.length > 0) {
                                selectedList = next.addClass('selected');
                            } else {
                                selectedList = spanList.eq(0).addClass('selected');
                            }
                        } else {
                            selectedList = spanList.eq(0).addClass('selected');
                        }
                    } else if (EVENTKEY.which === UP) {
                        if (selectedList) {
                            selectedList.removeClass('selected');
                            next = selectedList.prev();
                            if (next.length > 0) {
                                selectedList = next.addClass('selected');
                            } else {
                                selectedList = spanList.last().addClass('selected');
                            }
                        } else {
                            selectedList = spanList.last().addClass('selected');
                        }
                    } else if (EVENTKEY.which === ESC) {
                        $scope.hideList();
                        selectedList = '';
                        return false;
                    }

                    if (navegationKeyPress) {
                        var itemList = $scope.selectAutoCompleteElement.find('.list-items');
                        var item = navegationKeyPress.find('.selected');
                        var index;

                        if (item.offset() !== undefined) {
                            if (EVENTKEY.which === ENTER) {
                                spanList = $scope.selectAutoCompleteElement.find('.show-select span');
                                index = $scope.dropDownLimit - 10;
                                movimentation = (index + 3.7) * 32 + item.outerHeight() - itemList.innerHeight();
                                animateItemFocus(itemList, movimentation);
                                selectedList = spanList.eq(index);
                                selectedList.addClass('selected');
                            } else {
                                index = parseInt(item.attr('data-item-index')) || parseInt(item.prev().attr('data-item-index')) + 1;
                                var movimentation = 0;
                                if (item.position().top + item.outerHeight() > itemList.innerHeight()) {
                                    movimentation = (index * 32 + item.outerHeight() - itemList.innerHeight());
                                    animateItemFocus(itemList, movimentation);
                                } else if (item.position().top < 0) {
                                    movimentation = index * 32;
                                    animateItemFocus(itemList, movimentation);
                                }
                            }
                        }
                    }
                });
            }

            /**
             * Makes the animation to scroll the item for the one who has focus.
             *
             * @function animateItemFocus
             * @private
             * @param  {Object} itemList      - The element witch has the list of items
             * @param  {Number} movimentation - The value in pixels of the scrolling distance from the top.
             */
            function animateItemFocus(itemList, movimentation) {
                itemList.finish().animate({
                    scrollTop: movimentation
                }, 500);
            }

            /**
             * Get all the focusabel items.
             *
             * @function getFocusableItems
             * @private
             * @returns {Array.<Object>} The focusable items on the screen.
             */
            function getFocusableItems() {
                return $(':tabbable');
            }

            /**
             * Test if the given selectedList is a valid row to be selected.
             *
             * @function canSelect
             * @private
             * @returns {Boolean} Result telling if the selectedList is a valid row to be selected.
             */
            function canSelect(selectedList) {
                return (typeof selectedList === "string" && selectedList !== "") ||
                    (typeof selectedList === "object" && selectedList.text() !== "") &&
                    selectedList.attr("data-item-identifier");
            }

            function isShowMore(selectedItem) {
                return selectedItem && selectedItem.hasClass("view-more");
            }

            /**
             * Open the field's dropdown list.
             *
             * @function openList
             */
            $scope.openList = function() {
                $scope.hideList();
                $scope.selectAutoCompleteElement.find(".show-select").css("display", "block");
                $scope.selectAutoCompleteElement.find('.list-items').scrollTop(0);
            };


            /**
             * Change the dropdown list position on field.
             *
             * @function changeDropdownListPosition
             */
            $scope.changeDropdownListPosition = function() {
                var dropdown = $scope.selectAutoCompleteElement.find('.zh-select-autocomplete');
                var dropdownOffset = dropdown.offset().top;
                var listItemsElement = $scope.selectAutoCompleteElement.find('.list-items');

                updateListWidth(listItemsElement, dropdown);
                updateListPosition(listItemsElement, dropdownOffset, dropdown);
            };

            /**
             * Updates the position of the dropdown list.
             *
             * @function updateListPosition
             * @param {Element} listItemsElement - The list's DOM.
             * @param {Element} dropdownOffset - The dropdown's offset.
             * @param {Element} dropdown - The dropdown's DOM.
             */
            function updateListPosition(listItemsElement, dropdownOffset, dropdown) {
                var popupModal = $('.popup-modal');
                if (popupModal.length) {
                    dropdownOffset -= popupModal.offset().top;
                }
                listItemsElement.css('top', dropdownOffset + dropdown.outerHeight() - getParentFixedTop(dropdown));
                if (dropdown.offset().top + dropdown.outerHeight() + listItemsElement.outerHeight() + 10 > $(window).height()) {
                    listItemsElement.css('margin-top', -1 * (dropdown.outerHeight() + listItemsElement.outerHeight()));
                }
                else {
                    listItemsElement.css('margin-top', 0);
                }
            }

            /**
             * Updates the width of the dropdown list.
             *
             * @function updateListWidth
             * @param {Element} listItemsElement - The list's DOM.
             * @param {Element} dropdown - The dropdown's DOM.
             */
            function updateListWidth(listItemsElement, dropdown) {
                if(listItemsElement.width() !== dropdown.innerWidth()){
                    listItemsElement.width(dropdown.innerWidth());
                }
            }

            /**
             * Get the parent fixed top position element.
             *
             * @function getParentFixedTop
             * @param {String} el - A element of the DOM.
             */
            function getParentFixedTop(el) {
                var parents = el.parents();
                var top = 0;
                parents.each(function(idx, item) {
                    item = $(item);
                    if ((item.css('position') === "fixed" || item.css('position') === "absolute") &&
                        item.parent() && (item.parent().css('position') === "fixed" || item.parent().css('position') === "absolute")) {
                        top = item.offset().top;
                        return false;
                    }
                });

                return top;
            }

            /**
             * Clear the field input's text.
             *
             * @function clearInputFieldText
             */
            $scope.clearInputFieldText = function() {
                $scope.selectAutoCompleteElement.find('input:text').val('');
            };

            /**
             * Hide the fields's dropdown list.
             *
             * @function hideList
             */
            $scope.hideList = function() {
                $(".show-select").hide();
                $('.show-select span').removeClass('selected');
                $scope.selectAutoCompleteElement.closest("[zh-scroller]").off("scroll." + $scope.$id);
            };

            /**
             * Set as selected the given item.
             *
             * @function selectItem
             * @param {Object} selected - The DOM element of the selected row.
             */
            $scope.selectItem = function(selected) {
                if(!selected) return;
                selectedItem = selected.text();
                var itemIdentifier = selected.attr("data-item-identifier");
                $scope.onAutoCompleteItemSelect(itemIdentifier);
            };

            /**
             * Focus on the next item of the screen.
             *
             * @function focusOnNextItem
             */
            $scope.focusOnNextItem = function(reverse) {
                $scope.inputHasFocus = false;
                $canfocus = getFocusableItems();
                var index = $canfocus.index($scope.inputWithEditableContent) + (reverse ? -1 : 1);
                if (!reverse && index >= $canfocus.length) index = 0;
                if (reverse && index < 0) index = $canfocus.length - 1;
                $canfocus.eq(index).focus();
            };

            $scope.focusOnInput = function() {
                if ($scope.field.isReadOnly()) return;
                $scope.inputWithEditableContent.focus();
            };

            $scope.removeFocusOfInput = function() {
                $scope.clearInputFieldText();
                $scope.showSpan = $scope.hasValueSet();
                $scope.hideList();
                $timeout(function() {
                    $scope.$apply();
                }, 0, false);
            };

            $scope.clearSelectedItem = function() {
                var item = $scope.inputWithEditableContent.find('.selected');
                selectedList = '';
                item.removeClass('selected');
            };

            function updateDropdownOnResize() {
                $scope.changeDropdownListPosition();
            }

            $(window).resize(updateDropdownOnResize);

            $scope.$on("$destroy", function(){
                $('div.zh-background-loading').off('mouseup');
                $(window).unbind('mouseup', updateDropdownOnResize);
                $scope.selectAutoCompleteElement.closest("[zh-scroller]").off("scroll." + $scope.$id);
                eventEngine.unbindEvent($scope.inputWithEditableContent, $scope.field.lazyLoadEvent, lazyLoadEventIndex);
            });

        };

        return {
            restrict: 'A',
            link: linkFunction
        };
    }
})();

// FILE: src/registers/zh-select-autocomplete.register.js
(function () {

	Configuration(registerSelectAutocomplete);

	function registerSelectAutocomplete(decodeTemplateFieldService) {
		decodeTemplateFieldService.registerViewTemplate(
			"zh-select-autocomplete#field/select-autocomplete.html",
			"zh-select-autocomplete#field/select-autocomplete-view.html"
		);
	}

})();

// FILE: ./bower_components/zh-rich-text/dist/zh-rich-text.js

// FILE: src/lib/00.html-css-sanitizer-minified.js
(function(){var c=void 0,n=!0,s=null,C=!1,J=["aliceblue,antiquewhite,aqua,aquamarine,azure,beige,bisque,black,blanchedalmond,blue,blueviolet,brown,burlywood,cadetblue,chartreuse,chocolate,coral,cornflowerblue,cornsilk,crimson,cyan,darkblue,darkcyan,darkgoldenrod,darkgray,darkgreen,darkkhaki,darkmagenta,darkolivegreen,darkorange,darkorchid,darkred,darksalmon,darkseagreen,darkslateblue,darkslategray,darkturquoise,darkviolet,deeppink,deepskyblue,dimgray,dodgerblue,firebrick,floralwhite,forestgreen,fuchsia,gainsboro,ghostwhite,gold,goldenrod,gray,green,greenyellow,honeydew,hotpink,indianred,indigo,ivory,khaki,lavender,lavenderblush,lawngreen,lemonchiffon,lightblue,lightcoral,lightcyan,lightgoldenrodyellow,lightgreen,lightgrey,lightpink,lightsalmon,lightseagreen,lightskyblue,lightslategray,lightsteelblue,lightyellow,lime,limegreen,linen,magenta,maroon,mediumaquamarine,mediumblue,mediumorchid,mediumpurple,mediumseagreen,mediumslateblue,mediumspringgreen,mediumturquoise,mediumvioletred,midnightblue,mintcream,mistyrose,moccasin,navajowhite,navy,oldlace,olive,olivedrab,orange,orangered,orchid,palegoldenrod,palegreen,paleturquoise,palevioletred,papayawhip,peachpuff,peru,pink,plum,powderblue,purple,red,rosybrown,royalblue,saddlebrown,salmon,sandybrown,seagreen,seashell,sienna,silver,skyblue,slateblue,slategray,snow,springgreen,steelblue,tan,teal,thistle,tomato,transparent,turquoise,violet,wheat,white,whitesmoke,yellow,yellowgreen".split(","),
"all-scroll,col-resize,crosshair,default,e-resize,hand,help,move,n-resize,ne-resize,no-drop,not-allowed,nw-resize,pointer,progress,row-resize,s-resize,se-resize,sw-resize,text,vertical-text,w-resize,wait".split(","),"armenian,decimal,decimal-leading-zero,disc,georgian,lower-alpha,lower-greek,lower-latin,lower-roman,square,upper-alpha,upper-latin,upper-roman".split(","),"100,200,300,400,500,600,700,800,900,bold,bolder,lighter".split(","),"block-level,inline-level,table-caption,table-cell,table-column,table-column-group,table-footer-group,table-header-group,table-row,table-row-group".split(","),
"condensed,expanded,extra-condensed,extra-expanded,narrower,semi-condensed,semi-expanded,ultra-condensed,ultra-expanded,wider".split(","),"inherit,inline,inline-block,inline-box,inline-flex,inline-grid,inline-list-item,inline-stack,inline-table,run-in".split(","),"behind,center-left,center-right,far-left,far-right,left-side,leftwards,right-side,rightwards".split(","),"large,larger,small,smaller,x-large,x-small,xx-large,xx-small".split(","),"dashed,dotted,double,groove,outset,ridge,solid".split(","),
"ease,ease-in,ease-in-out,ease-out,linear,step-end,step-start".split(","),"at,closest-corner,closest-side,ellipse,farthest-corner,farthest-side".split(","),"baseline,middle,sub,super,text-bottom,text-top".split(","),"caption,icon,menu,message-box,small-caption,status-bar".split(","),"fast,faster,slow,slower,x-fast,x-slow".split(","),["above","below","higher","level","lower"],["cursive","fantasy","monospace","sans-serif","serif"],["loud","silent","soft","x-loud","x-soft"],["no-repeat","repeat-x","repeat-y",
"round","space"],["blink","line-through","overline","underline"],["block","flex","grid","table"],["high","low","x-high","x-low"],["nowrap","pre","pre-line","pre-wrap"],["absolute","relative","static"],["alternate","alternate-reverse","reverse"],["border-box","content-box","padding-box"],["capitalize","lowercase","uppercase"],["child","female","male"],["=","opacity"],["backwards","forwards"],["bidi-override","embed"],["bottom","top"],["break-all","keep-all"],["clip","ellipsis"],["contain","cover"],
["continuous","digits"],["end","start"],["flat","preserve-3d"],["hide","show"],["horizontal","vertical"],["inside","outside"],["italic","oblique"],["left","right"],["ltr","rtl"],["no-content","no-display"],["paused","running"],["suppress","unrestricted"],["thick","thin"],[","],["/"],["all"],["always"],["auto"],["avoid"],["both"],["break-word"],["center"],["circle"],["code"],["collapse"],["contents"],["fixed"],["hidden"],["infinite"],["inset"],["invert"],["justify"],["list-item"],["local"],["medium"],
["mix"],["none"],["normal"],["once"],["repeat"],["scroll"],["separate"],["small-caps"],["spell-out"],["to"],["visible"]],L={animation:{cssPropBits:517,cssLitGroup:[J[10],J[24],J[29],J[45],J[48],J[54],J[63],J[71],J[72]],cssFns:["cubic-bezier()","steps()"]},"animation-delay":{cssPropBits:5,cssLitGroup:[J[48]],cssFns:[]},"animation-direction":{cssPropBits:0,cssLitGroup:[J[24],J[48],J[72]],cssFns:[]},"animation-duration":"animation-delay","animation-fill-mode":{cssPropBits:0,cssLitGroup:[J[29],J[48],
J[54],J[71]],cssFns:[]},"animation-iteration-count":{cssPropBits:5,cssLitGroup:[J[48],J[63]],cssFns:[]},"animation-name":{cssPropBits:512,cssLitGroup:[J[48],J[71]],cssFns:[]},"animation-play-state":{cssPropBits:0,cssLitGroup:[J[45],J[48]],cssFns:[]},"animation-timing-function":{cssPropBits:0,cssLitGroup:[J[10],J[48]],cssFns:["cubic-bezier()","steps()"]},appearance:{cssPropBits:0,cssLitGroup:[J[71]],cssFns:[]},azimuth:{cssPropBits:5,cssLitGroup:[J[7],J[42],J[56]],cssFns:[]},"backface-visibility":{cssPropBits:0,
cssLitGroup:[J[59],J[62],J[80]],cssFns:[]},background:{cssPropBits:23,cssLitGroup:[J[0],J[18],J[25],J[31],J[34],J[42],J[48],J[49],J[52],J[56],J[61],J[68],J[71],J[74],J[75]],cssFns:"image(),linear-gradient(),radial-gradient(),repeating-linear-gradient(),repeating-radial-gradient(),rgb(),rgba()".split(",")},"background-attachment":{cssPropBits:0,cssLitGroup:[J[48],J[61],J[68],J[75]],cssFns:[]},"background-color":{cssPropBits:2,cssLitGroup:[J[0]],cssFns:["rgb()","rgba()"]},"background-image":{cssPropBits:16,
cssLitGroup:[J[48],J[71]],cssFns:["image()","linear-gradient()","radial-gradient()","repeating-linear-gradient()","repeating-radial-gradient()"]},"background-position":{cssPropBits:5,cssLitGroup:[J[31],J[42],J[48],J[56]],cssFns:[]},"background-repeat":{cssPropBits:0,cssLitGroup:[J[18],J[48],J[74]],cssFns:[]},"background-size":{cssPropBits:5,cssLitGroup:[J[34],J[48],J[52]],cssFns:[]},border:{cssPropBits:7,cssLitGroup:[J[0],J[9],J[47],J[62],J[64],J[69],J[71]],cssFns:["rgb()","rgba()"]},"border-bottom":"border",
"border-bottom-color":"background-color","border-bottom-left-radius":{cssPropBits:5,cssFns:[]},"border-bottom-right-radius":"border-bottom-left-radius","border-bottom-style":{cssPropBits:0,cssLitGroup:[J[9],J[62],J[64],J[71]],cssFns:[]},"border-bottom-width":{cssPropBits:5,cssLitGroup:[J[47],J[69]],cssFns:[]},"border-collapse":{cssPropBits:0,cssLitGroup:[J[59],J[76]],cssFns:[]},"border-color":"background-color","border-left":"border","border-left-color":"background-color","border-left-style":"border-bottom-style",
"border-left-width":"border-bottom-width","border-radius":{cssPropBits:5,cssLitGroup:[J[49]],cssFns:[]},"border-right":"border","border-right-color":"background-color","border-right-style":"border-bottom-style","border-right-width":"border-bottom-width","border-spacing":"border-bottom-left-radius","border-style":"border-bottom-style","border-top":"border","border-top-color":"background-color","border-top-left-radius":"border-bottom-left-radius","border-top-right-radius":"border-bottom-left-radius",
"border-top-style":"border-bottom-style","border-top-width":"border-bottom-width","border-width":"border-bottom-width",bottom:{cssPropBits:5,cssLitGroup:[J[52]],cssFns:[]},box:{cssPropBits:0,cssLitGroup:[J[60],J[71],J[72]],cssFns:[]},"box-shadow":{cssPropBits:7,cssLitGroup:[J[0],J[48],J[64],J[71]],cssFns:["rgb()","rgba()"]},"box-sizing":{cssPropBits:0,cssLitGroup:[J[25]],cssFns:[]},"caption-side":{cssPropBits:0,cssLitGroup:[J[31]],cssFns:[]},clear:{cssPropBits:0,cssLitGroup:[J[42],J[54],J[71]],cssFns:[]},
clip:{cssPropBits:0,cssLitGroup:[J[52]],cssFns:["rect()"]},color:"background-color",content:{cssPropBits:8,cssLitGroup:[J[71],J[72]],cssFns:[]},cue:{cssPropBits:16,cssLitGroup:[J[71]],cssFns:[]},"cue-after":"cue","cue-before":"cue",cursor:{cssPropBits:16,cssLitGroup:[J[1],J[48],J[52]],cssFns:[]},direction:{cssPropBits:0,cssLitGroup:[J[43]],cssFns:[]},display:{cssPropBits:0,cssLitGroup:[J[4],J[6],J[20],J[52],J[67],J[71]],cssFns:[]},"display-extras":{cssPropBits:0,cssLitGroup:[J[67],J[71]],cssFns:[]},
"display-inside":{cssPropBits:0,cssLitGroup:[J[20],J[52]],cssFns:[]},"display-outside":{cssPropBits:0,cssLitGroup:[J[4],J[71]],cssFns:[]},elevation:{cssPropBits:5,cssLitGroup:[J[15]],cssFns:[]},"empty-cells":{cssPropBits:0,cssLitGroup:[J[38]],cssFns:[]},filter:{cssPropBits:0,cssFns:["alpha()"]},"float":{cssPropBits:0,cssLitGroup:[J[42],J[71]],cssFns:[]},font:{cssPropBits:73,cssLitGroup:[J[3],J[8],J[13],J[16],J[41],J[48],J[49],J[69],J[72],J[77]],cssFns:[]},"font-family":{cssPropBits:72,cssLitGroup:[J[16],
J[48]],cssFns:[]},"font-size":{cssPropBits:1,cssLitGroup:[J[8],J[69]],cssFns:[]},"font-stretch":{cssPropBits:0,cssLitGroup:[J[5],J[72]],cssFns:[]},"font-style":{cssPropBits:0,cssLitGroup:[J[41],J[72]],cssFns:[]},"font-variant":{cssPropBits:0,cssLitGroup:[J[72],J[77]],cssFns:[]},"font-weight":{cssPropBits:0,cssLitGroup:[J[3],J[72]],cssFns:[]},height:"bottom",left:"bottom","letter-spacing":{cssPropBits:5,cssLitGroup:[J[72]],cssFns:[]},"line-height":{cssPropBits:1,cssLitGroup:[J[72]],cssFns:[]},"list-style":{cssPropBits:16,
cssLitGroup:[J[2],J[40],J[57],J[71]],cssFns:["image()","linear-gradient()","radial-gradient()","repeating-linear-gradient()","repeating-radial-gradient()"]},"list-style-image":{cssPropBits:16,cssLitGroup:[J[71]],cssFns:["image()","linear-gradient()","radial-gradient()","repeating-linear-gradient()","repeating-radial-gradient()"]},"list-style-position":{cssPropBits:0,cssLitGroup:[J[40]],cssFns:[]},"list-style-type":{cssPropBits:0,cssLitGroup:[J[2],J[57],J[71]],cssFns:[]},margin:"bottom","margin-bottom":"bottom",
"margin-left":"bottom","margin-right":"bottom","margin-top":"bottom","max-height":{cssPropBits:1,cssLitGroup:[J[52],J[71]],cssFns:[]},"max-width":"max-height","min-height":{cssPropBits:1,cssLitGroup:[J[52]],cssFns:[]},"min-width":"min-height",opacity:{cssPropBits:1,cssFns:[]},outline:{cssPropBits:7,cssLitGroup:[J[0],J[9],J[47],J[62],J[64],J[65],J[69],J[71]],cssFns:["rgb()","rgba()"]},"outline-color":{cssPropBits:2,cssLitGroup:[J[0],J[65]],cssFns:["rgb()","rgba()"]},"outline-style":"border-bottom-style",
"outline-width":"border-bottom-width",overflow:{cssPropBits:0,cssLitGroup:[J[52],J[62],J[75],J[80]],cssFns:[]},"overflow-wrap":{cssPropBits:0,cssLitGroup:[J[55],J[72]],cssFns:[]},"overflow-x":{cssPropBits:0,cssLitGroup:[J[44],J[52],J[62],J[75],J[80]],cssFns:[]},"overflow-y":"overflow-x",padding:"opacity","padding-bottom":"opacity","padding-left":"opacity","padding-right":"opacity","padding-top":"opacity","page-break-after":{cssPropBits:0,cssLitGroup:[J[42],J[51],J[52],J[53]],cssFns:[]},"page-break-before":"page-break-after",
"page-break-inside":{cssPropBits:0,cssLitGroup:[J[52],J[53]],cssFns:[]},pause:"border-bottom-left-radius","pause-after":"border-bottom-left-radius","pause-before":"border-bottom-left-radius",perspective:{cssPropBits:5,cssLitGroup:[J[71]],cssFns:[]},"perspective-origin":{cssPropBits:5,cssLitGroup:[J[31],J[42],J[56]],cssFns:[]},pitch:{cssPropBits:5,cssLitGroup:[J[21],J[69]],cssFns:[]},"pitch-range":"border-bottom-left-radius","play-during":{cssPropBits:16,cssLitGroup:[J[52],J[70],J[71],J[74]],cssFns:[]},
position:{cssPropBits:0,cssLitGroup:[J[23]],cssFns:[]},quotes:{cssPropBits:8,cssLitGroup:[J[71]],cssFns:[]},resize:{cssPropBits:0,cssLitGroup:[J[39],J[54],J[71]],cssFns:[]},richness:"border-bottom-left-radius",right:"bottom",speak:{cssPropBits:0,cssLitGroup:[J[71],J[72],J[78]],cssFns:[]},"speak-header":{cssPropBits:0,cssLitGroup:[J[51],J[73]],cssFns:[]},"speak-numeral":{cssPropBits:0,cssLitGroup:[J[35]],cssFns:[]},"speak-punctuation":{cssPropBits:0,cssLitGroup:[J[58],J[71]],cssFns:[]},"speech-rate":{cssPropBits:5,
cssLitGroup:[J[14],J[69]],cssFns:[]},stress:"border-bottom-left-radius","table-layout":{cssPropBits:0,cssLitGroup:[J[52],J[61]],cssFns:[]},"text-align":{cssPropBits:0,cssLitGroup:[J[42],J[56],J[66]],cssFns:[]},"text-decoration":{cssPropBits:0,cssLitGroup:[J[19],J[71]],cssFns:[]},"text-indent":"border-bottom-left-radius","text-overflow":{cssPropBits:8,cssLitGroup:[J[33]],cssFns:[]},"text-shadow":"box-shadow","text-transform":{cssPropBits:0,cssLitGroup:[J[26],J[71]],cssFns:[]},"text-wrap":{cssPropBits:0,
cssLitGroup:[J[46],J[71],J[72]],cssFns:[]},top:"bottom",transform:{cssPropBits:0,cssLitGroup:[J[71]],cssFns:"matrix(),perspective(),rotate(),rotate3d(),rotatex(),rotatey(),rotatez(),scale(),scale3d(),scalex(),scaley(),scalez(),skew(),skewx(),skewy(),translate(),translate3d(),translatex(),translatey(),translatez()".split(",")},"transform-origin":"perspective-origin","transform-style":{cssPropBits:0,cssLitGroup:[J[37]],cssFns:[]},transition:{cssPropBits:1029,cssLitGroup:[J[10],J[48],J[50],J[71]],cssFns:["cubic-bezier()",
"steps()"]},"transition-delay":"animation-delay","transition-duration":"animation-delay","transition-property":{cssPropBits:1024,cssLitGroup:[J[48],J[50]],cssFns:[]},"transition-timing-function":"animation-timing-function","unicode-bidi":{cssPropBits:0,cssLitGroup:[J[30],J[72]],cssFns:[]},"vertical-align":{cssPropBits:5,cssLitGroup:[J[12],J[31]],cssFns:[]},visibility:"backface-visibility","voice-family":{cssPropBits:8,cssLitGroup:[J[27],J[48]],cssFns:[]},volume:{cssPropBits:1,cssLitGroup:[J[17],J[69]],
cssFns:[]},"white-space":{cssPropBits:0,cssLitGroup:[J[22],J[72]],cssFns:[]},width:"min-height","word-break":{cssPropBits:0,cssLitGroup:[J[32],J[72]],cssFns:[]},"word-spacing":"letter-spacing","word-wrap":"overflow-wrap","z-index":"bottom",zoom:"line-height","cubic-bezier()":"animation-delay","steps()":{cssPropBits:5,cssLitGroup:[J[36],J[48]],cssFns:[]},"image()":{cssPropBits:18,cssLitGroup:[J[0],J[48]],cssFns:["rgb()","rgba()"]},"linear-gradient()":{cssPropBits:7,cssLitGroup:[J[0],J[31],J[42],J[48],
J[79]],cssFns:["rgb()","rgba()"]},"radial-gradient()":{cssPropBits:7,cssLitGroup:[J[0],J[11],J[31],J[42],J[48],J[56],J[57]],cssFns:["rgb()","rgba()"]},"repeating-linear-gradient()":"linear-gradient()","repeating-radial-gradient()":"radial-gradient()","rgb()":{cssPropBits:1,cssLitGroup:[J[48]],cssFns:[]},"rgba()":"rgb()","rect()":{cssPropBits:5,cssLitGroup:[J[48],J[52]],cssFns:[]},"alpha()":{cssPropBits:1,cssLitGroup:[J[28]],cssFns:[]},"matrix()":"animation-delay","perspective()":"border-bottom-left-radius",
"rotate()":"border-bottom-left-radius","rotate3d()":"animation-delay","rotatex()":"border-bottom-left-radius","rotatey()":"border-bottom-left-radius","rotatez()":"border-bottom-left-radius","scale()":"animation-delay","scale3d()":"animation-delay","scalex()":"border-bottom-left-radius","scaley()":"border-bottom-left-radius","scalez()":"border-bottom-left-radius","skew()":"animation-delay","skewx()":"border-bottom-left-radius","skewy()":"border-bottom-left-radius","translate()":"animation-delay","translate3d()":"animation-delay",
"translatex()":"border-bottom-left-radius","translatey()":"border-bottom-left-radius","translatez()":"border-bottom-left-radius"},O;for(O in L)"string"===typeof L[O]&&Object.hasOwnProperty.call(L,O)&&(L[O]=L[L[O]]);"undefined"!==typeof window&&(window.cssSchema=L);var U,X;
(function(){function g(a){var b=parseInt(a.substring(1),16);return 65535<b?(b-=65536,String.fromCharCode(55296+(b>>10),56320+(b&1023))):b==b?String.fromCharCode(b):" ">a[1]?"":a[1]}function w(a,b){return'"'+a.replace(/[\u0000-\u001f\\\"<>]/g,b)+'"'}function M(a){return E[a]||(E[a]="\\"+a.charCodeAt(0).toString(16)+" ")}function x(a){return e[a]||(e[a]=("\u0010">a?"%0":"%")+a.charCodeAt(0).toString(16))}var E={"\\":"\\\\"},e={"\\":"%5c"},v=RegExp("\\uFEFF|U[+][0-9A-F?]{1,6}(?:-[0-9A-F]{1,6})?|url[(][\\t\\n\\f ]*(?:\"(?:'|[^'\"\\n\\f\\\\]|\\\\[\\s\\S])*\"|'(?:\"|[^'\"\\n\\f\\\\]|\\\\[\\s\\S])*'|(?:[\\t\\x21\\x23-\\x26\\x28-\\x5b\\x5d-\\x7e]|[\\u0080-\\ud7ff\\ue000-\\ufffd]|[\\ud800-\\udbff][\\udc00-\\udfff]|\\\\(?:[0-9a-fA-F]{1,6}[\\t\\n\\f ]?|[\\u0020-\\u007e\\u0080-\\ud7ff\\ue000\\ufffd]|[\\ud800-\\udbff][\\udc00-\\udfff]))*)[\\t\\n\\f ]*[)]|(?!url[(])-?(?:[a-zA-Z_]|[\\u0080-\\ud7ff\\ue000-\\ufffd]|[\\ud800-\\udbff][\\udc00-\\udfff]|\\\\(?:[0-9a-fA-F]{1,6}[\\t\\n\\f ]?|[\\u0020-\\u007e\\u0080-\\ud7ff\\ue000\\ufffd]|[\\ud800-\\udbff][\\udc00-\\udfff]))(?:[a-zA-Z0-9_-]|[\\u0080-\\ud7ff\\ue000-\\ufffd]|[\\ud800-\\udbff][\\udc00-\\udfff]|\\\\(?:[0-9a-fA-F]{1,6}[\\t\\n\\f ]?|[\\u0020-\\u007e\\u0080-\\ud7ff\\ue000\\ufffd]|[\\ud800-\\udbff][\\udc00-\\udfff]))*[(]|(?:@?-?(?:[a-zA-Z_]|[\\u0080-\\ud7ff\\ue000-\\ufffd]|[\\ud800-\\udbff][\\udc00-\\udfff]|\\\\(?:[0-9a-fA-F]{1,6}[\\t\\n\\f ]?|[\\u0020-\\u007e\\u0080-\\ud7ff\\ue000\\ufffd]|[\\ud800-\\udbff][\\udc00-\\udfff]))|#)(?:[a-zA-Z0-9_-]|[\\u0080-\\ud7ff\\ue000-\\ufffd]|[\\ud800-\\udbff][\\udc00-\\udfff]|\\\\(?:[0-9a-fA-F]{1,6}[\\t\\n\\f ]?|[\\u0020-\\u007e\\u0080-\\ud7ff\\ue000\\ufffd]|[\\ud800-\\udbff][\\udc00-\\udfff]))*|\"(?:'|[^'\"\\n\\f\\\\]|\\\\[\\s\\S])*\"|'(?:\"|[^'\"\\n\\f\\\\]|\\\\[\\s\\S])*'|[-+]?(?:[0-9]+(?:[.][0-9]+)?|[.][0-9]+)(?:%|-?(?:[a-zA-Z_]|[\\u0080-\\ud7ff\\ue000-\\ufffd]|[\\ud800-\\udbff][\\udc00-\\udfff]|\\\\(?:[0-9a-fA-F]{1,6}[\\t\\n\\f ]?|[\\u0020-\\u007e\\u0080-\\ud7ff\\ue000\\ufffd]|[\\ud800-\\udbff][\\udc00-\\udfff]))(?:[a-zA-Z0-9_-]|[\\u0080-\\ud7ff\\ue000-\\ufffd]|[\\ud800-\\udbff][\\udc00-\\udfff]|\\\\(?:[0-9a-fA-F]{1,6}[\\t\\n\\f ]?|[\\u0020-\\u007e\\u0080-\\ud7ff\\ue000\\ufffd]|[\\ud800-\\udbff][\\udc00-\\udfff]))*)?|<\!--|--\>|[\\t\\n\\f ]+|/(?:[*][^*]*[*]+(?:[^/][^*]*[*]+)*/|/[^\\n\\f]*)|[~|^$*]=|[^\"'\\\\/]|/(?![/*])","gi"),
f=RegExp("\\\\(?:(?:[0-9a-fA-F]{1,6}[\\t\\n\\f ]?|[\\u0020-\\u007e\\u0080-\\ud7ff\\ue000\\ufffd]|[\\ud800-\\udbff][\\udc00-\\udfff])|[\\n\\f])","g"),a=RegExp("^url\\([\\t\\n\\f ]*[\"']?|[\"']?[\\t\\n\\f ]*\\)$","gi");X=function(a){return a.replace(f,g)};U=function(f){for(var f=("\uffff"+f).replace(/^\uffff/,""),f=f.replace(/\r\n?/g,"\n"),f=f.match(v)||[],b=0,h=" ",d=0,y=f.length;d<y;++d){var l=X(f[d]),V=l.length,g=l.charCodeAt(0),l=34==g||39==g?w(l.substring(1,V-1),M):47==g&&1<V||"\\"==l||"--\>"==
l||"<\!--"==l||"\ufeff"==l||32>=g?" ":/url\(/i.test(l)?"url("+w(l.replace(a,""),x)+")":l;if(h!=l||" "!=l)f[b++]=h=l}f.length=b;return f}})();"undefined"!==typeof window&&(window.lexCss=U,window.decodeCss=X);var Y=function(){function g(d){d=(""+d).match(i);return!d?s:new e(v(d[1]),v(d[2]),v(d[3]),v(d[4]),v(d[5]),v(d[6]),v(d[7]))}function w(d,a){return"string"==typeof d?encodeURI(d).replace(a,M):s}function M(d){d=d.charCodeAt(0);return"%"+"0123456789ABCDEF".charAt(d>>4&15)+"0123456789ABCDEF".charAt(d&15)}function x(d){if(d===s)return s;for(var d=d.replace(/(^|\/)\.(?:\/|$)/g,"$1").replace(/\/{2,}/g,"/"),a=f,h;(h=d.replace(a,"$1"))!=d;d=h);return d}function E(d,h){var f=d.T(),b=h.K();b?f.ga(h.j):b=h.X();
b?f.da(h.n):b=h.Y();b?f.ea(h.k):b=h.$();var g=h.g,i=x(g);if(b)f.ca(h.V()),i=i&&i.replace(a,"");else if(b=!!g){if(47!==i.charCodeAt(0))var i=x(f.g||"").replace(a,""),e=i.lastIndexOf("/")+1,i=x((e?i.substring(0,e):"")+x(g)).replace(a,"")}else i=i&&i.replace(a,""),i!==g&&f.G(i);b?f.G(i):b=h.aa();b?f.O(h.l):b=h.Z();b&&f.fa(h.o);return f}function e(d,a,h,f,b,g,i){this.j=d;this.n=a;this.k=h;this.h=f;this.g=b;this.l=g;this.o=i}function v(d){return"string"==typeof d&&0<d.length?d:s}var f=RegExp(/(\/|^)(?:[^./][^/]*|\.{2,}(?:[^./][^/]*)|\.{3,}[^/]*)\/\.\.(?:\/|$)/),
a=/^(?:\.\.\/)*(?:\.\.$)?/;e.prototype.toString=function(){var d=[];s!==this.j&&d.push(this.j,":");s!==this.k&&(d.push("//"),s!==this.n&&d.push(this.n,"@"),d.push(this.k),s!==this.h&&d.push(":",this.h.toString()));s!==this.g&&d.push(this.g);s!==this.l&&d.push("?",this.l);s!==this.o&&d.push("#",this.o);return d.join("")};e.prototype.T=function(){return new e(this.j,this.n,this.k,this.h,this.g,this.l,this.o)};e.prototype.W=function(){return this.j&&decodeURIComponent(this.j).toLowerCase()};e.prototype.ga=
function(d){this.j=d?d:s};e.prototype.K=function(){return s!==this.j};e.prototype.da=function(d){this.n=d?d:s};e.prototype.X=function(){return s!==this.n};e.prototype.ea=function(d){this.k=d?d:s;this.G(this.g)};e.prototype.Y=function(){return s!==this.k};e.prototype.V=function(){return this.h&&decodeURIComponent(this.h)};e.prototype.ca=function(d){if(d){d=Number(d);if(d!==(d&65535))throw Error("Bad port number "+d);this.h=""+d}else this.h=s};e.prototype.$=function(){return s!==this.h};e.prototype.U=
function(){return this.g&&decodeURIComponent(this.g)};e.prototype.G=function(d){d?(d=""+d,this.g=!this.k||/^\//.test(d)?d:"/"+d):this.g=s};e.prototype.O=function(d){this.l=d?d:s};e.prototype.aa=function(){return s!==this.l};e.prototype.ba=function(d){if("object"===typeof d&&!(d instanceof Array)&&(d instanceof Object||"[object Array]"!==Object.prototype.toString.call(d))){var a=[],h=-1,f;for(f in d){var b=d[f];"string"===typeof b&&(a[++h]=f,a[++h]=b)}d=a}for(var a=[],h="",g=0;g<d.length;)f=d[g++],
b=d[g++],a.push(h,encodeURIComponent(f.toString())),h="&",b&&a.push("=",encodeURIComponent(b.toString()));this.l=a.join("")};e.prototype.fa=function(d){this.o=d?d:s};e.prototype.Z=function(){return s!==this.o};var i=/^(?:([^:/?#]+):)?(?:\/\/(?:([^/?#]*)@)?([^/?#:@]*)(?::([0-9]+))?)?([^?#]+)?(?:\?([^#]*))?(?:#(.*))?$/,b=/[#\/\?@]/g,h=/[\#\?]/g;e.parse=g;e.create=function(d,a,f,g,i,Q,N){d=new e(w(d,b),w(a,b),"string"==typeof f?encodeURIComponent(f):s,0<g?g.toString():s,w(i,h),s,"string"==typeof N?encodeURIComponent(N):
s);Q&&("string"===typeof Q?d.O(Q.replace(/[^?&=0-9A-Za-z_\-~.%]/g,M)):d.ba(Q));return d};e.N=E;e.ma=x;e.ha={ua:function(d){return/\.html$/.test(g(d).U())?"text/html":"application/javascript"},N:function(d,a){return d?E(g(d),g(a)).toString():""+a}};return e}();"undefined"!==typeof window&&(window.URI=Y);var aa=c,ba=c,da=c,Z=c;
(function(){function g(a){return"string"===typeof a?'url("'+a.replace(e,w)+'")':'url("about:blank")'}function w(a){return v[a]}function M(a,d){return a?Y.ha.N(a,d):d}function x(h,d,b){if(!b)return s;var g=(""+h).match(f);return g&&(!g[1]||a.test(g[1]))?b(h,d):s}function E(a){return a.replace(/^-(?:apple|css|epub|khtml|moz|mso?|o|rim|wap|webkit|xv)-(?=[a-z])/,"")}var e=/[\n\f\r\"\'()*<>]/g,v={"\n":"%0a","\u000c":"%0c","\r":"%0d",'"':"%22","'":"%27","(":"%28",")":"%29","*":"%2a","<":"%3c",">":"%3e"},
f=/^(?:([^:/?# ]+):)?/,a=/^(?:https?|geo|mailto|sms|tel)$/i;aa=function(){var a={};return function y(f,b,i,e,N){var f=E(f),u=L[f];if(!u||"object"!==typeof u)b.length=0;else{for(var k=u.cssPropBits,q=k&80,B=k&1536,F=NaN,r=0,o=0;r<b.length;++r){var j=b[r].toLowerCase(),I=j.charCodeAt(0),R,v,P,S,D,w;if(32===I)j="";else if(34===I)j=16===q?i?g(x(M(e,X(b[r].substring(1,j.length-1))),f,i)):"":k&8&&!(q&q-1)?j:"";else if("inherit"!==j){if(D=u.cssLitGroup){var G;if(!(G=u.cssLitMap)){G={};for(var K=D.length;0<=
--K;)for(var A=D[K],T=A.length;0<=--T;)G[A[T]]=a;G=u.cssLitMap=G}D=G}else D=a;if(!(w=D,w[E(j)]===a))if(35===I&&/^#(?:[0-9a-f]{3}){1,2}$/.test(j))j=k&2?j:"";else if(48<=I&&57>=I)j=k&1?j:"";else if(R=j.charCodeAt(1),v=j.charCodeAt(2),P=48<=R&&57>=R,S=48<=v&&57>=v,43===I&&(P||46===R&&S))j=k&1?(P?"":"0")+j.substring(1):"";else if(45===I&&(P||46===R&&S))j=k&4?(P?"-":"-0")+j.substring(1):k&1?"0":"";else if(46===I&&P)j=k&1?"0"+j:"";else if('url("'===j.substring(0,5))j=i&&k&16?g(x(M(e,b[r].substring(5,j.length-
2)),f,i)):"";else if("("===j.charAt(j.length-1))a:{D=b;G=r;j=1;K=G+1;for(I=D.length;K<I&&j;)A=D[K++],j+=")"===A?-1:/^[^"']*\($/.test(A);if(!j){j=D[G].toLowerCase();I=E(j);D=D.splice(G,K-G,"");G=u.cssFns;K=0;for(A=G.length;K<A;++K)if(G[K].substring(0,I.length)==I){D[0]=D[D.length-1]="";y(G[K],D,i,e);j=j+D.join(" ")+")";break a}}j=""}else j=B&&/^-?[a-z_][\w\-]*$/.test(j)&&!/__$/.test(j)?N&&512===B?b[r]+N:1024===B&&L[j]&&"number"===typeof L[j].oa?j:"":/^\w+$/.test(j)&&64===q&&k&8?F+1===o?(b[F]=b[F].substring(0,
b[F].length-1)+" "+j+'"',""):(F=o,'"'+j+'"'):""}j&&(b[o++]=j)}1===o&&'url("about:blank")'===b[0]&&(o=0);b.length=o}}}();var i=RegExp("^(active|after|before|blank|checked|default|disabled|drop|empty|enabled|first|first-child|first-letter|first-line|first-of-type|fullscreen|focus|hover|in-range|indeterminate|invalid|last-child|last-of-type|left|link|only-child|only-of-type|optional|out-of-range|placeholder-shown|read-only|read-write|required|right|root|scope|user-error|valid|visited)$"),b={};b[">"]=
b["+"]=b["~"]=b;ba=function(a,d,f){function g(k,r){function o(b,f,g){var y,e,k,l,o,m=n;y="";if(b<f)if(o=a[b],"*"===o)++b,y=o;else if(/^[a-zA-Z]/.test(o)&&(e=x(o.toLowerCase(),[])))"tagName"in e&&(o=e.tagName),++b,y=o;for(l=k=e="";m&&b<f;++b)if(o=a[b],"#"===o.charAt(0))/^#_|__$|[^\w#:\-]/.test(o)?m=C:e+=o+v;else if("."===o)++b<f&&/^[0-9A-Za-z:_\-]+$/.test(o=a[b])&&!/^_|__$/.test(o)?e+="."+o:m=C;else if(b+1<f&&"["===a[b]){++b;var H=a[b++].toLowerCase();o=$.m[y+"::"+H];o!==+o&&(o=$.m["*::"+H]);var W;
d.ia?(W=d.ia(y,H),"string"!==typeof W&&(m=C,W=H),m&&o!==+o&&(o=$.d.NONE)):(W=H,o!==+o&&(m=C));var p=H="",ca=C;/^[~^$*|]?=$/.test(a[b])&&(H=a[b++],p=a[b++],/^[0-9A-Za-z:_\-]+$/.test(p)?p='"'+p+'"':"]"===p&&(p='""',--b),/^"([^\"\\]|\\.)*"$/.test(p)||(m=C),(ca="i"===a[b])&&++b);"]"!==a[b]&&(++b,m=C);switch(o){case $.d.CLASSES:case $.d.LOCAL_NAME:case $.d.NONE:break;case $.d.GLOBAL_NAME:case $.d.ID:case $.d.IDREF:("="===H||"~="===H||"$="===H)&&'""'!=p&&!ca?p='"'+p.substring(1,p.length-1)+v+'"':"|="===
H||""===H||(m=C);break;case $.d.URI:case $.d.URI_FRAGMENT:""!==H&&(m=C);break;default:m=C}m&&(k+="["+W.replace(/[^\w-]/g,"\\$&")+H+p+(ca?" i]":"]"))}else if(b<f&&":"===a[b])if(o=a[++b],i.test(o))l+=":"+o;else break;else break;b!==f&&(m=C);m&&(b=(y+e).replace(/[^ .*#\w-]/g,"\\$&")+k+l+g)&&j.push(b);return m}" "===a[k]&&++k;r-1!==k&&" "===a[r]&&--r;for(var j=[],l=k,q=n,u=k;q&&u<r;++u){var B=a[u];if(b[B]===b||" "===B)o(l,u,B)?l=u+1:q=C}o(l,r,"")||(q=C);return q?(j.length&&(l=j.join(""),e!==s&&(l="."+
e+" "+l),N.push(l)),n):!f||f(a.slice(k,r))}var e=d.na,v=d.L,x=d.Aa,N=[],u=0,k,q=0,B;for(k=0;k<a.length;++k)if(B=a[k],"("==B||"["==B?(++q,n):")"==B||"]"==B?(q&&--q,n):!(" "==a[k]&&(q||b[a[k-1]]===b||b[a[k+1]]===b)))a[u++]=a[k];a.length=u;u=a.length;for(k=q=0;k<u;++k)if(","===a[k]){if(!g(q,k))return s;q=k+1}return!g(q,u)?s:N};(function(){var a=/^\w/,d=RegExp("^(?:(?:(?:(?:only|not) )?(?:all|aural|braille|embossed|handheld|print|projection|screen|speech|tty|tv)|\\( (?:(?:min-|max-)?(?:(?:device-)?(?:aspect-ratio|height|width)|color(?:-index)?|monochrome|orientation|resolution)|grid|hover|luminosity|pointer|scan|script) (?:: -?(?:[a-z]\\w+(?:-\\w+)*|\\d+(?: / \\d+|(?:\\.\\d+)?(?:p[cxt]|[cem]m|in|dpi|dppx|dpcm|%)?)) )?\\))(?: and ?\\( (?:(?:min-|max-)?(?:(?:device-)?(?:aspect-ratio|height|width)|color(?:-index)?|monochrome|orientation|resolution)|grid|hover|luminosity|pointer|scan|script) (?:: -?(?:[a-z]\\w+(?:-\\w+)*|\\d+(?: / \\d+|(?:\\.\\d+)?(?:p[cxt]|[cem]m|in|dpi|dppx|dpcm|%)?)) )?\\))*)(?: , (?:(?:(?:(?:only|not) )?(?:all|aural|braille|embossed|handheld|print|projection|screen|speech|tty|tv)|\\( (?:(?:min-|max-)?(?:(?:device-)?(?:aspect-ratio|height|width)|color(?:-index)?|monochrome|orientation|resolution)|grid|hover|luminosity|pointer|scan|script) (?:: -?(?:[a-z]\\w+(?:-\\w+)*|\\d+(?: / \\d+|(?:\\.\\d+)?(?:p[cxt]|[cem]m|in|dpi|dppx|dpcm|%)?)) )?\\))(?: and ?\\( (?:(?:min-|max-)?(?:(?:device-)?(?:aspect-ratio|height|width)|color(?:-index)?|monochrome|orientation|resolution)|grid|hover|luminosity|pointer|scan|script) (?:: -?(?:[a-z]\\w+(?:-\\w+)*|\\d+(?: / \\d+|(?:\\.\\d+)?(?:p[cxt]|[cem]m|in|dpi|dppx|dpcm|%)?)) )?\\))*))*$",
"i");Z=function(b){for(var b=b.slice(),f=b.length,g=0,i=0;i<f;++i){var e=b[i];" "!=e&&(b[g++]=e)}b.length=g;b=b.join(" ");return b=!b.length?"":!d.test(b)?"not all":a.test(b)?b:"not all , "+b}})();(function(){function a(b){var d=/^\s*[']([^']*)[']\s*$/,f=/^\s*url\s*[(]["]([^"]*)["][)]\s*$/,g=/^\s*url\s*[(][']([^']*)['][)]\s*$/,h=/^\s*url\s*[(]([^)]*)[)]\s*$/,i;return(i=/^\s*["]([^"]*)["]\s*$/.exec(b))||(i=d.exec(b))||(i=f.exec(b))||(i=g.exec(b))||(i=h.exec(b))?i[1]:s}function b(f,g,i,e,v,w,u){function k(){r=
F.length&&F[F.length-1]===s}var q=c,B=u||[0],F=[],r=C;fa(g,{startStylesheet:function(){q=[]},endStylesheet:function(){},startAtrule:function(g,j){if(r)g=s;else if("@media"===g)q.push("@media"," ",Z(j));else if("@keyframes"===g||"@-webkit-keyframes"===g){var k=j[0];1===j.length&&!/__$|[^\w\-]/.test(k)?(q.push(g," ",k+i.L),g="@keyframes"):g=s}else if("@import"===g&&0<j.length)if(g=s,"function"===typeof w){var l=Z(j.slice(1));if("not all"!==l){++B[0];var u=[];q.push(u);var E=x(M(f,a(j[0])),function(a){var f=
b(E,a.qa,i,e,v,w,B);--B[0];a=l?{toString:function(){return"@media "+l+" {"+f.result+"}"}}:f.result;u[0]=a;w(a,!!B[0])},v)}}else window.console&&window.console.log("@import "+j.join(" ")+" elided");r=!g;F.push(g)},endAtrule:function(){F.pop();r||q.push(";");k()},startBlock:function(){r||q.push("{")},endBlock:function(){r||(q.push("}"),r=n)},startRuleset:function(a){if(!r){var b=c;"@keyframes"===F[F.length-1]?(b=a.join(" ").match(/^ *(?:from|to|\d+(?:\.\d+)?%) *(?:, *(?:from|to|\d+(?:\.\d+)?%) *)*$/i),
r=!b,b&&(b=b[0].replace(/ +/g,""))):(a=ba(a,i),!a||!a.length?r=n:b=a.join(", "));r||q.push(b,"{")}F.push(s)},endRuleset:function(){F.pop();r||q.push("}");k()},declaration:function(a,b){if(!r){var d=C,g=b.length;2<=g&&"!"===b[g-2]&&"important"===b[g-1].toLowerCase()&&(d=n,b.length-=2);aa(a,b,e,f,i.L);b.length&&q.push(a,":",b.join(" "),d?" !important;":";")}}});return{result:{toString:function(){return q.join("")}},va:!!B[0]}}da=function(a,f,g,i){return b(a,f,g,i,c,c).result.toString()}})()})();
"undefined"!==typeof window&&(window.sanitizeCssProperty=aa,window.sanitizeCssSelectorList=ba,window.sanitizeStylesheet=da,window.sanitizeMediaQuery=Z);var fa,ga;
(function(){function g(f,a,g,b,h){for(var d=a++;a<g&&"{"!==f[a]&&";"!==f[a];)++a;if(a<g&&(h||";"===f[a])){var h=d+1,e=a;h<g&&" "===f[h]&&++h;e>h&&" "===f[e-1]&&--e;b.startAtrule&&b.startAtrule(f[d].toLowerCase(),f.slice(h,e));a="{"===f[a]?w(f,a,g,b):a+1;b.endAtrule&&b.endAtrule()}return a}function w(f,a,i,b){++a;for(b.startBlock&&b.startBlock();a<i;){var h=f[a].charAt(0);if("}"==h){++a;break}a=" "===h||";"===h?a+1:"@"===h?g(f,a,i,b,C):"{"===h?w(f,a,i,b):M(f,a,i,b)}b.endBlock&&b.endBlock();return a}
function M(f,a,g,b){var h=a,d=x(f,a,g,n);if(0>d)return d=~d,d===h?d+1:d;var y=f[d];if("{"!==y)return d===h?d+1:d;a=d+1;d>h&&" "===f[d-1]&&--d;for(b.startRuleset&&b.startRuleset(f.slice(h,d));a<g;){y=f[a];if("}"===y){++a;break}a=" "===y?a+1:e(f,a,g,b)}b.endRuleset&&b.endRuleset();return a}function x(f,a,g,b){for(var h,d=[],e=-1;a<g;++a)if(h=f[a].charAt(0),"["===h||"("===h)d[++e]=h;else if("]"===h&&"["===d[e]||")"===h&&"("===d[e])--e;else if("{"===h||"}"===h||";"===h||"@"===h||":"===h&&!b)break;0<=
e&&(a=~(a+1));return a}function E(f,a,g){for(;a<g&&";"!==f[a]&&"}"!==f[a];)++a;return a<g&&";"===f[a]?a+1:a}function e(f,a,g,b){var h=f[a++];if(!v.test(h))return E(f,a,g);a<g&&" "===f[a]&&++a;if(a==g||":"!==f[a])return E(f,a,g);++a;a<g&&" "===f[a]&&++a;var d=x(f,a,g,C);if(0>d)d=~d;else{for(var e=[],l=0,w=a;w<d;++w)a=f[w]," "!==a&&(e[l++]=a);if(d<g){do{a=f[d];if(";"===a||"}"===a)break;l=0}while(++d<g);";"===a&&++d}l&&b.declaration&&b.declaration(h.toLowerCase(),e)}return d}fa=function(f,a){var e=U(f);
a.startStylesheet&&a.startStylesheet();for(var b=0,h=e.length;b<h;)b=" "===e[b]?b+1:b<h?"@"===e[b].charAt(0)?g(e,b,h,a,n):M(e,b,h,a):b;a.endStylesheet&&a.endStylesheet()};var v=/^-?[a-z]/i;ga=function(g,a){for(var i=U(g),b=0,h=i.length;b<h;)b=" "!==i[b]?e(i,b,h,a):b+1}})();"undefined"!==typeof window&&(window.parseCssStylesheet=fa,window.parseCssDeclarations=ga);var $={d:{NONE:0,URI:1,URI_FRAGMENT:11,SCRIPT:2,STYLE:3,HTML:12,ID:4,IDREF:5,IDREFS:6,GLOBAL_NAME:7,LOCAL_NAME:8,CLASSES:9,FRAME_TARGET:10,MEDIA_QUERY:13}};$.atype=$.d;
$.m={"*::class":9,"*::dir":0,"*::draggable":0,"*::hidden":0,"*::id":4,"*::inert":0,"*::itemprop":0,"*::itemref":6,"*::itemscope":0,"*::lang":0,"*::onblur":2,"*::onchange":2,"*::onclick":2,"*::ondblclick":2,"*::onerror":2,"*::onfocus":2,"*::onkeydown":2,"*::onkeypress":2,"*::onkeyup":2,"*::onload":2,"*::onmousedown":2,"*::onmousemove":2,"*::onmouseout":2,"*::onmouseover":2,"*::onmouseup":2,"*::onreset":2,"*::onscroll":2,"*::onselect":2,"*::onsubmit":2,"*::ontouchcancel":2,"*::ontouchend":2,"*::ontouchenter":2,
"*::ontouchleave":2,"*::ontouchmove":2,"*::ontouchstart":2,"*::onunload":2,"*::spellcheck":0,"*::style":3,"*::tabindex":0,"*::title":0,"*::translate":0,"a::accesskey":0,"a::coords":0,"a::href":1,"a::hreflang":0,"a::name":7,"a::onblur":2,"a::onfocus":2,"a::shape":0,"a::target":10,"a::type":0,"area::accesskey":0,"area::alt":0,"area::coords":0,"area::href":1,"area::nohref":0,"area::onblur":2,"area::onfocus":2,"area::shape":0,"area::target":10,"audio::controls":0,"audio::loop":0,"audio::mediagroup":5,
"audio::muted":0,"audio::preload":0,"audio::src":1,"bdo::dir":0,"blockquote::cite":1,"br::clear":0,"button::accesskey":0,"button::disabled":0,"button::name":8,"button::onblur":2,"button::onfocus":2,"button::type":0,"button::value":0,"canvas::height":0,"canvas::width":0,"caption::align":0,"col::align":0,"col::char":0,"col::charoff":0,"col::span":0,"col::valign":0,"col::width":0,"colgroup::align":0,"colgroup::char":0,"colgroup::charoff":0,"colgroup::span":0,"colgroup::valign":0,"colgroup::width":0,
"command::checked":0,"command::command":5,"command::disabled":0,"command::icon":1,"command::label":0,"command::radiogroup":0,"command::type":0,"data::value":0,"del::cite":1,"del::datetime":0,"details::open":0,"dir::compact":0,"div::align":0,"dl::compact":0,"fieldset::disabled":0,"font::color":0,"font::face":0,"font::size":0,"form::accept":0,"form::action":1,"form::autocomplete":0,"form::enctype":0,"form::method":0,"form::name":7,"form::novalidate":0,"form::onreset":2,"form::onsubmit":2,"form::target":10,
"h1::align":0,"h2::align":0,"h3::align":0,"h4::align":0,"h5::align":0,"h6::align":0,"hr::align":0,"hr::noshade":0,"hr::size":0,"hr::width":0,"iframe::align":0,"iframe::frameborder":0,"iframe::height":0,"iframe::marginheight":0,"iframe::marginwidth":0,"iframe::width":0,"img::align":0,"img::alt":0,"img::border":0,"img::height":0,"img::hspace":0,"img::ismap":0,"img::name":7,"img::src":1,"img::usemap":11,"img::vspace":0,"img::width":0,"input::accept":0,"input::accesskey":0,"input::align":0,"input::alt":0,
"input::autocomplete":0,"input::checked":0,"input::disabled":0,"input::inputmode":0,"input::ismap":0,"input::list":5,"input::max":0,"input::maxlength":0,"input::min":0,"input::multiple":0,"input::name":8,"input::onblur":2,"input::onchange":2,"input::onfocus":2,"input::onselect":2,"input::pattern":0,"input::placeholder":0,"input::readonly":0,"input::required":0,"input::size":0,"input::src":1,"input::step":0,"input::type":0,"input::usemap":11,"input::value":0,"ins::cite":1,"ins::datetime":0,"label::accesskey":0,
"label::for":5,"label::onblur":2,"label::onfocus":2,"legend::accesskey":0,"legend::align":0,"li::type":0,"li::value":0,"map::name":7,"menu::compact":0,"menu::label":0,"menu::type":0,"meter::high":0,"meter::low":0,"meter::max":0,"meter::min":0,"meter::optimum":0,"meter::value":0,"ol::compact":0,"ol::reversed":0,"ol::start":0,"ol::type":0,"optgroup::disabled":0,"optgroup::label":0,"option::disabled":0,"option::label":0,"option::selected":0,"option::value":0,"output::for":6,"output::name":8,"p::align":0,
"pre::width":0,"progress::max":0,"progress::min":0,"progress::value":0,"q::cite":1,"select::autocomplete":0,"select::disabled":0,"select::multiple":0,"select::name":8,"select::onblur":2,"select::onchange":2,"select::onfocus":2,"select::required":0,"select::size":0,"source::type":0,"table::align":0,"table::bgcolor":0,"table::border":0,"table::cellpadding":0,"table::cellspacing":0,"table::frame":0,"table::rules":0,"table::summary":0,"table::width":0,"tbody::align":0,"tbody::char":0,"tbody::charoff":0,
"tbody::valign":0,"td::abbr":0,"td::align":0,"td::axis":0,"td::bgcolor":0,"td::char":0,"td::charoff":0,"td::colspan":0,"td::headers":6,"td::height":0,"td::nowrap":0,"td::rowspan":0,"td::scope":0,"td::valign":0,"td::width":0,"textarea::accesskey":0,"textarea::autocomplete":0,"textarea::cols":0,"textarea::disabled":0,"textarea::inputmode":0,"textarea::name":8,"textarea::onblur":2,"textarea::onchange":2,"textarea::onfocus":2,"textarea::onselect":2,"textarea::placeholder":0,"textarea::readonly":0,"textarea::required":0,
"textarea::rows":0,"textarea::wrap":0,"tfoot::align":0,"tfoot::char":0,"tfoot::charoff":0,"tfoot::valign":0,"th::abbr":0,"th::align":0,"th::axis":0,"th::bgcolor":0,"th::char":0,"th::charoff":0,"th::colspan":0,"th::headers":6,"th::height":0,"th::nowrap":0,"th::rowspan":0,"th::scope":0,"th::valign":0,"th::width":0,"thead::align":0,"thead::char":0,"thead::charoff":0,"thead::valign":0,"tr::align":0,"tr::bgcolor":0,"tr::char":0,"tr::charoff":0,"tr::valign":0,"track::default":0,"track::kind":0,"track::label":0,
"track::srclang":0,"ul::compact":0,"ul::type":0,"video::controls":0,"video::height":0,"video::loop":0,"video::mediagroup":5,"video::muted":0,"video::poster":1,"video::preload":0,"video::src":1,"video::width":0};$.ATTRIBS=$.m;$.c={OPTIONAL_ENDTAG:1,EMPTY:2,CDATA:4,RCDATA:8,UNSAFE:16,FOLDABLE:32,SCRIPT:64,STYLE:128,VIRTUALIZED:256};$.eflags=$.c;
$.f={a:0,abbr:0,acronym:0,address:0,applet:272,area:2,article:0,aside:0,audio:0,b:0,base:274,basefont:274,bdi:0,bdo:0,big:0,blockquote:0,body:305,br:2,button:0,canvas:0,caption:0,center:0,cite:0,code:0,col:2,colgroup:1,command:2,data:0,datalist:0,dd:1,del:0,details:0,dfn:0,dialog:272,dir:0,div:0,dl:0,dt:1,em:0,fieldset:0,figcaption:0,figure:0,font:0,footer:0,form:0,frame:274,frameset:272,h1:0,h2:0,h3:0,h4:0,h5:0,h6:0,head:305,header:0,hgroup:0,hr:2,html:305,i:0,iframe:4,img:2,input:2,ins:0,isindex:274,
kbd:0,keygen:274,label:0,legend:0,li:1,link:274,map:0,mark:0,menu:0,meta:274,meter:0,nav:0,nobr:0,noembed:276,noframes:276,noscript:276,object:272,ol:0,optgroup:0,option:1,output:0,p:1,param:274,pre:0,progress:0,q:0,s:0,samp:0,script:84,section:0,select:0,small:0,source:2,span:0,strike:0,strong:0,style:148,sub:0,summary:0,sup:0,table:0,tbody:1,td:1,textarea:8,tfoot:1,th:1,thead:1,time:0,title:280,tr:1,track:2,tt:0,u:0,ul:0,"var":0,video:0,wbr:2};$.ELEMENTS=$.f;
$.Q={a:"HTMLAnchorElement",abbr:"HTMLElement",acronym:"HTMLElement",address:"HTMLElement",applet:"HTMLAppletElement",area:"HTMLAreaElement",article:"HTMLElement",aside:"HTMLElement",audio:"HTMLAudioElement",b:"HTMLElement",base:"HTMLBaseElement",basefont:"HTMLBaseFontElement",bdi:"HTMLElement",bdo:"HTMLElement",big:"HTMLElement",blockquote:"HTMLQuoteElement",body:"HTMLBodyElement",br:"HTMLBRElement",button:"HTMLButtonElement",canvas:"HTMLCanvasElement",caption:"HTMLTableCaptionElement",center:"HTMLElement",
cite:"HTMLElement",code:"HTMLElement",col:"HTMLTableColElement",colgroup:"HTMLTableColElement",command:"HTMLCommandElement",data:"HTMLElement",datalist:"HTMLDataListElement",dd:"HTMLElement",del:"HTMLModElement",details:"HTMLDetailsElement",dfn:"HTMLElement",dialog:"HTMLDialogElement",dir:"HTMLDirectoryElement",div:"HTMLDivElement",dl:"HTMLDListElement",dt:"HTMLElement",em:"HTMLElement",fieldset:"HTMLFieldSetElement",figcaption:"HTMLElement",figure:"HTMLElement",font:"HTMLFontElement",footer:"HTMLElement",
form:"HTMLFormElement",frame:"HTMLFrameElement",frameset:"HTMLFrameSetElement",h1:"HTMLHeadingElement",h2:"HTMLHeadingElement",h3:"HTMLHeadingElement",h4:"HTMLHeadingElement",h5:"HTMLHeadingElement",h6:"HTMLHeadingElement",head:"HTMLHeadElement",header:"HTMLElement",hgroup:"HTMLElement",hr:"HTMLHRElement",html:"HTMLHtmlElement",i:"HTMLElement",iframe:"HTMLIFrameElement",img:"HTMLImageElement",input:"HTMLInputElement",ins:"HTMLModElement",isindex:"HTMLUnknownElement",kbd:"HTMLElement",keygen:"HTMLKeygenElement",
label:"HTMLLabelElement",legend:"HTMLLegendElement",li:"HTMLLIElement",link:"HTMLLinkElement",map:"HTMLMapElement",mark:"HTMLElement",menu:"HTMLMenuElement",meta:"HTMLMetaElement",meter:"HTMLMeterElement",nav:"HTMLElement",nobr:"HTMLElement",noembed:"HTMLElement",noframes:"HTMLElement",noscript:"HTMLElement",object:"HTMLObjectElement",ol:"HTMLOListElement",optgroup:"HTMLOptGroupElement",option:"HTMLOptionElement",output:"HTMLOutputElement",p:"HTMLParagraphElement",param:"HTMLParamElement",pre:"HTMLPreElement",
progress:"HTMLProgressElement",q:"HTMLQuoteElement",s:"HTMLElement",samp:"HTMLElement",script:"HTMLScriptElement",section:"HTMLElement",select:"HTMLSelectElement",small:"HTMLElement",source:"HTMLSourceElement",span:"HTMLSpanElement",strike:"HTMLElement",strong:"HTMLElement",style:"HTMLStyleElement",sub:"HTMLElement",summary:"HTMLElement",sup:"HTMLElement",table:"HTMLTableElement",tbody:"HTMLTableSectionElement",td:"HTMLTableDataCellElement",textarea:"HTMLTextAreaElement",tfoot:"HTMLTableSectionElement",
th:"HTMLTableHeaderCellElement",thead:"HTMLTableSectionElement",time:"HTMLTimeElement",title:"HTMLTitleElement",tr:"HTMLTableRowElement",track:"HTMLTrackElement",tt:"HTMLElement",u:"HTMLElement",ul:"HTMLUListElement","var":"HTMLElement",video:"HTMLVideoElement",wbr:"HTMLElement"};$.ELEMENT_DOM_INTERFACES=$.Q;$.P={NOT_LOADED:0,SAME_DOCUMENT:1,NEW_DOCUMENT:2};$.ueffects=$.P;
$.J={"a::href":2,"area::href":2,"audio::src":1,"blockquote::cite":0,"command::icon":1,"del::cite":0,"form::action":2,"img::src":1,"input::src":1,"ins::cite":0,"q::cite":0,"video::poster":1,"video::src":1};$.URIEFFECTS=$.J;$.M={UNSANDBOXED:2,SANDBOXED:1,DATA:0};$.ltypes=$.M;$.I={"a::href":2,"area::href":2,"audio::src":2,"blockquote::cite":2,"command::icon":1,"del::cite":2,"form::action":2,"img::src":1,"input::src":1,"ins::cite":2,"q::cite":2,"video::poster":1,"video::src":2};$.LOADERTYPES=$.I;
"undefined"!==typeof window&&(window.html4=$);var ha=function(g){function w(a){if(k.hasOwnProperty(a))return k[a];var b=a.match(q);return b?String.fromCharCode(parseInt(b[1],10)):(b=a.match(B))?String.fromCharCode(parseInt(b[1],16)):r&&F.test(a)?(r.innerHTML="&"+a+";",b=r.textContent,k[a]=b):"&"+a+";"}function M(a,b){return w(b)}function x(a){return a.replace(j,M)}function E(a){return(""+a).replace(R,"&amp;").replace(P,"&lt;").replace(S,"&gt;").replace(D,"&#34;")}function e(a){return a.replace(ia,"&amp;$1").replace(P,"&lt;").replace(S,"&gt;")}
function v(b){var d={z:b.z||b.cdata,A:b.A||b.comment,B:b.B||b.endDoc,t:b.t||b.endTag,e:b.e||b.pcdata,F:b.F||b.rcdata,H:b.H||b.startDoc,w:b.w||b.startTag};return function(b,g){var f;var H=/(<\/|<\!--|<[!?]|[&<>])/g;f=b+"";if(G)f=f.split(H);else{for(var e=[],h=0,j;(j=H.exec(f))!==s;)e.push(f.substring(h,j.index)),e.push(j[0]),h=j.index+j[0].length;e.push(f.substring(h));f=e}a(d,f,0,{r:C,C:C},g)}}function f(b,d,g,f,t){return function(){a(b,d,g,f,t)}}function a(a,d,p,e,t){try{a.H&&0==p&&a.H(t);for(var h,
z,j,k=d.length;p<k;){var o=d[p++],l=d[p];switch(o){case "&":I.test(l)?(a.e&&a.e("&"+l,t,A,f(a,d,p,e,t)),p++):a.e&&a.e("&amp;",t,A,f(a,d,p,e,t));break;case "</":if(h=/^([-\w:]+)[^\'\"]*/.exec(l))if(h[0].length===l.length&&">"===d[p+1])p+=2,j=h[1].toLowerCase(),a.t&&a.t(j,t,A,f(a,d,p,e,t));else{var m=d,q=p,r=a,u=t,v=A,y=e,w=b(m,q);w?(r.t&&r.t(w.name,u,v,f(r,m,q,y,u)),p=w.next):p=m.length}else a.e&&a.e("&lt;/",t,A,f(a,d,p,e,t));break;case "<":if(h=/^([-\w:]+)\s*\/?/.exec(l))if(h[0].length===l.length&&
">"===d[p+1]){p+=2;j=h[1].toLowerCase();a.w&&a.w(j,[],t,A,f(a,d,p,e,t));var B=g.f[j];B&K&&(p=i(d,{name:j,next:p,c:B},a,t,A,e))}else{var m=d,q=a,r=t,u=A,v=e,x=b(m,p);x?(q.w&&q.w(x.name,x.R,r,u,f(q,m,x.next,v,r)),p=x.c&K?i(m,x,q,r,u,v):x.next):p=m.length}else a.e&&a.e("&lt;",t,A,f(a,d,p,e,t));break;case "<\!--":if(!e.C){for(z=p+1;z<k&&!(">"===d[z]&&/--$/.test(d[z-1]));z++);if(z<k){if(a.A){var D=d.slice(p,z).join("");a.A(D.substr(0,D.length-2),t,A,f(a,d,z+1,e,t))}p=z+1}else e.C=n}e.C&&a.e&&a.e("&lt;!--",
t,A,f(a,d,p,e,t));break;case "<!":if(/^\w/.test(l)){if(!e.r){for(z=p+1;z<k&&">"!==d[z];z++);z<k?p=z+1:e.r=n}e.r&&a.e&&a.e("&lt;!",t,A,f(a,d,p,e,t))}else a.e&&a.e("&lt;!",t,A,f(a,d,p,e,t));break;case "<?":if(!e.r){for(z=p+1;z<k&&">"!==d[z];z++);z<k?p=z+1:e.r=n}e.r&&a.e&&a.e("&lt;?",t,A,f(a,d,p,e,t));break;case ">":a.e&&a.e("&gt;",t,A,f(a,d,p,e,t));break;case "":break;default:a.e&&a.e(o,t,A,f(a,d,p,e,t))}}a.B&&a.B(t)}catch(E){if(E!==A)throw E;}}function i(a,b,d,h,t,j){var z=a.length;T.hasOwnProperty(b.name)||
(T[b.name]=RegExp("^"+b.name+"(?:[\\s\\/]|$)","i"));for(var i=T[b.name],k=b.next,l=b.next+1;l<z&&!("</"===a[l-1]&&i.test(a[l]));l++);l<z&&(l-=1);z=a.slice(k,l).join("");if(b.c&g.c.CDATA)d.z&&d.z(z,h,t,f(d,a,l,j,h));else if(b.c&g.c.RCDATA)d.F&&d.F(e(z),h,t,f(d,a,l,j,h));else throw Error("bug");return l}function b(a,b){var d=/^([-\w:]+)/.exec(a[b]),f={};f.name=d[1].toLowerCase();f.c=g.f[f.name];for(var e=a[b].substr(d[0].length),h=b+1,j=a.length;h<j&&">"!==a[h];h++)e+=a[h];if(!(j<=h)){for(var i=[];""!==
e;)if(d=ja.exec(e))if(d[4]&&!d[5]||d[6]&&!d[7]){for(var d=d[4]||d[6],l=C,e=[e,a[h++]];h<j;h++){if(l){if(">"===a[h])break}else 0<=a[h].indexOf(d)&&(l=n);e.push(a[h])}if(j<=h)break;e=e.join("")}else{var l=d[1].toLowerCase(),k;if(d[2]){k=d[3];var m=k.charCodeAt(0);if(34===m||39===m)k=k.substr(1,k.length-2);k=x(k.replace(o,""))}else k="";i.push(l,k);e=e.substr(d[0].length)}else e=e.replace(/^[\s\S][^a-z\s]*/,"");f.R=i;f.next=h+1;return f}}function h(a){function b(a,d){f||d.push(a)}var d,f;return v({startDoc:function(){d=
[];f=C},startTag:function(b,e,h){if(!f&&g.f.hasOwnProperty(b)){var j=g.f[b];if(!(j&g.c.FOLDABLE)){var k=a(b,e);if(k){if("object"!==typeof k)throw Error("tagPolicy did not return object (old API?)");if("attribs"in k)e=k.attribs;else throw Error("tagPolicy gave no attribs");var i;"tagName"in k?(i=k.tagName,k=g.f[i]):(i=b,k=j);if(j&g.c.OPTIONAL_ENDTAG){var l=d[d.length-1];l&&l.D===b&&(l.v!==i||b!==i)&&h.push("</",l.v,">")}j&g.c.EMPTY||d.push({D:b,v:i});h.push("<",i);b=0;for(l=e.length;b<l;b+=2){var m=
e[b],o=e[b+1];o!==s&&o!==c&&h.push(" ",m,'="',E(o),'"')}h.push(">");j&g.c.EMPTY&&!(k&g.c.EMPTY)&&h.push("</",i,">")}else f=!(j&g.c.EMPTY)}}},endTag:function(a,b){if(f)f=C;else if(g.f.hasOwnProperty(a)){var e=g.f[a];if(!(e&(g.c.EMPTY|g.c.FOLDABLE))){if(e&g.c.OPTIONAL_ENDTAG)for(e=d.length;0<=--e;){var h=d[e].D;if(h===a)break;if(!(g.f[h]&g.c.OPTIONAL_ENDTAG))return}else for(e=d.length;0<=--e&&d[e].D!==a;);if(!(0>e)){for(h=d.length;--h>e;){var j=d[h].v;g.f[j]&g.c.OPTIONAL_ENDTAG||b.push("</",j,">")}e<
d.length&&(a=d[e].v);d.length=e;b.push("</",a,">")}}}},pcdata:b,rcdata:b,cdata:b,endDoc:function(a){for(;d.length;d.length--)a.push("</",d[d.length-1].v,">")}})}function d(a,b,d,e,f){if(!f)return s;try{var g=Y.parse(""+a);if(g&&(!g.K()||ka.test(g.W()))){var h=f(g,b,d,e);return h?h.toString():s}}catch(j){}return s}function y(a,b,d,f,e){d||a(b+" removed",{S:"removed",tagName:b});if(f!==e){var g="changed";f&&!e?g="removed":!f&&e&&(g="added");a(b+"."+d+" "+g,{S:g,tagName:b,la:d,oldValue:f,newValue:e})}}
function l(a,b,d){b=b+"::"+d;if(a.hasOwnProperty(b))return a[b];b="*::"+d;if(a.hasOwnProperty(b))return a[b]}function V(a,b,f,e,h){for(var j=0;j<b.length;j+=2){var k=b[j],i=b[j+1],m=i,o=s,q;if((q=a+"::"+k,g.m.hasOwnProperty(q))||(q="*::"+k,g.m.hasOwnProperty(q)))o=g.m[q];if(o!==s)switch(o){case g.d.NONE:break;case g.d.SCRIPT:i=s;h&&y(h,a,k,m,i);break;case g.d.STYLE:if("undefined"===typeof N){i=s;h&&y(h,a,k,m,i);break}var r=[];N(i,{declaration:function(a,b){var e=a.toLowerCase();u(e,b,f?function(a){return d(a,
g.P.ja,g.M.ka,{TYPE:"CSS",CSS_PROP:e},f)}:s);b.length&&r.push(e+": "+b.join(" "))}});i=0<r.length?r.join(" ; "):s;h&&y(h,a,k,m,i);break;case g.d.ID:case g.d.IDREF:case g.d.IDREFS:case g.d.GLOBAL_NAME:case g.d.LOCAL_NAME:case g.d.CLASSES:i=e?e(i):i;h&&y(h,a,k,m,i);break;case g.d.URI:i=d(i,l(g.J,a,k),l(g.I,a,k),{TYPE:"MARKUP",XML_ATTR:k,XML_TAG:a},f);h&&y(h,a,k,m,i);break;case g.d.URI_FRAGMENT:i&&"#"===i.charAt(0)?(i=i.substring(1),i=e?e(i):i,i!==s&&i!==c&&(i="#"+i)):i=s;h&&y(h,a,k,m,i);break;default:i=
s,h&&y(h,a,k,m,i)}else i=s,h&&y(h,a,k,m,i);b[j+1]=i}return b}function ea(a,b,d){return function(e,f){if(g.f[e]&g.c.UNSAFE)d&&y(d,e,c,c,c);else return{attribs:V(e,f,a,b,d)}}}function Q(a,b){var d=[];h(b)(a,d);return d.join("")}var N,u;"undefined"!==typeof window&&(N=window.parseCssDeclarations,u=window.sanitizeCssProperty);var k={lt:"<",LT:"<",gt:">",GT:">",amp:"&",AMP:"&",quot:'"',apos:"'",nbsp:"\u00a0"},q=/^#(\d+)$/,B=/^#x([0-9A-Fa-f]+)$/,F=/^[A-Za-z][A-za-z0-9]+$/,r="undefined"!==typeof window&&
window.document?window.document.createElement("textarea"):s,o=/\0/g,j=/&(#[0-9]+|#[xX][0-9A-Fa-f]+|\w+);/g,I=/^(#[0-9]+|#[xX][0-9A-Fa-f]+|\w+);/,R=/&/g,ia=/&([^a-z#]|#(?:[^0-9x]|x(?:[^0-9a-f]|$)|$)|$)/gi,P=/[<]/g,S=/>/g,D=/\"/g,ja=/^\s*([-.:\w]+)(?:\s*(=)\s*((")[^"]*("|$)|(')[^']*('|$)|(?=[a-z][-\w]*\s*=)|[^"'\s]*))?/i,G=3==="a,b".split(/(,)/).length,K=g.c.CDATA|g.c.RCDATA,A={},T={},ka=/^(?:https?|geo|mailto|sms|tel)$/i,m={};m.pa=m.escapeAttrib=E;m.ra=m.makeHtmlSanitizer=h;m.sa=m.makeSaxParser=v;
m.ta=m.makeTagPolicy=ea;m.wa=m.normalizeRCData=e;m.xa=m.sanitize=function(a,b,d,e){return Q(a,ea(b,d,e))};m.ya=m.sanitizeAttribs=V;m.za=m.sanitizeWithPolicy=Q;m.Ba=m.unescapeEntities=x;return m}($),la=ha.sanitize;"undefined"!==typeof window&&(window.html=ha,window.html_sanitize=la);})();


// FILE: src/lib/00.rich-text-sanitize.js
function richTextSanitize(htmlText){
    var basicPolicy = html.makeTagPolicy();

    /* check if attribute is an image */
    function isImage(src) {
        const isScript = src.toUpperCase().indexOf('JAVASCRIPT') !== -1;
        const isBase64 = src.indexOf('data:image') === 0;
        const isFile = src.toUpperCase().substr(-4) === '.JPG' ||
                       src.toUpperCase().substr(-5) === '.JPEG' ||    
                       src.toUpperCase().substr(-4) === '.PNG' ||    
                       src.toUpperCase().substr(-4) === '.SVG' ||    
                       src.toUpperCase().substr(-4) === '.GIF';    
        return !isScript && (isBase64 || isFile);    
    }

    /* custom function built to override default policies */
    function customPolicy(tagName, attribs) {
        if (tagName == 'img' && attribs.length) {
            var src;
            for (var i = 0; i < attribs.length; i += 2) {
                if (attribs[i] == 'src') {
                    src = attribs[i + 1];
                    break;
                }
            }

            if (src && isImage(src)) {
                var attrs = html.sanitizeAttribs(tagName, attribs);
                attrs.push('src');
                attrs.push(src);
                return {
                    attribs: attrs
                };
            }
        }
        return basicPolicy(tagName, attribs);
    }

    htmlText = htmlText || '';

    return html.sanitizeWithPolicy(htmlText, customPolicy);
}

// FILE: src/lib/01.summernote.js
/**
 * Super simple wysiwyg editor v0.8.7
 * http://summernote.org/
 *
 * summernote.js
 * Copyright 2013- Alan Hong. and other contributors
 * summernote may be freely distributed under the MIT license./
 *
 * Date: 2017-08-15T06:31Z
 */
(function (factory) {
  /* global define */
  if (typeof define === 'function' && define.amd) {
    // AMD. Register as an anonymous module.
    define(['jquery'], factory);
  } else if (typeof module === 'object' && module.exports) {
    // Node/CommonJS
    module.exports = factory(require('jquery'));
  } else {
    // Browser globals
    factory(window.jQuery);
  }
}(function ($) {
  'use strict';

  var isSupportAmd = typeof define === 'function' && define.amd;

  /**
   * returns whether font is installed or not.
   *
   * @param {String} fontName
   * @return {Boolean}
   */
  var isFontInstalled = function (fontName) {
    var testFontName = fontName === 'Comic Sans MS' ? 'Courier New' : 'Comic Sans MS';
    var $tester = $('<div>').css({
      position: 'absolute',
      left: '-9999px',
      top: '-9999px',
      fontSize: '200px'
    }).text('mmmmmmmmmwwwwwww').appendTo(document.body);

    var originalWidth = $tester.css('fontFamily', testFontName).width();
    var width = $tester.css('fontFamily', fontName + ',' + testFontName).width();

    $tester.remove();

    return originalWidth !== width;
  };

  var userAgent = navigator.userAgent;
  var isMSIE = /MSIE|Trident/i.test(userAgent);
  var browserVersion;
  if (isMSIE) {
    var matches = /MSIE (\d+[.]\d+)/.exec(userAgent);
    if (matches) {
      browserVersion = parseFloat(matches[1]);
    }
    matches = /Trident\/.*rv:([0-9]{1,}[\.0-9]{0,})/.exec(userAgent);
    if (matches) {
      browserVersion = parseFloat(matches[1]);
    }
  }

  var isEdge = /Edge\/\d+/.test(userAgent);

  var hasCodeMirror = !!window.CodeMirror;
  if (!hasCodeMirror && isSupportAmd && typeof require !== 'undefined') {
    if (typeof require.resolve !== 'undefined') {
      try {
        // If CodeMirror can't be resolved, `require.resolve` will throw an
        // exception and `hasCodeMirror` won't be set to `true`.
        require.resolve('codemirror');
        hasCodeMirror = true;
      } catch (e) {
        // Do nothing.
      }
    } else if (typeof eval('require').specified !== 'undefined') {
      hasCodeMirror = eval('require').specified('codemirror');
    }
  }

  var isSupportTouch =
    (('ontouchstart' in window) ||
     (navigator.MaxTouchPoints > 0) ||
     (navigator.msMaxTouchPoints > 0));

  /**
   * @class core.agent
   *
   * Object which check platform and agent
   *
   * @singleton
   * @alternateClassName agent
   */
  var agent = {
    isMac: navigator.appVersion.indexOf('Mac') > -1,
    isMSIE: isMSIE,
    isEdge: isEdge,
    isFF: !isEdge && /firefox/i.test(userAgent),
    isPhantom: /PhantomJS/i.test(userAgent),
    isWebkit: !isEdge && /webkit/i.test(userAgent),
    isChrome: !isEdge && /chrome/i.test(userAgent),
    isSafari: !isEdge && /safari/i.test(userAgent),
    browserVersion: browserVersion,
    jqueryVersion: parseFloat($.fn.jquery),
    isSupportAmd: isSupportAmd,
    isSupportTouch: isSupportTouch,
    hasCodeMirror: hasCodeMirror,
    isFontInstalled: isFontInstalled,
    isW3CRangeSupport: !!document.createRange
  };

  /**
   * @class core.func
   *
   * func utils (for high-order func's arg)
   *
   * @singleton
   * @alternateClassName func
   */
  var func = (function () {
    var eq = function (itemA) {
      return function (itemB) {
        return itemA === itemB;
      };
    };

    var eq2 = function (itemA, itemB) {
      return itemA === itemB;
    };

    var peq2 = function (propName) {
      return function (itemA, itemB) {
        return itemA[propName] === itemB[propName];
      };
    };

    var ok = function () {
      return true;
    };

    var fail = function () {
      return false;
    };

    var not = function (f) {
      return function () {
        return !f.apply(f, arguments);
      };
    };

    var and = function (fA, fB) {
      return function (item) {
        return fA(item) && fB(item);
      };
    };

    var self = function (a) {
      return a;
    };

    var invoke = function (obj, method) {
      return function () {
        return obj[method].apply(obj, arguments);
      };
    };

    var idCounter = 0;

    /**
     * generate a globally-unique id
     *
     * @param {String} [prefix]
     */
    var uniqueId = function (prefix) {
      var id = ++idCounter + '';
      return prefix ? prefix + id : id;
    };

    /**
     * returns bnd (bounds) from rect
     *
     * - IE Compatibility Issue: http://goo.gl/sRLOAo
     * - Scroll Issue: http://goo.gl/sNjUc
     *
     * @param {Rect} rect
     * @return {Object} bounds
     * @return {Number} bounds.top
     * @return {Number} bounds.left
     * @return {Number} bounds.width
     * @return {Number} bounds.height
     */
    var rect2bnd = function (rect) {
      var $document = $(document);
      return {
        top: rect.top + $document.scrollTop(),
        left: rect.left + $document.scrollLeft(),
        width: rect.right - rect.left,
        height: rect.bottom - rect.top
      };
    };

    /**
     * returns a copy of the object where the keys have become the values and the values the keys.
     * @param {Object} obj
     * @return {Object}
     */
    var invertObject = function (obj) {
      var inverted = {};
      for (var key in obj) {
        if (obj.hasOwnProperty(key)) {
          inverted[obj[key]] = key;
        }
      }
      return inverted;
    };

    /**
     * @param {String} namespace
     * @param {String} [prefix]
     * @return {String}
     */
    var namespaceToCamel = function (namespace, prefix) {
      prefix = prefix || '';
      return prefix + namespace.split('.').map(function (name) {
        return name.substring(0, 1).toUpperCase() + name.substring(1);
      }).join('');
    };

    /**
     * Returns a function, that, as long as it continues to be invoked, will not
     * be triggered. The function will be called after it stops being called for
     * N milliseconds. If `immediate` is passed, trigger the function on the
     * leading edge, instead of the trailing.
     * @param {Function} func
     * @param {Number} wait
     * @param {Boolean} immediate
     * @return {Function}
     */
    var debounce = function (func, wait, immediate) {
      var timeout;
      return function () {
        var context = this, args = arguments;
        var later = function () {
          timeout = null;
          if (!immediate) {
            func.apply(context, args);
          }
        };
        var callNow = immediate && !timeout;
        clearTimeout(timeout);
        timeout = setTimeout(later, wait);
        if (callNow) {
          func.apply(context, args);
        }
      };
    };

    return {
      eq: eq,
      eq2: eq2,
      peq2: peq2,
      ok: ok,
      fail: fail,
      self: self,
      not: not,
      and: and,
      invoke: invoke,
      uniqueId: uniqueId,
      rect2bnd: rect2bnd,
      invertObject: invertObject,
      namespaceToCamel: namespaceToCamel,
      debounce: debounce
    };
  })();

  /**
   * @class core.list
   *
   * list utils
   *
   * @singleton
   * @alternateClassName list
   */
  var list = (function () {
    /**
     * returns the first item of an array.
     *
     * @param {Array} array
     */
    var head = function (array) {
      return array[0];
    };

    /**
     * returns the last item of an array.
     *
     * @param {Array} array
     */
    var last = function (array) {
      return array[array.length - 1];
    };

    /**
     * returns everything but the last entry of the array.
     *
     * @param {Array} array
     */
    var initial = function (array) {
      return array.slice(0, array.length - 1);
    };

    /**
     * returns the rest of the items in an array.
     *
     * @param {Array} array
     */
    var tail = function (array) {
      return array.slice(1);
    };

    /**
     * returns item of array
     */
    var find = function (array, pred) {
      for (var idx = 0, len = array.length; idx < len; idx ++) {
        var item = array[idx];
        if (pred(item)) {
          return item;
        }
      }
    };

    /**
     * returns true if all of the values in the array pass the predicate truth test.
     */
    var all = function (array, pred) {
      for (var idx = 0, len = array.length; idx < len; idx ++) {
        if (!pred(array[idx])) {
          return false;
        }
      }
      return true;
    };

    /**
     * returns index of item
     */
    var indexOf = function (array, item) {
      return $.inArray(item, array);
    };

    /**
     * returns true if the value is present in the list.
     */
    var contains = function (array, item) {
      return indexOf(array, item) !== -1;
    };

    /**
     * get sum from a list
     *
     * @param {Array} array - array
     * @param {Function} fn - iterator
     */
    var sum = function (array, fn) {
      fn = fn || func.self;
      return array.reduce(function (memo, v) {
        return memo + fn(v);
      }, 0);
    };
  
    /**
     * returns a copy of the collection with array type.
     * @param {Collection} collection - collection eg) node.childNodes, ...
     */
    var from = function (collection) {
      var result = [], idx = -1, length = collection.length;
      while (++idx < length) {
        result[idx] = collection[idx];
      }
      return result;
    };

    /**
     * returns whether list is empty or not
     */
    var isEmpty = function (array) {
      return !array || !array.length;
    };
  
    /**
     * cluster elements by predicate function.
     *
     * @param {Array} array - array
     * @param {Function} fn - predicate function for cluster rule
     * @param {Array[]}
     */
    var clusterBy = function (array, fn) {
      if (!array.length) { return []; }
      var aTail = tail(array);
      return aTail.reduce(function (memo, v) {
        var aLast = last(memo);
        if (fn(last(aLast), v)) {
          aLast[aLast.length] = v;
        } else {
          memo[memo.length] = [v];
        }
        return memo;
      }, [[head(array)]]);
    };
  
    /**
     * returns a copy of the array with all false values removed
     *
     * @param {Array} array - array
     * @param {Function} fn - predicate function for cluster rule
     */
    var compact = function (array) {
      var aResult = [];
      for (var idx = 0, len = array.length; idx < len; idx ++) {
        if (array[idx]) { aResult.push(array[idx]); }
      }
      return aResult;
    };

    /**
     * produces a duplicate-free version of the array
     *
     * @param {Array} array
     */
    var unique = function (array) {
      var results = [];

      for (var idx = 0, len = array.length; idx < len; idx ++) {
        if (!contains(results, array[idx])) {
          results.push(array[idx]);
        }
      }

      return results;
    };

    /**
     * returns next item.
     * @param {Array} array
     */
    var next = function (array, item) {
      var idx = indexOf(array, item);
      if (idx === -1) { return null; }

      return array[idx + 1];
    };

    /**
     * returns prev item.
     * @param {Array} array
     */
    var prev = function (array, item) {
      var idx = indexOf(array, item);
      if (idx === -1) { return null; }

      return array[idx - 1];
    };

    return { head: head, last: last, initial: initial, tail: tail,
             prev: prev, next: next, find: find, contains: contains,
             all: all, sum: sum, from: from, isEmpty: isEmpty,
             clusterBy: clusterBy, compact: compact, unique: unique };
  })();


  var NBSP_CHAR = String.fromCharCode(160);
  var ZERO_WIDTH_NBSP_CHAR = '\ufeff';

  /**
   * @class core.dom
   *
   * Dom functions
   *
   * @singleton
   * @alternateClassName dom
   */
  var dom = (function () {
    /**
     * @method isEditable
     *
     * returns whether node is `note-editable` or not.
     *
     * @param {Node} node
     * @return {Boolean}
     */
    var isEditable = function (node) {
      return node && $(node).hasClass('note-editable');
    };

    /**
     * @method isControlSizing
     *
     * returns whether node is `note-control-sizing` or not.
     *
     * @param {Node} node
     * @return {Boolean}
     */
    var isControlSizing = function (node) {
      return node && $(node).hasClass('note-control-sizing');
    };

    /**
     * @method makePredByNodeName
     *
     * returns predicate which judge whether nodeName is same
     *
     * @param {String} nodeName
     * @return {Function}
     */
    var makePredByNodeName = function (nodeName) {
      nodeName = nodeName.toUpperCase();
      return function (node) {
        return node && node.nodeName.toUpperCase() === nodeName;
      };
    };

    /**
     * @method isText
     *
     *
     *
     * @param {Node} node
     * @return {Boolean} true if node's type is text(3)
     */
    var isText = function (node) {
      return node && node.nodeType === 3;
    };

    /**
     * @method isElement
     *
     *
     *
     * @param {Node} node
     * @return {Boolean} true if node's type is element(1)
     */
    var isElement = function (node) {
      return node && node.nodeType === 1;
    };

    /**
     * ex) br, col, embed, hr, img, input, ...
     * @see http://www.w3.org/html/wg/drafts/html/master/syntax.html#void-elements
     */
    var isVoid = function (node) {
      return node && /^BR|^IMG|^HR|^IFRAME|^BUTTON|^INPUT/.test(node.nodeName.toUpperCase());
    };

    var isPara = function (node) {
      if (isEditable(node)) {
        return false;
      }

      // Chrome(v31.0), FF(v25.0.1) use DIV for paragraph
      return node && /^DIV|^P|^LI|^H[1-7]/.test(node.nodeName.toUpperCase());
    };

    var isHeading = function (node) {
      return node && /^H[1-7]/.test(node.nodeName.toUpperCase());
    };

    var isPre = makePredByNodeName('PRE');

    var isLi = makePredByNodeName('LI');

    var isPurePara = function (node) {
      return isPara(node) && !isLi(node);
    };

    var isTable = makePredByNodeName('TABLE');

    var isData = makePredByNodeName('DATA');

    var isInline = function (node) {
      return !isBodyContainer(node) &&
             !isList(node) &&
             !isHr(node) &&
             !isPara(node) &&
             !isTable(node) &&
             !isBlockquote(node) &&
             !isData(node);
    };

    var isList = function (node) {
      return node && /^UL|^OL/.test(node.nodeName.toUpperCase());
    };

    var isHr = makePredByNodeName('HR');

    var isCell = function (node) {
      return node && /^TD|^TH/.test(node.nodeName.toUpperCase());
    };

    var isBlockquote = makePredByNodeName('BLOCKQUOTE');

    var isBodyContainer = function (node) {
      return isCell(node) || isBlockquote(node) || isEditable(node);
    };

    var isAnchor = makePredByNodeName('A');

    var isParaInline = function (node) {
      return isInline(node) && !!ancestor(node, isPara);
    };

    var isBodyInline = function (node) {
      return isInline(node) && !ancestor(node, isPara);
    };

    var isBody = makePredByNodeName('BODY');

    /**
     * returns whether nodeB is closest sibling of nodeA
     *
     * @param {Node} nodeA
     * @param {Node} nodeB
     * @return {Boolean}
     */
    var isClosestSibling = function (nodeA, nodeB) {
      return nodeA.nextSibling === nodeB ||
             nodeA.previousSibling === nodeB;
    };

    /**
     * returns array of closest siblings with node
     *
     * @param {Node} node
     * @param {function} [pred] - predicate function
     * @return {Node[]}
     */
    var withClosestSiblings = function (node, pred) {
      pred = pred || func.ok;

      var siblings = [];
      if (node.previousSibling && pred(node.previousSibling)) {
        siblings.push(node.previousSibling);
      }
      siblings.push(node);
      if (node.nextSibling && pred(node.nextSibling)) {
        siblings.push(node.nextSibling);
      }
      return siblings;
    };

    /**
     * blank HTML for cursor position
     * - [workaround] old IE only works with &nbsp;
     * - [workaround] IE11 and other browser works with bogus br
     */
    var blankHTML = agent.isMSIE && agent.browserVersion < 11 ? '&nbsp;' : '<br>';

    /**
     * @method nodeLength
     *
     * returns #text's text size or element's childNodes size
     *
     * @param {Node} node
     */
    var nodeLength = function (node) {
      if (isText(node)) {
        return node.nodeValue.length;
      }
      
      if (node) {
        return node.childNodes.length;
      }
      
      return 0;
      
    };

    /**
     * returns whether node is empty or not.
     *
     * @param {Node} node
     * @return {Boolean}
     */
    var isEmpty = function (node) {
      var len = nodeLength(node);

      if (len === 0) {
        return true;
      } else if (!isText(node) && len === 1 && node.innerHTML === blankHTML) {
        // ex) <p><br></p>, <span><br></span>
        return true;
      } else if (list.all(node.childNodes, isText) && node.innerHTML === '') {
        // ex) <p></p>, <span></span>
        return true;
      }

      return false;
    };

    /**
     * padding blankHTML if node is empty (for cursor position)
     */
    var paddingBlankHTML = function (node) {
      if (!isVoid(node) && !nodeLength(node)) {
        node.innerHTML = blankHTML;
      }
    };

    /**
     * find nearest ancestor predicate hit
     *
     * @param {Node} node
     * @param {Function} pred - predicate function
     */
    var ancestor = function (node, pred) {
      while (node) {
        if (pred(node)) { return node; }
        if (isEditable(node)) { break; }

        node = node.parentNode;
      }
      return null;
    };

    /**
     * find nearest ancestor only single child blood line and predicate hit
     *
     * @param {Node} node
     * @param {Function} pred - predicate function
     */
    var singleChildAncestor = function (node, pred) {
      node = node.parentNode;

      while (node) {
        if (nodeLength(node) !== 1) { break; }
        if (pred(node)) { return node; }
        if (isEditable(node)) { break; }

        node = node.parentNode;
      }
      return null;
    };

    /**
     * returns new array of ancestor nodes (until predicate hit).
     *
     * @param {Node} node
     * @param {Function} [optional] pred - predicate function
     */
    var listAncestor = function (node, pred) {
      pred = pred || func.fail;

      var ancestors = [];
      ancestor(node, function (el) {
        if (!isEditable(el)) {
          ancestors.push(el);
        }

        return pred(el);
      });
      return ancestors;
    };

    /**
     * find farthest ancestor predicate hit
     */
    var lastAncestor = function (node, pred) {
      var ancestors = listAncestor(node);
      return list.last(ancestors.filter(pred));
    };

    /**
     * returns common ancestor node between two nodes.
     *
     * @param {Node} nodeA
     * @param {Node} nodeB
     */
    var commonAncestor = function (nodeA, nodeB) {
      var ancestors = listAncestor(nodeA);
      for (var n = nodeB; n; n = n.parentNode) {
        if ($.inArray(n, ancestors) > -1) { return n; }
      }
      return null; // difference document area
    };

    /**
     * listing all previous siblings (until predicate hit).
     *
     * @param {Node} node
     * @param {Function} [optional] pred - predicate function
     */
    var listPrev = function (node, pred) {
      pred = pred || func.fail;

      var nodes = [];
      while (node) {
        if (pred(node)) { break; }
        nodes.push(node);
        node = node.previousSibling;
      }
      return nodes;
    };

    /**
     * listing next siblings (until predicate hit).
     *
     * @param {Node} node
     * @param {Function} [pred] - predicate function
     */
    var listNext = function (node, pred) {
      pred = pred || func.fail;

      var nodes = [];
      while (node) {
        if (pred(node)) { break; }
        nodes.push(node);
        node = node.nextSibling;
      }
      return nodes;
    };

    /**
     * listing descendant nodes
     *
     * @param {Node} node
     * @param {Function} [pred] - predicate function
     */
    var listDescendant = function (node, pred) {
      var descendants = [];
      pred = pred || func.ok;

      // start DFS(depth first search) with node
      (function fnWalk(current) {
        if (node !== current && pred(current)) {
          descendants.push(current);
        }
        for (var idx = 0, len = current.childNodes.length; idx < len; idx++) {
          fnWalk(current.childNodes[idx]);
        }
      })(node);

      return descendants;
    };

    /**
     * wrap node with new tag.
     *
     * @param {Node} node
     * @param {Node} tagName of wrapper
     * @return {Node} - wrapper
     */
    var wrap = function (node, wrapperName) {
      var parent = node.parentNode;
      var wrapper = $('<' + wrapperName + '>')[0];

      parent.insertBefore(wrapper, node);
      wrapper.appendChild(node);

      return wrapper;
    };

    /**
     * insert node after preceding
     *
     * @param {Node} node
     * @param {Node} preceding - predicate function
     */
    var insertAfter = function (node, preceding) {
      var next = preceding.nextSibling, parent = preceding.parentNode;
      if (next) {
        parent.insertBefore(node, next);
      } else {
        parent.appendChild(node);
      }
      return node;
    };

    /**
     * append elements.
     *
     * @param {Node} node
     * @param {Collection} aChild
     */
    var appendChildNodes = function (node, aChild) {
      $.each(aChild, function (idx, child) {
        node.appendChild(child);
      });
      return node;
    };

    /**
     * returns whether boundaryPoint is left edge or not.
     *
     * @param {BoundaryPoint} point
     * @return {Boolean}
     */
    var isLeftEdgePoint = function (point) {
      return point.offset === 0;
    };

    /**
     * returns whether boundaryPoint is right edge or not.
     *
     * @param {BoundaryPoint} point
     * @return {Boolean}
     */
    var isRightEdgePoint = function (point) {
      return point.offset === nodeLength(point.node);
    };

    /**
     * returns whether boundaryPoint is edge or not.
     *
     * @param {BoundaryPoint} point
     * @return {Boolean}
     */
    var isEdgePoint = function (point) {
      return isLeftEdgePoint(point) || isRightEdgePoint(point);
    };

    /**
     * returns whether node is left edge of ancestor or not.
     *
     * @param {Node} node
     * @param {Node} ancestor
     * @return {Boolean}
     */
    var isLeftEdgeOf = function (node, ancestor) {
      while (node && node !== ancestor) {
        if (position(node) !== 0) {
          return false;
        }
        node = node.parentNode;
      }

      return true;
    };

    /**
     * returns whether node is right edge of ancestor or not.
     *
     * @param {Node} node
     * @param {Node} ancestor
     * @return {Boolean}
     */
    var isRightEdgeOf = function (node, ancestor) {
      if (!ancestor) {
        return false;
      }
      while (node && node !== ancestor) {
        if (position(node) !== nodeLength(node.parentNode) - 1) {
          return false;
        }
        node = node.parentNode;
      }

      return true;
    };

    /**
     * returns whether point is left edge of ancestor or not.
     * @param {BoundaryPoint} point
     * @param {Node} ancestor
     * @return {Boolean}
     */
    var isLeftEdgePointOf = function (point, ancestor) {
      return isLeftEdgePoint(point) && isLeftEdgeOf(point.node, ancestor);
    };

    /**
     * returns whether point is right edge of ancestor or not.
     * @param {BoundaryPoint} point
     * @param {Node} ancestor
     * @return {Boolean}
     */
    var isRightEdgePointOf = function (point, ancestor) {
      return isRightEdgePoint(point) && isRightEdgeOf(point.node, ancestor);
    };

    /**
     * returns offset from parent.
     *
     * @param {Node} node
     */
    var position = function (node) {
      var offset = 0;
      while ((node = node.previousSibling)) {
        offset += 1;
      }
      return offset;
    };

    var hasChildren = function (node) {
      return !!(node && node.childNodes && node.childNodes.length);
    };

    /**
     * returns previous boundaryPoint
     *
     * @param {BoundaryPoint} point
     * @param {Boolean} isSkipInnerOffset
     * @return {BoundaryPoint}
     */
    var prevPoint = function (point, isSkipInnerOffset) {
      var node, offset;

      if (point.offset === 0) {
        if (isEditable(point.node)) {
          return null;
        }

        node = point.node.parentNode;
        offset = position(point.node);
      } else if (hasChildren(point.node)) {
        node = point.node.childNodes[point.offset - 1];
        offset = nodeLength(node);
      } else {
        node = point.node;
        offset = isSkipInnerOffset ? 0 : point.offset - 1;
      }

      return {
        node: node,
        offset: offset
      };
    };

    /**
     * returns next boundaryPoint
     *
     * @param {BoundaryPoint} point
     * @param {Boolean} isSkipInnerOffset
     * @return {BoundaryPoint}
     */
    var nextPoint = function (point, isSkipInnerOffset) {
      var node, offset;

      if (nodeLength(point.node) === point.offset) {
        if (isEditable(point.node)) {
          return null;
        }

        node = point.node.parentNode;
        offset = position(point.node) + 1;
      } else if (hasChildren(point.node)) {
        node = point.node.childNodes[point.offset];
        offset = 0;
      } else {
        node = point.node;
        offset = isSkipInnerOffset ? nodeLength(point.node) : point.offset + 1;
      }

      return {
        node: node,
        offset: offset
      };
    };

    /**
     * returns whether pointA and pointB is same or not.
     *
     * @param {BoundaryPoint} pointA
     * @param {BoundaryPoint} pointB
     * @return {Boolean}
     */
    var isSamePoint = function (pointA, pointB) {
      return pointA.node === pointB.node && pointA.offset === pointB.offset;
    };

    /**
     * returns whether point is visible (can set cursor) or not.
     *
     * @param {BoundaryPoint} point
     * @return {Boolean}
     */
    var isVisiblePoint = function (point) {
      if (isText(point.node) || !hasChildren(point.node) || isEmpty(point.node)) {
        return true;
      }

      var leftNode = point.node.childNodes[point.offset - 1];
      var rightNode = point.node.childNodes[point.offset];
      if ((!leftNode || isVoid(leftNode)) && (!rightNode || isVoid(rightNode))) {
        return true;
      }

      return false;
    };

    /**
     * @method prevPointUtil
     *
     * @param {BoundaryPoint} point
     * @param {Function} pred
     * @return {BoundaryPoint}
     */
    var prevPointUntil = function (point, pred) {
      while (point) {
        if (pred(point)) {
          return point;
        }

        point = prevPoint(point);
      }

      return null;
    };

    /**
     * @method nextPointUntil
     *
     * @param {BoundaryPoint} point
     * @param {Function} pred
     * @return {BoundaryPoint}
     */
    var nextPointUntil = function (point, pred) {
      while (point) {
        if (pred(point)) {
          return point;
        }

        point = nextPoint(point);
      }

      return null;
    };

    /**
     * returns whether point has character or not.
     *
     * @param {Point} point
     * @return {Boolean}
     */
    var isCharPoint = function (point) {
      if (!isText(point.node)) {
        return false;
      }

      var ch = point.node.nodeValue.charAt(point.offset - 1);
      return ch && (ch !== ' ' && ch !== NBSP_CHAR);
    };

    /**
     * @method walkPoint
     *
     * @param {BoundaryPoint} startPoint
     * @param {BoundaryPoint} endPoint
     * @param {Function} handler
     * @param {Boolean} isSkipInnerOffset
     */
    var walkPoint = function (startPoint, endPoint, handler, isSkipInnerOffset) {
      var point = startPoint;

      while (point) {
        handler(point);

        if (isSamePoint(point, endPoint)) {
          break;
        }

        var isSkipOffset = isSkipInnerOffset &&
                           startPoint.node !== point.node &&
                           endPoint.node !== point.node;
        point = nextPoint(point, isSkipOffset);
      }
    };

    /**
     * @method makeOffsetPath
     *
     * return offsetPath(array of offset) from ancestor
     *
     * @param {Node} ancestor - ancestor node
     * @param {Node} node
     */
    var makeOffsetPath = function (ancestor, node) {
      var ancestors = listAncestor(node, func.eq(ancestor));
      return ancestors.map(position).reverse();
    };

    /**
     * @method fromOffsetPath
     *
     * return element from offsetPath(array of offset)
     *
     * @param {Node} ancestor - ancestor node
     * @param {array} offsets - offsetPath
     */
    var fromOffsetPath = function (ancestor, offsets) {
      var current = ancestor;
      for (var i = 0, len = offsets.length; i < len; i++) {
        if (current.childNodes.length <= offsets[i]) {
          current = current.childNodes[current.childNodes.length - 1];
        } else {
          current = current.childNodes[offsets[i]];
        }
      }
      return current;
    };

    /**
     * @method splitNode
     *
     * split element or #text
     *
     * @param {BoundaryPoint} point
     * @param {Object} [options]
     * @param {Boolean} [options.isSkipPaddingBlankHTML] - default: false
     * @param {Boolean} [options.isNotSplitEdgePoint] - default: false
     * @return {Node} right node of boundaryPoint
     */
    var splitNode = function (point, options) {
      var isSkipPaddingBlankHTML = options && options.isSkipPaddingBlankHTML;
      var isNotSplitEdgePoint = options && options.isNotSplitEdgePoint;

      // edge case
      if (isEdgePoint(point) && (isText(point.node) || isNotSplitEdgePoint)) {
        if (isLeftEdgePoint(point)) {
          return point.node;
        } else if (isRightEdgePoint(point)) {
          return point.node.nextSibling;
        }
      }

      // split #text
      if (isText(point.node)) {
        return point.node.splitText(point.offset);
      } else {
        var childNode = point.node.childNodes[point.offset];
        var clone = insertAfter(point.node.cloneNode(false), point.node);
        appendChildNodes(clone, listNext(childNode));

        if (!isSkipPaddingBlankHTML) {
          paddingBlankHTML(point.node);
          paddingBlankHTML(clone);
        }

        return clone;
      }
    };

    /**
     * @method splitTree
     *
     * split tree by point
     *
     * @param {Node} root - split root
     * @param {BoundaryPoint} point
     * @param {Object} [options]
     * @param {Boolean} [options.isSkipPaddingBlankHTML] - default: false
     * @param {Boolean} [options.isNotSplitEdgePoint] - default: false
     * @return {Node} right node of boundaryPoint
     */
    var splitTree = function (root, point, options) {
      // ex) [#text, <span>, <p>]
      var ancestors = listAncestor(point.node, func.eq(root));

      if (!ancestors.length) {
        return null;
      } else if (ancestors.length === 1) {
        return splitNode(point, options);
      }

      return ancestors.reduce(function (node, parent) {
        if (node === point.node) {
          node = splitNode(point, options);
        }

        return splitNode({
          node: parent,
          offset: node ? dom.position(node) : nodeLength(parent)
        }, options);
      });
    };

    /**
     * split point
     *
     * @param {Point} point
     * @param {Boolean} isInline
     * @return {Object}
     */
    var splitPoint = function (point, isInline) {
      // find splitRoot, container
      //  - inline: splitRoot is a child of paragraph
      //  - block: splitRoot is a child of bodyContainer
      var pred = isInline ? isPara : isBodyContainer;
      var ancestors = listAncestor(point.node, pred);
      var topAncestor = list.last(ancestors) || point.node;

      var splitRoot, container;
      if (pred(topAncestor)) {
        splitRoot = ancestors[ancestors.length - 2];
        container = topAncestor;
      } else {
        splitRoot = topAncestor;
        container = splitRoot.parentNode;
      }

      // if splitRoot is exists, split with splitTree
      var pivot = splitRoot && splitTree(splitRoot, point, {
        isSkipPaddingBlankHTML: isInline,
        isNotSplitEdgePoint: isInline
      });

      // if container is point.node, find pivot with point.offset
      if (!pivot && container === point.node) {
        pivot = point.node.childNodes[point.offset];
      }

      return {
        rightNode: pivot,
        container: container
      };
    };

    var create = function (nodeName) {
      return document.createElement(nodeName);
    };

    var createText = function (text) {
      return document.createTextNode(text);
    };

    /**
     * @method remove
     *
     * remove node, (isRemoveChild: remove child or not)
     *
     * @param {Node} node
     * @param {Boolean} isRemoveChild
     */
    var remove = function (node, isRemoveChild) {
      if (!node || !node.parentNode) { return; }
      if (node.removeNode) { return node.removeNode(isRemoveChild); }

      var parent = node.parentNode;
      if (!isRemoveChild) {
        var nodes = [];
        var i, len;
        for (i = 0, len = node.childNodes.length; i < len; i++) {
          nodes.push(node.childNodes[i]);
        }

        for (i = 0, len = nodes.length; i < len; i++) {
          parent.insertBefore(nodes[i], node);
        }
      }

      parent.removeChild(node);
    };

    /**
     * @method removeWhile
     *
     * @param {Node} node
     * @param {Function} pred
     */
    var removeWhile = function (node, pred) {
      while (node) {
        if (isEditable(node) || !pred(node)) {
          break;
        }

        var parent = node.parentNode;
        remove(node);
        node = parent;
      }
    };

    /**
     * @method replace
     *
     * replace node with provided nodeName
     *
     * @param {Node} node
     * @param {String} nodeName
     * @return {Node} - new node
     */
    var replace = function (node, nodeName) {
      if (node.nodeName.toUpperCase() === nodeName.toUpperCase()) {
        return node;
      }

      var newNode = create(nodeName);

      if (node.style.cssText) {
        newNode.style.cssText = node.style.cssText;
      }

      appendChildNodes(newNode, list.from(node.childNodes));
      insertAfter(newNode, node);
      remove(node);

      return newNode;
    };

    var isTextarea = makePredByNodeName('TEXTAREA');

    /**
     * @param {jQuery} $node
     * @param {Boolean} [stripLinebreaks] - default: false
     */
    var value = function ($node, stripLinebreaks) {
      var val = isTextarea($node[0]) ? $node.val() : $node.html();
      if (stripLinebreaks) {
        return val.replace(/[\n\r]/g, '');
      }
      return val;
    };

    /**
     * @method html
     *
     * get the HTML contents of node
     *
     * @param {jQuery} $node
     * @param {Boolean} [isNewlineOnBlock]
     */
    var html = function ($node, isNewlineOnBlock) {
      var markup = value($node);

      if (isNewlineOnBlock) {
        var regexTag = /<(\/?)(\b(?!!)[^>\s]*)(.*?)(\s*\/?>)/g;
        markup = markup.replace(regexTag, function (match, endSlash, name) {
          name = name.toUpperCase();
          var isEndOfInlineContainer = /^DIV|^TD|^TH|^P|^LI|^H[1-7]/.test(name) &&
                                       !!endSlash;
          var isBlockNode = /^BLOCKQUOTE|^TABLE|^TBODY|^TR|^HR|^UL|^OL/.test(name);

          return match + ((isEndOfInlineContainer || isBlockNode) ? '\n' : '');
        });
        markup = $.trim(markup);
      }

      return markup;
    };

    var posFromPlaceholder = function (placeholder) {
      var $placeholder = $(placeholder);
      var pos = $placeholder.offset();
      var height = $placeholder.outerHeight(true); // include margin

      return {
        left: pos.left,
        top: pos.top + height
      };
    };

    var attachEvents = function ($node, events) {
      Object.keys(events).forEach(function (key) {
        $node.on(key, events[key]);
      });
    };

    var detachEvents = function ($node, events) {
      Object.keys(events).forEach(function (key) {
        $node.off(key, events[key]);
      });
    };

    /**
     * @method isCustomStyleTag
     *
     * assert if a node contains a "note-styletag" class,
     * which implies that's a custom-made style tag node
     *
     * @param {Node} an HTML DOM node
     */
    var isCustomStyleTag = function (node) {
      return node && !dom.isText(node) && list.contains(node.classList, 'note-styletag');
    };

    return {
      /** @property {String} NBSP_CHAR */
      NBSP_CHAR: NBSP_CHAR,
      /** @property {String} ZERO_WIDTH_NBSP_CHAR */
      ZERO_WIDTH_NBSP_CHAR: ZERO_WIDTH_NBSP_CHAR,
      /** @property {String} blank */
      blank: blankHTML,
      /** @property {String} emptyPara */
      emptyPara: '<p>' + blankHTML + '</p>',
      makePredByNodeName: makePredByNodeName,
      isEditable: isEditable,
      isControlSizing: isControlSizing,
      isText: isText,
      isElement: isElement,
      isVoid: isVoid,
      isPara: isPara,
      isPurePara: isPurePara,
      isHeading: isHeading,
      isInline: isInline,
      isBlock: func.not(isInline),
      isBodyInline: isBodyInline,
      isBody: isBody,
      isParaInline: isParaInline,
      isPre: isPre,
      isList: isList,
      isTable: isTable,
      isData: isData,
      isCell: isCell,
      isBlockquote: isBlockquote,
      isBodyContainer: isBodyContainer,
      isAnchor: isAnchor,
      isDiv: makePredByNodeName('DIV'),
      isLi: isLi,
      isBR: makePredByNodeName('BR'),
      isSpan: makePredByNodeName('SPAN'),
      isB: makePredByNodeName('B'),
      isU: makePredByNodeName('U'),
      isS: makePredByNodeName('S'),
      isI: makePredByNodeName('I'),
      isImg: makePredByNodeName('IMG'),
      isTextarea: isTextarea,
      isEmpty: isEmpty,
      isEmptyAnchor: func.and(isAnchor, isEmpty),
      isClosestSibling: isClosestSibling,
      withClosestSiblings: withClosestSiblings,
      nodeLength: nodeLength,
      isLeftEdgePoint: isLeftEdgePoint,
      isRightEdgePoint: isRightEdgePoint,
      isEdgePoint: isEdgePoint,
      isLeftEdgeOf: isLeftEdgeOf,
      isRightEdgeOf: isRightEdgeOf,
      isLeftEdgePointOf: isLeftEdgePointOf,
      isRightEdgePointOf: isRightEdgePointOf,
      prevPoint: prevPoint,
      nextPoint: nextPoint,
      isSamePoint: isSamePoint,
      isVisiblePoint: isVisiblePoint,
      prevPointUntil: prevPointUntil,
      nextPointUntil: nextPointUntil,
      isCharPoint: isCharPoint,
      walkPoint: walkPoint,
      ancestor: ancestor,
      singleChildAncestor: singleChildAncestor,
      listAncestor: listAncestor,
      lastAncestor: lastAncestor,
      listNext: listNext,
      listPrev: listPrev,
      listDescendant: listDescendant,
      commonAncestor: commonAncestor,
      wrap: wrap,
      insertAfter: insertAfter,
      appendChildNodes: appendChildNodes,
      position: position,
      hasChildren: hasChildren,
      makeOffsetPath: makeOffsetPath,
      fromOffsetPath: fromOffsetPath,
      splitTree: splitTree,
      splitPoint: splitPoint,
      create: create,
      createText: createText,
      remove: remove,
      removeWhile: removeWhile,
      replace: replace,
      html: html,
      value: value,
      posFromPlaceholder: posFromPlaceholder,
      attachEvents: attachEvents,
      detachEvents: detachEvents,
      isCustomStyleTag: isCustomStyleTag
    };
  })();

  /**
   * @param {jQuery} $note
   * @param {Object} options
   * @return {Context}
   */
  var Context = function ($note, options) {
    var self = this;

    var ui = $.summernote.ui;
    this.memos = {};
    this.modules = {};
    this.layoutInfo = {};
    this.options = options;

    /**
     * create layout and initialize modules and other resources
     */
    this.initialize = function () {
      this.layoutInfo = ui.createLayout($note, options);
      this._initialize();
      $note.hide();
      return this;
    };

    /**
     * destroy modules and other resources and remove layout
     */
    this.destroy = function () {
      this._destroy();
      $note.removeData('summernote');
      ui.removeLayout($note, this.layoutInfo);
    };

    /**
     * destory modules and other resources and initialize it again
     */
    this.reset = function () {
      var disabled = self.isDisabled();
      this.code(dom.emptyPara);
      this._destroy();
      this._initialize();

      if (disabled) {
        self.disable();
      }
    };

    this._initialize = function () {
      // add optional buttons
      var buttons = $.extend({}, this.options.buttons);
      Object.keys(buttons).forEach(function (key) {
        self.memo('button.' + key, buttons[key]);
      });

      var modules = $.extend({}, this.options.modules, $.summernote.plugins || {});

      // add and initialize modules
      Object.keys(modules).forEach(function (key) {
        self.module(key, modules[key], true);
      });

      Object.keys(this.modules).forEach(function (key) {
        self.initializeModule(key);
      });
    };

    this._destroy = function () {
      // destroy modules with reversed order
      Object.keys(this.modules).reverse().forEach(function (key) {
        self.removeModule(key);
      });

      Object.keys(this.memos).forEach(function (key) {
        self.removeMemo(key);
      });
      // trigger custom onDestroy callback
      this.triggerEvent('destroy', this);
    };

    this.code = function (html) {
      var isActivated = this.invoke('codeview.isActivated');

      if (html === undefined) {
        this.invoke('codeview.sync');
        return isActivated ? this.layoutInfo.codable.val() : this.layoutInfo.editable.html();
      } else {
        if (isActivated) {
          this.layoutInfo.codable.val(html);
        } else {
          this.layoutInfo.editable.html(html);
        }
        $note.val(html);
        this.triggerEvent('change', html);
      }
    };

    this.isDisabled = function () {
      return this.layoutInfo.editable.attr('contenteditable') === 'false';
    };

    this.enable = function () {
      this.layoutInfo.editable.attr('contenteditable', true);
      this.invoke('toolbar.activate', true);
      this.triggerEvent('disable', false);
    };

    this.disable = function () {
      // close codeview if codeview is opend
      if (this.invoke('codeview.isActivated')) {
        this.invoke('codeview.deactivate');
      }
      this.layoutInfo.editable.attr('contenteditable', false);
      this.invoke('toolbar.deactivate', true);

      this.triggerEvent('disable', true);
    };

    this.triggerEvent = function () {
      var namespace = list.head(arguments);
      var args = list.tail(list.from(arguments));

      var callback = this.options.callbacks[func.namespaceToCamel(namespace, 'on')];
      if (callback) {
        callback.apply($note[0], args);
      }
      $note.trigger('summernote.' + namespace, args);
    };

    this.initializeModule = function (key) {
      var module = this.modules[key];
      module.shouldInitialize = module.shouldInitialize || func.ok;
      if (!module.shouldInitialize()) {
        return;
      }

      // initialize module
      if (module.initialize) {
        module.initialize();
      }

      // attach events
      if (module.events) {
        dom.attachEvents($note, module.events);
      }
    };

    this.module = function (key, ModuleClass, withoutIntialize) {
      if (arguments.length === 1) {
        return this.modules[key];
      }

      this.modules[key] = new ModuleClass(this);

      if (!withoutIntialize) {
        this.initializeModule(key);
      }
    };

    this.removeModule = function (key) {
      var module = this.modules[key];
      if (module.shouldInitialize()) {
        if (module.events) {
          dom.detachEvents($note, module.events);
        }

        if (module.destroy) {
          module.destroy();
        }
      }

      delete this.modules[key];
    };

    this.memo = function (key, obj) {
      if (arguments.length === 1) {
        return this.memos[key];
      }
      this.memos[key] = obj;
    };

    this.removeMemo = function (key) {
      if (this.memos[key] && this.memos[key].destroy) {
        this.memos[key].destroy();
      }

      delete this.memos[key];
    };

    /**
     *Some buttons need to change their visual style immediately once they get pressed
     */
    this.createInvokeHandlerAndUpdateState = function (namespace, value) {
      return function (event) {
        self.createInvokeHandler(namespace, value)(event);
        self.invoke('buttons.updateCurrentStyle');
      };
    };

    this.createInvokeHandler = function (namespace, value) {
      return function (event) {
        event.preventDefault();
        var $target = $(event.target);
        self.invoke(namespace, value || $target.closest('[data-value]').data('value'), $target);
      };
    };

    this.invoke = function () {
      var namespace = list.head(arguments);
      var args = list.tail(list.from(arguments));

      var splits = namespace.split('.');
      var hasSeparator = splits.length > 1;
      var moduleName = hasSeparator && list.head(splits);
      var methodName = hasSeparator ? list.last(splits) : list.head(splits);

      var module = this.modules[moduleName || 'editor'];
      if (!moduleName && this[methodName]) {
        return this[methodName].apply(this, args);
      } else if (module && module[methodName] && module.shouldInitialize()) {
        return module[methodName].apply(module, args);
      }
    };

    return this.initialize();
  };

  $.fn.extend({
    /**
     * Summernote API
     *
     * @param {Object|String}
     * @return {this}
     */
    summernote: function () {
      var type = $.type(list.head(arguments));
      var isExternalAPICalled = type === 'string';
      var hasInitOptions = type === 'object';

      var options = hasInitOptions ? list.head(arguments) : {};

      options = $.extend({}, $.summernote.options, options);

      // Update options
      options.langInfo = $.extend(true, {}, $.summernote.lang['en-US'], $.summernote.lang[options.lang]);
      options.icons = $.extend(true, {}, $.summernote.options.icons, options.icons);
      options.tooltip = options.tooltip === 'auto' ? !agent.isSupportTouch : options.tooltip;

      this.each(function (idx, note) {
        var $note = $(note);
        if (!$note.data('summernote')) {
          var context = new Context($note, options);
          $note.data('summernote', context);
          $note.data('summernote').triggerEvent('init', context.layoutInfo);
        }
      });

      var $note = this.first();
      if ($note.length) {
        var context = $note.data('summernote');
        if (isExternalAPICalled) {
          return context.invoke.apply(context, list.from(arguments));
        } else if (options.focus) {
          context.invoke('editor.focus');
        }
      }

      return this;
    }
  });


  var Renderer = function (markup, children, options, callback) {
    this.render = function ($parent) {
      var $node = $(markup);

      if (options && options.contents) {
        $node.html(options.contents);
      }

      if (options && options.className) {
        $node.addClass(options.className);
      }

      if (options && options.data) {
        $.each(options.data, function (k, v) {
          $node.attr('data-' + k, v);
        });
      }

      if (options && options.click) {
        $node.on('click', options.click);
      }

      if (children) {
        var $container = $node.find('.note-children-container');
        children.forEach(function (child) {
          child.render($container.length ? $container : $node);
        });
      }

      if (callback) {
        callback($node, options);
      }

      if (options && options.callback) {
        options.callback($node);
      }

      if ($parent) {
        $parent.append($node);
      }

      return $node;
    };
  };

  var renderer = {
    create: function (markup, callback) {
      return function () {
        var children = $.isArray(arguments[0]) ? arguments[0] : [];
        var options = typeof arguments[1] === 'object' ? arguments[1] : arguments[0];
        if (options && options.children) {
          children = options.children;
        }
        return new Renderer(markup, children, options, callback);
      };
    }
  };

  var editor = renderer.create('<div class="note-editor note-frame panel panel-default"/>');
  var toolbar = renderer.create('<div class="note-toolbar panel-heading"/>');
  var editingArea = renderer.create('<div class="note-editing-area"/>');
  var codable = renderer.create('<textarea class="note-codable"/>');
  var editable = renderer.create('<div class="note-editable panel-body" contentEditable="true"/>');
  var statusbar = renderer.create([
    '<div class="note-statusbar">',
    '  <div class="note-resizebar">',
    '    <div class="note-icon-bar"/>',
    '    <div class="note-icon-bar"/>',
    '    <div class="note-icon-bar"/>',
    '  </div>',
    '</div>'
  ].join(''));

  var airEditor = renderer.create('<div class="note-editor"/>');
  var airEditable = renderer.create('<div class="note-editable" contentEditable="true"/>');

  var buttonGroup = renderer.create('<div class="note-btn-group btn-group">');

  var dropdown = renderer.create('<div class="dropdown-menu">', function ($node, options) {
    var markup = $.isArray(options.items) ? options.items.map(function (item) {
      var value = (typeof item === 'string') ? item : (item.value || '');
      var content = options.template ? options.template(item) : item;
      var option = (typeof item === 'object') ? item.option : undefined;

      var dataValue = 'data-value="' + value + '"';
      var dataOption = (option !== undefined) ? ' data-option="' + option + '"' : '';
      return '<li><a href="#" ' + (dataValue + dataOption) + '>' + content + '</a></li>';
    }).join('') : options.items;

    $node.html(markup);
  });

  var dropdownCheck = renderer.create('<div class="dropdown-menu note-check">', function ($node, options) {
    var markup = $.isArray(options.items) ? options.items.map(function (item) {
      var value = (typeof item === 'string') ? item : (item.value || '');
      var content = options.template ? options.template(item) : item;
      return '<li><a href="#" data-value="' + value + '">' + icon(options.checkClassName) + ' ' + content + '</a></li>';
    }).join('') : options.items;
    $node.html(markup);
  });

  var palette = renderer.create('<div class="note-color-palette"/>', function ($node, options) {
    var contents = [];
    for (var row = 0, rowSize = options.colors.length; row < rowSize; row++) {
      var eventName = options.eventName;
      var colors = options.colors[row];
      var buttons = [];
      for (var col = 0, colSize = colors.length; col < colSize; col++) {
        var color = colors[col];
        buttons.push([
          '<button type="button" class="note-color-btn"',
          'style="background-color:', color, '" ',
          'data-event="', eventName, '" ',
          'data-value="', color, '" ',
          'title="', color, '" ',
          'data-toggle="button" tabindex="-1"></button>'
        ].join(''));
      }
      contents.push('<div class="note-color-row">' + buttons.join('') + '</div>');
    }
    $node.html(contents.join(''));

    if (options.tooltip) {
      $node.find('.note-color-btn').tooltip({
        container: 'body',
        trigger: 'hover',
        placement: 'bottom'
      });
    }
  });

  var dialog = renderer.create('<div class="modal" aria-hidden="false" tabindex="-1"/>', function ($node, options) {
    if (options.fade) {
      $node.addClass('fade');
    }
    $node.html([
      '<div class="modal-dialog">',
      '  <div class="modal-content">',
      (options.title ?
      '    <div class="modal-header">' +
      '      <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>' +
      '      <h4 class="modal-title">' + options.title + '</h4>' +
      '    </div>' : ''
      ),
      '    <div class="modal-body">' + options.body + '</div>',
      (options.footer ?
      '    <div class="modal-footer">' + options.footer + '</div>' : ''
      ),
      '  </div>',
      '</div>'
    ].join(''));
  });

  var popover = renderer.create([
    '<div class="note-popover popover in">',
    '  <div class="arrow"/>',
    '  <div class="popover-content note-children-container"/>',
    '</div>'
  ].join(''), function ($node, options) {
    var direction = typeof options.direction !== 'undefined' ? options.direction : 'bottom';

    $node.addClass(direction);

    if (options.hideArrow) {
      $node.find('.arrow').hide();
    }
  });

  var icon = function (iconClassName, tagName) {
    tagName = tagName || 'i';
    return '<' + tagName + ' class="' + iconClassName + '"/>';
  };

  var ui = {
    editor: editor,
    toolbar: toolbar,
    editingArea: editingArea,
    codable: codable,
    editable: editable,
    statusbar: statusbar,
    airEditor: airEditor,
    airEditable: airEditable,
    buttonGroup: buttonGroup,
    dropdown: dropdown,
    dropdownCheck: dropdownCheck,
    palette: palette,
    dialog: dialog,
    popover: popover,
    icon: icon,
    options: {},

    button: function ($node, options) {
      return renderer.create('<button type="button" class="note-btn btn btn-default btn-sm" tabindex="-1">', function ($node, options) {
        if (options && options.tooltip && self.options.tooltip) {
          $node.attr({
            title: options.tooltip
          }).tooltip({
            container: 'body',
            trigger: 'hover',
            placement: 'bottom'
          });
        }
      })($node, options);
    },

    toggleBtn: function ($btn, isEnable) {
      $btn.toggleClass('disabled', !isEnable);
      $btn.attr('disabled', !isEnable);
    },

    toggleBtnActive: function ($btn, isActive) {
      $btn.toggleClass('active', isActive);
    },

    onDialogShown: function ($dialog, handler) {
      $dialog.one('shown.bs.modal', handler);
    },

    onDialogHidden: function ($dialog, handler) {
      $dialog.one('hidden.bs.modal', handler);
    },

    showDialog: function ($dialog) {
      $dialog.modal('show');
    },

    hideDialog: function ($dialog) {
      $dialog.modal('hide');
    },

    createLayout: function ($note, options) {
      self.options = options;
      var $editor = (options.airMode ? ui.airEditor([
        ui.editingArea([
          ui.airEditable()
        ])
      ]) : ui.editor([
        ui.toolbar(),
        ui.editingArea([
          ui.codable(),
          ui.editable()
        ]),
        ui.statusbar()
      ])).render();

      $editor.insertAfter($note);

      return {
        note: $note,
        editor: $editor,
        toolbar: $editor.find('.note-toolbar'),
        editingArea: $editor.find('.note-editing-area'),
        editable: $editor.find('.note-editable'),
        codable: $editor.find('.note-codable'),
        statusbar: $editor.find('.note-statusbar')
      };
    },

    removeLayout: function ($note, layoutInfo) {
      $note.html(layoutInfo.editable.html());
      layoutInfo.editor.remove();
      $note.show();
    }
  };

  $.summernote = $.summernote || {
    lang: {}
  };

  $.extend($.summernote.lang, {
    'en-US': {
      font: {
        bold: 'Bold',
        italic: 'Italic',
        underline: 'Underline',
        clear: 'Remove Font Style',
        height: 'Line Height',
        name: 'Font Family',
        strikethrough: 'Strikethrough',
        subscript: 'Subscript',
        superscript: 'Superscript',
        size: 'Font Size'
      },
      image: {
        image: 'Picture',
        insert: 'Insert Image',
        resizeFull: 'Resize Full',
        resizeHalf: 'Resize Half',
        resizeQuarter: 'Resize Quarter',
        floatLeft: 'Float Left',
        floatRight: 'Float Right',
        floatNone: 'Float None',
        shapeRounded: 'Shape: Rounded',
        shapeCircle: 'Shape: Circle',
        shapeThumbnail: 'Shape: Thumbnail',
        shapeNone: 'Shape: None',
        dragImageHere: 'Drag image or text here',
        dropImage: 'Drop image or Text',
        selectFromFiles: 'Select from files',
        maximumFileSize: 'Maximum file size',
        maximumFileSizeError: 'Maximum file size exceeded.',
        url: 'Image URL',
        remove: 'Remove Image'
      },
      video: {
        video: 'Video',
        videoLink: 'Video Link',
        insert: 'Insert Video',
        url: 'Video URL?',
        providers: '(YouTube, Vimeo, Vine, Instagram, DailyMotion or Youku)'
      },
      link: {
        link: 'Link',
        insert: 'Insert Link',
        unlink: 'Unlink',
        edit: 'Edit',
        textToDisplay: 'Text to display',
        url: 'To what URL should this link go?',
        openInNewWindow: 'Open in new window'
      },
      table: {
        table: 'Table',
        addRowAbove: 'Add row above',
        addRowBelow: 'Add row below',
        addColLeft: 'Add column left',
        addColRight: 'Add column right',
        delRow: 'Delete row',
        delCol: 'Delete column',
        delTable: 'Delete table'
      },
      hr: {
        insert: 'Insert Horizontal Rule'
      },
      style: {
        style: 'Style',
        p: 'Normal',
        blockquote: 'Quote',
        pre: 'Code',
        h1: 'Header 1',
        h2: 'Header 2',
        h3: 'Header 3',
        h4: 'Header 4',
        h5: 'Header 5',
        h6: 'Header 6'
      },
      lists: {
        unordered: 'Unordered list',
        ordered: 'Ordered list'
      },
      options: {
        help: 'Help',
        fullscreen: 'Full Screen',
        codeview: 'Code View'
      },
      paragraph: {
        paragraph: 'Paragraph',
        outdent: 'Outdent',
        indent: 'Indent',
        left: 'Align left',
        center: 'Align center',
        right: 'Align right',
        justify: 'Justify full'
      },
      color: {
        recent: 'Recent Color',
        more: 'More Color',
        background: 'Background Color',
        foreground: 'Foreground Color',
        transparent: 'Transparent',
        setTransparent: 'Set transparent',
        reset: 'Reset',
        resetToDefault: 'Reset to default'
      },
      shortcut: {
        shortcuts: 'Keyboard shortcuts',
        close: 'Close',
        textFormatting: 'Text formatting',
        action: 'Action',
        paragraphFormatting: 'Paragraph formatting',
        documentStyle: 'Document Style',
        extraKeys: 'Extra keys'
      },
      help: {
        'insertParagraph': 'Insert Paragraph',
        'undo': 'Undoes the last command',
        'redo': 'Redoes the last command',
        'tab': 'Tab',
        'untab': 'Untab',
        'bold': 'Set a bold style',
        'italic': 'Set a italic style',
        'underline': 'Set a underline style',
        'strikethrough': 'Set a strikethrough style',
        'removeFormat': 'Clean a style',
        'justifyLeft': 'Set left align',
        'justifyCenter': 'Set center align',
        'justifyRight': 'Set right align',
        'justifyFull': 'Set full align',
        'insertUnorderedList': 'Toggle unordered list',
        'insertOrderedList': 'Toggle ordered list',
        'outdent': 'Outdent on current paragraph',
        'indent': 'Indent on current paragraph',
        'formatPara': 'Change current block\'s format as a paragraph(P tag)',
        'formatH1': 'Change current block\'s format as H1',
        'formatH2': 'Change current block\'s format as H2',
        'formatH3': 'Change current block\'s format as H3',
        'formatH4': 'Change current block\'s format as H4',
        'formatH5': 'Change current block\'s format as H5',
        'formatH6': 'Change current block\'s format as H6',
        'insertHorizontalRule': 'Insert horizontal rule',
        'linkDialog.show': 'Show Link Dialog'
      },
      history: {
        undo: 'Undo',
        redo: 'Redo'
      },
      specialChar: {
        specialChar: 'SPECIAL CHARACTERS',
        select: 'Select Special characters'
      }
    }
  });


  /**
   * @class core.key
   *
   * Object for keycodes.
   *
   * @singleton
   * @alternateClassName key
   */
  var key = (function () {
    var keyMap = {
      'BACKSPACE': 8,
      'TAB': 9,
      'ENTER': 13,
      'SPACE': 32,
      'DELETE': 46,

      // Arrow
      'LEFT': 37,
      'UP': 38,
      'RIGHT': 39,
      'DOWN': 40,

      // Number: 0-9
      'NUM0': 48,
      'NUM1': 49,
      'NUM2': 50,
      'NUM3': 51,
      'NUM4': 52,
      'NUM5': 53,
      'NUM6': 54,
      'NUM7': 55,
      'NUM8': 56,

      // Alphabet: a-z
      'B': 66,
      'E': 69,
      'I': 73,
      'J': 74,
      'K': 75,
      'L': 76,
      'R': 82,
      'S': 83,
      'U': 85,
      'V': 86,
      'Y': 89,
      'Z': 90,

      'SLASH': 191,
      'LEFTBRACKET': 219,
      'BACKSLASH': 220,
      'RIGHTBRACKET': 221
    };

    return {
      /**
       * @method isEdit
       *
       * @param {Number} keyCode
       * @return {Boolean}
       */
      isEdit: function (keyCode) {
        return list.contains([
          keyMap.BACKSPACE,
          keyMap.TAB,
          keyMap.ENTER,
          keyMap.SPACE,
          keyMap.DELETE
        ], keyCode);
      },
      /**
       * @method isMove
       *
       * @param {Number} keyCode
       * @return {Boolean}
       */
      isMove: function (keyCode) {
        return list.contains([
          keyMap.LEFT,
          keyMap.UP,
          keyMap.RIGHT,
          keyMap.DOWN
        ], keyCode);
      },
      /**
       * @property {Object} nameFromCode
       * @property {String} nameFromCode.8 "BACKSPACE"
       */
      nameFromCode: func.invertObject(keyMap),
      code: keyMap
    };
  })();

  var range = (function () {

    /**
     * return boundaryPoint from TextRange, inspired by Andy Na's HuskyRange.js
     *
     * @param {TextRange} textRange
     * @param {Boolean} isStart
     * @return {BoundaryPoint}
     *
     * @see http://msdn.microsoft.com/en-us/library/ie/ms535872(v=vs.85).aspx
     */
    var textRangeToPoint = function (textRange, isStart) {
      var container = textRange.parentElement(), offset;
  
      var tester = document.body.createTextRange(), prevContainer;
      var childNodes = list.from(container.childNodes);
      for (offset = 0; offset < childNodes.length; offset++) {
        if (dom.isText(childNodes[offset])) {
          continue;
        }
        tester.moveToElementText(childNodes[offset]);
        if (tester.compareEndPoints('StartToStart', textRange) >= 0) {
          break;
        }
        prevContainer = childNodes[offset];
      }
  
      if (offset !== 0 && dom.isText(childNodes[offset - 1])) {
        var textRangeStart = document.body.createTextRange(), curTextNode = null;
        textRangeStart.moveToElementText(prevContainer || container);
        textRangeStart.collapse(!prevContainer);
        curTextNode = prevContainer ? prevContainer.nextSibling : container.firstChild;
  
        var pointTester = textRange.duplicate();
        pointTester.setEndPoint('StartToStart', textRangeStart);
        var textCount = pointTester.text.replace(/[\r\n]/g, '').length;
  
        while (textCount > curTextNode.nodeValue.length && curTextNode.nextSibling) {
          textCount -= curTextNode.nodeValue.length;
          curTextNode = curTextNode.nextSibling;
        }
  
        /* jshint ignore:start */
        var dummy = curTextNode.nodeValue; // enforce IE to re-reference curTextNode, hack
        /* jshint ignore:end */
  
        if (isStart && curTextNode.nextSibling && dom.isText(curTextNode.nextSibling) &&
            textCount === curTextNode.nodeValue.length) {
          textCount -= curTextNode.nodeValue.length;
          curTextNode = curTextNode.nextSibling;
        }
  
        container = curTextNode;
        offset = textCount;
      }
  
      return {
        cont: container,
        offset: offset
      };
    };
    
    /**
     * return TextRange from boundary point (inspired by google closure-library)
     * @param {BoundaryPoint} point
     * @return {TextRange}
     */
    var pointToTextRange = function (point) {
      var textRangeInfo = function (container, offset) {
        var node, isCollapseToStart;
  
        if (dom.isText(container)) {
          var prevTextNodes = dom.listPrev(container, func.not(dom.isText));
          var prevContainer = list.last(prevTextNodes).previousSibling;
          node =  prevContainer || container.parentNode;
          offset += list.sum(list.tail(prevTextNodes), dom.nodeLength);
          isCollapseToStart = !prevContainer;
        } else {
          node = container.childNodes[offset] || container;
          if (dom.isText(node)) {
            return textRangeInfo(node, 0);
          }
  
          offset = 0;
          isCollapseToStart = false;
        }
  
        return {
          node: node,
          collapseToStart: isCollapseToStart,
          offset: offset
        };
      };
  
      var textRange = document.body.createTextRange();
      var info = textRangeInfo(point.node, point.offset);
  
      textRange.moveToElementText(info.node);
      textRange.collapse(info.collapseToStart);
      textRange.moveStart('character', info.offset);
      return textRange;
    };
    
    /**
     * Wrapped Range
     *
     * @constructor
     * @param {Node} sc - start container
     * @param {Number} so - start offset
     * @param {Node} ec - end container
     * @param {Number} eo - end offset
     */
    var WrappedRange = function (sc, so, ec, eo) {
      this.sc = sc;
      this.so = so;
      this.ec = ec;
      this.eo = eo;
  
      // nativeRange: get nativeRange from sc, so, ec, eo
      var nativeRange = function () {
        if (agent.isW3CRangeSupport) {
          var w3cRange = document.createRange();
          w3cRange.setStart(sc, so);
          w3cRange.setEnd(ec, eo);

          return w3cRange;
        } else {
          var textRange = pointToTextRange({
            node: sc,
            offset: so
          });

          textRange.setEndPoint('EndToEnd', pointToTextRange({
            node: ec,
            offset: eo
          }));

          return textRange;
        }
      };

      this.getPoints = function () {
        return {
          sc: sc,
          so: so,
          ec: ec,
          eo: eo
        };
      };

      this.getStartPoint = function () {
        return {
          node: sc,
          offset: so
        };
      };

      this.getEndPoint = function () {
        return {
          node: ec,
          offset: eo
        };
      };

      /**
       * select update visible range
       */
      this.select = function () {
        var nativeRng = nativeRange();
        if (agent.isW3CRangeSupport) {
          var selection = document.getSelection();
          if (selection.rangeCount > 0) {
            selection.removeAllRanges();
          }
          selection.addRange(nativeRng);
        } else {
          nativeRng.select();
        }
        
        return this;
      };

      /**
       * Moves the scrollbar to start container(sc) of current range
       *
       * @return {WrappedRange}
       */
      this.scrollIntoView = function (container) {
        var height = $(container).height();
        if (container.scrollTop + height < this.sc.offsetTop) {
          container.scrollTop += Math.abs(container.scrollTop + height - this.sc.offsetTop);
        }

        return this;
      };

      /**
       * @return {WrappedRange}
       */
      this.normalize = function () {

        /**
         * @param {BoundaryPoint} point
         * @param {Boolean} isLeftToRight
         * @return {BoundaryPoint}
         */
        var getVisiblePoint = function (point, isLeftToRight) {
          if ((dom.isVisiblePoint(point) && !dom.isEdgePoint(point)) ||
              (dom.isVisiblePoint(point) && dom.isRightEdgePoint(point) && !isLeftToRight) ||
              (dom.isVisiblePoint(point) && dom.isLeftEdgePoint(point) && isLeftToRight) ||
              (dom.isVisiblePoint(point) && dom.isBlock(point.node) && dom.isEmpty(point.node))) {
            return point;
          }

          // point on block's edge
          var block = dom.ancestor(point.node, dom.isBlock);
          if (((dom.isLeftEdgePointOf(point, block) || dom.isVoid(dom.prevPoint(point).node)) && !isLeftToRight) ||
              ((dom.isRightEdgePointOf(point, block) || dom.isVoid(dom.nextPoint(point).node)) && isLeftToRight)) {

            // returns point already on visible point
            if (dom.isVisiblePoint(point)) {
              return point;
            }
            // reverse direction 
            isLeftToRight = !isLeftToRight;
          }

          var nextPoint = isLeftToRight ? dom.nextPointUntil(dom.nextPoint(point), dom.isVisiblePoint) :
                                          dom.prevPointUntil(dom.prevPoint(point), dom.isVisiblePoint);
          return nextPoint || point;
        };

        var endPoint = getVisiblePoint(this.getEndPoint(), false);
        var startPoint = this.isCollapsed() ? endPoint : getVisiblePoint(this.getStartPoint(), true);

        return new WrappedRange(
          startPoint.node,
          startPoint.offset,
          endPoint.node,
          endPoint.offset
        );
      };

      /**
       * returns matched nodes on range
       *
       * @param {Function} [pred] - predicate function
       * @param {Object} [options]
       * @param {Boolean} [options.includeAncestor]
       * @param {Boolean} [options.fullyContains]
       * @return {Node[]}
       */
      this.nodes = function (pred, options) {
        pred = pred || func.ok;

        var includeAncestor = options && options.includeAncestor;
        var fullyContains = options && options.fullyContains;

        // TODO compare points and sort
        var startPoint = this.getStartPoint();
        var endPoint = this.getEndPoint();

        var nodes = [];
        var leftEdgeNodes = [];

        dom.walkPoint(startPoint, endPoint, function (point) {
          if (dom.isEditable(point.node)) {
            return;
          }

          var node;
          if (fullyContains) {
            if (dom.isLeftEdgePoint(point)) {
              leftEdgeNodes.push(point.node);
            }
            if (dom.isRightEdgePoint(point) && list.contains(leftEdgeNodes, point.node)) {
              node = point.node;
            }
          } else if (includeAncestor) {
            node = dom.ancestor(point.node, pred);
          } else {
            node = point.node;
          }

          if (node && pred(node)) {
            nodes.push(node);
          }
        }, true);

        return list.unique(nodes);
      };

      /**
       * returns commonAncestor of range
       * @return {Element} - commonAncestor
       */
      this.commonAncestor = function () {
        return dom.commonAncestor(sc, ec);
      };

      /**
       * returns expanded range by pred
       *
       * @param {Function} pred - predicate function
       * @return {WrappedRange}
       */
      this.expand = function (pred) {
        var startAncestor = dom.ancestor(sc, pred);
        var endAncestor = dom.ancestor(ec, pred);

        if (!startAncestor && !endAncestor) {
          return new WrappedRange(sc, so, ec, eo);
        }

        var boundaryPoints = this.getPoints();

        if (startAncestor) {
          boundaryPoints.sc = startAncestor;
          boundaryPoints.so = 0;
        }

        if (endAncestor) {
          boundaryPoints.ec = endAncestor;
          boundaryPoints.eo = dom.nodeLength(endAncestor);
        }

        return new WrappedRange(
          boundaryPoints.sc,
          boundaryPoints.so,
          boundaryPoints.ec,
          boundaryPoints.eo
        );
      };

      /**
       * @param {Boolean} isCollapseToStart
       * @return {WrappedRange}
       */
      this.collapse = function (isCollapseToStart) {
        if (isCollapseToStart) {
          return new WrappedRange(sc, so, sc, so);
        } else {
          return new WrappedRange(ec, eo, ec, eo);
        }
      };

      /**
       * splitText on range
       */
      this.splitText = function () {
        var isSameContainer = sc === ec;
        var boundaryPoints = this.getPoints();

        if (dom.isText(ec) && !dom.isEdgePoint(this.getEndPoint())) {
          ec.splitText(eo);
        }

        if (dom.isText(sc) && !dom.isEdgePoint(this.getStartPoint())) {
          boundaryPoints.sc = sc.splitText(so);
          boundaryPoints.so = 0;

          if (isSameContainer) {
            boundaryPoints.ec = boundaryPoints.sc;
            boundaryPoints.eo = eo - so;
          }
        }

        return new WrappedRange(
          boundaryPoints.sc,
          boundaryPoints.so,
          boundaryPoints.ec,
          boundaryPoints.eo
        );
      };

      /**
       * delete contents on range
       * @return {WrappedRange}
       */
      this.deleteContents = function () {
        if (this.isCollapsed()) {
          return this;
        }

        var rng = this.splitText();
        var nodes = rng.nodes(null, {
          fullyContains: true
        });

        // find new cursor point
        var point = dom.prevPointUntil(rng.getStartPoint(), function (point) {
          return !list.contains(nodes, point.node);
        });

        var emptyParents = [];
        $.each(nodes, function (idx, node) {
          // find empty parents
          var parent = node.parentNode;
          if (point.node !== parent && dom.nodeLength(parent) === 1) {
            emptyParents.push(parent);
          }
          dom.remove(node, false);
        });

        // remove empty parents
        $.each(emptyParents, function (idx, node) {
          dom.remove(node, false);
        });

        return new WrappedRange(
          point.node,
          point.offset,
          point.node,
          point.offset
        ).normalize();
      };
      
      /**
       * makeIsOn: return isOn(pred) function
       */
      var makeIsOn = function (pred) {
        return function () {
          var ancestor = dom.ancestor(sc, pred);
          return !!ancestor && (ancestor === dom.ancestor(ec, pred));
        };
      };
  
      // isOnEditable: judge whether range is on editable or not
      this.isOnEditable = makeIsOn(dom.isEditable);
      // isOnList: judge whether range is on list node or not
      this.isOnList = makeIsOn(dom.isList);
      // isOnAnchor: judge whether range is on anchor node or not
      this.isOnAnchor = makeIsOn(dom.isAnchor);
      // isOnCell: judge whether range is on cell node or not
      this.isOnCell = makeIsOn(dom.isCell);
      // isOnData: judge whether range is on data node or not
      this.isOnData = makeIsOn(dom.isData);

      /**
       * @param {Function} pred
       * @return {Boolean}
       */
      this.isLeftEdgeOf = function (pred) {
        if (!dom.isLeftEdgePoint(this.getStartPoint())) {
          return false;
        }

        var node = dom.ancestor(this.sc, pred);
        return node && dom.isLeftEdgeOf(this.sc, node);
      };

      /**
       * returns whether range was collapsed or not
       */
      this.isCollapsed = function () {
        return sc === ec && so === eo;
      };

      /**
       * wrap inline nodes which children of body with paragraph
       *
       * @return {WrappedRange}
       */
      this.wrapBodyInlineWithPara = function () {
        if (dom.isBodyContainer(sc) && dom.isEmpty(sc)) {
          sc.innerHTML = dom.emptyPara;
          return new WrappedRange(sc.firstChild, 0, sc.firstChild, 0);
        }

        /**
         * [workaround] firefox often create range on not visible point. so normalize here.
         *  - firefox: |<p>text</p>|
         *  - chrome: <p>|text|</p>
         */
        var rng = this.normalize();
        if (dom.isParaInline(sc) || dom.isPara(sc)) {
          return rng;
        }

        // find inline top ancestor
        var topAncestor;
        if (dom.isInline(rng.sc)) {
          var ancestors = dom.listAncestor(rng.sc, func.not(dom.isInline));
          topAncestor = list.last(ancestors);
          if (!dom.isInline(topAncestor)) {
            topAncestor = ancestors[ancestors.length - 2] || rng.sc.childNodes[rng.so];
          }
        } else {
          topAncestor = rng.sc.childNodes[rng.so > 0 ? rng.so - 1 : 0];
        }

        // siblings not in paragraph
        var inlineSiblings = dom.listPrev(topAncestor, dom.isParaInline).reverse();
        inlineSiblings = inlineSiblings.concat(dom.listNext(topAncestor.nextSibling, dom.isParaInline));

        // wrap with paragraph
        if (inlineSiblings.length) {
          var para = dom.wrap(list.head(inlineSiblings), 'p');
          dom.appendChildNodes(para, list.tail(inlineSiblings));
        }

        return this.normalize();
      };

      /**
       * insert node at current cursor
       *
       * @param {Node} node
       * @return {Node}
       */
      this.insertNode = function (node) {
        var rng = this.wrapBodyInlineWithPara().deleteContents();
        var info = dom.splitPoint(rng.getStartPoint(), dom.isInline(node));

        if (info.rightNode) {
          info.rightNode.parentNode.insertBefore(node, info.rightNode);
        } else {
          info.container.appendChild(node);
        }

        return node;
      };

      /**
       * insert html at current cursor
       */
      this.pasteHTML = function (markup) {
        var contentsContainer = $('<div></div>').html(markup)[0];
        var childNodes = list.from(contentsContainer.childNodes);

        var rng = this.wrapBodyInlineWithPara().deleteContents();

        return childNodes.reverse().map(function (childNode) {
          return rng.insertNode(childNode);
        }).reverse();
      };
  
      /**
       * returns text in range
       *
       * @return {String}
       */
      this.toString = function () {
        var nativeRng = nativeRange();
        return agent.isW3CRangeSupport ? nativeRng.toString() : nativeRng.text;
      };

      /**
       * returns range for word before cursor
       *
       * @param {Boolean} [findAfter] - find after cursor, default: false
       * @return {WrappedRange}
       */
      this.getWordRange = function (findAfter) {
        var endPoint = this.getEndPoint();

        if (!dom.isCharPoint(endPoint)) {
          return this;
        }

        var startPoint = dom.prevPointUntil(endPoint, function (point) {
          return !dom.isCharPoint(point);
        });

        if (findAfter) {
          endPoint = dom.nextPointUntil(endPoint, function (point) {
            return !dom.isCharPoint(point);
          });
        }

        return new WrappedRange(
          startPoint.node,
          startPoint.offset,
          endPoint.node,
          endPoint.offset
        );
      };
  
      /**
       * create offsetPath bookmark
       *
       * @param {Node} editable
       */
      this.bookmark = function (editable) {
        return {
          s: {
            path: dom.makeOffsetPath(editable, sc),
            offset: so
          },
          e: {
            path: dom.makeOffsetPath(editable, ec),
            offset: eo
          }
        };
      };

      /**
       * create offsetPath bookmark base on paragraph
       *
       * @param {Node[]} paras
       */
      this.paraBookmark = function (paras) {
        return {
          s: {
            path: list.tail(dom.makeOffsetPath(list.head(paras), sc)),
            offset: so
          },
          e: {
            path: list.tail(dom.makeOffsetPath(list.last(paras), ec)),
            offset: eo
          }
        };
      };

      /**
       * getClientRects
       * @return {Rect[]}
       */
      this.getClientRects = function () {
        var nativeRng = nativeRange();
        return nativeRng.getClientRects();
      };
    };

  /**
   * @class core.range
   *
   * Data structure
   *  * BoundaryPoint: a point of dom tree
   *  * BoundaryPoints: two boundaryPoints corresponding to the start and the end of the Range
   *
   * See to http://www.w3.org/TR/DOM-Level-2-Traversal-Range/ranges.html#Level-2-Range-Position
   *
   * @singleton
   * @alternateClassName range
   */
    return {
      /**
       * create Range Object From arguments or Browser Selection
       *
       * @param {Node} sc - start container
       * @param {Number} so - start offset
       * @param {Node} ec - end container
       * @param {Number} eo - end offset
       * @return {WrappedRange}
       */
      create: function (sc, so, ec, eo) {
        if (arguments.length === 4) {
          return new WrappedRange(sc, so, ec, eo);
        } else if (arguments.length === 2) { //collapsed
          ec = sc;
          eo = so;
          return new WrappedRange(sc, so, ec, eo);
        } else {
          var wrappedRange = this.createFromSelection();
          if (!wrappedRange && arguments.length === 1) {
            wrappedRange = this.createFromNode(arguments[0]);
            return wrappedRange.collapse(dom.emptyPara === arguments[0].innerHTML);
          }
          return wrappedRange;
        }
      },

      createFromSelection: function () {
        var sc, so, ec, eo;
        if (agent.isW3CRangeSupport) {
          var selection = document.getSelection();
          if (!selection || selection.rangeCount === 0) {
            return null;
          } else if (dom.isBody(selection.anchorNode)) {
            // Firefox: returns entire body as range on initialization.
            // We won't never need it.
            return null;
          }

          var nativeRng = selection.getRangeAt(0);
          sc = nativeRng.startContainer;
          so = nativeRng.startOffset;
          ec = nativeRng.endContainer;
          eo = nativeRng.endOffset;
        } else { // IE8: TextRange
          var textRange = document.selection.createRange();
          var textRangeEnd = textRange.duplicate();
          textRangeEnd.collapse(false);
          var textRangeStart = textRange;
          textRangeStart.collapse(true);

          var startPoint = textRangeToPoint(textRangeStart, true),
          endPoint = textRangeToPoint(textRangeEnd, false);

          // same visible point case: range was collapsed.
          if (dom.isText(startPoint.node) && dom.isLeftEdgePoint(startPoint) &&
              dom.isTextNode(endPoint.node) && dom.isRightEdgePoint(endPoint) &&
              endPoint.node.nextSibling === startPoint.node) {
            startPoint = endPoint;
          }

          sc = startPoint.cont;
          so = startPoint.offset;
          ec = endPoint.cont;
          eo = endPoint.offset;
        }

        return new WrappedRange(sc, so, ec, eo);
      },

      /**
       * @method 
       * 
       * create WrappedRange from node
       *
       * @param {Node} node
       * @return {WrappedRange}
       */
      createFromNode: function (node) {
        var sc = node;
        var so = 0;
        var ec = node;
        var eo = dom.nodeLength(ec);

        // browsers can't target a picture or void node
        if (dom.isVoid(sc)) {
          so = dom.listPrev(sc).length - 1;
          sc = sc.parentNode;
        }
        if (dom.isBR(ec)) {
          eo = dom.listPrev(ec).length - 1;
          ec = ec.parentNode;
        } else if (dom.isVoid(ec)) {
          eo = dom.listPrev(ec).length;
          ec = ec.parentNode;
        }

        return this.create(sc, so, ec, eo);
      },

      /**
       * create WrappedRange from node after position
       *
       * @param {Node} node
       * @return {WrappedRange}
       */
      createFromNodeBefore: function (node) {
        return this.createFromNode(node).collapse(true);
      },

      /**
       * create WrappedRange from node after position
       *
       * @param {Node} node
       * @return {WrappedRange}
       */
      createFromNodeAfter: function (node) {
        return this.createFromNode(node).collapse();
      },

      /**
       * @method 
       * 
       * create WrappedRange from bookmark
       *
       * @param {Node} editable
       * @param {Object} bookmark
       * @return {WrappedRange}
       */
      createFromBookmark: function (editable, bookmark) {
        var sc = dom.fromOffsetPath(editable, bookmark.s.path);
        var so = bookmark.s.offset;
        var ec = dom.fromOffsetPath(editable, bookmark.e.path);
        var eo = bookmark.e.offset;
        return new WrappedRange(sc, so, ec, eo);
      },

      /**
       * @method 
       *
       * create WrappedRange from paraBookmark
       *
       * @param {Object} bookmark
       * @param {Node[]} paras
       * @return {WrappedRange}
       */
      createFromParaBookmark: function (bookmark, paras) {
        var so = bookmark.s.offset;
        var eo = bookmark.e.offset;
        var sc = dom.fromOffsetPath(list.head(paras), bookmark.s.path);
        var ec = dom.fromOffsetPath(list.last(paras), bookmark.e.path);

        return new WrappedRange(sc, so, ec, eo);
      }
    };
  })();

  /**
   * @class core.async
   *
   * Async functions which returns `Promise`
   *
   * @singleton
   * @alternateClassName async
   */
  var async = (function () {
    /**
     * @method readFileAsDataURL
     *
     * read contents of file as representing URL
     *
     * @param {File} file
     * @return {Promise} - then: dataUrl
     */
    var readFileAsDataURL = function (file) {
      return $.Deferred(function (deferred) {
        $.extend(new FileReader(), {
          onload: function (e) {
            var dataURL = e.target.result;
            deferred.resolve(dataURL);
          },
          onerror: function () {
            deferred.reject(this);
          }
        }).readAsDataURL(file);
      }).promise();
    };
  
    /**
     * @method createImage
     *
     * create `<image>` from url string
     *
     * @param {String} url
     * @return {Promise} - then: $image
     */
    var createImage = function (url) {
      return $.Deferred(function (deferred) {
        var $img = $('<img>');

        $img.one('load', function () {
          $img.off('error abort');
          deferred.resolve($img);
        }).one('error abort', function () {
          $img.off('load').detach();
          deferred.reject($img);
        }).css({
          display: 'none'
        }).appendTo(document.body).attr('src', url);
      }).promise();
    };

    return {
      readFileAsDataURL: readFileAsDataURL,
      createImage: createImage
    };
  })();

  /**
   * @class editing.History
   *
   * Editor History
   *
   */
  var History = function ($editable) {
    var stack = [], stackOffset = -1;
    var editable = $editable[0];

    var makeSnapshot = function () {
      var rng = range.create(editable);
      var emptyBookmark = {s: {path: [], offset: 0}, e: {path: [], offset: 0}};

      return {
        contents: $editable.html(),
        bookmark: (rng ? rng.bookmark(editable) : emptyBookmark)
      };
    };

    var applySnapshot = function (snapshot) {
      if (snapshot.contents !== null) {
        $editable.html(snapshot.contents);
      }
      if (snapshot.bookmark !== null) {
        range.createFromBookmark(editable, snapshot.bookmark).select();
      }
    };

    /**
    * @method rewind
    * Rewinds the history stack back to the first snapshot taken.
    * Leaves the stack intact, so that "Redo" can still be used.
    */
    this.rewind = function () {
      // Create snap shot if not yet recorded
      if ($editable.html() !== stack[stackOffset].contents) {
        this.recordUndo();
      }

      // Return to the first available snapshot.
      stackOffset = 0;

      // Apply that snapshot.
      applySnapshot(stack[stackOffset]);
    };

    /**
    * @method reset
    * Resets the history stack completely; reverting to an empty editor.
    */
    this.reset = function () {
      // Clear the stack.
      stack = [];

      // Restore stackOffset to its original value.
      stackOffset = -1;

      // Clear the editable area.
      $editable.html('');

      // Record our first snapshot (of nothing).
      this.recordUndo();
    };

    /**
     * undo
     */
    this.undo = function () {
      // Create snap shot if not yet recorded
      if ($editable.html() !== stack[stackOffset].contents) {
        this.recordUndo();
      }

      if (0 < stackOffset) {
        stackOffset--;
        applySnapshot(stack[stackOffset]);
      }
    };

    /**
     * redo
     */
    this.redo = function () {
      if (stack.length - 1 > stackOffset) {
        stackOffset++;
        applySnapshot(stack[stackOffset]);
      }
    };

    /**
     * recorded undo
     */
    this.recordUndo = function () {
      stackOffset++;

      // Wash out stack after stackOffset
      if (stack.length > stackOffset) {
        stack = stack.slice(0, stackOffset);
      }

      // Create new snapshot and push it to the end
      stack.push(makeSnapshot());
    };
  };

  /**
   * @class editing.Style
   *
   * Style
   *
   */
  var Style = function () {
    /**
     * @method jQueryCSS
     *
     * [workaround] for old jQuery
     * passing an array of style properties to .css()
     * will result in an object of property-value pairs.
     * (compability with version < 1.9)
     *
     * @private
     * @param  {jQuery} $obj
     * @param  {Array} propertyNames - An array of one or more CSS properties.
     * @return {Object}
     */
    var jQueryCSS = function ($obj, propertyNames) {
      if (agent.jqueryVersion < 1.9) {
        var result = {};
        $.each(propertyNames, function (idx, propertyName) {
          result[propertyName] = $obj.css(propertyName);
        });
        return result;
      }
      return $obj.css.call($obj, propertyNames);
    };

    /**
     * returns style object from node
     *
     * @param {jQuery} $node
     * @return {Object}
     */
    this.fromNode = function ($node) {
      var properties = ['font-family', 'font-size', 'text-align', 'list-style-type', 'line-height'];
      var styleInfo = jQueryCSS($node, properties) || {};
      styleInfo['font-size'] = parseInt(styleInfo['font-size'], 10);
      return styleInfo;
    };

    /**
     * paragraph level style
     *
     * @param {WrappedRange} rng
     * @param {Object} styleInfo
     */
    this.stylePara = function (rng, styleInfo) {
      $.each(rng.nodes(dom.isPara, {
        includeAncestor: true
      }), function (idx, para) {
        $(para).css(styleInfo);
      });
    };

    /**
     * insert and returns styleNodes on range.
     *
     * @param {WrappedRange} rng
     * @param {Object} [options] - options for styleNodes
     * @param {String} [options.nodeName] - default: `SPAN`
     * @param {Boolean} [options.expandClosestSibling] - default: `false`
     * @param {Boolean} [options.onlyPartialContains] - default: `false`
     * @return {Node[]}
     */
    this.styleNodes = function (rng, options) {
      rng = rng.splitText();

      var nodeName = options && options.nodeName || 'SPAN';
      var expandClosestSibling = !!(options && options.expandClosestSibling);
      var onlyPartialContains = !!(options && options.onlyPartialContains);

      if (rng.isCollapsed()) {
        return [rng.insertNode(dom.create(nodeName))];
      }

      var pred = dom.makePredByNodeName(nodeName);
      var nodes = rng.nodes(dom.isText, {
        fullyContains: true
      }).map(function (text) {
        return dom.singleChildAncestor(text, pred) || dom.wrap(text, nodeName);
      });

      if (expandClosestSibling) {
        if (onlyPartialContains) {
          var nodesInRange = rng.nodes();
          // compose with partial contains predication
          pred = func.and(pred, function (node) {
            return list.contains(nodesInRange, node);
          });
        }

        return nodes.map(function (node) {
          var siblings = dom.withClosestSiblings(node, pred);
          var head = list.head(siblings);
          var tails = list.tail(siblings);
          $.each(tails, function (idx, elem) {
            dom.appendChildNodes(head, elem.childNodes);
            dom.remove(elem);
          });
          return list.head(siblings);
        });
      } else {
        return nodes;
      }
    };

    /**
     * get current style on cursor
     *
     * @param {WrappedRange} rng
     * @return {Object} - object contains style properties.
     */
    this.current = function (rng) {
      var $cont = $(!dom.isElement(rng.sc) ? rng.sc.parentNode : rng.sc);
      var styleInfo = this.fromNode($cont);

      // document.queryCommandState for toggle state
      // [workaround] prevent Firefox nsresult: "0x80004005 (NS_ERROR_FAILURE)"
      try {
        styleInfo = $.extend(styleInfo, {
          'font-bold': document.queryCommandState('bold') ? 'bold' : 'normal',
          'font-italic': document.queryCommandState('italic') ? 'italic' : 'normal',
          'font-underline': document.queryCommandState('underline') ? 'underline' : 'normal',
          'font-subscript': document.queryCommandState('subscript') ? 'subscript' : 'normal',
          'font-superscript': document.queryCommandState('superscript') ? 'superscript' : 'normal',
          'font-strikethrough': document.queryCommandState('strikethrough') ? 'strikethrough' : 'normal',
          'font-family': document.queryCommandValue('fontname') || styleInfo['font-family']
        });
      } catch (e) {}

      // list-style-type to list-style(unordered, ordered)
      if (!rng.isOnList()) {
        styleInfo['list-style'] = 'none';
      } else {
        var orderedTypes = ['circle', 'disc', 'disc-leading-zero', 'square'];
        var isUnordered = $.inArray(styleInfo['list-style-type'], orderedTypes) > -1;
        styleInfo['list-style'] = isUnordered ? 'unordered' : 'ordered';
      }

      var para = dom.ancestor(rng.sc, dom.isPara);
      if (para && para.style['line-height']) {
        styleInfo['line-height'] = para.style.lineHeight;
      } else {
        var lineHeight = parseInt(styleInfo['line-height'], 10) / parseInt(styleInfo['font-size'], 10);
        styleInfo['line-height'] = lineHeight.toFixed(1);
      }

      styleInfo.anchor = rng.isOnAnchor() && dom.ancestor(rng.sc, dom.isAnchor);
      styleInfo.ancestors = dom.listAncestor(rng.sc, dom.isEditable);
      styleInfo.range = rng;

      return styleInfo;
    };
  };


  /**
   * @class editing.Bullet
   *
   * @alternateClassName Bullet
   */
  var Bullet = function () {
    var self = this;

    /**
     * toggle ordered list
     */
    this.insertOrderedList = function (editable) {
      this.toggleList('OL', editable);
    };

    /**
     * toggle unordered list
     */
    this.insertUnorderedList = function (editable) {
      this.toggleList('UL', editable);
    };

    /**
     * indent
     */
    this.indent = function (editable) {
      var self = this;
      var rng = range.create(editable).wrapBodyInlineWithPara();

      var paras = rng.nodes(dom.isPara, { includeAncestor: true });
      var clustereds = list.clusterBy(paras, func.peq2('parentNode'));

      $.each(clustereds, function (idx, paras) {
        var head = list.head(paras);
        if (dom.isLi(head)) {
          self.wrapList(paras, head.parentNode.nodeName);
        } else {
          $.each(paras, function (idx, para) {
            $(para).css('marginLeft', function (idx, val) {
              return (parseInt(val, 10) || 0) + 25;
            });
          });
        }
      });

      rng.select();
    };

    /**
     * outdent
     */
    this.outdent = function (editable) {
      var self = this;
      var rng = range.create(editable).wrapBodyInlineWithPara();

      var paras = rng.nodes(dom.isPara, { includeAncestor: true });
      var clustereds = list.clusterBy(paras, func.peq2('parentNode'));

      $.each(clustereds, function (idx, paras) {
        var head = list.head(paras);
        if (dom.isLi(head)) {
          self.releaseList([paras]);
        } else {
          $.each(paras, function (idx, para) {
            $(para).css('marginLeft', function (idx, val) {
              val = (parseInt(val, 10) || 0);
              return val > 25 ? val - 25 : '';
            });
          });
        }
      });

      rng.select();
    };

    /**
     * toggle list
     *
     * @param {String} listName - OL or UL
     */
    this.toggleList = function (listName, editable) {
      var rng = range.create(editable).wrapBodyInlineWithPara();

      var paras = rng.nodes(dom.isPara, { includeAncestor: true });
      var bookmark = rng.paraBookmark(paras);
      var clustereds = list.clusterBy(paras, func.peq2('parentNode'));

      // paragraph to list
      if (list.find(paras, dom.isPurePara)) {
        var wrappedParas = [];
        $.each(clustereds, function (idx, paras) {
          wrappedParas = wrappedParas.concat(self.wrapList(paras, listName));
        });
        paras = wrappedParas;
      // list to paragraph or change list style
      } else {
        var diffLists = rng.nodes(dom.isList, {
          includeAncestor: true
        }).filter(function (listNode) {
          return !$.nodeName(listNode, listName);
        });

        if (diffLists.length) {
          $.each(diffLists, function (idx, listNode) {
            dom.replace(listNode, listName);
          });
        } else {
          paras = this.releaseList(clustereds, true);
        }
      }

      range.createFromParaBookmark(bookmark, paras).select();
    };

    /**
     * @param {Node[]} paras
     * @param {String} listName
     * @return {Node[]}
     */
    this.wrapList = function (paras, listName) {
      var head = list.head(paras);
      var last = list.last(paras);

      var prevList = dom.isList(head.previousSibling) && head.previousSibling;
      var nextList = dom.isList(last.nextSibling) && last.nextSibling;

      var listNode = prevList || dom.insertAfter(dom.create(listName || 'UL'), last);

      // P to LI
      paras = paras.map(function (para) {
        return dom.isPurePara(para) ? dom.replace(para, 'LI') : para;
      });

      // append to list(<ul>, <ol>)
      dom.appendChildNodes(listNode, paras);

      if (nextList) {
        dom.appendChildNodes(listNode, list.from(nextList.childNodes));
        dom.remove(nextList);
      }

      return paras;
    };

    /**
     * @method releaseList
     *
     * @param {Array[]} clustereds
     * @param {Boolean} isEscapseToBody
     * @return {Node[]}
     */
    this.releaseList = function (clustereds, isEscapseToBody) {
      var releasedParas = [];

      $.each(clustereds, function (idx, paras) {
        var head = list.head(paras);
        var last = list.last(paras);

        var headList = isEscapseToBody ? dom.lastAncestor(head, dom.isList) :
                                         head.parentNode;
        var lastList = headList.childNodes.length > 1 ? dom.splitTree(headList, {
          node: last.parentNode,
          offset: dom.position(last) + 1
        }, {
          isSkipPaddingBlankHTML: true
        }) : null;

        var middleList = dom.splitTree(headList, {
          node: head.parentNode,
          offset: dom.position(head)
        }, {
          isSkipPaddingBlankHTML: true
        });

        paras = isEscapseToBody ? dom.listDescendant(middleList, dom.isLi) :
                                  list.from(middleList.childNodes).filter(dom.isLi);

        // LI to P
        if (isEscapseToBody || !dom.isList(headList.parentNode)) {
          paras = paras.map(function (para) {
            return dom.replace(para, 'P');
          });
        }

        $.each(list.from(paras).reverse(), function (idx, para) {
          dom.insertAfter(para, headList);
        });

        // remove empty lists
        var rootLists = list.compact([headList, middleList, lastList]);
        $.each(rootLists, function (idx, rootList) {
          var listNodes = [rootList].concat(dom.listDescendant(rootList, dom.isList));
          $.each(listNodes.reverse(), function (idx, listNode) {
            if (!dom.nodeLength(listNode)) {
              dom.remove(listNode, true);
            }
          });
        });

        releasedParas = releasedParas.concat(paras);
      });

      return releasedParas;
    };
  };


  /**
   * @class editing.Typing
   *
   * Typing
   *
   */
  var Typing = function () {

    // a Bullet instance to toggle lists off
    var bullet = new Bullet();

    /**
     * insert tab
     *
     * @param {WrappedRange} rng
     * @param {Number} tabsize
     */
    this.insertTab = function (rng, tabsize) {
      var tab = dom.createText(new Array(tabsize + 1).join(dom.NBSP_CHAR));
      rng = rng.deleteContents();
      rng.insertNode(tab, true);

      rng = range.create(tab, tabsize);
      rng.select();
    };

    /**
     * insert paragraph
     */
    this.insertParagraph = function (editable) {
      var rng = range.create(editable);

      // deleteContents on range.
      rng = rng.deleteContents();

      // Wrap range if it needs to be wrapped by paragraph
      rng = rng.wrapBodyInlineWithPara();

      // finding paragraph
      var splitRoot = dom.ancestor(rng.sc, dom.isPara);

      var nextPara;
      // on paragraph: split paragraph
      if (splitRoot) {
        // if it is an empty line with li
        if (dom.isEmpty(splitRoot) && dom.isLi(splitRoot)) {
          // toogle UL/OL and escape
          bullet.toggleList(splitRoot.parentNode.nodeName);
          return;
        // if it is an empty line with para on blockquote
        } else if (dom.isEmpty(splitRoot) && dom.isPara(splitRoot) && dom.isBlockquote(splitRoot.parentNode)) {
          // escape blockquote
          dom.insertAfter(splitRoot, splitRoot.parentNode);
          nextPara = splitRoot;
        // if new line has content (not a line break)
        } else {
          nextPara = dom.splitTree(splitRoot, rng.getStartPoint());

          var emptyAnchors = dom.listDescendant(splitRoot, dom.isEmptyAnchor);
          emptyAnchors = emptyAnchors.concat(dom.listDescendant(nextPara, dom.isEmptyAnchor));

          $.each(emptyAnchors, function (idx, anchor) {
            dom.remove(anchor);
          });

          // replace empty heading, pre or custom-made styleTag with P tag
          if ((dom.isHeading(nextPara) || dom.isPre(nextPara) || dom.isCustomStyleTag(nextPara)) && dom.isEmpty(nextPara)) {
            nextPara = dom.replace(nextPara, 'p');
          }
        }
      // no paragraph: insert empty paragraph
      } else {
        var next = rng.sc.childNodes[rng.so];
        nextPara = $(dom.emptyPara)[0];
        if (next) {
          rng.sc.insertBefore(nextPara, next);
        } else {
          rng.sc.appendChild(nextPara);
        }
      }

      range.create(nextPara, 0).normalize().select().scrollIntoView(editable);
    };
  };


  /**
   * @class Create a virtual table to create what actions to do in change.
   * @param {object} startPoint Cell selected to apply change.
   * @param {enum} where  Where change will be applied Row or Col. Use enum: TableResultAction.where
   * @param {enum} action Action to be applied. Use enum: TableResultAction.requestAction
   * @param {object} domTable Dom element of table to make changes.
   */
  var TableResultAction = function (startPoint, where, action, domTable) {
    var _startPoint = { 'colPos': 0, 'rowPos': 0 };
    var _virtualTable = [];
    var _actionCellList = [];

    //////////////////////////////////////////////
    // Private functions
    //////////////////////////////////////////////

    /**
     * Set the startPoint of action.
     */
    function setStartPoint() {
      if (!startPoint || !startPoint.tagName || (startPoint.tagName.toLowerCase() !== 'td' && startPoint.tagName.toLowerCase() !== 'th')) {
        console.error('Impossible to identify start Cell point.', startPoint);
        return;
      }
      _startPoint.colPos = startPoint.cellIndex;
      if (!startPoint.parentElement || !startPoint.parentElement.tagName || startPoint.parentElement.tagName.toLowerCase() !== 'tr') {
        console.error('Impossible to identify start Row point.', startPoint);
        return;
      }
      _startPoint.rowPos = startPoint.parentElement.rowIndex;
    }

    /**
     * Define virtual table position info object.
     * 
     * @param {int} rowIndex Index position in line of virtual table.
     * @param {int} cellIndex Index position in column of virtual table.
     * @param {object} baseRow Row affected by this position.
     * @param {object} baseCell Cell affected by this position.
     * @param {bool} isSpan Inform if it is an span cell/row.
     */
    function setVirtualTablePosition(rowIndex, cellIndex, baseRow, baseCell, isRowSpan, isColSpan, isVirtualCell) {
      var objPosition = {
        'baseRow': baseRow,
        'baseCell': baseCell,
        'isRowSpan': isRowSpan,
        'isColSpan': isColSpan,
        'isVirtual': isVirtualCell
      };
      if (!_virtualTable[rowIndex]) {
        _virtualTable[rowIndex] = [];
      }
      _virtualTable[rowIndex][cellIndex] = objPosition;
    }

    /**
     * Create action cell object.
     * 
     * @param {object} virtualTableCellObj Object of specific position on virtual table.
     * @param {enum} resultAction Action to be applied in that item.
     */
    function getActionCell(virtualTableCellObj, resultAction, virtualRowPosition, virtualColPosition) {
      return {
        'baseCell': virtualTableCellObj.baseCell,
        'action': resultAction,
        'virtualTable': {
          'rowIndex': virtualRowPosition,
          'cellIndex': virtualColPosition
        }
      };
    }

    /**
     * Recover free index of row to append Cell.
     * 
     * @param {int} rowIndex Index of row to find free space.
     * @param {int} cellIndex Index of cell to find free space in table.
     */
    function recoverCellIndex(rowIndex, cellIndex) {
      if (!_virtualTable[rowIndex]) {
        return cellIndex;
      }
      if (!_virtualTable[rowIndex][cellIndex]) {
        return cellIndex;
      }

      var newCellIndex = cellIndex;
      while (_virtualTable[rowIndex][newCellIndex]) {
        newCellIndex++;
        if (!_virtualTable[rowIndex][newCellIndex]) {
          return newCellIndex;
        }
      }
    }

    /**
     * Recover info about row and cell and add information to virtual table.
     * 
     * @param {object} row Row to recover information.
     * @param {object} cell Cell to recover information.
     */
    function addCellInfoToVirtual(row, cell) {
      var cellIndex = recoverCellIndex(row.rowIndex, cell.cellIndex);
      var cellHasColspan = (cell.colSpan > 1);
      var cellHasRowspan = (cell.rowSpan > 1);
      var isThisSelectedCell = (row.rowIndex === _startPoint.rowPos && cell.cellIndex === _startPoint.colPos);
      setVirtualTablePosition(row.rowIndex, cellIndex, row, cell, cellHasRowspan, cellHasColspan, false);

      // Add span rows to virtual Table.
      var rowspanNumber = cell.attributes.rowSpan ? parseInt(cell.attributes.rowSpan.value, 10) : 0;
      if (rowspanNumber > 1) {
        for (var rp = 1; rp < rowspanNumber; rp++) {
          var rowspanIndex = row.rowIndex + rp;
          adjustStartPoint(rowspanIndex, cellIndex, cell, isThisSelectedCell);
          setVirtualTablePosition(rowspanIndex, cellIndex, row, cell, true, cellHasColspan, true);
        }
      }

      // Add span cols to virtual table.
      var colspanNumber = cell.attributes.colSpan ? parseInt(cell.attributes.colSpan.value, 10) : 0;
      if (colspanNumber > 1) {
        for (var cp = 1; cp < colspanNumber; cp++) {
          var cellspanIndex = recoverCellIndex(row.rowIndex, (cellIndex + cp));
          adjustStartPoint(row.rowIndex, cellspanIndex, cell, isThisSelectedCell);
          setVirtualTablePosition(row.rowIndex, cellspanIndex, row, cell, cellHasRowspan, true, true);
        }
      }
    }

    /**
     * Process validation and adjust of start point if needed
     * 
     * @param {int} rowIndex 
     * @param {int} cellIndex 
     * @param {object} cell 
     * @param {bool} isSelectedCell 
     */
    function adjustStartPoint(rowIndex, cellIndex, cell, isSelectedCell) {
      if (rowIndex === _startPoint.rowPos && _startPoint.colPos >= cell.cellIndex && cell.cellIndex <= cellIndex && !isSelectedCell) {
        _startPoint.colPos++;
      }
    }

    /**
     * Create virtual table of cells with all cells, including span cells.
     */
    function createVirtualTable() {
      var rows = domTable.rows;
      for (var rowIndex = 0; rowIndex < rows.length; rowIndex++) {
        var cells = rows[rowIndex].cells;
        for (var cellIndex = 0; cellIndex < cells.length; cellIndex++) {
          addCellInfoToVirtual(rows[rowIndex], cells[cellIndex]);
        }
      }
    }

    /**
     * Get action to be applied on the cell.
     * 
     * @param {object} cell virtual table cell to apply action
     */
    function getDeleteResultActionToCell(cell) {
      switch (where) {
        case TableResultAction.where.Column:
          if (cell.isColSpan) {
            return TableResultAction.resultAction.SubtractSpanCount;
          }
          break;
        case TableResultAction.where.Row:
          if (!cell.isVirtual && cell.isRowSpan) {
            return TableResultAction.resultAction.AddCell;
          }
          else if (cell.isRowSpan) {
            return TableResultAction.resultAction.SubtractSpanCount;
          }
          break;
      }
      return TableResultAction.resultAction.RemoveCell;
    }

    /**
     * Get action to be applied on the cell.
     * 
     * @param {object} cell virtual table cell to apply action
     */
    function getAddResultActionToCell(cell) {
      switch (where) {
        case TableResultAction.where.Column:
          if (cell.isColSpan) {
            return TableResultAction.resultAction.SumSpanCount;
          } else if (cell.isRowSpan && cell.isVirtual) {
            return TableResultAction.resultAction.Ignore;
          }
          break;
        case TableResultAction.where.Row:
          if (cell.isRowSpan) {
            return TableResultAction.resultAction.SumSpanCount;
          } else if (cell.isColSpan && cell.isVirtual) {
            return TableResultAction.resultAction.Ignore;
          }
          break;
      }
      return TableResultAction.resultAction.AddCell;
    }

    function init() {
      setStartPoint();
      createVirtualTable();
    }

    //////////////////////////////////////////////
    // Public functions
    //////////////////////////////////////////////

    /**
     * Recover array os what to do in table.
     */
    this.getActionList = function () {
      var fixedRow = (where === TableResultAction.where.Row) ? _startPoint.rowPos : -1;
      var fixedCol = (where === TableResultAction.where.Column) ? _startPoint.colPos : -1;

      var actualPosition = 0;
      var canContinue = true;
      while (canContinue) {
        var rowPosition = (fixedRow >= 0) ? fixedRow : actualPosition;
        var colPosition = (fixedCol >= 0) ? fixedCol : actualPosition;
        var row = _virtualTable[rowPosition];
        if (!row) {
          canContinue = false;
          return _actionCellList;
        }
        var cell = row[colPosition];
        if (!cell) {
          canContinue = false;
          return _actionCellList;
        }

        // Define action to be applied in this cell
        var resultAction = TableResultAction.resultAction.Ignore;
        switch (action) {
          case TableResultAction.requestAction.Add:
            resultAction = getAddResultActionToCell(cell);
            break;
          case TableResultAction.requestAction.Delete:
            resultAction = getDeleteResultActionToCell(cell);
            break;
        }
        _actionCellList.push(getActionCell(cell, resultAction, rowPosition, colPosition));
        actualPosition++;
      }

      return _actionCellList;
    };

    init();
  };
  /**
  * 
  * Where action occours enum.
  */
  TableResultAction.where = { 'Row': 0, 'Column': 1 };
  /**
  * 
  * Requested action to apply enum.
  */
  TableResultAction.requestAction = { 'Add': 0, 'Delete': 1 };
  /**
  * 
  * Result action to be executed enum.
  */
  TableResultAction.resultAction = { 'Ignore': 0, 'SubtractSpanCount': 1, 'RemoveCell': 2, 'AddCell': 3, 'SumSpanCount': 4 };

  /**
   * 
   * @class editing.Table
   *
   * Table
   *
   */
  var Table = function () {
    /**
     * handle tab key
     *
     * @param {WrappedRange} rng
     * @param {Boolean} isShift
     */
    this.tab = function (rng, isShift) {
      var cell = dom.ancestor(rng.commonAncestor(), dom.isCell);
      var table = dom.ancestor(cell, dom.isTable);
      var cells = dom.listDescendant(table, dom.isCell);

      var nextCell = list[isShift ? 'prev' : 'next'](cells, cell);
      if (nextCell) {
        range.create(nextCell, 0).select();
      }
    };

    /**
     * Add a new row
     *
     * @param {WrappedRange} rng
     * @param {String} position (top/bottom)
     * @return {Node}
     */
    this.addRow = function (rng, position) {
      var cell = dom.ancestor(rng.commonAncestor(), dom.isCell);

      var currentTr = $(cell).closest('tr');
      var trAttributes = this.recoverAttributes(currentTr);
      var html = $('<tr' + trAttributes + '></tr>');

      var vTable = new TableResultAction(cell, TableResultAction.where.Row,
        TableResultAction.requestAction.Add, $(currentTr).closest('table')[0]);
      var actions = vTable.getActionList();

      for (var idCell = 0; idCell < actions.length; idCell++) {
        var currentCell = actions[idCell];
        var tdAttributes = this.recoverAttributes(currentCell.baseCell);
        switch (currentCell.action) {
          case TableResultAction.resultAction.AddCell:
            html.append('<td' + tdAttributes + '>' + dom.blank + '</td>');
            break;
          case TableResultAction.resultAction.SumSpanCount:
            if (position === 'top') {
              var baseCellTr = currentCell.baseCell.parent;
              var isTopFromRowSpan = (!baseCellTr ? 0 : currentCell.baseCell.closest('tr').rowIndex) <= currentTr[0].rowIndex;
              if (isTopFromRowSpan) {
                var newTd = $('<div></div>').append($('<td' + tdAttributes + '>' + dom.blank + '</td>').removeAttr('rowspan')).html();
                html.append(newTd);
                break;
              }
            }
            var rowspanNumber = parseInt(currentCell.baseCell.rowSpan, 10);
            rowspanNumber++;
            currentCell.baseCell.setAttribute('rowSpan', rowspanNumber);
            break;
        }
      }

      if (position === 'top') {
        currentTr.before(html);
      }
      else {
        var cellHasRowspan = (cell.rowSpan > 1);
        if (cellHasRowspan) {
          var lastTrIndex = currentTr[0].rowIndex + (cell.rowSpan - 2);
          $($(currentTr).parent().find('tr')[lastTrIndex]).after($(html));
          return;
        }
        currentTr.after(html);
      }
    };

    /**
     * Add a new col
     *
     * @param {WrappedRange} rng
     * @param {String} position (left/right)
     * @return {Node}
     */
    this.addCol = function (rng, position) {
      var cell = dom.ancestor(rng.commonAncestor(), dom.isCell);
      var row = $(cell).closest('tr');
      var rowsGroup = $(row).siblings();
      rowsGroup.push(row);

      var vTable = new TableResultAction(cell, TableResultAction.where.Column,
        TableResultAction.requestAction.Add, $(row).closest('table')[0]);
      var actions = vTable.getActionList();

      for (var actionIndex = 0; actionIndex < actions.length; actionIndex++) {
        var currentCell = actions[actionIndex];
        var tdAttributes = this.recoverAttributes(currentCell.baseCell);
        switch (currentCell.action) {
          case TableResultAction.resultAction.AddCell:
            if (position === 'right') {
              $(currentCell.baseCell).after('<td' + tdAttributes + '>' + dom.blank + '</td>');
            } else {
              $(currentCell.baseCell).before('<td' + tdAttributes + '>' + dom.blank + '</td>');
            }
            break;
          case TableResultAction.resultAction.SumSpanCount:
            if (position === 'right') {
              var colspanNumber = parseInt(currentCell.baseCell.colSpan, 10);
              colspanNumber++;
              currentCell.baseCell.setAttribute('colSpan', colspanNumber);
            } else {
              $(currentCell.baseCell).before('<td' + tdAttributes + '>' + dom.blank + '</td>');
            }
            break;
        }
      }
    };

    /*
    * Copy attributes from element.
    *
    * @param {object} Element to recover attributes.
    * @return {string} Copied string elements.
    */
    this.recoverAttributes = function (el) {
      var resultStr = '';

      if (!el) {
        return resultStr;
      }

      var attrList = el.attributes || [];

      for (var i = 0; i < attrList.length; i++) {
        if (attrList[i].name.toLowerCase() === 'id') {
          continue;
        }

        if (attrList[i].specified) {
          resultStr += ' ' + attrList[i].name + '=\'' + attrList[i].value + '\'';
        }
      }

      return resultStr;
    };

    /**
     * Delete current row
     *
     * @param {WrappedRange} rng
     * @return {Node}
     */
    this.deleteRow = function (rng) {
      var cell = dom.ancestor(rng.commonAncestor(), dom.isCell);
      var row = $(cell).closest('tr');
      var cellPos = row.children('td, th').index($(cell));
      var rowPos = row[0].rowIndex;

      var vTable = new TableResultAction(cell, TableResultAction.where.Row,
        TableResultAction.requestAction.Delete, $(row).closest('table')[0]);
      var actions = vTable.getActionList();

      for (var actionIndex = 0; actionIndex < actions.length; actionIndex++) {
        if (!actions[actionIndex]) {
          continue;
        }

        var baseCell = actions[actionIndex].baseCell;
        var virtualPosition = actions[actionIndex].virtualTable;
        var hasRowspan = (baseCell.rowSpan && baseCell.rowSpan > 1);
        var rowspanNumber = (hasRowspan) ? parseInt(baseCell.rowSpan, 10) : 0;
        switch (actions[actionIndex].action) {
          case TableResultAction.resultAction.Ignore:
            continue;
          case TableResultAction.resultAction.AddCell:
            var nextRow = row.next('tr')[0];
            if (!nextRow) { continue; }
            var cloneRow = row[0].cells[cellPos];
            if (hasRowspan) {
              if (rowspanNumber > 2) {
                rowspanNumber--;
                nextRow.insertBefore(cloneRow, nextRow.cells[cellPos]);
                nextRow.cells[cellPos].setAttribute('rowSpan', rowspanNumber);
                nextRow.cells[cellPos].innerHTML = '';
              } else if (rowspanNumber === 2) {
                nextRow.insertBefore(cloneRow, nextRow.cells[cellPos]);
                nextRow.cells[cellPos].removeAttribute('rowSpan');
                nextRow.cells[cellPos].innerHTML = '';
              }
            }
            continue;
          case TableResultAction.resultAction.SubtractSpanCount:
            if (hasRowspan) {
              if (rowspanNumber > 2) {
                rowspanNumber--;
                baseCell.setAttribute('rowSpan', rowspanNumber);
                if (virtualPosition.rowIndex !== rowPos && baseCell.cellIndex === cellPos) { baseCell.innerHTML = ''; }
              } else if (rowspanNumber === 2) {
                baseCell.removeAttribute('rowSpan');
                if (virtualPosition.rowIndex !== rowPos && baseCell.cellIndex === cellPos) { baseCell.innerHTML = ''; }
              }
            }
            continue;
          case TableResultAction.resultAction.RemoveCell:
            // Do not need remove cell because row will be deleted.
            continue;
        }
      }
      row.remove();
    };

    /**
     * Delete current col
     *
     * @param {WrappedRange} rng
     * @return {Node}
     */
    this.deleteCol = function (rng) {
      var cell = dom.ancestor(rng.commonAncestor(), dom.isCell);
      var row = $(cell).closest('tr');
      var cellPos = row.children('td, th').index($(cell));

      var vTable = new TableResultAction(cell, TableResultAction.where.Column,
        TableResultAction.requestAction.Delete, $(row).closest('table')[0]);
      var actions = vTable.getActionList();

      for (var actionIndex = 0; actionIndex < actions.length; actionIndex++) {
        if (!actions[actionIndex]) {
          continue;
        }
        switch (actions[actionIndex].action) {
          case TableResultAction.resultAction.Ignore:
            continue;
          case TableResultAction.resultAction.SubtractSpanCount:
            var baseCell = actions[actionIndex].baseCell;
            var hasColspan = (baseCell.colSpan && baseCell.colSpan > 1);
            if (hasColspan) {
              var colspanNumber = (baseCell.colSpan) ? parseInt(baseCell.colSpan, 10) : 0;
              if (colspanNumber > 2) {
                colspanNumber--;
                baseCell.setAttribute('colSpan', colspanNumber);
                if (baseCell.cellIndex === cellPos) { baseCell.innerHTML = ''; }
              } else if (colspanNumber === 2) {
                baseCell.removeAttribute('colSpan');
                if (baseCell.cellIndex === cellPos) { baseCell.innerHTML = ''; }
              }
            }
            continue;
          case TableResultAction.resultAction.RemoveCell:
            dom.remove(actions[actionIndex].baseCell, true);
            continue;
        }
      }
    };

    /**
     * create empty table element
     *
     * @param {Number} rowCount
     * @param {Number} colCount
     * @return {Node}
     */
    this.createTable = function (colCount, rowCount, options) {
      var tds = [], tdHTML;
      for (var idxCol = 0; idxCol < colCount; idxCol++) {
        tds.push('<td>' + dom.blank + '</td>');
      }
      tdHTML = tds.join('');

      var trs = [], trHTML;
      for (var idxRow = 0; idxRow < rowCount; idxRow++) {
        trs.push('<tr>' + tdHTML + '</tr>');
      }
      trHTML = trs.join('');
      var $table = $('<table>' + trHTML + '</table>');
      if (options && options.tableClassName) {
        $table.addClass(options.tableClassName);
      }

      return $table[0];
    };

    /**
     * Delete current table
     *
     * @param {WrappedRange} rng
     * @return {Node}
     */
    this.deleteTable = function (rng) {
      var cell = dom.ancestor(rng.commonAncestor(), dom.isCell);
      $(cell).closest('table').remove();
    };
  };


  var KEY_BOGUS = 'bogus';

  /**
   * @class Editor
   */
  var Editor = function (context) {
    var self = this;

    var $note = context.layoutInfo.note;
    var $editor = context.layoutInfo.editor;
    var $editable = context.layoutInfo.editable;
    var options = context.options;
    var lang = options.langInfo;

    var editable = $editable[0];
    var lastRange = null;

    var style = new Style();
    var table = new Table();
    var typing = new Typing();
    var bullet = new Bullet();
    var history = new History($editable);

    this.initialize = function () {
      // bind custom events
      $editable.on('keydown', function (event) {
        if (event.keyCode === key.code.ENTER) {
          context.triggerEvent('enter', event);
        }
        context.triggerEvent('keydown', event);

        if (!event.isDefaultPrevented()) {
          if (options.shortcuts) {
            self.handleKeyMap(event);
          } else {
            self.preventDefaultEditableShortCuts(event);
          }
        }
      }).on('keyup', function (event) {
        context.triggerEvent('keyup', event);
      }).on('focus', function (event) {
        context.triggerEvent('focus', event);
      }).on('blur', function (event) {
        context.triggerEvent('blur', event);
      }).on('mousedown', function (event) {
        context.triggerEvent('mousedown', event);
      }).on('mouseup', function (event) {
        context.triggerEvent('mouseup', event);
      }).on('scroll', function (event) {
        context.triggerEvent('scroll', event);
      }).on('paste', function (event) {
        context.triggerEvent('paste', event);
      });

      // init content before set event
      $editable.html(dom.html($note) || dom.emptyPara);

      // [workaround] IE doesn't have input events for contentEditable
      // - see: https://goo.gl/4bfIvA
      var changeEventName = agent.isMSIE ? 'DOMCharacterDataModified DOMSubtreeModified DOMNodeInserted' : 'input';
      $editable.on(changeEventName, func.debounce(function () {
        context.triggerEvent('change', $editable.html());
      }, 250));

      $editor.on('focusin', function (event) {
        context.triggerEvent('focusin', event);
      }).on('focusout', function (event) {
        context.triggerEvent('focusout', event);
      });

      if (!options.airMode) {
        if (options.width) {
          $editor.outerWidth(options.width);
        }
        if (options.height) {
          $editable.outerHeight(options.height);
        }
        if (options.maxHeight) {
          $editable.css('max-height', options.maxHeight);
        }
        if (options.minHeight) {
          $editable.css('min-height', options.minHeight);
        }
      }

      history.recordUndo();
    };

    this.destroy = function () {
      $editable.off();
    };

    this.handleKeyMap = function (event) {
      var keyMap = options.keyMap[agent.isMac ? 'mac' : 'pc'];
      var keys = [];

      if (event.metaKey) { keys.push('CMD'); }
      if (event.ctrlKey && !event.altKey) { keys.push('CTRL'); }
      if (event.shiftKey) { keys.push('SHIFT'); }

      var keyName = key.nameFromCode[event.keyCode];
      if (keyName) {
        keys.push(keyName);
      }

      var eventName = keyMap[keys.join('+')];
      if (eventName) {
        event.preventDefault();
        context.invoke(eventName);
      } else if (key.isEdit(event.keyCode)) {
        this.afterCommand();
      }
    };

    this.preventDefaultEditableShortCuts = function (event) {
      // B(Bold, 66) / I(Italic, 73) / U(Underline, 85)
      if ((event.ctrlKey || event.metaKey) &&
        list.contains([66, 73, 85], event.keyCode)) {
        event.preventDefault();
      }
    };

    /**
     * create range
     * @return {WrappedRange}
     */
    this.createRange = function () {
      this.focus();
      return range.create(editable);
    };

    /**
     * saveRange
     *
     * save current range
     *
     * @param {Boolean} [thenCollapse=false]
     */
    this.saveRange = function (thenCollapse) {
      lastRange = this.createRange();
      if (thenCollapse) {
        lastRange.collapse().select();
      }
    };

    /**
     * restoreRange
     *
     * restore lately range
     */
    this.restoreRange = function () {
      if (lastRange) {
        lastRange.select();
        this.focus();
      }
    };

    this.saveTarget = function (node) {
      $editable.data('target', node);
    };

    this.clearTarget = function () {
      $editable.removeData('target');
    };

    this.restoreTarget = function () {
      return $editable.data('target');
    };

    /**
     * currentStyle
     *
     * current style
     * @return {Object|Boolean} unfocus
     */
    this.currentStyle = function () {
      var rng = range.create();
      if (rng) {
        rng = rng.normalize();
      }
      return rng ? style.current(rng) : style.fromNode($editable);
    };

    /**
     * style from node
     *
     * @param {jQuery} $node
     * @return {Object}
     */
    this.styleFromNode = function ($node) {
      return style.fromNode($node);
    };

    /**
     * undo
     */
    this.undo = function () {
      context.triggerEvent('before.command', $editable.html());
      history.undo();
      context.triggerEvent('change', $editable.html());
    };
    context.memo('help.undo', lang.help.undo);

    /**
     * redo
     */
    this.redo = function () {
      context.triggerEvent('before.command', $editable.html());
      history.redo();
      context.triggerEvent('change', $editable.html());
    };
    context.memo('help.redo', lang.help.redo);

    /**
     * before command
     */
    var beforeCommand = this.beforeCommand = function () {
      context.triggerEvent('before.command', $editable.html());
      // keep focus on editable before command execution
      self.focus();
    };

    /**
     * after command
     * @param {Boolean} isPreventTrigger
     */
    var afterCommand = this.afterCommand = function (isPreventTrigger) {
      history.recordUndo();
      if (!isPreventTrigger) {
        context.triggerEvent('change', $editable.html());
      }
    };

    /* jshint ignore:start */
    // native commands(with execCommand), generate function for execCommand
    var commands = ['bold', 'italic', 'underline', 'strikethrough', 'superscript', 'subscript',
                    'justifyLeft', 'justifyCenter', 'justifyRight', 'justifyFull',
                    'formatBlock', 'removeFormat',
                    'backColor', 'foreColor', 'fontName'];

    for (var idx = 0, len = commands.length; idx < len; idx ++) {
      this[commands[idx]] = (function (sCmd) {
        return function (value) {
          beforeCommand();
          document.execCommand(sCmd, false, value);
          afterCommand(true);
        };
      })(commands[idx]);
      context.memo('help.' + commands[idx], lang.help[commands[idx]]);
    }
    /* jshint ignore:end */

    /**
     * handle tab key
     */
    this.tab = function () {
      var rng = this.createRange();
      if (rng.isCollapsed() && rng.isOnCell()) {
        table.tab(rng);
      } else {
        beforeCommand();
        typing.insertTab(rng, options.tabSize);
        afterCommand();
      }
    };
    context.memo('help.tab', lang.help.tab);

    /**
     * handle shift+tab key
     */
    this.untab = function () {
      var rng = this.createRange();
      if (rng.isCollapsed() && rng.isOnCell()) {
        table.tab(rng, true);
      }
    };
    context.memo('help.untab', lang.help.untab);

    /**
     * run given function between beforeCommand and afterCommand
     */
    this.wrapCommand = function (fn) {
      return function () {
        beforeCommand();
        fn.apply(self, arguments);
        afterCommand();
      };
    };

    /**
     * insert paragraph
     */
    this.insertParagraph = this.wrapCommand(function () {
      typing.insertParagraph(editable);
    });
    context.memo('help.insertParagraph', lang.help.insertParagraph);

    this.insertOrderedList = this.wrapCommand(function () {
      bullet.insertOrderedList(editable);
    });
    context.memo('help.insertOrderedList', lang.help.insertOrderedList);

    this.insertUnorderedList = this.wrapCommand(function () {
      bullet.insertUnorderedList(editable);
    });
    context.memo('help.insertUnorderedList', lang.help.insertUnorderedList);

    this.indent = this.wrapCommand(function () {
      bullet.indent(editable);
    });
    context.memo('help.indent', lang.help.indent);

    this.outdent = this.wrapCommand(function () {
      bullet.outdent(editable);
    });
    context.memo('help.outdent', lang.help.outdent);

    /**
     * insert image
     *
     * @param {String} src
     * @param {String|Function} param
     * @return {Promise}
     */
    this.insertImage = function (src, param) {
      return async.createImage(src, param).then(function ($image) {
        beforeCommand();

        if (typeof param === 'function') {
          param($image);
        } else {
          if (typeof param === 'string') {
            $image.attr('data-filename', param);
          }
          $image.css('width', Math.min($editable.width(), $image.width()));
        }

        $image.show();
        range.create(editable).insertNode($image[0]);
        range.createFromNodeAfter($image[0]).select();
        afterCommand();
      }).fail(function (e) {
        context.triggerEvent('image.upload.error', e);
      });
    };

    /**
     * insertImages
     * @param {File[]} files
     */
    this.insertImages = function (files) {
      $.each(files, function (idx, file) {
        var filename = file.name;
        if (options.maximumImageFileSize && options.maximumImageFileSize < file.size) {
          context.triggerEvent('image.upload.error', lang.image.maximumFileSizeError);
        } else {
          async.readFileAsDataURL(file).then(function (dataURL) {
            return self.insertImage(dataURL, filename);
          }).fail(function () {
            context.triggerEvent('image.upload.error');
          });
        }
      });
    };

    /**
     * insertImagesOrCallback
     * @param {File[]} files
     */
    this.insertImagesOrCallback = function (files) {
      var callbacks = options.callbacks;

      // If onImageUpload options setted
      if (callbacks.onImageUpload) {
        context.triggerEvent('image.upload', files);
      // else insert Image as dataURL
      } else {
        this.insertImages(files);
      }
    };

    /**
     * insertNode
     * insert node
     * @param {Node} node
     */
    this.insertNode = this.wrapCommand(function (node) {
      var rng = this.createRange();
      rng.insertNode(node);
      range.createFromNodeAfter(node).select();
    });

    /**
     * insert text
     * @param {String} text
     */
    this.insertText = this.wrapCommand(function (text) {
      var rng = this.createRange();
      var textNode = rng.insertNode(dom.createText(text));
      range.create(textNode, dom.nodeLength(textNode)).select();
    });

    /**
     * return selected plain text
     * @return {String} text
     */
    this.getSelectedText = function () {
      var rng = this.createRange();

      // if range on anchor, expand range with anchor
      if (rng.isOnAnchor()) {
        rng = range.createFromNode(dom.ancestor(rng.sc, dom.isAnchor));
      }

      return rng.toString();
    };

    /**
     * paste HTML
     * @param {String} markup
     */
    this.pasteHTML = this.wrapCommand(function (markup) {
      var contents = this.createRange().pasteHTML(markup);
      range.createFromNodeAfter(list.last(contents)).select();
    });

    /**
     * formatBlock
     *
     * @param {String} tagName
     */
    this.formatBlock = this.wrapCommand(function (tagName, $target) {
      var onApplyCustomStyle = context.options.callbacks.onApplyCustomStyle;
      if (onApplyCustomStyle) {
        onApplyCustomStyle.call(this, $target, context, this.onFormatBlock);
      } else {
        this.onFormatBlock(tagName);
      }
    });

    this.onFormatBlock = function (tagName) {
      // [workaround] for MSIE, IE need `<`
      tagName = agent.isMSIE ? '<' + tagName + '>' : tagName;
      document.execCommand('FormatBlock', false, tagName);
    };

    this.formatPara = function () {
      this.formatBlock('P');
    };
    context.memo('help.formatPara', lang.help.formatPara);

    /* jshint ignore:start */
    for (var idx = 1; idx <= 6; idx ++) {
      this['formatH' + idx] = function (idx) {
        return function () {
          this.formatBlock('H' + idx);
        };
      }(idx);
      context.memo('help.formatH'+idx, lang.help['formatH' + idx]);
    };
    /* jshint ignore:end */

    /**
     * fontSize
     *
     * @param {String} value - px
     */
    this.fontSize = function (value) {
      var rng = this.createRange();

      if (rng && rng.isCollapsed()) {
        var currentStyle = this.currentStyle();
        var spans = style.styleNodes(rng);
        var firstSpan = list.head(spans);

        $(spans).css({
          'font-size': value + 'px'
        });

        // [workaround] added styled bogus span for style
        //  - also bogus character needed for cursor position
        if (firstSpan && !dom.nodeLength(firstSpan)) {
          firstSpan.innerHTML = dom.ZERO_WIDTH_NBSP_CHAR;
          range.createFromNodeAfter(firstSpan.firstChild).select();
          $editable.data(KEY_BOGUS, firstSpan);
        }

        this.fontName(currentStyle["font-family"]);
      } else {
        beforeCommand();
        $(style.styleNodes(rng)).css({
          'font-size': value + 'px'
        });
        afterCommand();
      }
    };

    /**
     * insert horizontal rule
     */
    this.insertHorizontalRule = this.wrapCommand(function () {
      var hrNode = this.createRange().insertNode(dom.create('HR'));
      if (hrNode.nextSibling) {
        range.create(hrNode.nextSibling, 0).normalize().select();
      }
    });
    context.memo('help.insertHorizontalRule', lang.help.insertHorizontalRule);

    /**
     * remove bogus node and character
     */
    this.removeBogus = function () {
      var bogusNode = $editable.data(KEY_BOGUS);
      if (!bogusNode) {
        return;
      }

      var textNode = list.find(list.from(bogusNode.childNodes), dom.isText);

      var bogusCharIdx = textNode.nodeValue.indexOf(dom.ZERO_WIDTH_NBSP_CHAR);
      if (bogusCharIdx !== -1) {
        textNode.deleteData(bogusCharIdx, 1);
      }

      if (dom.isEmpty(bogusNode)) {
        dom.remove(bogusNode);
      }

      $editable.removeData(KEY_BOGUS);
    };

    /**
     * lineHeight
     * @param {String} value
     */
    this.lineHeight = this.wrapCommand(function (value) {
      style.stylePara(this.createRange(), {
        lineHeight: value
      });
    });

    /**
     * unlink
     *
     * @type command
     */
    this.unlink = function () {
      var rng = this.createRange();
      if (rng.isOnAnchor()) {
        var anchor = dom.ancestor(rng.sc, dom.isAnchor);
        rng = range.createFromNode(anchor);
        rng.select();

        beforeCommand();
        document.execCommand('unlink');
        afterCommand();
      }
    };

    /**
     * create link (command)
     *
     * @param {Object} linkInfo
     */
    this.createLink = this.wrapCommand(function (linkInfo) {
      var linkUrl = linkInfo.url;
      var linkText = linkInfo.text;
      var isNewWindow = linkInfo.isNewWindow;
      var rng = linkInfo.range || this.createRange();
      var isTextChanged = rng.toString() !== linkText;

      // handle spaced urls from input
      if (typeof linkUrl === 'string') {
        linkUrl = linkUrl.trim();
      }

      if (options.onCreateLink) {
        linkUrl = options.onCreateLink(linkUrl);
      } else {
        // if url doesn't match an URL schema, set http:// as default
        linkUrl = /^[A-Za-z][A-Za-z0-9+-.]*\:[\/\/]?/.test(linkUrl) ?
          linkUrl : 'http://' + linkUrl;
      }

      var anchors = [];
      if (isTextChanged) {
        rng = rng.deleteContents();
        var anchor = rng.insertNode($('<A>' + linkText + '</A>')[0]);
        anchors.push(anchor);
      } else {
        anchors = style.styleNodes(rng, {
          nodeName: 'A',
          expandClosestSibling: true,
          onlyPartialContains: true
        });
      }

      $.each(anchors, function (idx, anchor) {
        $(anchor).attr('href', linkUrl);
        if (isNewWindow) {
          $(anchor).attr('target', '_blank');
        } else {
          $(anchor).removeAttr('target');
        }
      });

      var startRange = range.createFromNodeBefore(list.head(anchors));
      var startPoint = startRange.getStartPoint();
      var endRange = range.createFromNodeAfter(list.last(anchors));
      var endPoint = endRange.getEndPoint();

      range.create(
        startPoint.node,
        startPoint.offset,
        endPoint.node,
        endPoint.offset
      ).select();
    });

    /**
     * returns link info
     *
     * @return {Object}
     * @return {WrappedRange} return.range
     * @return {String} return.text
     * @return {Boolean} [return.isNewWindow=true]
     * @return {String} [return.url=""]
     */
    this.getLinkInfo = function () {
      var rng = this.createRange().expand(dom.isAnchor);

      // Get the first anchor on range(for edit).
      var $anchor = $(list.head(rng.nodes(dom.isAnchor)));
      var linkInfo = {
        range: rng,
        text: rng.toString(),
        url: $anchor.length ? $anchor.attr('href') : ''
      };

      // Define isNewWindow when anchor exists.
      if ($anchor.length) {
        linkInfo.isNewWindow = $anchor.attr('target') === '_blank';
      }

      return linkInfo;
    };

    /**
     * setting color
     *
     * @param {Object} sObjColor  color code
     * @param {String} sObjColor.foreColor foreground color
     * @param {String} sObjColor.backColor background color
     */
    this.color = this.wrapCommand(function (colorInfo) {
      var foreColor = colorInfo.foreColor;
      var backColor = colorInfo.backColor;

      if (foreColor) { document.execCommand('foreColor', false, foreColor); }
      if (backColor) { document.execCommand('backColor', false, backColor); }
    });

    /**
     * insert Table
     *
     * @param {String} dimension of table (ex : "5x5")
     */
    this.insertTable = this.wrapCommand(function (dim) {
      var dimension = dim.split('x');

      var rng = this.createRange().deleteContents();
      rng.insertNode(table.createTable(dimension[0], dimension[1], options));
    });

     /**
     * @method addRow
     *
     *
     */
    this.addRow = function (position) {
      var rng = this.createRange($editable);
      if (rng.isCollapsed() && rng.isOnCell()) {
        beforeCommand();
        table.addRow(rng, position);
        afterCommand();
      }
    };

     /**
     * @method addCol
     *
     *
     */
    this.addCol = function (position) {
      var rng = this.createRange($editable);
      if (rng.isCollapsed() && rng.isOnCell()) {
        beforeCommand();
        table.addCol(rng, position);
        afterCommand();
      }
    };

    /**
     * @method deleteRow
     *
     *
     */
    this.deleteRow = function () {
      var rng = this.createRange($editable);
      if (rng.isCollapsed() && rng.isOnCell()) {
        beforeCommand();
        table.deleteRow(rng);
        afterCommand();
      }
    };

    /**
     * @method deleteCol
     *
     *
     */
    this.deleteCol = function () {
      var rng = this.createRange($editable);
      if (rng.isCollapsed() && rng.isOnCell()) {
        beforeCommand();
        table.deleteCol(rng);
        afterCommand();
      }
    };

    /**
     * @method deleteTable
     *
     *
     */
    this.deleteTable = function () {
      var rng = this.createRange($editable);
      if (rng.isCollapsed() && rng.isOnCell()) {
        beforeCommand();
        table.deleteTable(rng);
        afterCommand();
      }
    };

    /**
     * float me
     *
     * @param {String} value
     */
    this.floatMe = this.wrapCommand(function (value) {
      var $target = $(this.restoreTarget());
      $target.toggleClass('note-float-left', value === 'left');
      $target.toggleClass('note-float-right', value === 'right');
      $target.css('float', value);
    });

    /**
     * resize overlay element
     * @param {String} value
     */
    this.resize = this.wrapCommand(function (value) {
      var $target = $(this.restoreTarget());
      $target.css({
        width: value * 100 + '%',
        height: ''
      });
    });

    /**
     * @param {Position} pos
     * @param {jQuery} $target - target element
     * @param {Boolean} [bKeepRatio] - keep ratio
     */
    this.resizeTo = function (pos, $target, bKeepRatio) {
      var imageSize;
      if (bKeepRatio) {
        var newRatio = pos.y / pos.x;
        var ratio = $target.data('ratio');
        imageSize = {
          width: ratio > newRatio ? pos.x : pos.y / ratio,
          height: ratio > newRatio ? pos.x * ratio : pos.y
        };
      } else {
        imageSize = {
          width: pos.x,
          height: pos.y
        };
      }

      $target.css(imageSize);
    };

    /**
     * remove media object
     */
    this.removeMedia = this.wrapCommand(function () {
      var $target = $(this.restoreTarget()).detach();
      context.triggerEvent('media.delete', $target, $editable);
    });

    /**
     * returns whether editable area has focus or not.
     */
    this.hasFocus = function () {
      return $editable.is(':focus');
    };

    /**
     * set focus
     */
    this.focus = function () {
      // [workaround] Screen will move when page is scolled in IE.
      //  - do focus when not focused
      if (!this.hasFocus()) {
        $editable.focus();
      }
    };

    /**
     * returns whether contents is empty or not.
     * @return {Boolean}
     */
    this.isEmpty = function () {
      return dom.isEmpty($editable[0]) || dom.emptyPara === $editable.html();
    };

    /**
     * Removes all contents and restores the editable instance to an _emptyPara_.
     */
    this.empty = function () {
      context.invoke('code', dom.emptyPara);
    };
  };

  var Clipboard = function (context) {
    var self = this;

    var $editable = context.layoutInfo.editable;

    this.events = {
      'summernote.keydown': function (we, e) {
        if (self.needKeydownHook()) {
          if ((e.ctrlKey || e.metaKey) && e.keyCode === key.code.V) {
            context.invoke('editor.saveRange');
            self.$paste.focus();

            setTimeout(function () {
              self.pasteByHook();
            }, 0);
          }
        }
      }
    };

    this.needKeydownHook = function () {
      return (agent.isMSIE && agent.browserVersion > 10) || agent.isFF;
    };

    this.initialize = function () {
      // [workaround] getting image from clipboard
      //  - IE11 and Firefox: CTRL+v hook
      //  - Webkit: event.clipboardData
      if (this.needKeydownHook()) {
        this.$paste = $('<div tabindex="-1" />').attr('contenteditable', true).css({
          position: 'absolute',
          left: -100000,
          opacity: 0
        });
        $editable.before(this.$paste);

        this.$paste.on('paste', function (event) {
          context.triggerEvent('paste', event);
        });
      } else {
        $editable.on('paste', this.pasteByEvent);
      }
    };

    this.destroy = function () {
      if (this.needKeydownHook()) {
        this.$paste.remove();
        this.$paste = null;
      }
    };

    this.pasteByHook = function () {
      var node = this.$paste[0].firstChild;

      var src = node && node.src;
      if (dom.isImg(node) && src.indexOf('data:') === 0) {
        var decodedData = atob(node.src.split(',')[1]);
        var array = new Uint8Array(decodedData.length);
        for (var i = 0; i < decodedData.length; i++) {
          array[i] = decodedData.charCodeAt(i);
        }

        var blob = new Blob([array], { type: 'image/png' });
        blob.name = 'clipboard.png';

        context.invoke('editor.restoreRange');
        context.invoke('editor.focus');
        context.invoke('editor.insertImagesOrCallback', [blob]);
      } else {
        var pasteContent = $('<div />').html(this.$paste.html()).html();
        context.invoke('editor.restoreRange');
        context.invoke('editor.focus');

        if (pasteContent) {
          context.invoke('editor.pasteHTML', pasteContent);
        }
      }

      this.$paste.empty();
    };

    /**
     * paste by clipboard event
     *
     * @param {Event} event
     */
    this.pasteByEvent = function (event) {
      var clipboardData = event.originalEvent.clipboardData;
      if (clipboardData && clipboardData.items && clipboardData.items.length) {
        var item = list.head(clipboardData.items);
        if (item.kind === 'file' && item.type.indexOf('image/') !== -1) {
          context.invoke('editor.insertImagesOrCallback', [item.getAsFile()]);
        }
        context.invoke('editor.afterCommand');
      }
    };
  };

  var Dropzone = function (context) {
    var $document = $(document);
    var $editor = context.layoutInfo.editor;
    var $editable = context.layoutInfo.editable;
    var options = context.options;
    var lang = options.langInfo;
    var documentEventHandlers = {};

    var $dropzone = $([
      '<div class="note-dropzone">',
      '  <div class="note-dropzone-message"/>',
      '</div>'
    ].join('')).prependTo($editor);

    var detachDocumentEvent = function () {
      Object.keys(documentEventHandlers).forEach(function (key) {
        $document.off(key.substr(2).toLowerCase(), documentEventHandlers[key]);
      });
      documentEventHandlers = {};
    };

    /**
     * attach Drag and Drop Events
     */
    this.initialize = function () {
      if (options.disableDragAndDrop) {
        // prevent default drop event
        documentEventHandlers.onDrop = function (e) {
          e.preventDefault();
        };
        $document.on('drop', documentEventHandlers.onDrop);
      } else {
        this.attachDragAndDropEvent();
      }
    };

    /**
     * attach Drag and Drop Events
     */
    this.attachDragAndDropEvent = function () {
      var collection = $(),
          $dropzoneMessage = $dropzone.find('.note-dropzone-message');

      documentEventHandlers.onDragenter = function (e) {
        var isCodeview = context.invoke('codeview.isActivated');
        var hasEditorSize = $editor.width() > 0 && $editor.height() > 0;
        if (!isCodeview && !collection.length && hasEditorSize) {
          $editor.addClass('dragover');
          $dropzone.width($editor.width());
          $dropzone.height($editor.height());
          $dropzoneMessage.text(lang.image.dragImageHere);
        }
        collection = collection.add(e.target);
      };

      documentEventHandlers.onDragleave = function (e) {
        collection = collection.not(e.target);
        if (!collection.length) {
          $editor.removeClass('dragover');
        }
      };

      documentEventHandlers.onDrop = function () {
        collection = $();
        $editor.removeClass('dragover');
      };

      // show dropzone on dragenter when dragging a object to document
      // -but only if the editor is visible, i.e. has a positive width and height
      $document.on('dragenter', documentEventHandlers.onDragenter)
        .on('dragleave', documentEventHandlers.onDragleave)
        .on('drop', documentEventHandlers.onDrop);

      // change dropzone's message on hover.
      $dropzone.on('dragenter', function () {
        $dropzone.addClass('hover');
        $dropzoneMessage.text(lang.image.dropImage);
      }).on('dragleave', function () {
        $dropzone.removeClass('hover');
        $dropzoneMessage.text(lang.image.dragImageHere);
      });

      // attach dropImage
      $dropzone.on('drop', function (event) {
        var dataTransfer = event.originalEvent.dataTransfer;

        if (dataTransfer && dataTransfer.files && dataTransfer.files.length) {
          event.preventDefault();
          $editable.focus();
          context.invoke('editor.insertImagesOrCallback', dataTransfer.files);
        } else {
          $.each(dataTransfer.types, function (idx, type) {
            var content = dataTransfer.getData(type);

            if (type.toLowerCase().indexOf('text') > -1) {
              context.invoke('editor.pasteHTML', content);
            } else {
              $(content).each(function () {
                context.invoke('editor.insertNode', this);
              });
            }
          });
        }
      }).on('dragover', false); // prevent default dragover event
    };

    this.destroy = function () {
      detachDocumentEvent();
    };
  };


  var CodeMirror;
  if (agent.hasCodeMirror) {
    if (agent.isSupportAmd) {
      require(['codemirror'], function (cm) {
        CodeMirror = cm;
      });
    } else {
      CodeMirror = window.CodeMirror;
    }
  }

  /**
   * @class Codeview
   */
  var Codeview = function (context) {
    var $editor = context.layoutInfo.editor;
    var $editable = context.layoutInfo.editable;
    var $codable = context.layoutInfo.codable;
    var options = context.options;

    this.sync = function () {
      var isCodeview = this.isActivated();
      if (isCodeview && agent.hasCodeMirror) {
        $codable.data('cmEditor').save();
      }
    };

    /**
     * @return {Boolean}
     */
    this.isActivated = function () {
      return $editor.hasClass('codeview');
    };

    /**
     * toggle codeview
     */
    this.toggle = function () {
      if (this.isActivated()) {
        this.deactivate();
      } else {
        this.activate();
      }
      context.triggerEvent('codeview.toggled');
    };

    /**
     * activate code view
     */
    this.activate = function () {
      $codable.val(dom.html($editable, options.prettifyHtml));
      $codable.height($editable.height());

      context.invoke('toolbar.updateCodeview', true);
      $editor.addClass('codeview');
      $codable.focus();

      // activate CodeMirror as codable
      if (agent.hasCodeMirror) {
        var cmEditor = CodeMirror.fromTextArea($codable[0], options.codemirror);

        // CodeMirror TernServer
        if (options.codemirror.tern) {
          var server = new CodeMirror.TernServer(options.codemirror.tern);
          cmEditor.ternServer = server;
          cmEditor.on('cursorActivity', function (cm) {
            server.updateArgHints(cm);
          });
        }

        // CodeMirror hasn't Padding.
        cmEditor.setSize(null, $editable.outerHeight());
        $codable.data('cmEditor', cmEditor);
      }
    };

    /**
     * deactivate code view
     */
    this.deactivate = function () {
      // deactivate CodeMirror as codable
      if (agent.hasCodeMirror) {
        var cmEditor = $codable.data('cmEditor');
        $codable.val(cmEditor.getValue());
        cmEditor.toTextArea();
      }

      var value = dom.value($codable, options.prettifyHtml) || dom.emptyPara;
      var isChange = $editable.html() !== value;

      $editable.html(value);
      $editable.height(options.height ? $codable.height() : 'auto');
      $editor.removeClass('codeview');

      if (isChange) {
        context.triggerEvent('change', $editable.html(), $editable);
      }

      $editable.focus();

      context.invoke('toolbar.updateCodeview', false);
    };

    this.destroy = function () {
      if (this.isActivated()) {
        this.deactivate();
      }
    };
  };

  var EDITABLE_PADDING = 24;

  var Statusbar = function (context) {
    var $document = $(document);
    var $statusbar = context.layoutInfo.statusbar;
    var $editable = context.layoutInfo.editable;
    var options = context.options;

    this.initialize = function () {
      if (options.airMode || options.disableResizeEditor) {
        this.destroy();
        return;
      }

      $statusbar.on('mousedown', function (event) {
        event.preventDefault();
        event.stopPropagation();

        var editableTop = $editable.offset().top - $document.scrollTop();
        var onMouseMove = function (event) {
          var height = event.clientY - (editableTop + EDITABLE_PADDING);

          height = (options.minheight > 0) ? Math.max(height, options.minheight) : height;
          height = (options.maxHeight > 0) ? Math.min(height, options.maxHeight) : height;

          $editable.height(height);
        };

        $document
          .on('mousemove', onMouseMove)
          .one('mouseup', function () {
            $document.off('mousemove', onMouseMove);
          });
      });
    };

    this.destroy = function () {
      $statusbar.off();
      $statusbar.remove();
    };
  };

  var Fullscreen = function (context) {
    var self = this;
    var $editor = context.layoutInfo.editor;
    var $toolbar = context.layoutInfo.toolbar;
    var $editable = context.layoutInfo.editable;
    var $codable = context.layoutInfo.codable;

    var $window = $(window);
    var $scrollbar = $('html, body');

    this.resizeTo = function (size) {
      $editable.css('height', size.h);
      $codable.css('height', size.h);
      if ($codable.data('cmeditor')) {
        $codable.data('cmeditor').setsize(null, size.h);
      }
    };

    this.onResize = function () {
      self.resizeTo({
        h: $window.height() - $toolbar.outerHeight()
      });
    };

    /**
     * toggle fullscreen
     */
    this.toggle = function () {
      $editor.toggleClass('fullscreen');
      if (this.isFullscreen()) {
        $editable.data('orgHeight', $editable.css('height'));
        $window.on('resize', this.onResize).trigger('resize');
        $scrollbar.css('overflow', 'hidden');
      } else {
        $window.off('resize', this.onResize);
        this.resizeTo({ h: $editable.data('orgHeight') });
        $scrollbar.css('overflow', 'visible');
      }

      context.invoke('toolbar.updateFullscreen', this.isFullscreen());
    };

    this.isFullscreen = function () {
      return $editor.hasClass('fullscreen');
    };
  };

  var Handle = function (context) {
    var self = this;

    var $document = $(document);
    var $editingArea = context.layoutInfo.editingArea;
    var options = context.options;

    this.events = {
      'summernote.mousedown': function (we, e) {
        if (self.update(e.target)) {
          e.preventDefault();
        }
      },
      'summernote.keyup summernote.scroll summernote.change summernote.dialog.shown': function () {
        self.update();
      },
      'summernote.disable': function () {
        self.hide();
      },
      'summernote.codeview.toggled': function () {
        self.update();
      }
    };

    this.initialize = function () {
      this.$handle = $([
        '<div class="note-handle">',
        '<div class="note-control-selection">',
        '<div class="note-control-selection-bg"></div>',
        '<div class="note-control-holder note-control-nw"></div>',
        '<div class="note-control-holder note-control-ne"></div>',
        '<div class="note-control-holder note-control-sw"></div>',
        '<div class="',
        (options.disableResizeImage ? 'note-control-holder' : 'note-control-sizing'),
        ' note-control-se"></div>',
        (options.disableResizeImage ? '' : '<div class="note-control-selection-info"></div>'),
        '</div>',
        '</div>'
      ].join('')).prependTo($editingArea);

      this.$handle.on('mousedown', function (event) {
        if (dom.isControlSizing(event.target)) {
          event.preventDefault();
          event.stopPropagation();

          var $target = self.$handle.find('.note-control-selection').data('target'),
              posStart = $target.offset(),
              scrollTop = $document.scrollTop();

          var onMouseMove = function (event) {
            context.invoke('editor.resizeTo', {
              x: event.clientX - posStart.left,
              y: event.clientY - (posStart.top - scrollTop)
            }, $target, !event.shiftKey);

            self.update($target[0]);
          };

          $document
            .on('mousemove', onMouseMove)
            .one('mouseup', function (e) {
              e.preventDefault();
              $document.off('mousemove', onMouseMove);
              context.invoke('editor.afterCommand');
            });

          if (!$target.data('ratio')) { // original ratio.
            $target.data('ratio', $target.height() / $target.width());
          }
        }
      });

      // Listen for scrolling on the handle overlay.
      this.$handle.on('wheel', function (e) {
        e.preventDefault();
        self.update();
      });
    };

    this.destroy = function () {
      this.$handle.remove();
    };

    this.update = function (target) {
      if (context.isDisabled()) {
        return false;
      }

      var isImage = dom.isImg(target);
      var $selection = this.$handle.find('.note-control-selection');

      context.invoke('imagePopover.update', target);

      if (isImage) {
        var $image = $(target);
        var position = $image.position();
        var pos = {
          left: position.left + parseInt($image.css('marginLeft'), 10),
          top: position.top + parseInt($image.css('marginTop'), 10)
        };

        // exclude margin
        var imageSize = {
          w: $image.outerWidth(false),
          h: $image.outerHeight(false)
        };

        $selection.css({
          display: 'block',
          left: pos.left,
          top: pos.top,
          width: imageSize.w,
          height: imageSize.h
        }).data('target', $image); // save current image element.

        var sizingText = imageSize.w + 'x' + imageSize.h;
        $selection.find('.note-control-selection-info').text(sizingText);
        context.invoke('editor.saveTarget', target);
      } else {
        this.hide();
      }

      return isImage;
    };

    /**
     * hide
     *
     * @param {jQuery} $handle
     */
    this.hide = function () {
      context.invoke('editor.clearTarget');
      this.$handle.children().hide();
    };
  };

  var AutoLink = function (context) {
    var self = this;
    var defaultScheme = 'http://';
    var linkPattern = /^([A-Za-z][A-Za-z0-9+-.]*\:[\/\/]?|mailto:[A-Z0-9._%+-]+@)?(www\.)?(.+)$/i;

    this.events = {
      'summernote.keyup': function (we, e) {
        if (!e.isDefaultPrevented()) {
          self.handleKeyup(e);
        }
      },
      'summernote.keydown': function (we, e) {
        self.handleKeydown(e);
      }
    };

    this.initialize = function () {
      this.lastWordRange = null;
    };

    this.destroy = function () {
      this.lastWordRange = null;
    };

    this.replace = function () {
      if (!this.lastWordRange) {
        return;
      }

      var keyword = this.lastWordRange.toString();
      var match = keyword.match(linkPattern);

      if (match && (match[1] || match[2])) {
        var link = match[1] ? keyword : defaultScheme + keyword;
        var node = $('<a />').html(keyword).attr('href', link)[0];

        this.lastWordRange.insertNode(node);
        this.lastWordRange = null;
        context.invoke('editor.focus');
      }

    };

    this.handleKeydown = function (e) {
      if (list.contains([key.code.ENTER, key.code.SPACE], e.keyCode)) {
        var wordRange = context.invoke('editor.createRange').getWordRange();
        this.lastWordRange = wordRange;
      }
    };

    this.handleKeyup = function (e) {
      if (list.contains([key.code.ENTER, key.code.SPACE], e.keyCode)) {
        this.replace();
      }
    };
  };

  /**
   * textarea auto sync.
   */
  var AutoSync = function (context) {
    var $note = context.layoutInfo.note;

    this.events = {
      'summernote.change': function () {
        $note.val(context.invoke('code'));
      }
    };

    this.shouldInitialize = function () {
      return dom.isTextarea($note[0]);
    };
  };

  var Placeholder = function (context) {
    var self = this;
    var $editingArea = context.layoutInfo.editingArea;
    var options = context.options;

    this.events = {
      'summernote.init summernote.change': function () {
        self.update();
      },
      'summernote.codeview.toggled': function () {
        self.update();
      }
    };

    this.shouldInitialize = function () {
      return !!options.placeholder;
    };

    this.initialize = function () {
      this.$placeholder = $('<div class="note-placeholder">');
      this.$placeholder.on('click', function () {
        context.invoke('focus');
      }).text(options.placeholder).prependTo($editingArea);
    };

    this.destroy = function () {
      this.$placeholder.remove();
    };

    this.update = function () {
      var isShow = !context.invoke('codeview.isActivated') && context.invoke('editor.isEmpty');
      this.$placeholder.toggle(isShow);
    };
  };

  var Buttons = function (context) {
    var self = this;
    var ui = $.summernote.ui;

    var $toolbar = context.layoutInfo.toolbar;
    var options = context.options;
    var lang = options.langInfo;

    var invertedKeyMap = func.invertObject(options.keyMap[agent.isMac ? 'mac' : 'pc']);

    var representShortcut = this.representShortcut = function (editorMethod) {
      var shortcut = invertedKeyMap[editorMethod];
      if (!options.shortcuts || !shortcut) {
        return '';
      }

      if (agent.isMac) {
        shortcut = shortcut.replace('CMD', '⌘').replace('SHIFT', '⇧');
      }

      shortcut = shortcut.replace('BACKSLASH', '\\')
                         .replace('SLASH', '/')
                         .replace('LEFTBRACKET', '[')
                         .replace('RIGHTBRACKET', ']');

      return ' (' + shortcut + ')';
    };

    this.initialize = function () {
      this.addToolbarButtons();
      this.addImagePopoverButtons();
      this.addLinkPopoverButtons();
      this.addTablePopoverButtons();
      this.fontInstalledMap = {};
    };

    this.destroy = function () {
      delete this.fontInstalledMap;
    };

    this.isFontInstalled = function (name) {
      if (!self.fontInstalledMap.hasOwnProperty(name)) {
        self.fontInstalledMap[name] = agent.isFontInstalled(name) ||
          list.contains(options.fontNamesIgnoreCheck, name);
      }

      return self.fontInstalledMap[name];
    };

    this.addToolbarButtons = function () {
      context.memo('button.style', function () {
        return ui.buttonGroup([
          ui.button({
            className: 'dropdown-toggle',
            contents: ui.icon(options.icons.magic) + ' ' + ui.icon(options.icons.caret, 'span'),
            tooltip: lang.style.style,
            data: {
              toggle: 'dropdown'
            }
          }),
          ui.dropdown({
            className: 'dropdown-style',
            items: context.options.styleTags,
            template: function (item) {

              if (typeof item === 'string') {
                item = { tag: item, title: (lang.style.hasOwnProperty(item) ? lang.style[item] : item) };
              }

              var tag = item.tag;
              var title = item.title;
              var style = item.style ? ' style="' + item.style + '" ' : '';
              var className = item.className ? ' class="' + item.className + '"' : '';

              return '<' + tag + style + className + '>' + title + '</' + tag +  '>';
            },
            click: context.createInvokeHandler('editor.formatBlock')
          })
        ]).render();
      });

      context.memo('button.bold', function () {
        return ui.button({
          className: 'note-btn-bold',
          contents: ui.icon(options.icons.bold),
          tooltip: lang.font.bold + representShortcut('bold'),
          click: context.createInvokeHandlerAndUpdateState('editor.bold')
        }).render();
      });

      context.memo('button.italic', function () {
        return ui.button({
          className: 'note-btn-italic',
          contents: ui.icon(options.icons.italic),
          tooltip: lang.font.italic + representShortcut('italic'),
          click: context.createInvokeHandlerAndUpdateState('editor.italic')
        }).render();
      });

      context.memo('button.underline', function () {
        return ui.button({
          className: 'note-btn-underline',
          contents: ui.icon(options.icons.underline),
          tooltip: lang.font.underline + representShortcut('underline'),
          click: context.createInvokeHandlerAndUpdateState('editor.underline')
        }).render();
      });

      context.memo('button.clear', function () {
        return ui.button({
          contents: ui.icon(options.icons.eraser),
          tooltip: lang.font.clear + representShortcut('removeFormat'),
          click: context.createInvokeHandler('editor.removeFormat')
        }).render();
      });

      context.memo('button.strikethrough', function () {
        return ui.button({
          className: 'note-btn-strikethrough',
          contents: ui.icon(options.icons.strikethrough),
          tooltip: lang.font.strikethrough + representShortcut('strikethrough'),
          click: context.createInvokeHandlerAndUpdateState('editor.strikethrough')
        }).render();
      });

      context.memo('button.superscript', function () {
        return ui.button({
          className: 'note-btn-superscript',
          contents: ui.icon(options.icons.superscript),
          tooltip: lang.font.superscript,
          click: context.createInvokeHandlerAndUpdateState('editor.superscript')
        }).render();
      });

      context.memo('button.subscript', function () {
        return ui.button({
          className: 'note-btn-subscript',
          contents: ui.icon(options.icons.subscript),
          tooltip: lang.font.subscript,
          click: context.createInvokeHandlerAndUpdateState('editor.subscript')
        }).render();
      });

      context.memo('button.fontname', function () {
        return ui.buttonGroup([
          ui.button({
            className: 'dropdown-toggle',
            contents: '<span class="note-current-fontname"/> ' + ui.icon(options.icons.caret, 'span'),
            tooltip: lang.font.name,
            data: {
              toggle: 'dropdown'
            }
          }),
          ui.dropdownCheck({
            className: 'dropdown-fontname',
            checkClassName: options.icons.menuCheck,
            items: options.fontNames.filter(self.isFontInstalled),
            template: function (item) {
              return '<span style="font-family:' + item + '">' + item + '</span>';
            },
            click: context.createInvokeHandlerAndUpdateState('editor.fontName')
          })
        ]).render();
      });

      context.memo('button.fontsize', function () {
        return ui.buttonGroup([
          ui.button({
            className: 'dropdown-toggle',
            contents: '<span class="note-current-fontsize"/>' + ui.icon(options.icons.caret, 'span'),
            tooltip: lang.font.size,
            data: {
              toggle: 'dropdown'
            }
          }),
          ui.dropdownCheck({
            className: 'dropdown-fontsize',
            checkClassName: options.icons.menuCheck,
            items: options.fontSizes,
            click: context.createInvokeHandlerAndUpdateState('editor.fontSize')
          })
        ]).render();
      });

      context.memo('button.color', function () {
        return ui.buttonGroup({
          className: 'note-color',
          children: [
            ui.button({
              className: 'note-current-color-button',
              contents: ui.icon(options.icons.font + ' note-recent-color'),
              tooltip: lang.color.recent,
              click: function (e) {
                var $button = $(e.currentTarget);
                context.invoke('editor.color', {
                  backColor: $button.attr('data-backColor'),
                  foreColor: $button.attr('data-foreColor')
                });
              },
              callback: function ($button) {
                var $recentColor = $button.find('.note-recent-color');
                $recentColor.css('background-color', '#FFFF00');
                $button.attr('data-backColor', '#FFFF00');
              }
            }),
            ui.button({
              className: 'dropdown-toggle',
              contents: ui.icon(options.icons.caret, 'span'),
              tooltip: lang.color.more,
              data: {
                toggle: 'dropdown'
              }
            }),
            ui.dropdown({
              items: [
                '<li>',
                '<div class="btn-group">',
                '  <div class="note-palette-title">' + lang.color.background + '</div>',
                '  <div>',
                '    <button type="button" class="note-color-reset btn btn-default" data-event="backColor" data-value="inherit">',
                lang.color.transparent,
                '    </button>',
                '  </div>',
                '  <div class="note-holder" data-event="backColor"/>',
                '</div>',
                '<div class="btn-group">',
                '  <div class="note-palette-title">' + lang.color.foreground + '</div>',
                '  <div>',
                '    <button type="button" class="note-color-reset btn btn-default" data-event="removeFormat" data-value="foreColor">',
                lang.color.resetToDefault,
                '    </button>',
                '  </div>',
                '  <div class="note-holder" data-event="foreColor"/>',
                '</div>',
                '</li>'
              ].join(''),
              callback: function ($dropdown) {
                $dropdown.find('.note-holder').each(function () {
                  var $holder = $(this);
                  $holder.append(ui.palette({
                    colors: options.colors,
                    eventName: $holder.data('event'),
                    tooltip: options.tooltip
                  }).render());
                });
              },
              click: function (event) {
                var $button = $(event.target);
                var eventName = $button.data('event');
                var value = $button.data('value');

                if (eventName && value) {
                  var key = eventName === 'backColor' ? 'background-color' : 'color';
                  var $color = $button.closest('.note-color').find('.note-recent-color');
                  var $currentButton = $button.closest('.note-color').find('.note-current-color-button');

                  $color.css(key, value);
                  $currentButton.attr('data-' + eventName, value);
                  context.invoke('editor.' + eventName, value);
                }
              }
            })
          ]
        }).render();
      });

      context.memo('button.ul',  function () {
        return ui.button({
          contents: ui.icon(options.icons.unorderedlist),
          tooltip: lang.lists.unordered + representShortcut('insertUnorderedList'),
          click: context.createInvokeHandler('editor.insertUnorderedList')
        }).render();
      });

      context.memo('button.ol', function () {
        return ui.button({
          contents: ui.icon(options.icons.orderedlist),
          tooltip: lang.lists.ordered + representShortcut('insertOrderedList'),
          click:  context.createInvokeHandler('editor.insertOrderedList')
        }).render();
      });

      var justifyLeft = ui.button({
        contents: ui.icon(options.icons.alignLeft),
        tooltip: lang.paragraph.left + representShortcut('justifyLeft'),
        click: context.createInvokeHandler('editor.justifyLeft')
      });

      var justifyCenter = ui.button({
        contents: ui.icon(options.icons.alignCenter),
        tooltip: lang.paragraph.center + representShortcut('justifyCenter'),
        click: context.createInvokeHandler('editor.justifyCenter')
      });

      var justifyRight = ui.button({
        contents: ui.icon(options.icons.alignRight),
        tooltip: lang.paragraph.right + representShortcut('justifyRight'),
        click: context.createInvokeHandler('editor.justifyRight')
      });

      var justifyFull = ui.button({
        contents: ui.icon(options.icons.alignJustify),
        tooltip: lang.paragraph.justify + representShortcut('justifyFull'),
        click: context.createInvokeHandler('editor.justifyFull')
      });

      var outdent = ui.button({
        contents: ui.icon(options.icons.outdent),
        tooltip: lang.paragraph.outdent + representShortcut('outdent'),
        click: context.createInvokeHandler('editor.outdent')
      });

      var indent = ui.button({
        contents: ui.icon(options.icons.indent),
        tooltip: lang.paragraph.indent + representShortcut('indent'),
        click: context.createInvokeHandler('editor.indent')
      });

      context.memo('button.justifyLeft', func.invoke(justifyLeft, 'render'));
      context.memo('button.justifyCenter', func.invoke(justifyCenter, 'render'));
      context.memo('button.justifyRight', func.invoke(justifyRight, 'render'));
      context.memo('button.justifyFull', func.invoke(justifyFull, 'render'));
      context.memo('button.outdent', func.invoke(outdent, 'render'));
      context.memo('button.indent', func.invoke(indent, 'render'));

      context.memo('button.paragraph', function () {
        return ui.buttonGroup([
          ui.button({
            className: 'dropdown-toggle',
            contents: ui.icon(options.icons.alignLeft) + ' ' + ui.icon(options.icons.caret, 'span'),
            tooltip: lang.paragraph.paragraph,
            data: {
              toggle: 'dropdown'
            }
          }),
          ui.dropdown([
            ui.buttonGroup({
              className: 'note-align',
              children: [justifyLeft, justifyCenter, justifyRight, justifyFull]
            }),
            ui.buttonGroup({
              className: 'note-list',
              children: [outdent, indent]
            })
          ])
        ]).render();
      });

      context.memo('button.height', function () {
        return ui.buttonGroup([
          ui.button({
            className: 'dropdown-toggle',
            contents: ui.icon(options.icons.textHeight) + ' ' + ui.icon(options.icons.caret, 'span'),
            tooltip: lang.font.height,
            data: {
              toggle: 'dropdown'
            }
          }),
          ui.dropdownCheck({
            items: options.lineHeights,
            checkClassName: options.icons.menuCheck,
            className: 'dropdown-line-height',
            click: context.createInvokeHandler('editor.lineHeight')
          })
        ]).render();
      });

      context.memo('button.table', function () {
        return ui.buttonGroup([
          ui.button({
            className: 'dropdown-toggle',
            contents: ui.icon(options.icons.table) + ' ' + ui.icon(options.icons.caret, 'span'),
            tooltip: lang.table.table,
            data: {
              toggle: 'dropdown'
            }
          }),
          ui.dropdown({
            className: 'note-table',
            items: [
              '<div class="note-dimension-picker">',
              '  <div class="note-dimension-picker-mousecatcher" data-event="insertTable" data-value="1x1"/>',
              '  <div class="note-dimension-picker-highlighted"/>',
              '  <div class="note-dimension-picker-unhighlighted"/>',
              '</div>',
              '<div class="note-dimension-display">1 x 1</div>'
            ].join('')
          })
        ], {
          callback: function ($node) {
            var $catcher = $node.find('.note-dimension-picker-mousecatcher');
            $catcher.css({
              width: options.insertTableMaxSize.col + 'em',
              height: options.insertTableMaxSize.row + 'em'
            }).mousedown(context.createInvokeHandler('editor.insertTable'))
              .on('mousemove', self.tableMoveHandler);
          }
        }).render();
      });

      context.memo('button.link', function () {
        return ui.button({
          contents: ui.icon(options.icons.link),
          tooltip: lang.link.link + representShortcut('linkDialog.show'),
          click: context.createInvokeHandler('linkDialog.show')
        }).render();
      });

      context.memo('button.picture', function () {
        return ui.button({
          contents: ui.icon(options.icons.picture),
          tooltip: lang.image.image,
          click: context.createInvokeHandler('imageDialog.show')
        }).render();
      });

      context.memo('button.video', function () {
        return ui.button({
          contents: ui.icon(options.icons.video),
          tooltip: lang.video.video,
          click: context.createInvokeHandler('videoDialog.show')
        }).render();
      });

      context.memo('button.hr', function () {
        return ui.button({
          contents: ui.icon(options.icons.minus),
          tooltip: lang.hr.insert + representShortcut('insertHorizontalRule'),
          click: context.createInvokeHandler('editor.insertHorizontalRule')
        }).render();
      });

      context.memo('button.fullscreen', function () {
        return ui.button({
          className: 'btn-fullscreen',
          contents: ui.icon(options.icons.arrowsAlt),
          tooltip: lang.options.fullscreen,
          click: context.createInvokeHandler('fullscreen.toggle')
        }).render();
      });

      context.memo('button.codeview', function () {
        return ui.button({
          className: 'btn-codeview',
          contents: ui.icon(options.icons.code),
          tooltip: lang.options.codeview,
          click: context.createInvokeHandler('codeview.toggle')
        }).render();
      });

      context.memo('button.redo', function () {
        return ui.button({
          contents: ui.icon(options.icons.redo),
          tooltip: lang.history.redo + representShortcut('redo'),
          click: context.createInvokeHandler('editor.redo')
        }).render();
      });

      context.memo('button.undo', function () {
        return ui.button({
          contents: ui.icon(options.icons.undo),
          tooltip: lang.history.undo + representShortcut('undo'),
          click: context.createInvokeHandler('editor.undo')
        }).render();
      });

      context.memo('button.help', function () {
        return ui.button({
          contents: ui.icon(options.icons.question),
          tooltip: lang.options.help,
          click: context.createInvokeHandler('helpDialog.show')
        }).render();
      });
    };

    /**
     * image : [
     *   ['imagesize', ['imageSize100', 'imageSize50', 'imageSize25']],
     *   ['float', ['floatLeft', 'floatRight', 'floatNone' ]],
     *   ['remove', ['removeMedia']]
     * ],
     */
    this.addImagePopoverButtons = function () {
      // Image Size Buttons
      context.memo('button.imageSize100', function () {
        return ui.button({
          contents: '<span class="note-fontsize-10">100%</span>',
          tooltip: lang.image.resizeFull,
          click: context.createInvokeHandler('editor.resize', '1')
        }).render();
      });
      context.memo('button.imageSize50', function () {
        return  ui.button({
          contents: '<span class="note-fontsize-10">50%</span>',
          tooltip: lang.image.resizeHalf,
          click: context.createInvokeHandler('editor.resize', '0.5')
        }).render();
      });
      context.memo('button.imageSize25', function () {
        return ui.button({
          contents: '<span class="note-fontsize-10">25%</span>',
          tooltip: lang.image.resizeQuarter,
          click: context.createInvokeHandler('editor.resize', '0.25')
        }).render();
      });

      // Float Buttons
      context.memo('button.floatLeft', function () {
        return ui.button({
          contents: ui.icon(options.icons.alignLeft),
          tooltip: lang.image.floatLeft,
          click: context.createInvokeHandler('editor.floatMe', 'left')
        }).render();
      });

      context.memo('button.floatRight', function () {
        return ui.button({
          contents: ui.icon(options.icons.alignRight),
          tooltip: lang.image.floatRight,
          click: context.createInvokeHandler('editor.floatMe', 'right')
        }).render();
      });

      context.memo('button.floatNone', function () {
        return ui.button({
          contents: ui.icon(options.icons.alignJustify),
          tooltip: lang.image.floatNone,
          click: context.createInvokeHandler('editor.floatMe', 'none')
        }).render();
      });

      // Remove Buttons
      context.memo('button.removeMedia', function () {
        return ui.button({
          contents: ui.icon(options.icons.trash),
          tooltip: lang.image.remove,
          click: context.createInvokeHandler('editor.removeMedia')
        }).render();
      });
    };

    this.addLinkPopoverButtons = function () {
      context.memo('button.linkDialogShow', function () {
        return ui.button({
          contents: ui.icon(options.icons.link),
          tooltip: lang.link.edit,
          click: context.createInvokeHandler('linkDialog.show')
        }).render();
      });

      context.memo('button.unlink', function () {
        return ui.button({
          contents: ui.icon(options.icons.unlink),
          tooltip: lang.link.unlink,
          click: context.createInvokeHandler('editor.unlink')
        }).render();
      });
    };

    /**
     * table : [
     *  ['add', ['addRowDown', 'addRowUp', 'addColLeft', 'addColRight']],
     *  ['delete', ['deleteRow', 'deleteCol', 'deleteTable']]
     * ],
     */
    this.addTablePopoverButtons = function () {
      context.memo('button.addRowUp', function () {
        return ui.button({
          className: 'btn-md',
          contents: ui.icon(options.icons.rowAbove),
          tooltip: lang.table.addRowAbove,
          click: context.createInvokeHandler('editor.addRow', 'top')
        }).render();
      });
      context.memo('button.addRowDown', function () {
        return ui.button({
          className: 'btn-md',
          contents: ui.icon(options.icons.rowBelow),
          tooltip: lang.table.addRowBelow,
          click: context.createInvokeHandler('editor.addRow', 'bottom')
        }).render();
      });
      context.memo('button.addColLeft', function () {
        return ui.button({
          className: 'btn-md',
          contents: ui.icon(options.icons.colBefore),
          tooltip: lang.table.addColLeft,
          click: context.createInvokeHandler('editor.addCol', 'left')
        }).render();
      });
      context.memo('button.addColRight', function () {
        return ui.button({
          className: 'btn-md',
          contents: ui.icon(options.icons.colAfter),
          tooltip: lang.table.addColRight,
          click: context.createInvokeHandler('editor.addCol', 'right')
        }).render();
      });
      context.memo('button.deleteRow', function () {
        return ui.button({
          className: 'btn-md',
          contents: ui.icon(options.icons.rowRemove),
          tooltip: lang.table.delRow,
          click: context.createInvokeHandler('editor.deleteRow')
        }).render();
      });
      context.memo('button.deleteCol', function () {
        return ui.button({
          className: 'btn-md',
          contents: ui.icon(options.icons.colRemove),
          tooltip: lang.table.delCol,
          click: context.createInvokeHandler('editor.deleteCol')
        }).render();
      });
      context.memo('button.deleteTable', function () {
        return ui.button({
          className: 'btn-md',
          contents: ui.icon(options.icons.trash),
          tooltip: lang.table.delTable,
          click: context.createInvokeHandler('editor.deleteTable')
        }).render();
      });
    };

    this.build = function ($container, groups) {
      for (var groupIdx = 0, groupLen = groups.length; groupIdx < groupLen; groupIdx++) {
        var group = groups[groupIdx];
        var groupName = group[0];
        var buttons = group[1];

        var $group = ui.buttonGroup({
          className: 'note-' + groupName
        }).render();

        for (var idx = 0, len = buttons.length; idx < len; idx++) {
          var button = context.memo('button.' + buttons[idx]);
          if (button) {
            $group.append(typeof button === 'function' ? button(context) : button);
          }
        }
        $group.appendTo($container);
      }
    };

    this.updateCurrentStyle = function () {
      var styleInfo = context.invoke('editor.currentStyle');
      this.updateBtnStates({
        '.note-btn-bold': function () {
          return styleInfo['font-bold'] === 'bold';
        },
        '.note-btn-italic': function () {
          return styleInfo['font-italic'] === 'italic';
        },
        '.note-btn-underline': function () {
          return styleInfo['font-underline'] === 'underline';
        },
        '.note-btn-subscript': function () {
          return styleInfo['font-subscript'] === 'subscript';
        },
        '.note-btn-superscript': function () {
          return styleInfo['font-superscript'] === 'superscript';
        },
        '.note-btn-strikethrough': function () {
          return styleInfo['font-strikethrough'] === 'strikethrough';
        }
      });

      if (styleInfo['font-family']) {
        var fontNames = styleInfo['font-family'].split(',').map(function (name) {
          return name.replace(/[\'\"]/g, '')
            .replace(/\s+$/, '')
            .replace(/^\s+/, '');
        });
        var fontName = list.find(fontNames, self.isFontInstalled);

        $toolbar.find('.dropdown-fontname li a').each(function () {
          // always compare string to avoid creating another func.
          var isChecked = ($(this).data('value') + '') === (fontName + '');
          this.className = isChecked ? 'checked' : '';
        });
        $toolbar.find('.note-current-fontname').text(fontName);
      }

      if (styleInfo['font-size']) {
        var fontSize = styleInfo['font-size'];
        $toolbar.find('.dropdown-fontsize li a').each(function () {
          // always compare with string to avoid creating another func.
          var isChecked = ($(this).data('value') + '') === (fontSize + '');
          this.className = isChecked ? 'checked' : '';
        });
        $toolbar.find('.note-current-fontsize').text(fontSize);
      }

      if (styleInfo['line-height']) {
        var lineHeight = styleInfo['line-height'];
        $toolbar.find('.dropdown-line-height li a').each(function () {
          // always compare with string to avoid creating another func.
          var isChecked = ($(this).data('value') + '') === (lineHeight + '');
          this.className = isChecked ? 'checked' : '';
        });
      }
    };

    this.updateBtnStates = function (infos) {
      $.each(infos, function (selector, pred) {
        ui.toggleBtnActive($toolbar.find(selector), pred());
      });
    };

    this.tableMoveHandler = function (event) {
      var PX_PER_EM = 18;
      var $picker = $(event.target.parentNode); // target is mousecatcher
      var $dimensionDisplay = $picker.next();
      var $catcher = $picker.find('.note-dimension-picker-mousecatcher');
      var $highlighted = $picker.find('.note-dimension-picker-highlighted');
      var $unhighlighted = $picker.find('.note-dimension-picker-unhighlighted');

      var posOffset;
      // HTML5 with jQuery - e.offsetX is undefined in Firefox
      if (event.offsetX === undefined) {
        var posCatcher = $(event.target).offset();
        posOffset = {
          x: event.pageX - posCatcher.left,
          y: event.pageY - posCatcher.top
        };
      } else {
        posOffset = {
          x: event.offsetX,
          y: event.offsetY
        };
      }

      var dim = {
        c: Math.ceil(posOffset.x / PX_PER_EM) || 1,
        r: Math.ceil(posOffset.y / PX_PER_EM) || 1
      };

      $highlighted.css({ width: dim.c + 'em', height: dim.r + 'em' });
      $catcher.data('value', dim.c + 'x' + dim.r);

      if (3 < dim.c && dim.c < options.insertTableMaxSize.col) {
        $unhighlighted.css({ width: dim.c + 1 + 'em'});
      }

      if (3 < dim.r && dim.r < options.insertTableMaxSize.row) {
        $unhighlighted.css({ height: dim.r + 1 + 'em'});
      }

      $dimensionDisplay.html(dim.c + ' x ' + dim.r);
    };
  };

  var Toolbar = function (context) {
    var ui = $.summernote.ui;

    var $note = context.layoutInfo.note;
    var $toolbar = context.layoutInfo.toolbar;
    var options = context.options;

    this.shouldInitialize = function () {
      return !options.airMode;
    };

    this.initialize = function () {
      options.toolbar = options.toolbar || [];

      if (!options.toolbar.length) {
        $toolbar.hide();
      } else {
        context.invoke('buttons.build', $toolbar, options.toolbar);
      }

      if (options.toolbarContainer) {
        $toolbar.appendTo(options.toolbarContainer);
      }

      $note.on('summernote.keyup summernote.mouseup summernote.change', function () {
        context.invoke('buttons.updateCurrentStyle');
      });

      context.invoke('buttons.updateCurrentStyle');
    };

    this.destroy = function () {
      $toolbar.children().remove();
    };

    this.updateFullscreen = function (isFullscreen) {
      ui.toggleBtnActive($toolbar.find('.btn-fullscreen'), isFullscreen);
    };

    this.updateCodeview = function (isCodeview) {
      ui.toggleBtnActive($toolbar.find('.btn-codeview'), isCodeview);
      if (isCodeview) {
        this.deactivate();
      } else {
        this.activate();
      }
    };

    this.activate = function (isIncludeCodeview) {
      var $btn = $toolbar.find('button');
      if (!isIncludeCodeview) {
        $btn = $btn.not('.btn-codeview');
      }
      ui.toggleBtn($btn, true);
    };

    this.deactivate = function (isIncludeCodeview) {
      var $btn = $toolbar.find('button');
      if (!isIncludeCodeview) {
        $btn = $btn.not('.btn-codeview');
      }
      ui.toggleBtn($btn, false);
    };
  };

  var LinkDialog = function (context) {
    var self = this;
    var ui = $.summernote.ui;

    var $editor = context.layoutInfo.editor;
    var options = context.options;
    var lang = options.langInfo;

    this.initialize = function () {
      var $container = options.dialogsInBody ? $(document.body) : $editor;

      var body = '<div class="form-group">' +
                   '<label>' + lang.link.textToDisplay + '</label>' +
                   '<input class="note-link-text form-control" type="text" />' +
                 '</div>' +
                 '<div class="form-group">' +
                   '<label>' + lang.link.url + '</label>' +
                   '<input class="note-link-url form-control" type="text" value="http://" />' +
                 '</div>' +
                 (!options.disableLinkTarget ?
                   '<div class="checkbox">' +
                     '<label for="sn-checkbox-open-in-new-window">' +
                       '<input type="checkbox" id="sn-checkbox-open-in-new-window" checked />' + lang.link.openInNewWindow +
                     '</label>' +
                   '</div>' : ''
                 );
      var footer = '<button href="#" class="btn btn-primary note-link-btn disabled" disabled>' + lang.link.insert + '</button>';

      this.$dialog = ui.dialog({
        className: 'link-dialog',
        title: lang.link.insert,
        fade: options.dialogsFade,
        body: body,
        footer: footer
      }).render().appendTo($container);
    };

    this.destroy = function () {
      ui.hideDialog(this.$dialog);
      this.$dialog.remove();
    };

    this.bindEnterKey = function ($input, $btn) {
      $input.on('keypress', function (event) {
        if (event.keyCode === key.code.ENTER) {
          $btn.trigger('click');
        }
      });
    };

    /**
     * toggle update button
     */
    this.toggleLinkBtn = function ($linkBtn, $linkText, $linkUrl) {
      ui.toggleBtn($linkBtn, $linkText.val() && $linkUrl.val());
    };

    /**
     * Show link dialog and set event handlers on dialog controls.
     *
     * @param {Object} linkInfo
     * @return {Promise}
     */
    this.showLinkDialog = function (linkInfo) {
      return $.Deferred(function (deferred) {
        var $linkText = self.$dialog.find('.note-link-text'),
        $linkUrl = self.$dialog.find('.note-link-url'),
        $linkBtn = self.$dialog.find('.note-link-btn'),
        $openInNewWindow = self.$dialog.find('input[type=checkbox]');

        ui.onDialogShown(self.$dialog, function () {
          context.triggerEvent('dialog.shown');

          // if no url was given, copy text to url
          if (!linkInfo.url) {
            linkInfo.url = linkInfo.text;
          }

          $linkText.val(linkInfo.text);

          var handleLinkTextUpdate = function () {
            self.toggleLinkBtn($linkBtn, $linkText, $linkUrl);
            // if linktext was modified by keyup,
            // stop cloning text from linkUrl
            linkInfo.text = $linkText.val();
          };

          $linkText.on('input', handleLinkTextUpdate).on('paste', function () {
            setTimeout(handleLinkTextUpdate, 0);
          });

          var handleLinkUrlUpdate = function () {
            self.toggleLinkBtn($linkBtn, $linkText, $linkUrl);
            // display same link on `Text to display` input
            // when create a new link
            if (!linkInfo.text) {
              $linkText.val($linkUrl.val());
            }
          };

          $linkUrl.on('input', handleLinkUrlUpdate).on('paste', function () {
            setTimeout(handleLinkUrlUpdate, 0);
          }).val(linkInfo.url).trigger('focus');

          self.toggleLinkBtn($linkBtn, $linkText, $linkUrl);
          self.bindEnterKey($linkUrl, $linkBtn);
          self.bindEnterKey($linkText, $linkBtn);

          var isChecked = linkInfo.isNewWindow !== undefined ?
            linkInfo.isNewWindow : context.options.linkTargetBlank;

          $openInNewWindow.prop('checked', isChecked);

          $linkBtn.one('click', function (event) {
            event.preventDefault();

            deferred.resolve({
              range: linkInfo.range,
              url: $linkUrl.val(),
              text: $linkText.val(),
              isNewWindow: $openInNewWindow.is(':checked')
            });
            self.$dialog.modal('hide');
          });
        });

        ui.onDialogHidden(self.$dialog, function () {
          // detach events
          $linkText.off('input paste keypress');
          $linkUrl.off('input paste keypress');
          $linkBtn.off('click');

          if (deferred.state() === 'pending') {
            deferred.reject();
          }
        });

        ui.showDialog(self.$dialog);
      }).promise();
    };

    /**
     * @param {Object} layoutInfo
     */
    this.show = function () {
      var linkInfo = context.invoke('editor.getLinkInfo');

      context.invoke('editor.saveRange');
      this.showLinkDialog(linkInfo).then(function (linkInfo) {
        context.invoke('editor.restoreRange');
        context.invoke('editor.createLink', linkInfo);
      }).fail(function () {
        context.invoke('editor.restoreRange');
      });
    };
    context.memo('help.linkDialog.show', options.langInfo.help['linkDialog.show']);
  };

  var LinkPopover = function (context) {
    var self = this;
    var ui = $.summernote.ui;

    var options = context.options;

    this.events = {
      'summernote.keyup summernote.mouseup summernote.change summernote.scroll': function () {
        self.update();
      },
      'summernote.disable summernote.dialog.shown': function () {
        self.hide();
      }
    };

    this.shouldInitialize = function () {
      return !list.isEmpty(options.popover.link);
    };

    this.initialize = function () {
      this.$popover = ui.popover({
        className: 'note-link-popover',
        callback: function ($node) {
          var $content = $node.find('.popover-content');
          $content.prepend('<span><a target="_blank"></a>&nbsp;</span>');
        }
      }).render().appendTo('body');
      var $content = this.$popover.find('.popover-content');

      context.invoke('buttons.build', $content, options.popover.link);
    };

    this.destroy = function () {
      this.$popover.remove();
    };

    this.update = function () {
      // Prevent focusing on editable when invoke('code') is executed
      if (!context.invoke('editor.hasFocus')) {
        this.hide();
        return;
      }

      var rng = context.invoke('editor.createRange');
      if (rng.isCollapsed() && rng.isOnAnchor()) {
        var anchor = dom.ancestor(rng.sc, dom.isAnchor);
        var href = $(anchor).attr('href');
        this.$popover.find('a').attr('href', href).html(href);

        var pos = dom.posFromPlaceholder(anchor);
        this.$popover.css({
          display: 'block',
          left: pos.left,
          top: pos.top
        });
      } else {
        this.hide();
      }
    };

    this.hide = function () {
      this.$popover.hide();
    };
  };

  var ImageDialog = function (context) {
    var self = this;
    var ui = $.summernote.ui;

    var $editor = context.layoutInfo.editor;
    var options = context.options;
    var lang = options.langInfo;

    this.initialize = function () {
      var $container = options.dialogsInBody ? $(document.body) : $editor;

      var imageLimitation = '';
      if (options.maximumImageFileSize) {
        var unit = Math.floor(Math.log(options.maximumImageFileSize) / Math.log(1024));
        var readableSize = (options.maximumImageFileSize / Math.pow(1024, unit)).toFixed(2) * 1 +
                           ' ' + ' KMGTP'[unit] + 'B';
        imageLimitation = '<small>' + lang.image.maximumFileSize + ' : ' + readableSize + '</small>';
      }

      var body = '<div class="form-group note-group-select-from-files">' +
                   '<label>' + lang.image.selectFromFiles + '</label>' +
                   '<input class="note-image-input form-control" type="file" name="files" accept="image/*" multiple="multiple" />' +
                   imageLimitation +
                 '</div>' +
                 '<div class="form-group note-group-image-url" style="overflow:auto;">' +
                   '<label>' + lang.image.url + '</label>' +
                   '<input class="note-image-url form-control col-md-12" type="text" />' +
                 '</div>';
      var footer = '<button href="#" class="btn btn-primary note-image-btn disabled" disabled>' + lang.image.insert + '</button>';

      this.$dialog = ui.dialog({
        title: lang.image.insert,
        fade: options.dialogsFade,
        body: body,
        footer: footer
      }).render().appendTo($container);
    };

    this.destroy = function () {
      ui.hideDialog(this.$dialog);
      this.$dialog.remove();
    };

    this.bindEnterKey = function ($input, $btn) {
      $input.on('keypress', function (event) {
        if (event.keyCode === key.code.ENTER) {
          $btn.trigger('click');
        }
      });
    };

    this.show = function () {
      context.invoke('editor.saveRange');
      this.showImageDialog().then(function (data) {
        // [workaround] hide dialog before restore range for IE range focus
        ui.hideDialog(self.$dialog);
        context.invoke('editor.restoreRange');

        if (typeof data === 'string') { // image url
          context.invoke('editor.insertImage', data);
        } else { // array of files
          context.invoke('editor.insertImagesOrCallback', data);
        }
      }).fail(function () {
        context.invoke('editor.restoreRange');
      });
    };

    /**
     * show image dialog
     *
     * @param {jQuery} $dialog
     * @return {Promise}
     */
    this.showImageDialog = function () {
      return $.Deferred(function (deferred) {
        var $imageInput = self.$dialog.find('.note-image-input'),
            $imageUrl = self.$dialog.find('.note-image-url'),
            $imageBtn = self.$dialog.find('.note-image-btn');

        ui.onDialogShown(self.$dialog, function () {
          context.triggerEvent('dialog.shown');

          // Cloning imageInput to clear element.
          $imageInput.replaceWith($imageInput.clone()
            .on('change', function () {
              deferred.resolve(this.files || this.value);
            })
            .val('')
          );

          $imageBtn.click(function (event) {
            event.preventDefault();

            deferred.resolve($imageUrl.val());
          });

          $imageUrl.on('keyup paste', function () {
            var url = $imageUrl.val();
            ui.toggleBtn($imageBtn, url);
          }).val('').trigger('focus');
          self.bindEnterKey($imageUrl, $imageBtn);
        });

        ui.onDialogHidden(self.$dialog, function () {
          $imageInput.off('change');
          $imageUrl.off('keyup paste keypress');
          $imageBtn.off('click');

          if (deferred.state() === 'pending') {
            deferred.reject();
          }
        });

        ui.showDialog(self.$dialog);
      });
    };
  };


  /**
   * Image popover module
   *  mouse events that show/hide popover will be handled by Handle.js.
   *  Handle.js will receive the events and invoke 'imagePopover.update'.
   */
  var ImagePopover = function (context) {
    var self = this;
    var ui = $.summernote.ui;

    var $editable = context.layoutInfo.editable;
    var editable = $editable[0];
    var options = context.options;

    this.events = {
      'summernote.disable': function () {
        self.hide();
      }
    };

    this.shouldInitialize = function () {
      return !list.isEmpty(options.popover.image);
    };

    this.initialize = function () {
      this.$popover = ui.popover({
        className: 'note-image-popover'
      }).render().appendTo('body');
      var $content = this.$popover.find('.popover-content');

      context.invoke('buttons.build', $content, options.popover.image);
    };

    this.destroy = function () {
      this.$popover.remove();
    };

    this.update = function (target) {
      if (dom.isImg(target)) {
        var pos = dom.posFromPlaceholder(target);
        var posEditor = dom.posFromPlaceholder(editable);

        this.$popover.css({
          display: 'block',
          left: pos.left,
          top: Math.min(pos.top, posEditor.top)
        });
      } else {
        this.hide();
      }
    };

    this.hide = function () {
      this.$popover.hide();
    };
  };

  var TablePopover = function (context) {
    var self = this;
    var ui = $.summernote.ui;

    var options = context.options;

    this.events = {
      'summernote.mousedown': function (we, e) {
        self.update(e.target);
      },
      'summernote.keyup summernote.scroll summernote.change': function () {
        self.update();
      },
      'summernote.disable': function () {
        self.hide();
      }
    };

    this.shouldInitialize = function () {
      return !list.isEmpty(options.popover.table);
    };

    this.initialize = function () {
      this.$popover = ui.popover({
        className: 'note-table-popover'
      }).render().appendTo('body');
      var $content = this.$popover.find('.popover-content');

      context.invoke('buttons.build', $content, options.popover.table);

      // [workaround] Disable Firefox's default table editor
      if (agent.isFF) {
        document.execCommand('enableInlineTableEditing', false, false);
      }
    };

    this.destroy = function () {
      this.$popover.remove();
    };

    this.update = function (target) {
      if (context.isDisabled()) {
        return false;
      }

      var isCell = dom.isCell(target);

      if (isCell) {
        var pos = dom.posFromPlaceholder(target);
        this.$popover.css({
          display: 'block',
          left: pos.left,
          top: pos.top
        });
      } else {
        this.hide();
      }

      return isCell;
    };

    this.hide = function () {
      this.$popover.hide();
    };
  };

  var VideoDialog = function (context) {
    var self = this;
    var ui = $.summernote.ui;

    var $editor = context.layoutInfo.editor;
    var options = context.options;
    var lang = options.langInfo;

    this.initialize = function () {
      var $container = options.dialogsInBody ? $(document.body) : $editor;

      var body = '<div class="form-group row-fluid">' +
          '<label>' + lang.video.url + ' <small class="text-muted">' + lang.video.providers + '</small></label>' +
          '<input class="note-video-url form-control span12" type="text" />' +
          '</div>';
      var footer = '<button href="#" class="btn btn-primary note-video-btn disabled" disabled>' + lang.video.insert + '</button>';

      this.$dialog = ui.dialog({
        title: lang.video.insert,
        fade: options.dialogsFade,
        body: body,
        footer: footer
      }).render().appendTo($container);
    };

    this.destroy = function () {
      ui.hideDialog(this.$dialog);
      this.$dialog.remove();
    };

    this.bindEnterKey = function ($input, $btn) {
      $input.on('keypress', function (event) {
        if (event.keyCode === key.code.ENTER) {
          $btn.trigger('click');
        }
      });
    };

    this.createVideoNode = function (url) {
      // video url patterns(youtube, instagram, vimeo, dailymotion, youku, mp4, ogg, webm)
      var ytRegExp = /^(?:https?:\/\/)?(?:www\.)?(?:youtu\.be\/|youtube\.com\/(?:embed\/|v\/|watch\?v=|watch\?.+&v=))((\w|-){11})(?:\S+)?$/;
      var ytMatch = url.match(ytRegExp);

      var igRegExp = /(?:www\.|\/\/)instagram\.com\/p\/(.[a-zA-Z0-9_-]*)/;
      var igMatch = url.match(igRegExp);

      var vRegExp = /\/\/vine\.co\/v\/([a-zA-Z0-9]+)/;
      var vMatch = url.match(vRegExp);

      var vimRegExp = /\/\/(player\.)?vimeo\.com\/([a-z]*\/)*(\d+)[?]?.*/;
      var vimMatch = url.match(vimRegExp);

      var dmRegExp = /.+dailymotion.com\/(video|hub)\/([^_]+)[^#]*(#video=([^_&]+))?/;
      var dmMatch = url.match(dmRegExp);

      var youkuRegExp = /\/\/v\.youku\.com\/v_show\/id_(\w+)=*\.html/;
      var youkuMatch = url.match(youkuRegExp);

      var qqRegExp = /\/\/v\.qq\.com.*?vid=(.+)/;
      var qqMatch = url.match(qqRegExp);

      var qqRegExp2 = /\/\/v\.qq\.com\/x?\/?(page|cover).*?\/([^\/]+)\.html\??.*/;
      var qqMatch2 = url.match(qqRegExp2);

      var mp4RegExp = /^.+.(mp4|m4v)$/;
      var mp4Match = url.match(mp4RegExp);

      var oggRegExp = /^.+.(ogg|ogv)$/;
      var oggMatch = url.match(oggRegExp);

      var webmRegExp = /^.+.(webm)$/;
      var webmMatch = url.match(webmRegExp);

      var $video;
      if (ytMatch && ytMatch[1].length === 11) {
        var youtubeId = ytMatch[1];
        $video = $('<iframe>')
            .attr('frameborder', 0)
            .attr('src', '//www.youtube.com/embed/' + youtubeId)
            .attr('width', '640').attr('height', '360');
      } else if (igMatch && igMatch[0].length) {
        $video = $('<iframe>')
            .attr('frameborder', 0)
            .attr('src', 'https://instagram.com/p/' + igMatch[1] + '/embed/')
            .attr('width', '612').attr('height', '710')
            .attr('scrolling', 'no')
            .attr('allowtransparency', 'true');
      } else if (vMatch && vMatch[0].length) {
        $video = $('<iframe>')
            .attr('frameborder', 0)
            .attr('src', vMatch[0] + '/embed/simple')
            .attr('width', '600').attr('height', '600')
            .attr('class', 'vine-embed');
      } else if (vimMatch && vimMatch[3].length) {
        $video = $('<iframe webkitallowfullscreen mozallowfullscreen allowfullscreen>')
            .attr('frameborder', 0)
            .attr('src', '//player.vimeo.com/video/' + vimMatch[3])
            .attr('width', '640').attr('height', '360');
      } else if (dmMatch && dmMatch[2].length) {
        $video = $('<iframe>')
            .attr('frameborder', 0)
            .attr('src', '//www.dailymotion.com/embed/video/' + dmMatch[2])
            .attr('width', '640').attr('height', '360');
      } else if (youkuMatch && youkuMatch[1].length) {
        $video = $('<iframe webkitallowfullscreen mozallowfullscreen allowfullscreen>')
            .attr('frameborder', 0)
            .attr('height', '498')
            .attr('width', '510')
            .attr('src', '//player.youku.com/embed/' + youkuMatch[1]);
      } else if ((qqMatch && qqMatch[1].length) || (qqMatch2 && qqMatch2[2].length)) {
        var vid = ((qqMatch && qqMatch[1].length) ? qqMatch[1]:qqMatch2[2]);
        $video = $('<iframe webkitallowfullscreen mozallowfullscreen allowfullscreen>')
            .attr('frameborder', 0)
            .attr('height', '310')
            .attr('width', '500')
            .attr('src', 'http://v.qq.com/iframe/player.html?vid=' + vid + '&amp;auto=0');
      } else if (mp4Match || oggMatch || webmMatch) {
        $video = $('<video controls>')
            .attr('src', url)
            .attr('width', '640').attr('height', '360');
      } else {
        // this is not a known video link. Now what, Cat? Now what?
        return false;
      }

      $video.addClass('note-video-clip');

      return $video[0];
    };

    this.show = function () {
      var text = context.invoke('editor.getSelectedText');
      context.invoke('editor.saveRange');
      this.showVideoDialog(text).then(function (url) {
        // [workaround] hide dialog before restore range for IE range focus
        ui.hideDialog(self.$dialog);
        context.invoke('editor.restoreRange');

        // build node
        var $node = self.createVideoNode(url);

        if ($node) {
          // insert video node
          context.invoke('editor.insertNode', $node);
        }
      }).fail(function () {
        context.invoke('editor.restoreRange');
      });
    };

    /**
     * show image dialog
     *
     * @param {jQuery} $dialog
     * @return {Promise}
     */
    this.showVideoDialog = function (text) {
      return $.Deferred(function (deferred) {
        var $videoUrl = self.$dialog.find('.note-video-url'),
            $videoBtn = self.$dialog.find('.note-video-btn');

        ui.onDialogShown(self.$dialog, function () {
          context.triggerEvent('dialog.shown');

          $videoUrl.val(text).on('input', function () {
            ui.toggleBtn($videoBtn, $videoUrl.val());
          }).trigger('focus');

          $videoBtn.click(function (event) {
            event.preventDefault();

            deferred.resolve($videoUrl.val());
          });

          self.bindEnterKey($videoUrl, $videoBtn);
        });

        ui.onDialogHidden(self.$dialog, function () {
          $videoUrl.off('input');
          $videoBtn.off('click');

          if (deferred.state() === 'pending') {
            deferred.reject();
          }
        });

        ui.showDialog(self.$dialog);
      });
    };
  };

  var HelpDialog = function (context) {
    var self = this;
    var ui = $.summernote.ui;

    var $editor = context.layoutInfo.editor;
    var options = context.options;
    var lang = options.langInfo;

    this.createShortCutList = function () {
      var keyMap = options.keyMap[agent.isMac ? 'mac' : 'pc'];
      return Object.keys(keyMap).map(function (key) {
        var command = keyMap[key];
        var $row = $('<div><div class="help-list-item"/></div>');
        $row.append($('<label><kbd>' + key + '</kdb></label>').css({
          'width': 180,
          'margin-right': 10
        })).append($('<span/>').html(context.memo('help.' + command) || command));
        return $row.html();
      }).join('');
    };

    this.initialize = function () {
      var $container = options.dialogsInBody ? $(document.body) : $editor;

      var body = [
        '<p class="text-center">',
        '<a href="http://summernote.org/" target="_blank">Summernote 0.8.7</a> · ',
        '<a href="https://github.com/summernote/summernote" target="_blank">Project</a> · ',
        '<a href="https://github.com/summernote/summernote/issues" target="_blank">Issues</a>',
        '</p>'
      ].join('');

      this.$dialog = ui.dialog({
        title: lang.options.help,
        fade: options.dialogsFade,
        body: this.createShortCutList(),
        footer: body,
        callback: function ($node) {
          $node.find('.modal-body').css({
            'max-height': 300,
            'overflow': 'scroll'
          });
        }
      }).render().appendTo($container);
    };

    this.destroy = function () {
      ui.hideDialog(this.$dialog);
      this.$dialog.remove();
    };

    /**
     * show help dialog
     *
     * @return {Promise}
     */
    this.showHelpDialog = function () {
      return $.Deferred(function (deferred) {
        ui.onDialogShown(self.$dialog, function () {
          context.triggerEvent('dialog.shown');
          deferred.resolve();
        });
        ui.showDialog(self.$dialog);
      }).promise();
    };

    this.show = function () {
      context.invoke('editor.saveRange');
      this.showHelpDialog().then(function () {
        context.invoke('editor.restoreRange');
      });
    };
  };

  var AirPopover = function (context) {
    var self = this;
    var ui = $.summernote.ui;

    var options = context.options;

    var AIR_MODE_POPOVER_X_OFFSET = 20;

    this.events = {
      'summernote.keyup summernote.mouseup summernote.scroll': function () {
        self.update();
      },
      'summernote.disable summernote.change summernote.dialog.shown': function () {
        self.hide();
      },
      'summernote.focusout': function (we, e) {
        // [workaround] Firefox doesn't support relatedTarget on focusout
        //  - Ignore hide action on focus out in FF.
        if (agent.isFF) {
          return;
        }

        if (!e.relatedTarget || !dom.ancestor(e.relatedTarget, func.eq(self.$popover[0]))) {
          self.hide();
        }
      }
    };

    this.shouldInitialize = function () {
      return options.airMode && !list.isEmpty(options.popover.air);
    };

    this.initialize = function () {
      this.$popover = ui.popover({
        className: 'note-air-popover'
      }).render().appendTo('body');
      var $content = this.$popover.find('.popover-content');

      context.invoke('buttons.build', $content, options.popover.air);
    };

    this.destroy = function () {
      this.$popover.remove();
    };

    this.update = function () {
      var styleInfo = context.invoke('editor.currentStyle');
      if (styleInfo.range && !styleInfo.range.isCollapsed()) {
        var rect = list.last(styleInfo.range.getClientRects());
        if (rect) {
          var bnd = func.rect2bnd(rect);
          this.$popover.css({
            display: 'block',
            left: Math.max(bnd.left + bnd.width / 2, 0) - AIR_MODE_POPOVER_X_OFFSET,
            top: bnd.top + bnd.height
          });
        }
      } else {
        this.hide();
      }
    };

    this.hide = function () {
      this.$popover.hide();
    };
  };

  var HintPopover = function (context) {
    var self = this;
    var ui = $.summernote.ui;

    var POPOVER_DIST = 5;
    var hint = context.options.hint || [];
    var direction = context.options.hintDirection || 'bottom';
    var hints = $.isArray(hint) ? hint : [hint];

    this.events = {
      'summernote.keyup': function (we, e) {
        if (!e.isDefaultPrevented()) {
          self.handleKeyup(e);
        }
      },
      'summernote.keydown': function (we, e) {
        self.handleKeydown(e);
      },
      'summernote.disable summernote.dialog.shown': function () {
        self.hide();
      }
    };

    this.shouldInitialize = function () {
      return hints.length > 0;
    };

    this.initialize = function () {
      this.lastWordRange = null;
      this.$popover = ui.popover({
        className: 'note-hint-popover',
        hideArrow: true,
        direction: ''
      }).render().appendTo('body');

      this.$popover.hide();

      this.$content = this.$popover.find('.popover-content');

      this.$content.on('click', '.note-hint-item', function () {
        self.$content.find('.active').removeClass('active');
        $(this).addClass('active');
        self.replace();
      });
    };

    this.destroy = function () {
      this.$popover.remove();
    };

    this.selectItem = function ($item) {
      this.$content.find('.active').removeClass('active');
      $item.addClass('active');

      this.$content[0].scrollTop = $item[0].offsetTop - (this.$content.innerHeight() / 2);
    };

    this.moveDown = function () {
      var $current = this.$content.find('.note-hint-item.active');
      var $next = $current.next();

      if ($next.length) {
        this.selectItem($next);
      } else {
        var $nextGroup = $current.parent().next();

        if (!$nextGroup.length) {
          $nextGroup = this.$content.find('.note-hint-group').first();
        }

        this.selectItem($nextGroup.find('.note-hint-item').first());
      }
    };

    this.moveUp = function () {
      var $current = this.$content.find('.note-hint-item.active');
      var $prev = $current.prev();

      if ($prev.length) {
        this.selectItem($prev);
      } else {
        var $prevGroup = $current.parent().prev();

        if (!$prevGroup.length) {
          $prevGroup = this.$content.find('.note-hint-group').last();
        }

        this.selectItem($prevGroup.find('.note-hint-item').last());
      }
    };

    this.replace = function () {
      var $item = this.$content.find('.note-hint-item.active');

      if ($item.length) {
        var node = this.nodeFromItem($item);
        // XXX: consider to move codes to editor for recording redo/undo.
        this.lastWordRange.insertNode(node);
        range.createFromNode(node).collapse().select();

        this.lastWordRange = null;
        this.hide();
        context.triggerEvent('change', context.layoutInfo.editable.html(), context.layoutInfo.editable);
        context.invoke('editor.focus');
      }

    };

    this.nodeFromItem = function ($item) {
      var hint = hints[$item.data('index')];
      var item = $item.data('item');
      var node = hint.content ? hint.content(item) : item;
      if (typeof node === 'string') {
        node = dom.createText(node);
      }
      return node;
    };

    this.createItemTemplates = function (hintIdx, items) {
      var hint = hints[hintIdx];
      return items.map(function (item, idx) {
        var $item = $('<div class="note-hint-item"/>');
        $item.append(hint.template ? hint.template(item) : item + '');
        $item.data({
          'index': hintIdx,
          'item': item
        });

        if (hintIdx === 0 && idx === 0) {
          $item.addClass('active');
        }
        return $item;
      });
    };

    this.handleKeydown = function (e) {
      if (!this.$popover.is(':visible')) {
        return;
      }

      if (e.keyCode === key.code.ENTER) {
        e.preventDefault();
        this.replace();
      } else if (e.keyCode === key.code.UP) {
        e.preventDefault();
        this.moveUp();
      } else if (e.keyCode === key.code.DOWN) {
        e.preventDefault();
        this.moveDown();
      }
    };

    this.searchKeyword = function (index, keyword, callback) {
      var hint = hints[index];
      if (hint && hint.match.test(keyword) && hint.search) {
        var matches = hint.match.exec(keyword);
        hint.search(matches[1], callback);
      } else {
        callback();
      }
    };

    this.createGroup = function (idx, keyword) {
      var $group = $('<div class="note-hint-group note-hint-group-' + idx + '"/>');
      this.searchKeyword(idx, keyword, function (items) {
        items = items || [];
        if (items.length) {
          $group.html(self.createItemTemplates(idx, items));
          self.show();
        }
      });

      return $group;
    };

    this.handleKeyup = function (e) {
      if (list.contains([key.code.ENTER, key.code.UP, key.code.DOWN], e.keyCode)) {
        if (e.keyCode === key.code.ENTER) {
          if (this.$popover.is(':visible')) {
            return;
          }
        }
      } else {
        var wordRange = context.invoke('editor.createRange').getWordRange();
        var keyword = wordRange.toString();
        if (hints.length && keyword) {
          this.$content.empty();

          var bnd = func.rect2bnd(list.last(wordRange.getClientRects()));
          if (bnd) {

            this.$popover.hide();

            this.lastWordRange = wordRange;

            hints.forEach(function (hint, idx) {
              if (hint.match.test(keyword)) {
                self.createGroup(idx, keyword).appendTo(self.$content);
              }
            });

            // set position for popover after group is created
            if (direction === 'top') {
              this.$popover.css({
                left: bnd.left,
                top: bnd.top - this.$popover.outerHeight() - POPOVER_DIST
              });
            } else {
              this.$popover.css({
                left: bnd.left,
                top: bnd.top + bnd.height + POPOVER_DIST
              });
            }

          }
        } else {
          this.hide();
        }
      }
    };

    this.show = function () {
      this.$popover.show();
    };

    this.hide = function () {
      this.$popover.hide();
    };
  };


  $.summernote = $.extend($.summernote, {
    version: '0.8.7',
    ui: ui,
    dom: dom,

    plugins: {},

    options: {
      modules: {
        'editor': Editor,
        'clipboard': Clipboard,
        'dropzone': Dropzone,
        'codeview': Codeview,
        'statusbar': Statusbar,
        'fullscreen': Fullscreen,
        'handle': Handle,
        // FIXME: HintPopover must be front of autolink
        //  - Script error about range when Enter key is pressed on hint popover
        'hintPopover': HintPopover,
        'autoLink': AutoLink,
        'autoSync': AutoSync,
        'placeholder': Placeholder,
        'buttons': Buttons,
        'toolbar': Toolbar,
        'linkDialog': LinkDialog,
        'linkPopover': LinkPopover,
        'imageDialog': ImageDialog,
        'imagePopover': ImagePopover,
        'tablePopover': TablePopover,
        'videoDialog': VideoDialog,
        'helpDialog': HelpDialog,
        'airPopover': AirPopover
      },

      buttons: {},

      lang: 'en-US',

      // toolbar
      toolbar: [
        ['style', ['style']],
        ['font', ['bold', 'underline', 'clear']],
        ['fontname', ['fontname']],
        ['color', ['color']],
        ['para', ['ul', 'ol', 'paragraph']],
        ['table', ['table']],
        ['insert', ['link', 'picture', 'video']],
        ['view', ['fullscreen', 'codeview', 'help']]
      ],

      // popover
      popover: {
        image: [
          ['imagesize', ['imageSize100', 'imageSize50', 'imageSize25']],
          ['float', ['floatLeft', 'floatRight', 'floatNone']],
          ['remove', ['removeMedia']]
        ],
        link: [
          ['link', ['linkDialogShow', 'unlink']]
        ],
        table: [
          ['add', ['addRowDown', 'addRowUp', 'addColLeft', 'addColRight']],
          ['delete', ['deleteRow', 'deleteCol', 'deleteTable']]
        ],
        air: [
          ['color', ['color']],
          ['font', ['bold', 'underline', 'clear']],
          ['para', ['ul', 'paragraph']],
          ['table', ['table']],
          ['insert', ['link', 'picture']]
        ]
      },

      // air mode: inline editor
      airMode: false,

      width: null,
      height: null,
      linkTargetBlank: true,

      focus: false,
      tabSize: 4,
      styleWithSpan: true,
      shortcuts: true,
      textareaAutoSync: true,
      direction: null,
      tooltip: 'auto',

      styleTags: ['p', 'blockquote', 'pre', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6'],

      fontNames: [
        'Arial', 'Arial Black', 'Comic Sans MS', 'Courier New',
        'Helvetica Neue', 'Helvetica', 'Impact', 'Lucida Grande',
        'Tahoma', 'Times New Roman', 'Verdana'
      ],

      fontSizes: ['8', '9', '10', '11', '12', '14', '18', '24', '36'],

      // pallete colors(n x n)
      colors: [
        ['#000000', '#424242', '#636363', '#9C9C94', '#CEC6CE', '#EFEFEF', '#F7F7F7', '#FFFFFF'],
        ['#FF0000', '#FF9C00', '#FFFF00', '#00FF00', '#00FFFF', '#0000FF', '#9C00FF', '#FF00FF'],
        ['#F7C6CE', '#FFE7CE', '#FFEFC6', '#D6EFD6', '#CEDEE7', '#CEE7F7', '#D6D6E7', '#E7D6DE'],
        ['#E79C9C', '#FFC69C', '#FFE79C', '#B5D6A5', '#A5C6CE', '#9CC6EF', '#B5A5D6', '#D6A5BD'],
        ['#E76363', '#F7AD6B', '#FFD663', '#94BD7B', '#73A5AD', '#6BADDE', '#8C7BC6', '#C67BA5'],
        ['#CE0000', '#E79439', '#EFC631', '#6BA54A', '#4A7B8C', '#3984C6', '#634AA5', '#A54A7B'],
        ['#9C0000', '#B56308', '#BD9400', '#397B21', '#104A5A', '#085294', '#311873', '#731842'],
        ['#630000', '#7B3900', '#846300', '#295218', '#083139', '#003163', '#21104A', '#4A1031']
      ],

      lineHeights: ['1.0', '1.2', '1.4', '1.5', '1.6', '1.8', '2.0', '3.0'],

      tableClassName: 'table table-bordered',

      insertTableMaxSize: {
        col: 10,
        row: 10
      },

      dialogsInBody: false,
      dialogsFade: false,

      maximumImageFileSize: null,

      callbacks: {
        onInit: null,
        onFocus: null,
        onBlur: null,
        onEnter: null,
        onKeyup: null,
        onKeydown: null,
        onImageUpload: null,
        onImageUploadError: null
      },

      codemirror: {
        mode: 'text/html',
        htmlMode: true,
        lineNumbers: true
      },

      keyMap: {
        pc: {
          'ENTER': 'insertParagraph',
          'CTRL+Z': 'undo',
          'CTRL+Y': 'redo',
          'TAB': 'tab',
          'SHIFT+TAB': 'untab',
          'CTRL+B': 'bold',
          'CTRL+I': 'italic',
          'CTRL+U': 'underline',
          'CTRL+SHIFT+S': 'strikethrough',
          'CTRL+BACKSLASH': 'removeFormat',
          'CTRL+SHIFT+L': 'justifyLeft',
          'CTRL+SHIFT+E': 'justifyCenter',
          'CTRL+SHIFT+R': 'justifyRight',
          'CTRL+SHIFT+J': 'justifyFull',
          'CTRL+SHIFT+NUM7': 'insertUnorderedList',
          'CTRL+SHIFT+NUM8': 'insertOrderedList',
          'CTRL+LEFTBRACKET': 'outdent',
          'CTRL+RIGHTBRACKET': 'indent',
          'CTRL+NUM0': 'formatPara',
          'CTRL+NUM1': 'formatH1',
          'CTRL+NUM2': 'formatH2',
          'CTRL+NUM3': 'formatH3',
          'CTRL+NUM4': 'formatH4',
          'CTRL+NUM5': 'formatH5',
          'CTRL+NUM6': 'formatH6',
          'CTRL+ENTER': 'insertHorizontalRule',
          'CTRL+K': 'linkDialog.show'
        },

        mac: {
          'ENTER': 'insertParagraph',
          'CMD+Z': 'undo',
          'CMD+SHIFT+Z': 'redo',
          'TAB': 'tab',
          'SHIFT+TAB': 'untab',
          'CMD+B': 'bold',
          'CMD+I': 'italic',
          'CMD+U': 'underline',
          'CMD+SHIFT+S': 'strikethrough',
          'CMD+BACKSLASH': 'removeFormat',
          'CMD+SHIFT+L': 'justifyLeft',
          'CMD+SHIFT+E': 'justifyCenter',
          'CMD+SHIFT+R': 'justifyRight',
          'CMD+SHIFT+J': 'justifyFull',
          'CMD+SHIFT+NUM7': 'insertUnorderedList',
          'CMD+SHIFT+NUM8': 'insertOrderedList',
          'CMD+LEFTBRACKET': 'outdent',
          'CMD+RIGHTBRACKET': 'indent',
          'CMD+NUM0': 'formatPara',
          'CMD+NUM1': 'formatH1',
          'CMD+NUM2': 'formatH2',
          'CMD+NUM3': 'formatH3',
          'CMD+NUM4': 'formatH4',
          'CMD+NUM5': 'formatH5',
          'CMD+NUM6': 'formatH6',
          'CMD+ENTER': 'insertHorizontalRule',
          'CMD+K': 'linkDialog.show'
        }
      },
      icons: {
        'align': 'note-icon-align',
        'alignCenter': 'note-icon-align-center',
        'alignJustify': 'note-icon-align-justify',
        'alignLeft': 'note-icon-align-left',
        'alignRight': 'note-icon-align-right',
        'rowBelow': 'note-icon-row-below',
        'colBefore': 'note-icon-col-before',
        'colAfter': 'note-icon-col-after',
        'rowAbove': 'note-icon-row-above',
        'rowRemove': 'note-icon-row-remove',
        'colRemove': 'note-icon-col-remove',
        'indent': 'note-icon-align-indent',
        'outdent': 'note-icon-align-outdent',
        'arrowsAlt': 'note-icon-arrows-alt',
        'bold': 'note-icon-bold',
        'caret': 'note-icon-caret',
        'circle': 'note-icon-circle',
        'close': 'note-icon-close',
        'code': 'note-icon-code',
        'eraser': 'note-icon-eraser',
        'font': 'note-icon-font',
        'frame': 'note-icon-frame',
        'italic': 'note-icon-italic',
        'link': 'note-icon-link',
        'unlink': 'note-icon-chain-broken',
        'magic': 'note-icon-magic',
        'menuCheck': 'note-icon-check',
        'minus': 'note-icon-minus',
        'orderedlist': 'note-icon-orderedlist',
        'pencil': 'note-icon-pencil',
        'picture': 'note-icon-picture',
        'question': 'note-icon-question',
        'redo': 'note-icon-redo',
        'square': 'note-icon-square',
        'strikethrough': 'note-icon-strikethrough',
        'subscript': 'note-icon-subscript',
        'superscript': 'note-icon-superscript',
        'table': 'note-icon-table',
        'textHeight': 'note-icon-text-height',
        'trash': 'note-icon-trash',
        'underline': 'note-icon-underline',
        'undo': 'note-icon-undo',
        'unorderedlist': 'note-icon-unorderedlist',
        'video': 'note-icon-video'
      }
    }
  });

}));


// FILE: src/lib/02.summernote-pt-BR.js
(function ($) {
  $.extend($.summernote.lang, {
    'pt-BR': {
      font: {
        bold: 'Negrito',
        italic: 'Itálico',
        underline: 'Sublinhado',
        clear: 'Remover estilo da fonte',
        height: 'Altura da linha',
        name: 'Fonte',
        strikethrough: 'Riscado',
        size: 'Tamanho da fonte'
      },
      image: {
        image: 'Imagem',
        insert: 'Inserir imagem',
        resizeFull: 'Redimensionar Completamente',
        resizeHalf: 'Redimensionar pela Metade',
        resizeQuarter: 'Redimensionar um Quarto',
        floatLeft: 'Flutuar para Esquerda',
        floatRight: 'Flutuar para Direira',
        floatNone: 'Não Flutuar',
        dragImageHere: 'Arraste uma imagem para cá',
        selectFromFiles: 'Selecione a partir dos arquivos',
        url: 'URL da imagem'
      },
      video: {
        video: 'Vídeo',
        videoLink: 'Link para vídeo',
        insert: 'Inserir vídeo',
        url: 'URL do vídeo?',
        providers: '(YouTube, Vimeo, Vine, Instagram, DailyMotion ou Youku)'
      },
      link: {
        link: 'Link',
        insert: 'Inserir link',
        unlink: 'Remover link',
        edit: 'Editar',
        textToDisplay: 'Texto para exibir',
        url: 'Para qual URL esse link leva?',
        openInNewWindow: 'Abrir em uma nova janela'
      },
      table: {
        table: 'Tabela',
        addRowAbove: 'Adicionar linha acima',
        addRowBelow: 'Adicionar linha abaixo',
        addColLeft: 'Adicionar coluna a esquerda',
        addColRight: 'Adicionar coluna a direita',
        delRow: 'Excluir linha',
        delCol: 'Excluir coluna'
      },
      hr: {
        insert: 'Inserir linha horizontal'
      },
      style: {
        style: 'Estilo',
        normal: 'Normal',
        blockquote: 'Citação',
        pre: 'Código',
        h1: 'Título 1',
        h2: 'Título 2',
        h3: 'Título 3',
        h4: 'Título 4',
        h5: 'Título 5',
        h6: 'Título 6'
      },
      lists: {
        unordered: 'Lista com marcadores',
        ordered: 'Lista numerada'
      },
      options: {
        help: 'Ajuda',
        fullscreen: 'Tela cheia',
        codeview: 'Ver código-fonte'
      },
      paragraph: {
        paragraph: 'Parágrafo',
        outdent: 'Menor tabulação',
        indent: 'Maior tabulação',
        left: 'Alinhar à esquerda',
        center: 'Alinhar ao centro',
        right: 'Alinha à direita',
        justify: 'Justificado'
      },
      color: {
        recent: 'Cor recente',
        more: 'Mais cores',
        background: 'Fundo',
        foreground: 'Fonte',
        transparent: 'Transparente',
        setTransparent: 'Fundo transparente',
        reset: 'Restaurar',
        resetToDefault: 'Restaurar padrão'
      },
      shortcut: {
        shortcuts: 'Atalhos do teclado',
        close: 'Fechar',
        textFormatting: 'Formatação de texto',
        action: 'Ação',
        paragraphFormatting: 'Formatação de parágrafo',
        documentStyle: 'Estilo de documento'
      },
      history: {
        undo: 'Desfazer',
        redo: 'Refazer'
      },
      help: {
        'insertParagraph': 'Inserir Parágrafo',
        'undo': 'Desfazer o último comando',
        'redo': 'Refazer o último comando',
        'tab': 'Tab',
        'untab': 'Desfazer tab',
        'bold': 'Colocar em negrito',
        'italic': 'Colocar em itálico',
        'underline': 'Sublinhado',
        'strikethrough': 'Tachado',
        'removeFormat': 'Remover estilo',
        'justifyLeft': 'Alinhar à esquerda',
        'justifyCenter': 'Centralizar',
        'justifyRight': 'Alinhar à esquerda',
        'justifyFull': 'Justificar',
        'insertUnorderedList': 'Lista não ordenada',
        'insertOrderedList': 'Lista ordenada',
        'outdent': 'Recuar parágrafo atual',
        'indent': 'Avançar parágrafo atual',
        'formatPara': 'Alterar formato do bloco para parágrafo(tag P)',
        'formatH1': 'Alterar formato do bloco para H1',
        'formatH2': 'Alterar formato do bloco para H2',
        'formatH3': 'Alterar formato do bloco para H3',
        'formatH4': 'Alterar formato do bloco para H4',
        'formatH5': 'Alterar formato do bloco para H5',
        'formatH6': 'Alterar formato do bloco para H6',
        'insertHorizontalRule': 'Inserir régua horizontal',
        'linkDialog.show': 'Inserir um Hiperlink'
      }
    }
  });
})(jQuery);


// FILE: src/lib/03.angular-summernote.js
/*  angular-summernote v0.8.1 | (c) 2016 JeongHoon Byun | MIT license */
/* global angular */
angular.module('summernote', [])

  .controller('SummernoteController', ['$scope', '$attrs', '$timeout', function($scope, $attrs, $timeout) {
    'use strict';

    var currentElement,
        summernoteConfig = angular.copy($scope.summernoteConfig) || {};

    if (angular.isDefined($attrs.height)) { summernoteConfig.height = +$attrs.height; }
    if (angular.isDefined($attrs.minHeight)) { summernoteConfig.minHeight = +$attrs.minHeight; }
    if (angular.isDefined($attrs.maxHeight)) { summernoteConfig.maxHeight = +$attrs.maxHeight; }
    if (angular.isDefined($attrs.placeholder)) { summernoteConfig.placeholder = $attrs.placeholder; }
    if (angular.isDefined($attrs.focus)) { summernoteConfig.focus = true; }
    if (angular.isDefined($attrs.airmode)) { summernoteConfig.airMode = true; }
    if (angular.isDefined($attrs.lang)) {
      if (!angular.isDefined($.summernote.lang[$attrs.lang])) {
        throw new Error('"' + $attrs.lang + '" lang file must be exist.');
      }
      summernoteConfig.lang = $attrs.lang;
    }

    summernoteConfig.callbacks = summernoteConfig.callbacks || {};

    if (angular.isDefined($attrs.onInit)) {
      summernoteConfig.callbacks.onInit = function(evt) {
        $scope.init({evt:evt});
      };
    }
    if (angular.isDefined($attrs.onEnter)) {
      summernoteConfig.callbacks.onEnter = function(evt) {
        $scope.enter({evt:evt});
      };
    }
    if (angular.isDefined($attrs.onFocus)) {
      summernoteConfig.callbacks.onFocus = function(evt) {
        $scope.focus({evt:evt});
      };
    }
    if (angular.isDefined($attrs.onPaste)) {
      summernoteConfig.callbacks.onPaste = function(evt) {
        $scope.paste({evt:evt});
      };
    }
    if (angular.isDefined($attrs.onKeyup)) {
      summernoteConfig.callbacks.onKeyup = function(evt) {
        $scope.keyup({evt:evt});
      };
    }
    if (angular.isDefined($attrs.onKeydown)) {
      summernoteConfig.callbacks.onKeydown = function(evt) {
        $scope.keydown({evt:evt});
      };
    }
    if (angular.isDefined($attrs.onImageUpload)) {
      summernoteConfig.callbacks.onImageUpload = function(files) {
        $scope.imageUpload({files:files, editable: $scope.editable});
      };
    }
    if (angular.isDefined($attrs.onMediaDelete)) {
      summernoteConfig.callbacks.onMediaDelete = function(target) {
        // make new object that has information of target to avoid error:isecdom
        var removedMedia = {attrs: {}};
        removedMedia.tagName = target[0].tagName;
        angular.forEach(target[0].attributes, function(attr) {
          removedMedia.attrs[attr.name] = attr.value;
        });
        $scope.mediaDelete({target: removedMedia});
      };
    }

    this.activate = function(scope, element, ngModel) {
      var updateNgModel = function() {
        var newValue = element.summernote('code');
        if (element.summernote('isEmpty')) { newValue = ''; }
        if (ngModel && ngModel.$viewValue !== newValue) {
          $timeout(function() {
            ngModel.$setViewValue(newValue);
          }, 0);
        }
      };

      var originalOnChange = summernoteConfig.callbacks.onChange;
      summernoteConfig.callbacks.onChange = function (contents) {
        $timeout(function () {
          if (element.summernote('isEmpty')) {
            contents = '';
          }
          updateNgModel();
        }, 0);
        if (angular.isDefined($attrs.onChange)) {
          $scope.change({contents: contents, editable: $scope.editable});
        } else if (angular.isFunction(originalOnChange)) {
          originalOnChange.apply(this, arguments);
        }
      };
      if (angular.isDefined($attrs.onBlur)) {
        summernoteConfig.callbacks.onBlur = function (evt) {
          (!summernoteConfig.airMode) && element.blur();
          $scope.blur({evt: evt});
        };
      }
      element.summernote(summernoteConfig);

      var editor$ = element.next('.note-editor'),
          unwatchNgModel;
      editor$.find('.note-toolbar').click(function() {
        updateNgModel();

        // sync ngModel in codeview mode
        if (editor$.hasClass('codeview')) {
          editor$.on('keyup', updateNgModel);
          if (ngModel) {
            unwatchNgModel = scope.$watch(function () {
              return ngModel.$modelValue;
            }, function(newValue) {
              editor$.find('.note-codable').val(newValue);
            });
          }
        } else {
          editor$.off('keyup', updateNgModel);
          if (angular.isFunction(unwatchNgModel)) {
            unwatchNgModel();
          }
        }
      });

      if (ngModel) {
        var _sanitize = function(objectHtml){
          return objectHtml ? richTextSanitize(objectHtml) : objectHtml;
        };
        ngModel.$render = function() {
          if (ngModel.$viewValue) {
            element.summernote('code', _sanitize(ngModel.$viewValue));
          } else {
            element.summernote('empty');
          }
        };
      }

      // set editable to avoid error:isecdom since Angular v1.3
      if (angular.isDefined($attrs.editable)) {
        $scope.editable = editor$.find('.note-editable');
      }
      if (angular.isDefined($attrs.editor)) {
        $scope.editor = element;
      }

      currentElement = element;
      // use jquery Event binding instead $on('$destroy') to preserve options data of DOM
      element.on('$destroy', function() {
        element.summernote('destroy');
        $scope.summernoteDestroyed = true;
      });
    };

    $scope.$on('$destroy', function () {
      // when destroying scope directly
      if (!$scope.summernoteDestroyed) {
        currentElement.summernote('destroy');
      }
    });
  }])
  .directive('summernote', [function() {
    'use strict';

    return {
      restrict: 'EA',
      transclude: 'element',
      replace: true,
      require: ['summernote', '?ngModel'],
      controller: 'SummernoteController',
      scope: {
        summernoteConfig: '=config',
        editable: '=',
        editor: '=',
        init: '&onInit',
        enter: '&onEnter',
        focus: '&onFocus',
        blur: '&onBlur',
        paste: '&onPaste',
        keyup: '&onKeyup',
        keydown: '&onKeydown',
        change: '&onChange',
        imageUpload: '&onImageUpload',
        mediaDelete: '&onMediaDelete'
      },
      template: '<div class="summernote"></div>',
      link: function(scope, element, attrs, ctrls, transclude) {
        var summernoteController = ctrls[0],
          ngModel = ctrls[1];
        var _sanitize = function(objectHtml){
          return objectHtml ? richTextSanitize(objectHtml) : objectHtml;
        };

          if (!ngModel) {
            transclude(scope, function(clone, scope) {
              // to prevent binding to angular scope (It require `tranclude: 'element'`)
              element.append(_sanitize(clone.html()));
            });
            summernoteController.activate(scope, element, ngModel);
          } else {
            var clearWatch = scope.$watch(function() {return ngModel.$viewValue; }, function(value) {
              clearWatch();
              element.append(_sanitize(value));
              summernoteController.activate(scope, element, ngModel);
            }, true);
          }
      }
    };
  }]);


// FILE: src/config/config.js
(function () {

	var ZeedhiApp = angular.module("ZeedhiApp");

	window.templateUrls = window.templateUrls || [];
	var packageName = 'zh-rich-text';

	var hasPackageRegistered = window.templateUrls.some(function (templateUrl) {
		return templateUrl.package === packageName;
	});

	if (!hasPackageRegistered) {
		window.templateUrls.push({
			'package': packageName,
			'baseUrl': './bower_components/' + packageName + '/dist/templates/'
		});
	}

	// add summernote dependemcy to ZeedhiApp
	ZeedhiApp.requires.push('summernote');

})();

// FILE: src/controllers/ZhRichTextController.js
var ZhRichTextController = function($scope) {
	var self = this;
	var field = $scope.field;

	var toolbarDefaultOptions = {
		undo: true,
		redo: true,
		bold: true,
		italic: true,
		underline: true,
		superscript: true,
		subscript: true,
		strikethrough: true,
		clear: true,
		fontname: true,
		fontsize: true,
		color: true,
		ul: true,
		ol: true,
		paragraph: true,
		lineheight: true,
		table: true,
		picture: true,
		codeview: false
	};

	toolbarDefaultOptions = $.extend(toolbarDefaultOptions, field.toolbar || {});

	$scope.editorOptions = {
		height: field.height,
		dialogsInBody: true,
		lang: 'pt-BR',
		toolbar: [
			['edit',['undo','redo']],
			['style', ['bold', 'italic', 'underline', 'superscript', 'subscript', 'strikethrough', 'clear']],
			['fontface', ['fontname']],
			['textsize', ['fontsize']],
			['fontclr', ['color']],
			['alignment', ['ul', 'ol', 'paragraph', 'lineheight']],
			['table', ['table']],
			['insert', ['picture']],
			['view', ['codeview']]
		],
		callbacks:{
			onInit: function() {
				$scope.onInitElement();
			},
			onChange: function() {
				if(arguments[0] !=='<p><span style="font-size: 14px;">﻿</span><br></p>'){
					$scope.onInitElement(arguments);
				}
			}
		}
	};

	$scope.getLabelToRichText = function(field){
		return field.help ? this.templateManager.getTemplateURL('field/label-with-tooltip.html') :
				this.templateManager.getTemplateURL('field/label-static.html');
	};

	Object.keys(toolbarDefaultOptions).forEach(function(key) {
		if (toolbarDefaultOptions[key] === false) {
			$scope.editorOptions.toolbar.forEach(function(group, index) {
				var groupButtons = group[1];
				var buttonIdx = groupButtons.indexOf(key);
				if (buttonIdx > -1) {
					groupButtons.splice(buttonIdx, 1);
				}
				if (groupButtons.length === 0) {
					$scope.editorOptions.toolbar.splice(index, 1);
				}
			});
		}
	});
};

ZeedhiController.controller('ZhRichTextController', ZhRichTextController);

// FILE: src/directives/ZhRichTextDirective.js
(function () {
	var ZeedhiDirectives = angular.module('ZeedhiDirectives');
	ZeedhiDirectives.directive('zhRichText', zhRichText);

	function zhRichText(templateManager, ZHPromise, $timeout) {
		return {
			restrict: 'A',
			require: '?ngModel',
			link: function(scope, element, attrs, controller) {
				function isEmptyText(text) {
					return text === "" || text == "<br>" || text == "<p><br></p>";
				}

				function setCursorPositionToEnd(node) {
					node.focus();
					var textNode = node.firstChild;
					var range = document.createRange();
					range.setStart(textNode, 1);
					range.setEnd(textNode, 1);
					var sel = window.getSelection();
					sel.removeAllRanges();
					sel.addRange(range);
				}

				scope.onInitElement = function() {
					if (isEmptyText(element.summernote('code'))) {
						var context = element.data('summernote');
						if (context && scope.field) {
							context.invoke('editor.fontSize', scope.field.defaultFontSize || 14);
							context.invoke('editor.fontName', scope.field.defaultFontName || "Arial");
							context.invoke('buttons.updateCurrentStyle');
						}
					} else {
						var editor = element.next().find('.note-editable')[0];
						var bogusCharPosition = editor.innerHTML.indexOf('\ufeff');
						if (bogusCharPosition !== -1) {
							editor.innerHTML = editor.innerHTML.slice(0,bogusCharPosition) + editor.innerHTML.slice(bogusCharPosition+1);

							setCursorPositionToEnd(editor);
						}
					}
				};

				if (controller) {
					controller.$parsers.unshift(function(value) {
						value = value.replace(/[\ufeff]/g,'').replace(/<p>/g,"<div>").replace(/<p /g,"<div ").replace(/<\/p>/g,"</div>");
						return value;
					});
				}
			}
		};
	}
})();

// FILE: src/registers/zhRichTextRegister.js
(function () {

	Configuration(registerRichTextDecoders);

	function registerRichTextDecoders(DecodeValueFieldService, decodeTemplateFieldService, $sce) {
		decodeTemplateFieldService.registerViewTemplate(
			"zh-rich-text#field/rich-text.html",
			"zh-rich-text#field/rich-text-view.html"
		);

		DecodeValueFieldService.register(
			"rich-text.html",
			richTextValueDecoder($sce)
		);
	}

	function richTextValueDecoder($sce) {
		return function (field, fieldRow) {
			return $sce.trustAsHtml(richTextSanitize(fieldRow));
		};
	}

})();

// FILE: ./bower_components/zh-image-uploader/dist/zh-image-uploader.js

// FILE: src/config/config.js
window.templateUrls = window.templateUrls || [];
var packageName = 'zh-image-uploader';

var hasPackageRegistered = window.templateUrls.some(function(templateUrl){
	return templateUrl.package === packageName;
});

if(!hasPackageRegistered){
	window.templateUrls.push({
		'package': packageName,
		'baseUrl': './bower_components/' + packageName + '/dist/templates/'
	});
}

// FILE: src/controllers/ImageUploaderController.js
var ImageUploaderController = function($scope, templateManager, ScreenService) {

	var self = this;

	var widgetAccessorDescriptor = {
		get: function() {
			return $scope.widget;
		}
	};

	var fieldAcessosDescriptor = {
		get: function() {
			return $scope.field;
		}
	};

	Object.defineProperty(self, "widget", widgetAccessorDescriptor);
	Object.defineProperty(self, "field", fieldAcessosDescriptor);

	/***************************************************
	 * Functions used by template
	 ***************************************************/
	this.getChooseFileText = function() {
		return self.field.chooseFileText || ScreenService.i18n("Choose a file...");
	};

	this.getNoFileSelectedText = function() {
		var currentFieldRow = self.widget.currentRow[self.field.name];
		if (currentFieldRow && (typeof(currentFieldRow) === 'object')) {
			self.field.noFileSelectedText = currentFieldRow[0].name;
		} else if (currentFieldRow) {
			self.field.noFileSelectedText = currentFieldRow;
		} else {
			self.field.noFileSelectedText = ScreenService.i18n("No file selected.");
		}
		return self.field.noFileSelectedText || ScreenService.i18n("No file selected.");
	};

	this.getCurrentThumbnail = function() {
		var currentFieldRow = self.widget.currentRow[self.field.name];
		var currentThumbnail = "//:0";
		if (typeof currentFieldRow === "string") {
			var root = templateManager.project.fileServiceBaseUrl || "";
			currentThumbnail = root + currentFieldRow;
		} else if (Array.isArray(currentFieldRow) && currentFieldRow.length > 0) {
			currentThumbnail = currentFieldRow[0].b64File;
		}

		return currentThumbnail;
	};

	this.getCurrentThumbnailStringify = function(){
		return JSON.stringify(self.getCurrentThumbnail());
	};

	this.isVisibleInCurrentFormTemplate = function() {};

	this.isEditMode = function() {
		return self.widget.mode === 'edit';
	};

	function clearCurrentRow() {
		self.widget.currentRow[self.field.name] = '';
		_callChangeEvent();
		_callAfterDeselectFileEvent();
	}

	this.clearImage = function(file) {

		if (file) {
			clearCurrentRow();

			file.name = ScreenService.i18n("No file selected.");
			return file.name;
		}

		clearCurrentRow();

		self.field.noFileSelectedText = ScreenService.i18n("No file selected.");
		return self.field.noFileSelectedText;
	};

	function _callChangeEvent() {
		if (self.field.change) {
			self.field.change();
		}
	}

	function _callAfterDeselectFileEvent() {
		if (self.field.afterDeselectFile) {
			self.field.afterDeselectFile();
		}
	}
};

ZeedhiController.controller('ImageUploaderController', ImageUploaderController);

// FILE: src/directives/ImageUploaderDirective.js
(function() {
	var ZeedhiDirectives = angular.module('ZeedhiDirectives');
	ZeedhiDirectives.directive('zhImageUploader', zhImageUploader);

	function zhImageUploader(templateManager, ZHPromise) {

		var linkFunction = function(scope, element, attrs) {
			var container = element.parent();
			var field = scope.field;
			var widget = field.widget;
			var filesPromises = [];

			field.fileList = [];
			element.shouldNotPreventDefaultOnClick = true;
			element.parent().find("ul").nonbounce();
			element.on('change', onFileSelected);

			var button = element.siblings('button');
			var input = element;

			button.on('click.file-upload touchstart.file-upload', function(e) {
				input.trigger(e.type);
			});

			function onFileSelected() {
				var files = this.files;

				if (files.length > 0) {
					_ensureCurrentRowPropertyExistence();
					_setCurrentRowAsChanged();
					_putFilesIntoPromises(files);
					_executeAllPromises();
				}

				this.value = "";
			}

			function _ensureCurrentRowPropertyExistence() {
				widget.currentRow = widget.currentRow || {};
				widget.currentRow[field.name] = widget.currentRow[field.name] || [];
			}

			function _setCurrentRowAsChanged() {
				widget.currentRow.changed = true;
			}

			function _putFilesIntoPromises(files) {
				for (var i in files) {
					if (files.hasOwnProperty(i) && files[i] instanceof File) {
						filesPromises.push(_buildFileData(files[i]));
					}
				}
			}

			function _buildFileData(file) {
				var deferred = ZHPromise.defer();
				var fileReader = new FileReader();

				fileReader.onload = function(event) {
					widget.currentRow[field.name] = [_addExtraDataToFile(file)];
					field.fileList = widget.currentRow[field.name];
					deferred.resolve();
				};

				fileReader.readAsDataURL(file);
				return deferred;
			}

			function _addExtraDataToFile(file) {
				// isso causa uma planificacao do objeto do tipo File o que resolve o problema do angular.copy e JSON.stringify
				return $.extend(false, {
					b64File: event.target.result
				}, file);
			}

			function _executeAllPromises() {
				ZHPromise.all(filesPromises)
					.then(function() {
						_callAfterSelectFileEvent();
						field.validate(field.value());
						templateManager.updateTemplate();
					});
			}

			function _callAfterSelectFileEvent() {
				if (field.afterSelectFile) {
					field.afterSelectFile();
				}
			}
		};

		return {
			restrict: 'A',
			link: linkFunction
		};
	}
})();

// FILE: src/registers/ImageUploaderRegister.js
function ImageUploaderRegister(DecodeValueFieldService, decodeTemplateFieldService){
    DecodeValueFieldService.registerType("zh-image-uploader#field/image-uploader.html", "image");

    decodeTemplateFieldService.registerViewTemplate(
            "zh-image-uploader#field/image-uploader.html",
            "zh-image-uploader#field/image-view.html"
        );
}

Configuration(function(ContextRegister){
    ContextRegister.register('ImageUploaderRegister', ImageUploaderRegister);
});

// FILE: ./bower_components/zh-interval-component/dist/zh-interval-component.js

// FILE: src/interval/config/config.js
window.templateUrls = window.templateUrls || [];
var packageName = 'zh-interval-component';

var hasPackageRegistered = window.templateUrls.some(function(templateUrl){
	return templateUrl.package === packageName;
});

if(!hasPackageRegistered){
	window.templateUrls.push({
		'package': packageName,
		'baseUrl': './bower_components/' + packageName + '/dist/templates/'
	});
}

// FILE: src/interval/registers/IntervalRegister.js
function IntervalRegister(DecodeValueFieldService, validateEngine, ScreenService) {
    var self = this;

    /**
     * DecodeValueField Register
     **/
    var DEFAULT_DISPLAY_FORMAT = 'YYYY-MM-DD';
    var DEFAULT_DATE_FORMAT = 'YYYY-MM-DD';

    self.decodeValueField = function(field, fieldRow) {
        var displayValue = "";
        var dateFormat = field.dateFormat || DEFAULT_DATE_FORMAT;
        var formattedDate = field.displayFormat || DEFAULT_DISPLAY_FORMAT;
        if(fieldRow){
            if (fieldRow.end || fieldRow.start || fieldRow.period) {
                var beginDate = fieldRow.start ? moment(fieldRow.start, dateFormat).format(formattedDate) : formattedDate.replace(/[a-z]/gi, '_');
                var endDate = fieldRow.end ? moment(fieldRow.end, dateFormat).format(formattedDate) : formattedDate.replace(/[a-z]/gi, '_');
                if (!fieldRow.period) {
                    displayValue = ScreenService.i18n("From ") + beginDate + ScreenService.i18n(" to ") + endDate;
                    return displayValue;
                } else {
                    var periodLabel = fieldRow.period.label;
                    displayValue = ScreenService.i18n("From ") + beginDate + ScreenService.i18n(" to ") + endDate + ' (' + periodLabel + ') ';
                    return displayValue;
                }

            }
        }

        return ScreenService.i18n("From ") + formattedDate.replace(/[a-z]/gi, '_') + ScreenService.i18n(" to ") + formattedDate.replace(/[a-z]/gi, '_');
    };

    DecodeValueFieldService.register("interval.html", self.decodeValueField);

    /**
     * ValidateEngine Register
     **/
    function required(value, validationAttrs) {
        return {
            "valid": requiredStart(value, validationAttrs).valid && requiredEnd(value, validationAttrs).valid,
            "message": ScreenService.i18n(validationAttrs.message) || ScreenService.i18n("Required field")
        };
    }

    function requiredStart(value, validationAttrs) {
        return buildRequiredMessage(value, validationAttrs, 'start');
    }

    function requiredEnd(value, validationAttrs) {
        return buildRequiredMessage(value, validationAttrs, 'end');
    }

    function buildRequiredMessage(value, validationAttrs, property) {
        return {
            "valid": value && Util.isObject(value) && !Util.isEmptyOrBlank(value[property]),
            "message": ScreenService.i18n(validationAttrs.message) || ScreenService.i18n('Required field')
        };
    }

    function completeInterval(value, validationAttrs) {
        var localValue = Util.isObject(value) ? value : {};
        return {
            "valid": Util.isEmptyOrBlank(localValue.start) ? Util.isEmptyOrBlank(localValue.end) : !Util.isEmptyOrBlank(localValue.end),
            "message": ScreenService.i18n(validationAttrs.message) || ScreenService.i18n('Incomplete interval')
        };
    }

    var registeredValidations = validateEngine.getMappedValidations();
    var validationsToRegister = {
        "requiredInterval": required,
        "requiredIntervalStart": requiredStart,
        "requiredIntervalEnd": requiredEnd,
        "completeInterval": completeInterval
    };

    for (var validationName in validationsToRegister) {
        if (!registeredValidations.hasOwnProperty(validationName)) {
            validateEngine.registerValidation(validationName, validationsToRegister[validationName]);
        }
    }
}

Configuration(IntervalRegister);

// FILE: src/interval/controllers/IntervalController.js
var IntervalController = function($scope, $rootScope, ZhUtil, ScreenService, metaDataFactory, eventEngine, templateManager) {
	var self = this;
	self.field = $scope.field;
	self.widget = $scope.widget;

	$scope.$root = $rootScope;

	/**
	 * Constant values
	 **/
	var DEFAULT_DISPLAY_FORMAT = moment().locale(window.lang).localeData().longDateFormat("L");
	var DEFAULT_DATE_FORMAT = moment().locale(window.lang).localeData().longDateFormat("L");
	var DEFAULT_START_LABEL = 'Begin on';
	var DEFAULT_END_LABEL = 'End on';
	var INCLUSIVE_SUFFIX = "inclusive";

	/**
	 * Initial values
	 **/
	var sourceElement = self.field || self.widget;
	$scope.dateFormat = sourceElement.dateFormat || DEFAULT_DATE_FORMAT;
	$scope.displayFormat = sourceElement.displayFormat || DEFAULT_DISPLAY_FORMAT;

	$scope.startLabel = ScreenService.i18n(sourceElement.startLabel || DEFAULT_START_LABEL);
	$scope.endLabel = ScreenService.i18n(sourceElement.endLabel || DEFAULT_END_LABEL);

	var emptyDefault = $scope.displayFormat.replace(/[Y,M,D]/gi, '_');

	if(!eventEngine.hasEvent("IntervalOnInvalidInput")){
		eventEngine.registerEvent("IntervalOnInvalidInput", "intervalOnInvalidInput");
	}

	function isStartField(fieldId){
		var startId = '_START';
		return fieldId.lastIndexOf(startId) + startId.length == fieldId.length;
	}

	function isEndField(fieldId){
		var endId = '_END';
		return fieldId.lastIndexOf(endId) + endId.length == fieldId.length;
	}

	$scope.fillCurrentRow = function(element){
		var dateString = element.value;
		if(element.id === self.field.name+"_END"){
			$scope.fieldRow.end = getValueByDisplayValue(dateString);
		} else {
			$scope.fieldRow.start = getValueByDisplayValue(dateString);
		}
		if(moment($scope.fieldRow.start, $scope.dateFormat)._d.getTime() > moment($scope.fieldRow.end, $scope.dateFormat)._d.getTime()){
			$scope.fieldRow.end = null;
			element.value = emptyDefault;

			if($scope.field.intervalOnInvalidInput){
				$scope.field.intervalOnInvalidInput();
			}
		}
	};

	function getDisplayValueByValue(value){
		var inDisplayFormat = moment(value, $scope.displayFormat, true).isValid();
		var displayValue = inDisplayFormat ? value : moment(value, $scope.dateFormat).format($scope.displayFormat);
		return displayValue;
	}

	function getValueByDisplayValue(displayValue){
		var inDateFormat = moment(displayValue, $scope.dateFormat, true).isValid();
		var value = inDateFormat ? displayValue : moment(displayValue, $scope.displayFormat).format($scope.dateFormat);
		return value;
	}

	function buildIntervals() {
		var fieldIntervals = self.field.intervals;
		var finalIntervals = [];

		//Set default Intervals
		if (fieldIntervals === undefined) {
			fieldIntervals = [{
				label: "Today",
				period: "today"
			}, {
				label: "Yesterday",
				period: "yesterday"
			}, {
				label: "Tomorrow",
				period: "tomorrow"
			}, {
				label: "This Week",
				period: "this-week"
			}, {
				label: "Last Week",
				period: "last-week"
			}, {
				label: "Next Week",
				period: "next-week"
			}, {
				label: "This Quarter",
				period: "this-quarter"
			}, {
				label: "Last Quarter",
				period: "last-quarter"
			}, {
				label: "Next Quarter",
				period: "next-quarter"
			}, {
				label: "This Month",
				period: "this-month"
			}, {
				label: "Last Month",
				period: "last-month"
			}, {
				label: "Next Month",
				period: "next-month"
			}, {
				label: "This Year",
				period: "this-year"
			}, {
				label: "Last Year",
				period: "last-year"
			}, {
				label: "Next Year",
				period: "next-year"
			}];
		}

		// Iterates in field periods to build each determined row
		if (Util.isArray(fieldIntervals)) {
			fieldIntervals.forEach(function(interval) {
				try {
					/**
					 *   @Note:
					 * - The customized flag is used to tell that such period was created by developer.
					 * - The personalized flag is used to tell that such period will be selected by the user because it's not in the period list.
					 */

					var row;

					// Evaluates possible custom intervals
					if (isCustomPeriod(interval.period)) {
						row = ZhUtil.evaluate(interval.period);
						row.customized = true;
					}
					else {
						row = buildObjectWithPeriodDetails(interval.period);
					}

					finalIntervals.push({
						"_period_label": interval.label,
						"_period": row,
						"_period_name": interval.period
					});
				}
				catch (e) {}
			});
		}

		return finalIntervals;
	}

	function isCustomPeriod(periodName) {
		return periodName[0] === '@';
	}

	function buildObjectWithPeriodDetails(word) {
		var decoded = decodeWordExpression(word);
		var buildIntervalMethod = (decoded.suffix === INCLUSIVE_SUFFIX) ? buildIntervalInclusive : buildInterval;
		return buildIntervalMethod(decoded.prefix, decoded.amount, decoded.unit);
	}

	function decodeWordExpression(word) {
		var exceptionWords = {
			'today': 'this-day',
			'yesterday': 'last-day',
			'tomorrow': 'next-day'
		};

		// Transform exception words due to function needs
		if (word in exceptionWords) {
			word = exceptionWords[word];
		}

		var prefix, amount, unit, suffix;
		var splitedString = word.split("-");

		if (splitedString.length === 2) {
			prefix = splitedString[0];
			unit = splitedString[1];
		}
		else if (splitedString.length > 2) {
			prefix = splitedString[0];
			amount = splitedString[1];
			unit = splitedString[2];
			suffix = splitedString[3];
		}
		else {
			throw "Used period has an incorrect format.";
		}

		return {
			prefix: prefix,
			amount: amount || 1,
			unit: unit,
			suffix: suffix
		};
	}

	function buildInterval(prefix, amount, unit) {
		var start = moment().startOf(unit),
			end = moment();
		switch (prefix) {
			case 'last':
				end.subtract(1, unit);
				start.subtract(amount, unit);
				break;
			case 'next':
				start.add(1, unit);
				end.add(amount, unit);
				break;
		}
		end.endOf(unit);
		return factoryInterval(start, end);
	}

	function buildIntervalInclusive(prefix, amount, unit) {
		var start = moment().startOf(unit),
			end = moment();
		switch (prefix) {
			case 'last':
				start.subtract(amount - 1, unit);
				break;
			case 'next':
				end.add(amount - 1, unit);
				break;
		}
		end.endOf(unit);
		return factoryInterval(start, end);
	}

	function factoryInterval(start, end) {
		return {
			"start": start.format($scope.dateFormat),
			"end": end.format($scope.dateFormat),
			"customized": false
		};
	}

	function clearInputValues(field, id){
		var parentElement = angular.element(field.element[0]);
		var element = parentElement.find('#' + id)[0];
		element.value = emptyDefault;
	}

	function clearInternalValues(field, id) {
		if(!self.field.isReadOnly()){
			var start = '';
			var end = '';
			var formattedStart = emptyDefault;
			var formattedEnd = emptyDefault;
			var intervalField = self.field;
			var parentWidget = intervalField.widget;

			if(id){
				if(isStartField(id)){
					end = $scope.fieldRow.end;
					formattedEnd = $scope.fieldRow.formattedEnd;
				} else if(isEndField(id)){
					start = $scope.fieldRow.start;
					formattedStart = $scope.fieldRow.formattedStart;
				}
				clearInputValues(field, id);
			}

			delete parentWidget.currentRow[intervalField.name];

			$scope.fieldRow = {
				start: start,
				end: end,
				formattedStart: formattedStart,
				formattedEnd: formattedEnd
			};

			intervalField.validate(intervalField.value());
			if(self.field.change){
				self.field.change();
			}

		}
	}

	function createIntervalWidget() {
		var actions = [{
			"label": ScreenService.i18n("Cancel"),
			"showAsAction": "back",
			"id": self.widget.id + "_cancel",
			"closeIntervalWidget": self.closeIntervalWidget,
			"isVisible": true,
			"events": [{
				"name": "ActionEvent",
				"code": "args.owner.closeIntervalWidget()"
			}]
		}, {
			"label": ScreenService.i18n("OK"),
			"showAsAction": "never",
			"id": self.widget.id + "_ok",
			"isVisible": true,
			"applyIntervalToWidgetRow": self.applyIntervalToWidgetRow,
			"closeIntervalWidget": self.closeIntervalWidget,
			"events": [{
				"name": "ActionEvent",
				"code": "args.owner.closeIntervalWidget(); args.owner.applyIntervalToWidgetRow();"
			}]
		}];

		return metaDataFactory.widgetFactory({
			"name": "Interval",
			"label": self.field.label,
			"template": "zh-interval-component#widget/interval.html",
			"container": self.field.widget.container,
			"isVisible": true,
			"intervalField": self.field,
			"startLabel": self.field.startLabel,
			"endLabel": self.field.endLabel,
			"dateFormat": $scope.dateFormat,
			"actions": actions,
			"parent": self.field,
			"displayFormat": self.field.displayFormat || $scope.dateFormat,
			"widgets": [{
				"name": "Calendar",
				"label": self.field.label,
				"template": "widget/calendar.html",
				"container": self.field.widget.container,
				"actions": actions,
				"dateFormat": $scope.dateFormat,
				"displayFormat": self.field.displayFormat || $scope.dateFormat,
				"isVisible": true,
				"floatingControl": false,
				"dataSource": {
					"data": (self.field.dataSource && self.field.dataSource.data) || [] 
				},
				"dateField": self.field.dateField,
				"showDescriptionOrder": false,
				"events": [{
					"name": "WidgetAfterMoveRow",
					"code": "args.owner.parent.selectIntervalDate(args)"
				}, {
					"name": "WidgetOnEnter",
					"code": "args.owner.parent.selectDatesBasedOnCurrentRow()"
				}]
			}, {
				"name": "List",
				"label": self.field.label,
				"template": "widget/list.html",
				"container": self.field.widget.container,
				"isVisible": true,
				"actions": actions,
				"showDescriptionOrder": false,
				"floatingControl": false,
				"fields": [{
					"label": "Period",
					"name": "_period_label",
					"translate": true,
					"showOnList": true
				}],
				"dataSource": {
					"data": buildIntervals()
				},
				"events": [{
					"name": "WidgetAfterMoveRow",
					"code": "args.owner.parent.selectIntervalPeriod(args.owner)"
				}]
			}],
			"events": []
		}, self.field.widget.container);
	}

	this.inputOnClick = function($event){
		$event.stopPropagation();
	};

	this.openIntervalWidget = function() {
		if(!self.field.isReadOnly()){
			self.field.intervalWidget = createIntervalWidget();
			self.batata = $scope.$root;
			applyIntervalWidgetInitialValues();
			resetIntervalValuesOnCurrentRow();
			createIntervalWidgetMethods();
			ScreenService.openPopup(self.field.intervalWidget).then(function() {
				if(self.field.intervalWidget === $scope.$root._currentPopup){
					$scope.$root._currentPopup = self.field.intervalWidget.widgets[0];
					$scope.$root._currentPopup.lastActiveWidget = self.field.intervalWidget.parent.widget;
				}
			});
		}
	};

	function applyIntervalWidgetInitialValues() {
		var intervalWidget = self.field.intervalWidget;
		intervalWidget.isIntervalEmpty = true;
		intervalWidget.beingSelected = 'start';
		intervalWidget.setBeingSelected = setBeingSelected;
		intervalWidget.carouselWidget = 'calendar';

		intervalWidget.intervalData = {};
		intervalWidget.intervalData.start = getInitialstartDate();
		intervalWidget.intervalData.end = getInitialEndDate();
		intervalWidget.widgets[0].currentDate = intervalWidget.intervalData.start;
		intervalWidget.formattedData = {};
		intervalWidget.formattedData.start = getDisplayValueByValue(getInitialstartDate());
		intervalWidget.formattedData.end = getDisplayValueByValue(getInitialEndDate());
	}

	function getInitialstartDate() {
		return getInitialDate('start');
	}

	function getInitialEndDate() {
		return getInitialDate('end');
	}

	function getInitialDate(property) {
		var field = self.field;
		var parentWidget = field.widget;
		var currentRowProperty = parentWidget.currentRow[field.name];
		return currentRowProperty ? currentRowProperty[property] : moment().format($scope.dateFormat);
	}

	function resetIntervalValuesOnCurrentRow() {
		var intervalField = self.field;
		var parentWidget = intervalField.widget;
		if (!parentWidget.currentRow[intervalField.name]) {
			parentWidget.currentRow[intervalField.name] = {
				start: null,
				end: null,
				period: null
			};
		}
	}

	function setBeingSelected(value) {
		self.field.intervalWidget.beingSelected = value;
	}

	this.applyIntervalToWidgetRow = function() {
		var intervalField = self.field;
		var parentWidget = intervalField.widget;
		var intervalData = intervalField.intervalWidget.intervalData;
		var formattedData = intervalField.intervalWidget.formattedData;

		$scope.fieldRow = {
			start: intervalData.start,
			end: intervalData.end,
			period: intervalData.period,
			formattedStart: formattedData.start,
			formattedEnd: formattedData.end
		};

		parentWidget.currentRow[intervalField.name] = $scope.fieldRow;

		intervalField.validate(intervalField.value());
		if (intervalField.change) {
			intervalField.change();
		}
	};

	this.closeIntervalWidget = function(){
		ScreenService.closePopup();
		setLastActivatedWidget(self.field.widget);
	};

	function createIntervalWidgetMethods() {
		self.field.intervalWidget.selectDatesBasedOnCurrentRow = function() {
			var field = self.field;
			var currentRow = field.widget.currentRow;
			var intervalWidget = field.intervalWidget;
			var intervalData = intervalWidget.intervalData;
			var formattedData = intervalWidget.formattedData;
			var startDate = currentRow[field.name] ? currentRow[field.name].start : null;
			var endDate = currentRow[field.name] ? currentRow[field.name].end : null;

			if (Util.isValidDate(startDate, $scope.dateFormat) && Util.isValidDate(endDate, $scope.dateFormat)) {
				intervalData.start = startDate;
				intervalData.end = endDate;
				formattedData.start = getDisplayValueByValue(startDate);
				formattedData.end = getDisplayValueByValue(endDate);
				selectIntervalOnCalendar();
			}
			else {
				intervalData.start = moment().format($scope.dateFormat);
				intervalData.end = moment().format($scope.dateFormat);
				formattedData.start = moment().format($scope.displayFormat);
				formattedData.end = moment().format($scope.displayFormat);
				selectIntervalOnCalendar();
			}
		};

		self.field.intervalWidget.selectIntervalDate = function(args) {
			var intervalWidget = self.field.intervalWidget;
			var intervalData = intervalWidget.intervalData;
			var formattedData = intervalWidget.formattedData;
			var selectedDate = args.row;
			var momentSelectedDate = moment(args.row, $scope.dateFormat);
			var momentstartDate = moment(intervalData.start, $scope.dateFormat);
			var momentEndDate = moment(intervalData.end, $scope.dateFormat);

			if (intervalWidget.beingSelected !== 'start' && intervalWidget.beingSelected !== 'end') {
				intervalWidget.beingSelected = 'start';
			}

			intervalData[intervalWidget.beingSelected] = selectedDate;
			formattedData[intervalWidget.beingSelected] = getDisplayValueByValue(selectedDate);

			var shouldToggleBeingSelected = true;

			if (intervalWidget.beingSelected === 'start' && momentSelectedDate.isAfter(momentEndDate)) {
				intervalData.end = selectedDate;
				formattedData.end = getDisplayValueByValue(selectedDate);
			} else if (intervalWidget.beingSelected === 'end' && momentSelectedDate.isBefore(momentstartDate)) {
				shouldToggleBeingSelected = false;
				intervalData.start = selectedDate;
				formattedData.start = getDisplayValueByValue(selectedDate);
			}

			if (shouldToggleBeingSelected) {
				toggleBeingSelected();
			}

			clearOldInterval();
			selectIntervalOnCalendar();
			intervalWidget.isIntervalEmpty = false;
		};

		self.field.intervalWidget.selectIntervalPeriod = function(listWidget) {
			var intervalWidget = self.field.intervalWidget;
			var intervalData = intervalWidget.intervalData;
			intervalData.start = listWidget.currentRow._period.start;
			intervalData.end = listWidget.currentRow._period.end;
			intervalData.period = {
				'name': listWidget.currentRow._period_name,
				'label': listWidget.currentRow._period_label,
				'customized': listWidget.currentRow._period.customized
			};

			intervalWidget.formattedData.start = getDisplayValueByValue(intervalData.start);
			intervalWidget.formattedData.end = getDisplayValueByValue(intervalData.end);

			clearOldInterval();
			selectIntervalOnCalendar();

			ScreenService.closePopup();
			self.field.widget.activate();
			self.applyIntervalToWidgetRow();
		};

		self.field.intervalWidget.isCalendarCurrentWidget = function() {
			return self.field.intervalWidget.carouselWidget === 'calendar';
		};

		self.field.intervalWidget.isPeriodSelectorCurrentWidget = function() {
			return self.field.intervalWidget.carouselWidget === 'periodSelector';
		};

		self.field.intervalWidget.toggleCurrentWidget = function() {
			var intervalWidget = self.field.intervalWidget;

			if (intervalWidget.isPeriodSelectorCurrentWidget()) {
				intervalWidget.carouselWidget = 'calendar';
				intervalWidget.beingSelected = 'start';
			}
			else {
				intervalWidget.carouselWidget = 'periodSelector';
				intervalWidget.beingSelected = 'none';
			}

			setLastActivatedWidget(self.field.widget);
			intervalWidget.nextWidget();
			intervalWidget.container.prepareActions();
		};
	}

	function setLastActivatedWidget(toBecomeActiveWidget) {
		toBecomeActiveWidget.activate();
		toBecomeActiveWidget.lastActiveWidget = self.field.widget.parent;
	}

	function toggleBeingSelected() {
		var intervalWidget = self.field.intervalWidget;
		intervalWidget.beingSelected = intervalWidget.beingSelected === 'start' ? 'end' : 'start';
	}

	function clearOldInterval() {
		var calendarWidget = self.field.intervalWidget.widgets[0];
		calendarWidget.selectedDates = [];
	}

	function selectIntervalOnCalendar() {
		var intervalWidget = self.field.intervalWidget || self.widget;
		var calendarWidget = intervalWidget.widgets[0];

		var dateFormat = self.field.dateFormat;
		var startDate = intervalWidget.intervalData.start;
		var endDate = intervalWidget.intervalData.end;

		var momentstartDate = moment(startDate, dateFormat);
		var momentEndDate = moment(endDate, dateFormat);
		var momentCurrentDate = momentstartDate;

		while (momentCurrentDate.isBefore(momentEndDate) || momentCurrentDate.isSame(momentEndDate)) {
			calendarWidget.setDateAsSelected(momentCurrentDate.format(dateFormat), dateFormat);
			momentCurrentDate.add(1, 'day');
		}

	}

	this.getPeriodLabel = function() {
		var label = '';
		var property = self.field.widget.currentRow[self.field.name];
		if (property && property.period && property.period.label) {
			label = '(' + property.period.label + ')';
		}
		return label;
	};

	if (self.field) {
		var field = self.field;
		var fieldName = field.name;
		var parentWidget = field.widget;

		field.value(self.field.value() || self.field.defaultValue);
		field.isRowSet = function() {
			var fieldName = this.name;
			var currentRow = this.widget.currentRow;
			var hasValue = currentRow[fieldName] && currentRow[fieldName].formattedStart;
			var startSet = hasValue && currentRow[fieldName].formattedStart.indexOf('_')===-1;
			var endSet = hasValue && currentRow[fieldName].formattedEnd.indexOf('_')===-1;
			return startSet && endSet;
		};
		field.clearValue = clearInternalValues;

		field.getDatesByPeriodName = function(periodName, periodLabel) {
			periodLabel = periodLabel || '';
			var date = isCustomPeriod(periodName) ? ZhUtil.evaluate(periodName) : buildObjectWithPeriodDetails(periodName);

			return {
				"start": date.start,
				"end": date.end,
				"formattedStart": getDisplayValueByValue(date.start),
				"formattedEnd": getDisplayValueByValue(date.end),
				"period": {
					"name": periodName,
					"label": periodLabel || '',
					"customized": date.customized
				}
			};
		};

		if (parentWidget.currentRow[fieldName] &&
			parentWidget.currentRow[fieldName].period &&
			parentWidget.currentRow[fieldName].period.name
		) {
			var date = field.getDatesByPeriodName(parentWidget.currentRow[fieldName].period.name);
			parentWidget.currentRow[fieldName].start = date.start;
			parentWidget.currentRow[fieldName].end = date.end;
		}

		$scope.$watch('fieldRow.start', function(newValue) {
			if(!parentWidget.currentRow[fieldName].keepFormatted){
				parentWidget.currentRow[fieldName].formattedStart = newValue ? getDisplayValueByValue(newValue) : emptyDefault;
			} else {
				delete parentWidget.currentRow[fieldName].keepFormatted;
			}
		});
		$scope.$watch('fieldRow.end', function(newValue) {
			if(!parentWidget.currentRow[fieldName].keepFormatted){
				parentWidget.currentRow[fieldName].formattedEnd = newValue ? getDisplayValueByValue(newValue) : emptyDefault;
			} else {
				delete parentWidget.currentRow[fieldName].keepFormatted;
			}
		});
	}

	/**
	 * Validations
	 **/
	$scope.isRequired = function(field) {
		return field.validations && (field.validations.requiredInterval || field.validations.requiredIntervalStart || field.validations.requiredIntervalEnd);
	};
};

ZeedhiController.controller('IntervalController', IntervalController);

// FILE: src/interval/directives/zhIntervalInput.js
var ZeedhiDiretiveDate = angular.module("ZeedhiDiretiveDate");
ZeedhiDiretiveDate.directive("zhIntervalInput", function(templateManager, ScreenService) {
	return {
		restrict: 'A',
		link: function($scope, $element, $attrs){
			var type = $attrs.zhIntervalInput || 'start';
			var field = $scope.field;
			var fieldName = field.name;
			var widget = field.widget;

			var arrowUpKey = 38;
			var arrowDownKey = 40;
			var homeKey = 36;
			var endKey = 35;
			var arrowLeftKey = 37;
			var arrowRightKey = 39;
			var backspaceKey = 8;
			var deleteKey = 46;

			var inputProperties = {};
			if(type !== 'start'){
				inputProperties = {
					scopeVariable: 'formattedEnd',
					searchVale: '_END',
					newValue: '_START',
					cursorIndex: $scope.displayFormat.length,
					toggleKeys: [arrowUpKey, homeKey, arrowLeftKey, backspaceKey],
					selectionPosition: 0,
					extraToggleCondition: function(){
						return false;
					}
				};
			} else {
				inputProperties = {
					scopeVariable: 'formattedStart',
					searchVale: '_START',
					newValue: '_END',
					cursorIndex: 0,
					toggleKeys: [arrowDownKey, endKey, arrowRightKey],
					selectionPosition: $scope.displayFormat.length,
					extraToggleCondition: function(keyCode, selectionStart){
						return isNumberKeyCode(keyCode) && selectionStart >= $scope.displayFormat.length - 1;
					}
				};
			}

			widget.currentRow.$error = widget.currentRow.$error || {};
			widget.currentRow.$error[fieldName] = widget.currentRow.$error[fieldName] || [];

			function isNumberKeyCode(keyCode){
				return (keyCode >= 96 && keyCode <= 105) || (keyCode >= 48 && keyCode <= 57);
			}

			function isToPreventDefault(evt){
				var toPrevent = [backspaceKey, deleteKey];
				return evt.keyCode && (evt.key.length < 2 || toPrevent.indexOf(evt.keyCode) !== -1);
			}

			function setCursorPosition(element, position){
				element.setSelectionRange(position, position);
			}

			function getToggleCondition(selectionStart, keyCode){
				return (inputProperties.toggleKeys.indexOf(keyCode) !== -1 && selectionStart == inputProperties.selectionPosition) || inputProperties.extraToggleCondition(keyCode, selectionStart);
			}

			function toggleInput(evt){
				evt.preventDefault();

				var fieldName = $element[0].id.replace(inputProperties.searchVale, inputProperties.newValue);
				var fieldElement = $element.parent().find('#' + fieldName);
				fieldElement.focus();
				setCursorPosition(fieldElement[0], inputProperties.cursorIndex);
			}

			function updateNextNumber(selectionStart, key){
				if(selectionStart < $scope.displayFormat.length){
					var value = $scope.fieldRow[inputProperties.scopeVariable];
					while(value[selectionStart] && value[selectionStart] !== '_' && isNaN(value[selectionStart])){
						selectionStart++;
					}
					$scope.fieldRow[inputProperties.scopeVariable] = value.substr(0, selectionStart) + key + value.substr(selectionStart + 1);
					templateManager.updateTemplate();
				} else {
					selectionStart++;
				}
				selectionStart++;
				setCursorPosition($element[0], selectionStart);
			}

			function clearPreviousNumber(selectionStart){
				if(selectionStart !== 0){
					var value = $scope.fieldRow[inputProperties.scopeVariable];
					selectionStart--;
					while(value[selectionStart] && value[selectionStart] !== '_' && isNaN(value[selectionStart])){
						selectionStart--;
					}
					$scope.fieldRow[inputProperties.scopeVariable] = value.substr(0, selectionStart) + '_' + value.substr(selectionStart + 1);
					templateManager.updateTemplate();
					setCursorPosition($element[0], selectionStart);
				}
			}

			$element.on('keydown', function(evt){
				if(isToPreventDefault(evt)){
					evt.preventDefault();
				}

				var key = evt.key;
				var keyCode = evt.keyCode;
				var selectionStart = $element[0].selectionStart;

				if(isNumberKeyCode(keyCode)){
					updateNextNumber(selectionStart, key);
				}

				if(getToggleCondition(selectionStart, keyCode)){
					toggleInput(evt);
				} else if(keyCode == backspaceKey){
					clearPreviousNumber(selectionStart);
				}
			});

			function valueIsFullfilled(value){
				return value.indexOf('_') === -1;
			}

			function showIntervalValidationsErrors(field){
				var value = field.value();
				var validStart = !valueIsFullfilled(value.formattedStart) || moment(value.formattedStart, $scope.displayFormat).isValid();
				var fieldName = field.name;
				var validateResult = {
					valid: true
				};
				if(!validStart){
					field.widget.currentRow[fieldName].keepFormatted = true;
					field.widget.currentRow[fieldName].start = '';
					validateResult = {
						valid: false,
						message: ScreenService.i18n('Invalid start date')
					};
				} else {
					var validEnd = !valueIsFullfilled(value.formattedEnd) || moment(value.formattedEnd, $scope.displayFormat).isValid();
					if(!validEnd){
						field.widget.currentRow[fieldName].keepFormatted = true;
						field.widget.currentRow[fieldName].end = '';
						validateResult = {
							valid: false,
							message: ScreenService.i18n('Invalid end date')
						};
					}
				}

				if(!validateResult.valid){
					field.widget.currentRow.$error[fieldName] = [];
					field.widget.currentRow.$error[fieldName].push(validateResult);
				}
				return validateResult.valid;
			}

			$element.on('blur', function(){
				var inputElement = $element[0];
				if(valueIsFullfilled(inputElement.value)){
					if(moment(inputElement.value, $scope.displayFormat).isValid()){
						$scope.fillCurrentRow(inputElement);
						templateManager.updateTemplate();

						if($scope.field.validate($scope.field.value()) && $scope.field.change) {
							$scope.field.change();
						}
					} else if($scope.field.intervalOnInvalidInput){
						$scope.field.intervalOnInvalidInput();
					}
				}
				$scope.field.validate($scope.field.value());
				showIntervalValidationsErrors(field);
			});
		}
	};
});


// FILE: ./bower_components/zh-cache-bypass/src/CacheBypass.js
(function() {
    angular.module("ZeedhiApp").config(function($httpProvider) {
        if (Boolean(window.applicationVersion)) {
            $httpProvider.interceptors.push(function() {
                return {
                    'request': function cacheBypass(config) {
                        if (config && config.url && shouldApplyBypass(config.url)) {
                            config.url += '?v='+window.applicationVersion;
                        }
                        return config;
                    }
                };
            });
        } else {
            console.warn('Missing "applicationVersion" global property for CacheBypass.');
        }
    });

    function shouldApplyBypass(url) {
        return (
            Util.stringEndsWith(url, '.json') ||
            Util.stringEndsWith(url, '.html') ||
            Util.stringEndsWith(url, '.svg')
        );
    }
})();

// FILE: ./bower_components/zhuaclfrontend/assets/dist/main.js
// FILE: assets/js/util/ZhuAclConfig.js
/* global Configuration */
function ZhuAclConfig() {
	var self = this;
	this.RULE_ALLOW = 'A';
	this.RULE_READONLY = 'R';
	this.RULE_INVISIBLE = 'I';

	this.menuElementsListWidgetName = 'elementsListWidget';
	this.containerElementsListWidgetName = 'containerElementsModal';
	this.containerElementsTreeWidgetName = 'containerElementsTree';

	this.containerType = 'container';

	this.getDefaultDataSourceFilter = function(groupIds, projectId, organizationId){
		var dataFilter = [];
		var groupFilter = {
			"name": "GROUP_ID",
			"operator": "=",
			"value": groupIds
		};
		var projectFilter = {
			"name": "PROJECT_ID",
			"operator": "=",
			"value": projectId
		};

		if(organizationId !== undefined){
			var organizationFilter = {
				"name": "ORGANIZATION_ID",
				"operator": "=",
				"value": organizationId
			};
			dataFilter.push(organizationFilter);
		}

		dataFilter.push(groupFilter);
		dataFilter.push(projectFilter);
		return dataFilter;
	};

	this.getAclMap = function(type){
		var aclMap = {
			"container": {
				"aclTypeCod": "C",
				"childs": ["widgets"]
			},
			"widgets": {
				"aclTypeCod": "W",
				"childs": ["widgets", "fields", "actions"]
			},
			"fields": {
				"aclTypeCod": "F",
				"childs": []
			},
			"actions": {
				"aclTypeCod": "A",
				"childs": []
			}
		};
		return aclMap[type] || {};
	};

	this.getRuleType = function(isVisible, isEditable){
		var ruleType;
		if(!isVisible){
			ruleType = self.RULE_INVISIBLE;
		} else if(!isEditable){
			ruleType = self.RULE_READONLY;
		} else {
			ruleType = self.RULE_ALLOW;
		}
		return ruleType;
	};

	this.getRuleConfiguration = function(ruleType){
		var ruleConfig = {
			isVisible: ruleType != self.RULE_INVISIBLE,
			isEditable: ruleType == self.RULE_ALLOW
		};
		return ruleConfig;
	};
}

Configuration(function(ContextRegister) {
	ContextRegister.register('ZhuAclConfig', ZhuAclConfig);
});

// FILE: assets/js/util/ZhuAclMessages.js
var ZhuAclMessages = {
	CANCEL: 'Cancelar',
	YES: 'Sim',
	NO: 'Não',
	VISIBLE: 'visíveis',
	EDITABLE: 'editáveis',
	INVISIBLE: 'invisíveis'
};
(function(){
	var mappedMessages = [
		"ACCESS_DENIED",
		"RULE_NOT_SAVED",
		"SUC_RULE_INSERTED",
		"ERR_RULE_INSERTED",
		"CANNOT_LOAD_RULES",
		"CONFIRMATION_MESSAGE",
		"CONFIRM_CHILDS_QUESTION",
		"NSHOW_WITHOUT_ID",
		"NSHOW_WITHOUT_CONTAINER_CONFIG",
		"NSHOW_WITHOUT_ID_AND_CONTAINER_CONFIG"
	];
	mappedMessages.forEach(function addMappedMessages(code){
		ZhuAclMessages[code] = 'zhuacl#' + code;
	});
})();

// FILE: assets/js/services/ZhuAccessButtonService.js
/* global _Notification, Util, ZeedhiServices */
function ZhuAccessButtonService(){
	this.insertButtonInProject = function(project){
		var notification = {
			"label": "Access Control",
			"name": "accessControl",
			"icon": "block",
			"isVisible": false,
			"tooltip": "Access Control",
			"isAclNotification": true,
			"events": [
				{
					"name": "NotificationEvent",
					"code": "ZhuAclController.openAclModalWidget();"
				}
			]
		};
		try {
			notification = Util.extend(new _Notification(), notification);
			project.notifications = project.notifications || [];
			project.notifications.push(notification);
		} catch (e){
			console.error('O Controle de acesso à elementos só funciona em versões acima da 1.40.x do Zeedhi Framework');
		}
	};

	this.disableButtonInProject = function(project){
		if(project.notifications){
			project.notifications = project.notifications.filter(function(notification){
				return !notification.isAclNotification;
			});
		}
	};

	this.enableButtonInProject = function(project){
		if(project.notifications){
			project.notifications.forEach(function(notification){
				if(notification.isAclNotification){
					notification.isVisible = true;
				}
			});
		}
	};
}

ZeedhiServices.service("ZhuAccessButtonService", function(ApplicationContext){
	var instance = new ZhuAccessButtonService();
	ApplicationContext.registerInstance("ZhuAccessButtonService", instance);
	return instance;
});


// FILE: assets/js/services/ZhuAclService.js
/* global Util, Configuration, ZhuAclMessages*/
function ZhuAclService(requestDataSourceEngine, restEngine, ZhuAclConfig){

	this.getZhuAclRules = function(projectId, groupIds){
		return requestDataSourceEngine.getDataSource('zhuacl#/acl_zhu_acl_rules', ZhuAclConfig.getDefaultDataSourceFilter(groupIds, projectId), 1, undefined, undefined, undefined, 120000).then(function(response){
			var dataset = response.dataset || {};
			var rules = dataset.zhu_access_control_rule_login;
			if(Util.isArray(rules)){
				var objToReturn = {
					aclRules: rules,
					defaultRule: dataset.zhu_access_control_default_rule.defaultRule,
				};
				return objToReturn;
			} else {
				throw {code: ZhuAclMessages.CANNOT_LOAD_RULES};
			}
		});
	};

	this.getWidgetMetadata = function(widgetName){
		var widgetUrl = 'zhuacl#json/'+ widgetName +'.json';
		return restEngine.requestMetaData(widgetUrl).then(function(metadata){
			return metadata.data;
		});
	};
}

Configuration(function(ContextRegister){
	ContextRegister.register('ZhuAclService', ZhuAclService);
});

// FILE: assets/js/controllers/ZhuAclController.js
/* global openWindow, Util, Configuration, ZhuAclMessages */
function ZhuAclController(ScreenService, templateManager, metaDataFactory, ZHPromise, ZhuAclService, ZhuAccessButtonService, ZhuAclConfig, MessageService, ApplicationContext, eventAggregator){
	var self = this;
	var user;
	var validProperties = ['widgets', 'fields', 'actions'];
	var loadedContainers = {};

	function User(userId, projectId, organizationId, defaultRule){
		var currentGroupId;
		var userDefaultRule = defaultRule || ZhuAclConfig.RULE_INVISIBLE;

		this.setCurrentGroupId = function(id){
			currentGroupId = id;
		};

		this.getDefaultRule = function(){
			return userDefaultRule;
		};

		this.getCurrentGroupId = function(){
			return currentGroupId;
		};

		this.getProjectId = function(){
			return projectId;
		};

		this.getUserId = function(){
			return userId;
		};

		this.getOrganizationId = function(){
			return organizationId;
		};
	}

	this.getDefaultRule = function(){
		return user.getDefaultRule();
	};

	this.getCurrentGroupId = function(){
		return user.getCurrentGroupId();
	};

	this.getProjectId = function(){
		return user.getProjectId();
	};

	var prepareLabelToName = function(label){
		var name = label.toLowerCase();
		name = name.replace(/\ /g, "_");
		return name.replace(/[^\w\s]/gi, '');
	};

	var translateLabel = function(label){
		return ScreenService.i18n(label);
	};

	this.getRulesFromDatasource = function(rulesData){
		var userId = user.getUserId();
		var rules = {};
		rulesData.forEach(function(row){
			var obj = {
				ruleRow: row,
				userGroups: {}
			};
			obj.userGroups[userId] = {
				rule: row.RULE
			};
			rules[row.ELEMENT_UNIQUE_ID] = obj;
		});
		return rules;
	};

	this.getElementRule = function(rules, itemId){
		var itemRule = {};
		if(rules[itemId]){
			itemRule = rules[itemId].ruleRow;
		}
		return itemRule;
	};

	this.getPlannedItemToInsertInDataSet = function(rules, item, itemType, parentId){
		var uniqueId = item.id;
		var itemRule = self.getElementRule(rules, uniqueId);
		var itemToInsert = {
			"UNIQUE_ID": uniqueId,
			"NAME": item.name || prepareLabelToName(item.label),
			"LABEL": translateLabel(item.label || item.name),
			"TYPE": itemType,
			"RULE": itemRule.RULE || this.getDefaultRule(),
			"RULE_ID": itemRule.ID,
			"PARENT_ID": parentId,
			"USER_ID": user.getUserId(),
			"PROJECT_ID": user.getProjectId(),
			"ORGANIZATION_ID": user.getOrganizationId()
		};

		itemToInsert.isVisible = item.aclIsVisible;
		itemToInsert.isEditable = !item.aclReadOnly && item.aclIsVisible;

		return itemToInsert;
	};

	var insertContainerElementsListWidget = function(container){
		return getFactoredWidget(container, ZhuAclConfig.containerElementsListWidgetName, true).then(function(factoredWidget){
			container.actions = container.actions || [];
			return factoredWidget;
		});
	};

	this.openAclModalWidget = function(){
		insertContainerElementsListWidget(templateManager.container).then(function(widget){
			ScreenService.openPopup(widget);
		});
	};

	var redirectToMainWindow = function(){
		var dashboardMenu = templateManager.project.getMenu('dashboard');
		var openLinkByMenu = ApplicationContext.LibUtilities && ApplicationContext.LibUtilities.openLinkByMenu;
		if(dashboardMenu && openLinkByMenu){
			openLinkByMenu(dashboardMenu);
		} else {
			openWindow(templateManager.project.mainWindow);
		}
	};

	var verifyContainerRule = function(rule){
		var containerIsRestrict = rule === ZhuAclConfig.RULE_INVISIBLE;
		if(containerIsRestrict){
			var actions = [{
				label: ScreenService.i18n("Ok"),
				code: redirectToMainWindow
			}];
			var dialogConfig = {
				type: 'ALERT',
				icon: 'exclamation',
				actions: actions
			};
			MessageService.showCustomDialogByCode(ZhuAclMessages.ACCESS_DENIED, {}, dialogConfig);
		}
		return !containerIsRestrict;
	};

	var mergeUndefinedRules = function(groupIds, itemRule, parentRules){
		parentRules = parentRules || {};

		var definedRule = itemRule.rule;
		var groupRules = parentRules.groupRules || {};

		if(!definedRule){
			definedRule = parentRules.rule || templateManager.project.aclDefaultRule;
		} else {
			var undefinedGroups = itemRule.undefinedGroups || [];
			groupIds.forEach(function(groupId){
				var parentRule = groupRules[groupId] || templateManager.project.aclDefaultRule;
				var isUndefinedGroup = undefinedGroups.indexOf(groupId) !== -1;
				var groupRule = isUndefinedGroup ? parentRule : definedRule;
				groupRules[groupId] = groupRule;

				if(definedRule !== ZhuAclConfig.RULE_ALLOW && groupRule !== ZhuAclConfig.RULE_INVISIBLE){
					definedRule = groupRule;
				}
			});
			itemRule.rule = definedRule;
		}

		return {rule: definedRule, groupRules: groupRules};
	};

	var updateContainerAcl = function(rules, groupIds, userId){
		var applyRule = function(item, parentRules){
			var id = item.id;
			var userRule = Util.getNestedProperty(rules, [id, 'userGroups', userId]) || {};
			var mergedItem = mergeUndefinedRules(groupIds, userRule, parentRules);
			var itemRule = mergedItem.rule;

			item.aclIsVisible = itemRule != ZhuAclConfig.RULE_INVISIBLE;
			item.aclReadOnly = itemRule != ZhuAclConfig.RULE_ALLOW;

			return mergedItem;
		};

		var updateItemAcl = function(item, type, parentRules){
			var mergedItem = applyRule(item, parentRules);

			ZhuAclConfig.getAclMap(type).childs.forEach(function(type){
				if(Util.isArray(item[type])){
					item[type].forEach(function(child){
						updateItemAcl(child, type, mergedItem);
					});
				}
			});
		};

		var changeNotificationVisibility = function(isVisible){
			templateManager.project.notifications.some(function(notification){
				var isAclNotification = notification.name === "accessControl";
				if(isAclNotification){
					notification.isVisible = isVisible;
				}
				return isAclNotification;
			});
		};

		var container = templateManager.container;
		var aclEnable = container.aclEnable;
		aclEnable = aclEnable !== undefined ? aclEnable : true;
		changeNotificationVisibility(aclEnable);

		if(aclEnable){
			var containerRule = applyRule(container);
			if(verifyContainerRule(containerRule.rule)){
				updateItemAcl(container, ZhuAclConfig.containerType);
			}
			loadedContainers[container.id] = true;
		}
	};

	var convertObjectRulesToArray = function(userId, objRules){
		var arrayRules = [];
		Object.keys(objRules).forEach(function(ruleId){
			var objRule = objRules[ruleId];
			var userRule = objRule.userGroups[userId];
			if(userRule){
				var rule = {
					"UNIQUE_ID": ruleId,
					"NAME": objRule.itemName,
					"RULE": userRule.rule
				};
				arrayRules.push(rule);
			}
		});
		return arrayRules;
	};

	var convertArrayRulesToObject = function(userId, arrayRules){
		var objRules = {};
		arrayRules.forEach(function(rule){
			var profileObjects = {};
			profileObjects[userId] = {
				'rule': rule.RULE,
				'undefinedGroups': rule.GROUP_ID || []
			};
			objRules[rule.UNIQUE_ID] = {
				'itemName': rule.NAME,
				'userGroups': profileObjects
			};
		});
		return objRules;
	};

	var subscribeContainerEvent = function(rules, groupIds, userId){
		eventAggregator.subscribe(EventAggregator.ON_CONTAINER_OPEN, function applyACL(){
			var containerId = templateManager.container.id;
			if(!loadedContainers[containerId]){
				updateContainerAcl(rules, groupIds, userId);
			}
		});

	};

	var updateProjectAcl = function(loginRules, defaultRule, groupIds){
		var rules = {};
		var userId = user.getUserId();
		if(Util.isObject(loginRules)){
			rules = loginRules;
			loginRules = convertObjectRulesToArray(userId, rules);
		} else if(Util.isArray(loginRules)){
			rules = convertArrayRulesToObject(userId, loginRules);
		}

		templateManager.project.aclDefaultRule = defaultRule || ZhuAclConfig.RULE_INVISIBLE;
		templateManager.userId = userId;

		templateManager.aclRules = rules;
		updateContainerAcl(rules, groupIds, userId);
		subscribeContainerEvent(rules, groupIds, userId);
	};

	var createUser = function createUser(userId, projectId, organizationId, defaultRule){
		user = new User(userId, projectId, organizationId, defaultRule);
	};

	this.setUserRules = function(groupIds, projectId, userId, organizationId, options){
		loadedContainers = {};
		options = options || {};

		if(options.canConfigureAcl){
			ZhuAccessButtonService.enableButtonInProject(templateManager.project);
			templateManager.updateTemplate();
		} else {
			ZhuAccessButtonService.disableButtonInProject(templateManager.project);
			templateManager.updateTemplate();
		}

		if(options.rules){
			createUser(userId, projectId, organizationId, options.defaultRule);
			updateProjectAcl(options.rules, options.defaultRule, groupIds);
		} else {
			ZhuAclService.getZhuAclRules(projectId, groupIds).then(function(response){
				createUser(userId, projectId, organizationId, response.defaultRule);
				updateProjectAcl(response.aclRules, response.defaultRule, groupIds);
			}).catch(function(err){
				MessageService.showMessageByCode(err.code);
			});
		}
	};

	this.setElementsListFilter = function(container, groupId, widgetName){
		widgetName = widgetName || ZhuAclConfig.menuElementsListWidgetName;
		var elementsWidget = container.getWidget(widgetName);
		elementsWidget.dataSourceFilter = ZhuAclConfig.getDefaultDataSourceFilter(groupId, user.getProjectId(), user.getOrganizationId());
		user.setCurrentGroupId(groupId);
	};

	var getFactoredWidget = function(container, widgetName, pushInContainer){
		var widget = container.getWidget(widgetName);
		if(widget){
			return ZHPromise.when(widget);
		} else {
			return ZhuAclService.getWidgetMetadata(widgetName).then(function(metadata){
				var factoredWidget = metaDataFactory.widgetFactory(metadata, container);
				if(pushInContainer){
					container.widgets.push(factoredWidget);
				}
				return factoredWidget;
			});
		}
	};

	this.insertElementsListWidget = function(container, parentWidget){
		getFactoredWidget(container, ZhuAclConfig.menuElementsListWidgetName).then(function(factoredWidget) {
			if(parentWidget && !factoredWidget.parent){
				factoredWidget.parent = parentWidget;
				parentWidget.widgets = parentWidget.widgets || [];
				parentWidget.widgets.push(factoredWidget);
			}
		});
	};

}

Configuration(function(ContextRegister){
	ContextRegister.register('ZhuAclController', ZhuAclController);
});


// FILE: assets/js/controllers/ZhuAclCRUDController.js
/* global Configuration, ZhuAclMessages */
function ZhuAclCRUDController(ScreenService, ZHPromise, ZhuAclConfig, ZhuAclController, MessageService){

	function defineQuestionToUse(rule){
		var question = ZhuAclMessages.VISIBLE;
		if(rule == ZhuAclConfig.RULE_INVISIBLE){
			question = ZhuAclMessages.INVISIBLE;
		} else if(rule == ZhuAclConfig.RULE_ALLOW){
			question = ZhuAclMessages.EDITABLE;
		}
		return {newVisibility: ScreenService.i18n(question)};
	}

	function deleteChildrensRules(elementsWidget, parentRow, groupId, ruleToContainer){
		if(parentRow._childCount){
			elementsWidget.dataSource.data.forEach(function(row){
				if(row._parent == parentRow){
					row.changed = true;
					row.__isDeleted = true;
					row.GROUP_ID = groupId;
					row.RULE_SAVE_CONTAINER = ruleToContainer;
					deleteChildrensRules(elementsWidget, row, groupId, ruleToContainer);
				}
			});
		}
	}

	function confirmChildsVisibility(elementsWidget, ruleType){
		var returnPromise = ZHPromise.when();
		if(elementsWidget.currentRow._childCount){
			var currentRow = elementsWidget.currentRow;
			var defer = ZHPromise.defer();
			var actions = [
				{
					label: ScreenService.i18n(ZhuAclMessages.YES),
					code: function(){
						currentRow.changed = true;
						deleteChildrensRules(elementsWidget, currentRow, currentRow.GROUP_ID, currentRow.RULE);
						defer.resolve();
					}
				},
				{
					label: ScreenService.i18n(ZhuAclMessages.NO),
					code: function(){
						var messageConfig = {
							type: 'confirmation',
							icon: 'question'
						};
						MessageService.showMessageByCode(ZhuAclMessages.CONFIRMATION_MESSAGE, {}, messageConfig);
						defer.reject();
					}
				}
			];
			var dialogConfig = {
				type: 'confirmation',
				icon: 'question',
				actions: actions
			};

			MessageService.showCustomDialogByCode(ZhuAclMessages.CONFIRM_CHILDS_QUESTION, defineQuestionToUse(ruleType), dialogConfig);
			returnPromise = defer.promise;
		}

		return returnPromise;
	}

	function reloadChildrensRules(elementsWidget, parentRow, updatedRules, deletedRules){
		if(parentRow._childCount){
			elementsWidget.dataSource.data.forEach(function(row){
				if(row._parent == parentRow){
					var rowId = row.UNIQUE_ID;
					row.isVisible = parentRow.isVisible;
					row.isEditable = parentRow.isEditable;

					if(deletedRules.indexOf(rowId) != -1){
						delete row.RULE_ID;
					}
					if(updatedRules[rowId] && updatedRules[rowId].containerId){
						row.CONTAINER_RULE_ID = updatedRules[rowId].containerId;
					}

					reloadChildrensRules(elementsWidget, row, updatedRules, deletedRules);
				}
				delete row.__isDeleted;
				delete row.changed;
			});
		}
	}

	function fixZeedhiBehavior(widget){
		widget.dataSource.data.forEach(function(data){
			data.isEditable = (data._childCount && data.isVisible) || data.isEditable;
		});
	}

	function isFatherVisible(parentRow, widget){
		return widget.dataSource.data.some(function(row){
			return (row.PARENT_ID == parentRow.UNIQUE_ID) && (row.isVisible || row.isEditable);
		});
	}

	function reloadParentsRules(row, widget){
		var parentRow = row._parent;
		if(parentRow){
			if(row.isVisible){
				parentRow.isEditable = parentRow.isEditable || row.isEditable || row.isVisible;
				parentRow.isVisible = true;
			} else {
				var updateFather = isFatherVisible(parentRow, widget);
				parentRow.isEditable = updateFather;
				parentRow.isVisible = updateFather;
			}
			reloadParentsRules(row._parent, widget);
		}
	}

	function reloadDataSourceAfterSave(elementsWidget, newRules){
		var currentRow = elementsWidget.currentRow;
		var currentRowId = currentRow.UNIQUE_ID;
		var updatedRule = newRules.updated[currentRowId];
		var deletedRules = newRules.deleted || [];
		if(updatedRule){
			if(Util.isObject(updatedRule)){
				currentRow.RULE_ID = updatedRule.menuId;
				currentRow.CONTAINER_RULE_ID = updatedRule.containerId;
			} else {
				currentRow.RULE_ID = updatedRule;
			}
			reloadChildrensRules(elementsWidget, currentRow, newRules.updated, deletedRules);
			reloadParentsRules(currentRow, elementsWidget);
			fixZeedhiBehavior(elementsWidget);
		}
	}

	function cancelSave(widget){
		widget.reload();
	}

	function changeElementRule(currentRow, isVisible, isEditable){
		currentRow.RULE = ZhuAclConfig.getRuleType(isVisible, isEditable);
		currentRow.isVisible = isVisible;
		currentRow.isEditable = isEditable;
		currentRow.GROUP_ID = currentRow.GROUP_ID || ZhuAclController.getCurrentGroupId();
	}

	function clearInlineChangedStatus(row){
		delete row.changed_isEditable;
		delete row.changed_isVisible;
	}

	function saveRule(widget, isEditable, isVisible){
		var currentRow = widget.currentRow;
		var ruleType = ZhuAclConfig.getRuleType(isVisible, isEditable);

		clearInlineChangedStatus(currentRow);
		changeElementRule(currentRow, isVisible, isEditable);

		confirmChildsVisibility(widget, ruleType).then(function(){
			widget.saveRow().then(function(response){
				reloadDataSourceAfterSave(widget, response.dataset.aclZhuAccessControlRule);
				MessageService.successNotificationByCode(ZhuAclMessages.SUC_RULE_INSERTED);
			}).catch(function(){
				cancelSave(widget);
				MessageService.notificationMessageByCode(ZhuAclMessages.ERR_RULE_INSERTED, {}, {type: "alert"});
			});
		}).catch(function(){
			cancelSave(widget);
			MessageService.notificationMessageByCode(ZhuAclMessages.RULE_NOT_SAVED, {}, {type: "alert"});
		});
	}

	this.changeIsEditable = function changeIsEditable(widget, row){
		var isEditable = row.isEditable;
		var isVisible = isEditable || row.isVisible;
		saveRule(widget, isEditable, isVisible);
	};

	this.changeIsVisible = function changeIsVisible(widget, row){
		var isVisible = row.isVisible;
		var isEditable = isVisible && row.isEditable;
		saveRule(widget, isEditable, isVisible);
	};
}

Configuration(function(ContextRegister){
	ContextRegister.register('ZhuAclCRUDController', ZhuAclCRUDController);
});


// FILE: assets/js/controllers/ZhuContainerElementsController.js
/* global Util, Configuration, ZhuAclMessages */
function ZhuContainerElementsController(templateManager, ZhuAclController, ZhuAclConfig, aclEngine, ZhuAclCRUDController, MessageService){
	var self = this;
	var idErrorMessages = "";

	var getContainerElementsTreeWidget = function(){
		return templateManager.container.getWidget(ZhuAclConfig.containerElementsTreeWidgetName);
	};

	var getContainerElementsListWidget = function(){
		return templateManager.container.getWidget(ZhuAclConfig.containerElementsListWidgetName);
	};

	var clearIdErrorsMessage = function(){
		idErrorMessages = "";
	};

	var showIdErrorsMessage = function(){
		if(idErrorMessages){
			var messageConfig = {
				type: 'alert',
				icon: 'exclamation'
			};
			MessageService.showMessageByCode(ZhuAclMessages.NSHOW_WITHOUT_ID, {elementsIds: idErrorMessages}, messageConfig);
		}
	};

	var getPlannedContainer = function(rules, item, itemType, parentId){
		var plannedItems = [];
		itemType = itemType || ZhuAclConfig.containerType;
		if(item && !item.isZhuAclElement){
			var uniqueId = item.id;
			if(uniqueId){
				var aclType = ZhuAclConfig.getAclMap(itemType);
				var itemToInsert = ZhuAclController.getPlannedItemToInsertInDataSet(rules, item, aclType.aclTypeCod, parentId);
				plannedItems.push(itemToInsert);
				aclType.childs.forEach(function(type){
					if(Util.isArray(item[type])){
						item[type].forEach(function(child){
							plannedItems = plannedItems.concat(getPlannedContainer(rules, child, type, uniqueId));
						});
					}
				});
			} else {
				var nameToShow = item.label || item.name;
				idErrorMessages += "<br> " + nameToShow + ";";
			}
		}
		return plannedItems;
	};

	this.reloadContainerElementsModal = function(){
		getContainerElementsListWidget().reload();
	};

	this.reloadContainerElementsTree = function(){
		getContainerElementsTreeWidget().reload();
	};

	this.selectAccessOnChange = function(selectedRow){
		if(selectedRow && selectedRow.SELECT_ACCESS){
			ZhuAclController.setElementsListFilter(templateManager.container, selectedRow.ID, ZhuAclConfig.containerElementsTreeWidgetName);
		}
		self.reloadContainerElementsTree();
	};

	var copyItem = function(itemToCopy, itemType, parentId){
		var item;
		if(itemToCopy && !itemToCopy.isZhuAclElement && !itemToCopy.ignoreAclElementsConfig){
			var uniqueId = itemToCopy.id;
			item = {
				id: uniqueId,
				name: itemToCopy.name,
				label: itemToCopy.label,
			};
			itemType = itemType || ZhuAclConfig.containerType;
			var aclType = ZhuAclConfig.getAclMap(itemType);
			aclType.childs.forEach(function(type){
				if(Util.isArray(itemToCopy[type])){
					item[type] = itemToCopy[type].map(function(child){
						return copyItem(child, type, uniqueId);
					}).filter(function(copiedChild){
						return copiedChild;
					});
				}
			});
		}
		return item;
	};

	this.containerElementsTreeAfterLoadDataSource = function(){
		clearIdErrorsMessage();
		var widget = getContainerElementsTreeWidget();
		var elementsListWidget = getContainerElementsListWidget();
		var elementsListRow = elementsListWidget && elementsListWidget.currentRow;
		var rulesData = Util.clone(widget.dataSource.data);
		widget.dataSource.data = [];

		if(elementsListRow && elementsListRow.SELECT_ACCESS){
			var rules = ZhuAclController.getRulesFromDatasource(rulesData);
			var container = copyItem(templateManager.container);
			if(container){
				aclEngine.processAcl(container, rules, templateManager.userId, templateManager.project.elementListDefaultRule || ZhuAclController.getDefaultRule());
				widget.dataSource.data = getPlannedContainer(rules, container);
				showIdErrorsMessage();
			}
		}
	};

	this.isEditableOnChange = function(currentRow){
		var widget = getContainerElementsTreeWidget();
		ZhuAclCRUDController.changeIsEditable(widget, currentRow);
	};

	this.isVisibleOnChange = function(currentRow){
		var widget = getContainerElementsTreeWidget();
		ZhuAclCRUDController.changeIsVisible(widget, currentRow);
	};
}

Configuration(function(ContextRegister){
	ContextRegister.register('ZhuContainerElementsController', ZhuContainerElementsController);
});

// FILE: assets/js/controllers/ZhuMenuElementsController.js
/* global Configuration Util ZhuAclMessages */
function ZhuMenuElementsController(ScreenService, templateManager, ZhuAclController, ZhuAclConfig, aclEngine, ZhuAclCRUDController, MessageService){
	var MENU = "M";
	var GROUP_MENU = "G";
	var IGNORED_MENUS = ['zhHistory'];
	var idErrorMessages = {"errorMenus": "", "errorContainers": ""};

	var getWidgetElements = function(){
		return templateManager.container.getWidget(ZhuAclConfig.menuElementsListWidgetName);
	};

	var clearIdErrorsMessage = function(){
		idErrorMessages = {"errorMenus": "", "errorContainers": ""};
	};

	var showIdErrorsMessage = function(){
		var messageCode;
		var errorMenus = idErrorMessages.errorMenus;
		var errorContainers = idErrorMessages.errorContainers;
		var messageParameters = {
			elementsIds: errorMenus,
			elementsWithoutContainer: errorContainers
		};

		if(errorMenus && errorContainers){
			messageCode = ZhuAclMessages.NSHOW_WITHOUT_ID_AND_CONTAINER_CONFIG;
		} else if(errorMenus){
			messageCode = ZhuAclMessages.NSHOW_WITHOUT_ID;
		} else if(errorContainers){
			messageCode = ZhuAclMessages.NSHOW_WITHOUT_CONTAINER_CONFIG;
		}

		if(messageCode){
			MessageService.showMessageByCode(messageCode, messageParameters, { type: 'alert' });
		}
	};

	var addErrorMenuId = function(item){
		var nameToShow = item.label || item.name;
		idErrorMessages.errorMenus += "<br> " + nameToShow + ";";
	};

	var addErrorContainerId = function(item){
		var nameToShow = item.label || item.name;
		idErrorMessages.errorContainers += "<br> " + nameToShow + ";";
	};

	this.elementsActionEventEdit = function(currentRow){
		if(!currentRow.buildedMenu){
			var elementsWidget = getWidgetElements();
			currentRow.isEditable = !currentRow.isEditable;
			ZhuAclCRUDController.changeIsEditable(elementsWidget, currentRow);
		}
	};

	this.elementsActionEventView = function(currentRow){
		if(!currentRow.buildedMenu){
			var elementsWidget = getWidgetElements();
			currentRow.isVisible = !currentRow.isVisible;
			currentRow.isEditable = currentRow.isVisible;
			ZhuAclCRUDController.changeIsVisible(elementsWidget, currentRow);
		}
	};

	this.elementsActionEventBack = function(){
		var elementsWidgetParent = getWidgetElements().parent;
		return ScreenService.closeSwipe().then(function(){
			elementsWidgetParent.list();
			elementsWidgetParent.activate();
		});
	};

	var addContainerProperties = function(item, menuItem, rules){
		var containerId = menuItem.containerId;
		var containerLabel = menuItem.containerLabel || menuItem.containerName;
		if(containerId && containerLabel){
			var containerRule = ZhuAclController.getElementRule(rules, containerId);
			item.CONTAINER_ID = containerId;
			item.CONTAINER_NAME = menuItem.containerName || ZhuAclController.prepareLabelToName(containerLabel);
			item.CONTAINER_LABEL = containerLabel;
			item.CONTAINER_RULE_ID = containerRule.RULE_ID;
		} else if(menuItem.windowName && !menuItem.buildedMenu){
			addErrorContainerId(menuItem);
		}
	};

	var planningMenuItem = function(menuItem, parentMenuItem, rules){
		var item;
		var uniqueId = menuItem.id;
		if(uniqueId){
			var parentId = parentMenuItem && parentMenuItem.id;
			var itemType = !parentId ? GROUP_MENU : MENU;
			item = ZhuAclController.getPlannedItemToInsertInDataSet(rules, menuItem, itemType, parentId);
			item.buildedMenu = menuItem.buildedMenu;
			addContainerProperties(item, menuItem, rules);
		} else {
			addErrorMenuId(menuItem);
		}

		return item;
	};

	var addMenusInDataSource = function(widget, rules, menus, parentMenu){
		menus.forEach(function(menu, index){
			var item = planningMenuItem(menu, parentMenu, rules);
			if(item){
				widget.dataSource.data.push(item);
				if (menu.menus && menu.menus.length > 0){
					addMenusInDataSource(widget, rules, menu.menus, menu);
				}
			}
		});
	};

	var getProjectMenu = function(){
		var projectMenu = Util.clone(templateManager.project.groupMenu);
		return projectMenu.filter(function(menu){
			return IGNORED_MENUS.indexOf(menu.name) == -1;
		});
	};

	this.loadPlanningTree = function(){
		var elementsWidget = getWidgetElements();
		var userId = templateManager.userId;
		var rules = ZhuAclController.getRulesFromDatasource(elementsWidget.dataSource.data);
		var newMenu = getProjectMenu();
		clearIdErrorsMessage();
		aclEngine.processMenuAcl(newMenu, rules, templateManager.containers, userId, templateManager.project.elementListDefaultRule || ZhuAclController.getDefaultRule());
		elementsWidget.dataSource.data = [];
		addMenusInDataSource(elementsWidget, rules, newMenu);
		showIdErrorsMessage();
	};

	this.reloadElementsWidget = function(){
		getWidgetElements().reload();
	};
}

Configuration(function(ContextRegister){
	ContextRegister.register('ZhuMenuElementsController', ZhuMenuElementsController);
});

// FILE: assets/js/adapter/config.js
ZeedhiApp.run(function(templateManager, ZhuAccessButtonService) {
	templateManager.projectPromise.then(function(project){
		if(templateManager.project.aclEnable){
			ZhuAccessButtonService.insertButtonInProject(templateManager.project);
		}
	});
});


// FILE: ./bower_components/zhulog/dist/main.js

// FILE: src/services/ZhuLogService.js
/* global Util, Configuration */
function ZhuLogService() {

    this.getPlainContentRows = function(value) {
        var data = [];
        var objValue = JSON.parse(value);

        createRows(data, objValue);
        return data;
    };

    function createRows(data, value, parent) {
        Object.keys(value).forEach(function(key) {
            createRow(data, key, value[key], parent);
        });
    }

    function createRow(data, key, value, parent) {
        var method;
        if (Util.isObject(value)) {
            method = factoryCreateObjectRowsMethod();
        } else if (Array.isArray(value)) {
            method = factoryCreateArrayRowsMethod();
        } else {
            method = createSimpleRow;
        }

        method(data, key, value, parent);
    }

    function factoryCreateObjectRowsMethod() {
        return factoryCreateObjectRows(': {}');
    }

    function factoryCreateArrayRowsMethod() {
        return factoryCreateObjectRows(': []');
    }

    function createSimpleRow(data, key, value, parent) {
        if (typeof value === 'string') {
            value = '"' + value + '"';
        }

        value = key + ': ' + value;
        addData(key, value, parent, data);
    }

    function addData(key, value, parent, data) {
        var id = parent + '#' + key;
        data.push({
            'ID': id,
            'VALUE': value,
            'PARENT': parent
        });

        return id;
    }

    function factoryCreateObjectRows(emptySufix) {
        return function createObjectRows(data, key, rowContent, parent) {
            var rowValue = key;
            if (Object.keys(rowContent).length === 0) {
                rowValue += emptySufix;
            }

            var id = addData(key, rowValue, parent, data);
            createRows(data, rowContent, id);
        };
    }

}

Configuration(function (ContextRegister) {
    ContextRegister.register('ZhuLogService', ZhuLogService);
});

// FILE: src/controllers/ZhuLogController.js
/* global Util, Configuration */
function ZhuLogController(ZhuLogService, ScreenService, templateManager, metaDataFactory, ZhPreferences, ZhFilterPreferences, $timeout, requestEngine, requestFactory) {

    var self = this;

    var LOG_WIDGET_NAME = 'zhuLog';
    var CONTENT_WIDGET = 'content';
    var CONTENT_FORM_WIDGET = 'contentForm';
    var CONTENT_GRID_WIDGET = 'contentGrid';
    var CONTENT_FILTER_WIDGET = 'select';
    
    var USER_ID_FIELD = 'USER_ID';
    var LOG_CONFIGURATION_WIDGET = 'logConfigurationWidget';

    var REMOVE = 'remove';
    var ALLOW = 'allow';
    var ALL = 'all';

    /**
     * Generates uniqid for element.
     *
     * @return {string}
     */
    function uniqid() {
        return Math.random().toString(10).substring(2, 15) + Math.random().toString(10).substring(2, 15);
    }

    /**
     * Closes the swipe and activates zhulog widget.
     *
     * @param {Widget} widget The swipe child widget.
     */
    this.closeSwipe = function(widget){
        ScreenService.closeSwipe();
        widget.container.getWidget(LOG_WIDGET_NAME).activate();
    };

    this.showActiveAll = function (widget) {
        requestEngine.doRequest(
            requestFactory.factory(
                {
                    serviceName: 'zhulog#/logConfiguration/areAllActive',
                    requestType: 'filterData'
                }
            )
        ).then(function (response) {
            var status = response.dataset.status[0];
            widget.getAction("allowAll").isVisible = !status;
            widget.noMatchText = status ? "All users allowed!" : "No user allowed!";
            widget.activate();
        });
    };

    /**
     * Prepare and opens popUp for user log allowance configuration.
     *
     * @param {Widget} widget
     */
    this.openPopUp = function (widget) {
        var popUpDefaults = {
            "id": uniqid(),
            "name": "controlPopUp",
            "showDescriptionOrder": false,
            "label": "Allow User's Log",
            "template": "widget/grid.html",
            "showCheckbox": true,
            "isVisible": true,
            "itemsPerPage": 30,
            "events": [
                {
                    "name": "WidgetAfterSelectRow",
                    "code": "ZhuLogController.setPopUpAllowActionVisiblity(args.owner, true)",
                },
                {
                    "name": "WidgetAfterUnselectRow",
                    "code": "ZhuLogController.setPopUpAllowActionVisiblity(args.owner, false)",
                }
            ],
            "parent": widget,
            "floatingControl": {
                "searchAction": true,
                "customizationAction": {
                    "filter": true,
                    "layout": false,
                    "view": false,
                },
                "xlsAction": false,
                "pdfAction": false,
                "csvAction": false,
            },
            "dataSource": {
                "rest": true,
                "localStorage": false,
                "data": [],
                "name": "/operador",
                "itemsPerPage": 30,
            },
            "dataSourceFilter": [
                {
                    "name": "IDATIVO",
                    "operator": "=",
                    "value": "S",
                }
            ],
            "fields": [
                {
                    "id": uniqid(),
                    "name": "CDOPERADOR",
                    "label": "ID",
                    "operator": "NOT IN",
                    "template": "field/text.html",
                    "isVisible": true,
                    "showOnList": true,
                },
                {
                    "id": uniqid(),
                    "name": "NMOPERADOR",
                    "label": "Name",
                    "template": "field/text.html",
                    "isVisible": true,
                    "showOnList": true,
                },
                {
                    "id": uniqid(),
                    "name": "DSEMAILOPER",
                    "label": "Email",
                    "template": "field/text.html",
                    "isVisible": true,
                    "showOnList": true,
                },
                {
                    "id": uniqid(),
                    "name": "NRORG",
                    "label": "Organization",
                    "template": "field/select.html",
                    "dataSource": {
                        "name": "/organization",
                        "rest": true,
                        "localStorage": false,
                        "data": [],
                    },
                    "dataSourceFilter": [],
                    "valueField": "ID",
                    "descriptionField": "NAME",
                    "isVisible": true,
                    "showOnList": true,
                },
            ],
            "actions": [
                {
                    "id": uniqid(),
                    "name": "allow",
                    "label": "Allow",
                    "isVisible": false,
                    "showAsAction": "never",
                    "events": [
                        {
                            "name": "ActionEvent",
                            "code": "ZhuLogController.setZhuLogConfiguration(args.owner.widget," + ALLOW + ")",
                        },
                    ],
                },
                {
                    "id": uniqid(),
                    "name": "back",
                    "label": "Cancel",
                    "isVisible": true,
                    "showAsAction": "back",
                    "events": [
                        {
                            "name": "ActionEvent",
                            "code": "ScreenService.closePopup()",
                        },
                    ],
                },
            ],
        };

        if (widget.dataSource.data.length) {
            popUpDefaults.dataSourceFilter.push(
                {
                    "name": "CDOPERADOR",
                    "operator": "NOT_IN",
                    "value": widget.dataSource.data.map(function(user){ return user[USER_ID_FIELD]; }),
                }   
            );
        }

        var popUp = metaDataFactory.widgetFactory(popUpDefaults, widget.container);
        ScreenService.openPopup(popUp);
    };

    /**
     * Switches the popUp allow action visibility.
     */
    this.setPopUpAllowActionVisiblity = function (widget, isVisible) {
        var action = widget.getAction(ALLOW);
        action.isVisible = isVisible;
        widget.activate();
    };

    /**
     * Switches log allowance for product status.
     */
    this.switchLogStatus = function (widget) {
        var params = {};
        requestEngine.doRequest(
            requestFactory.factory(
                {
                    serviceName: 'zhulog#/logConfiguration/switch',
                    requestType: 'dataSource',
                    dataSource: params,
                }
            )
        ).then(function (response) {
            widget.container.label = response.dataset.status[0] ? 'Log - Active' : 'Log - Inactive';
            widget.activate();
        });
    };

    /**
     * Changes user and product log allowance configuration.
     *
     * @param {Widget} widget
     * @param {string} method
     */
    this.setZhuLogConfiguration = function (widget, method) {
        var checkedUsers = widget.getCheckedRows();

        var params = {
            all: false,
            deny: false,
            allow: false,
        };

        switch (method) {
            case REMOVE:
                params.deny = true;
                break;
            case ALL:
                params.all = true;
        }

        params.users = !params.all ? checkedUsers : [];

        requestEngine.doRequest(
            requestFactory.factory(
                {
                    serviceName: 'zhulog#/logConfiguration/update',
                    requestType: 'dataSource',
                    dataSource: params,
                }
            )
        ).then(function () {
            ScreenService.closePopup(true);
            parentWidget = widget.container.getWidget(LOG_CONFIGURATION_WIDGET);
            self.showActiveAll(parentWidget);
            parentWidget.reload();
        });
    };

    function getContentWidget() {
        return templateManager.container.getWidget(CONTENT_WIDGET);
    }

    function getContentFormWidget() {
        return templateManager.container.getWidget(CONTENT_FORM_WIDGET);
    }

    function getContentGridWidget() {
        return templateManager.container.getWidget(CONTENT_GRID_WIDGET);
    }

    function getFilterWidget() {
        return templateManager.container.getWidget(CONTENT_FILTER_WIDGET);
    }

    function getZhuLogWidget() {
        return templateManager.container.getWidget(LOG_WIDGET_NAME);
    }

    this.openContent = function (widget) {
        var contentFormWidget = getContentFormWidget();
        contentFormWidget.currentRow = widget.currentRow;

        var rows = ZhuLogService.getPlainContentRows(widget.currentRow.CONTENT);
        getContentGridWidget().dataSource.data = rows;

        ScreenService.openSwipe(getContentWidget());
    };

    var startFilter = function (widget, currentRow) {
        ZhPreferences.getDefaultWidgetPreferences(widget.id).then(function (result) {
            if (result) {
                ZhFilterPreferences.openFilterWidget(widget, currentRow);
            }
        });
    };

    var isAppliedFilter = function (widget) {
        return !!widget.zhuLogAppliedFilter;
    };

    function setStatusToContainersLabel(widget) {
        requestEngine.doRequest(
            requestFactory.factory(
                {
                    serviceName: 'zhulog#/logConfiguration/status',
                    requestType: 'filterData'
                }
            )
        ).then(function (response) {
            widget.container.label = response.dataset.status[0] ? 'Log - Active' : 'Log - Inactive';
            widget.activate();
        });
    }

    this.zhuLogWidgetOnEnter = function () {
        var widget = getZhuLogWidget();
        $timeout(function () {
            if (widget.inListMode()) {
                if (isAppliedFilter(widget)) {
                    widget.reload();
                } else {
                    var currentRow = widget.currentRowDefaultFilter || widget.currentRow;
                    ZhFilterPreferences.setOriginalFilter(widget.id, currentRow);
                    startFilter(widget, currentRow);
                }
            }
            setStatusToContainersLabel(widget);
        }, 500, false);
    };

    this.zhuLogFilterAfterApply = function () {
        getZhuLogWidget().zhuLogAppliedFilter = true;
    };

    this.openFilterPopUp = function () {
        ScreenService.openPopup(getFilterWidget());
    };

    this.setSelectValues = function () {
        var selectWidget = templateManager.container.getWidget('select');
        var select2 = templateManager.container.getWidget('select').fields[1];

        if (selectWidget.currentRow.SNATIVE === 'REQUEST') {
            select2.label = 'Resquest type';
            select2.readOnly = false;

            select2.dataSource.data = [];
            select2.dataSource.data.push(
                { 'value': 'Dataset' },
                { 'value': 'Row' },
                { 'value': 'Empty' },
                { 'value': 'Filter' }
            );
        } else {
            if (selectWidget.currentRow.SNATIVE === 'RESPONSE') {
                select2.label = 'Response type';
                select2.readOnly = false;

                select2.dataSource.data = [];
                select2.dataSource.data.push(
                    {
                        'value': 'Dataset'
                    },
                    {
                        'value': 'Message'
                    }
                );
            } else {
                select2.dataSource.data = [];
                this.clearFieldsValue(1);
                select2.readOnly = true;
            }
        }
    };

    this.setTextEdit = function () {
        var selectWidget = templateManager.container.getWidget('select');

        selectWidget.actions[2].isVisible = true;
        selectWidget.actions[3].isVisible = true;
        // selectWidget.fields[2].isVisible = true;
        // selectWidget.fields[3].isVisible = true;

        if (selectWidget.currentRow.SNATIVE === 'REQUEST') {
            if (selectWidget.currentRow.SNATIVE2 === 'Dataset' || selectWidget.currentRow.SNATIVE2 === 'Row') {
                selectWidget.fields[2].label = 'Column name';
                selectWidget.fields[3].label = 'Operator';
                selectWidget.fields[3].template = 'field/select-native.html';
                selectWidget.fields[4].label = 'Value';
                this.addFields();
            }

            if (selectWidget.currentRow.SNATIVE2 === 'Empty') {
                selectWidget.fields[2].label = 'Parameter';
                selectWidget.fields[3].label = 'Operator';
                selectWidget.fields[3].template = 'field/select-native.html';
                selectWidget.fields[4].label = 'Value';

                this.addFields();
            }

            if (selectWidget.currentRow.SNATIVE2 === 'Filter') {
                selectWidget.fields[2].label = 'Column name';
                selectWidget.fields[3].label = 'Column value';
                selectWidget.fields[3].template = 'field/text-edit.html';
                selectWidget.fields[4].label = 'Value';

                this.addFields();
            }

            if (selectWidget.currentRow.SNATIVE2 === null) {
                this.removeExtraFields();
            }
        } else {
            if (selectWidget.currentRow.SNATIVE === 'RESPONSE') {
                if (selectWidget.currentRow.SNATIVE2 === 'Dataset') {
                    selectWidget.fields[2].label = 'Column name';
                    selectWidget.fields[3].label = 'Operator';
                    selectWidget.fields[3].template = 'field/select-native.html';
                    selectWidget.fields[4].label = 'Value';
                    this.addFields();
                }

                if (selectWidget.currentRow.SNATIVE2 == 'Message') {
                    selectWidget.fields[2].label = 'Column name';
                    selectWidget.fields[3].label = 'Operator';
                    selectWidget.fields[3].template = 'field/select-native.html';
                    selectWidget.fields[4].label = 'Value';
                    this.addFields();
                }

                if (selectWidget.currentRow.SNATIVE2 === null) {
                    this.removeExtraFields();
                }
            }
        }
    };

    this.removeExtraFields = function () {
        var selectWidget = templateManager.container.getWidget('select');
        var fields = selectWidget.fields;

        for (var i = (fields.length - 1); i > 6; i--) {
            if (!Util.isUndefined(fields[i])) {
                delete selectWidget.currentRow[fields[i].name];
                delete fields[i];
            }
        }
    };

    this.addFields = function () {
        var selectWidget = templateManager.container.getWidget('select');
        var fields = templateManager.container.getWidget('select').fields;
        var field;
        var dataSource;

        for (var i = 2; i <= 6; i++) {
            if (i !== 5) {
                var data;

                if (!Util.isUndefined(fields[i].dataSource)) {
                    data = fields[i].dataSource.data;
                    dataSource = {
                        'data': data
                    };
                }

                field = {
                    label: fields[i].label,
                    template: fields[i].template,
                    name: 'extraField' + fields.length,
                    class: fields[i].class,
                    events: fields[i].events,
                    dataSource: dataSource,
                    valueField: fields[i].valueField,
                    descriptionField: fields[i].descriptionField,
                    isVisible: true,
                    breakline: fields[i].breakline
                };

                metaDataFactory.fieldFactory(field, selectWidget, selectWidget);
            } else {
                field = {
                    label: fields[i].label,
                    template: fields[i].template,
                    name: 'extraField' + fields.length,
                    class: fields[i].class,
                    events: fields[i].events,
                    dataSource: dataSource,
                    valueField: fields[i].valueField,
                    descriptionField: fields[i].descriptionField,
                    isVisible: false,
                    breakline: fields[i].breakline
                };

                metaDataFactory.fieldFactory(field, selectWidget, selectWidget);
            }
        }
    };

    this.clearAllFields = function () {
        this.removeExtraFields();
        this.clearFieldsValue(0);
    };

    this.clearFieldsValue = function (startingValue) {
        var selectWidget = templateManager.container.getWidget('select');

        for (var i = startingValue; i < selectWidget.fields.length; i++) {
            if (!Util.isUndefined(selectWidget.fields[i])) {
                if (selectWidget.fields[i].value !== '') {
                    selectWidget.fields[i].value('');
                }
            }
        }

        selectWidget.fields[1].readOnly = true;
    };

    this.clearFields = function (args) {
        var fieldIndex = args.owner.field.sequenceInList;
        fieldIndex--;

        var selectWidget = templateManager.container.getWidget('select');
        var fields = selectWidget.fields;

        for (var i = fieldIndex; i >= fieldIndex - 4; i--) {

            delete selectWidget.currentRow[fields[i].name];
            delete fields[i];
        }

        templateManager.updateTemplate();
    };

    this.manageFields = function (args) {
        var operatorIndex = args.owner.field.sequenceInList;
        operatorIndex--;

        var selectWidget = templateManager.container.getWidget('select');
        var selectedfield = selectWidget.fields[operatorIndex];
        var selectedValue = selectedfield.value();

        if (selectedValue === 'IS_NULL' || selectedValue === 'IS_NOT_NULL') {
            selectWidget.fields[operatorIndex + 1].readOnly = false;
            selectWidget.fields[operatorIndex + 1].class = 4;
            selectWidget.fields[operatorIndex + 2].isVisible = false;
            selectWidget.fields[operatorIndex + 1].readOnly = true;
        } else if (selectedValue === 'BETWEEN' || selectedValue === 'NOT_BETWEEN') {
            selectWidget.fields[operatorIndex + 1].class = 2;
            selectWidget.fields[operatorIndex + 1].label = 'Begin';
            selectWidget.fields[operatorIndex + 2].isVisible = true;
        } else {
            selectWidget.fields[operatorIndex + 1].readOnly = false;
            selectWidget.fields[operatorIndex + 1].class = 4;
            selectWidget.fields[operatorIndex + 1].label = 'Value';
            selectWidget.fields[operatorIndex + 2].isVisible = false;
        }
    };

    this.startFiltering = function () {
        var selectWidget = templateManager.container.getWidget('select');
        var fields = selectWidget.fields;

        var i = 9;
        var j = 0;
        var params = [];

        while (i < fields.length) {
            if (!Util.isUndefined(fields[i])) {
                var name = fields[i].value();
                i++;
                var operator = fields[i].value();
                i++;

                var value;
                if (operator === 'IS_NULL' || operator === 'IS_NOT_NULL') {

                    value = '';
                    i += 3;

                } else if (operator === 'BETWEEN' || operator === 'NOT_BETWEEN') {
                    value = [];
                    value[0] = fields[i].value();
                    i++;
                    value[1] = fields[i].value();
                    i += 2;
                } else {
                    value = fields[i].value();
                    i += 3;
                }

                params[j] = {
                    name: name,
                    operator: operator,
                    value: value
                };
                j++;
            } else {
                i += 5;
            }
        }

    };
}

Configuration(function (ContextRegister) {
    ContextRegister.register('ZhuLogController', ZhuLogController);
});

// FILE: src/ZhuLogDecorator.js
/* global Configuration */
function ZhuLogDecorator(ApplicationContext, templateManager) {

    var LOG_CONTAINER_NAME = 'zhulog#log';
    var GRID_WIDGET_INDEX = 0;

    var logDecorator;
    function getLogDecorator() {
        if (logDecorator === undefined) {
            logDecorator = templateManager.projectPromise.then(function() {
                var decoratorServiceName = templateManager.project.zhuLogDecoratorService;
                var logDecorator = ApplicationContext[decoratorServiceName];

                return logDecorator;
            });
        }
        return logDecorator;
    }

    this.afterLoadDataSource = function(args) {
        getLogDecorator().then(function(logDecorator) {
            if (logDecorator) {
                var dataSource = args.owner.dataSource;
                dataSource.data = logDecorator.normalizeRows(dataSource.data);
            }
        });
    };

    this.beforeGridFilterApply = function(args) {
        getLogDecorator().then(function(logDecorator) {
            if (logDecorator) {
                var _event = args.e;
                _event.filters = logDecorator.normalizeFilters(_event.preference.FILTER_ROW);
            }
        });
    };

    this.apply = function(containerName, container) {
        return getLogDecorator().then(function(logDecorator) {
            if (logDecorator && containerName === LOG_CONTAINER_NAME) {
                var logWidget = container.widgets[GRID_WIDGET_INDEX];

                logWidget.events.push({
                    "name": "WidgetAfterLoadDataSource",
                    "code": "ZhuLogDecorator.afterLoadDataSource(args);"
                });

                logWidget.events.push({
                    "name": "FilterBeforeApply",
                    "code": "ZhuLogDecorator.beforeGridFilterApply(args);"
                });

                logDecorator.decorateWidget(logWidget);
            }

            return container;
        });
    };

}

Configuration(function (ContainerDecoratorProvider, ContextRegister, ApplicationContext, templateManager) {
    ContextRegister.register('ZhuLogDecorator', ZhuLogDecorator);
    ContainerDecoratorProvider.registerProvider(new ZhuLogDecorator(ApplicationContext, templateManager));
});

// FILE: src/ZhuLogHelper.js
/* global Util, Configuration */
function ZhuLogHelper() {

    this.moveField = function(widget, fieldName, position) {
        var index = -1;
        widget.fields.find(function(field) {
            index++;
            return field.name === fieldName;
        });
        widget.fields.splice(position - 1, 0, widget.fields.splice(index, 1)[0]);
    };

    this.getField = function(widget, fieldName) {
        var field = widget.fields.find(function(field) {
            return field.name === fieldName;
        });

        if (field === null) {
            throw 'Field "'+fieldName+'" not found';
        }

        return field;
    };

    this.addField = function(widget, field, position) {
        position = (position || widget.fields.length) - 1;
        widget.fields.splice(position, 0, field);
    };

    this.removeField = function(widget, fieldName) {
        widget.fields = widget.fields.filter(function(field) {
            return field.name !== fieldName;
        });
    };

    this.editField = function(widget, fieldName, editings) {
        var field = this.getField(widget, fieldName);
        Util.extend(field, editings);
    };

    this.getFilters = function(filters, filterName) {
        return filters.filter(function(filter) {
            return filter.name === filterName;
        });
    };

    this.addFilter = function(filters, filter) {
        filters.push(filter);
    };

    this.removeFilter = function(filters, filterName) {
        filters = filters.filter(function(filter) {
            return filter.name !== filterName;
        });
    };

}

Configuration(function(ContextRegister) {
    ContextRegister.register('ZhuLogHelper', ZhuLogHelper);
});

// FILE: ./bower_components/tek-libraries/dist/main.js

// FILE: js/Util/Colors.js
function Colors() {

	this.TColorToHex = function(TColor) {
		var rgb = this.TColorToRGB(TColor);
		return this.rgbToHex(rgb);
	};

	this.TColorToRGB = function(TColor) {
        var r = TColor & 0xFF;
        var g = (TColor >> 8) & 0xFF;
        var b = (TColor >> 16) & 0xFF;
        return [r,g,b];
	};

	this.rgbToHex = function (rgb) {
	    return "#" + ((1 << 24) + (rgb[0] << 16) + (rgb[1] << 8) + rgb[2]).toString(16).slice(1);
	};
	
	this.RGBToTColor = function(r, g, b){
		var Tcolor = r | (g << 8) | (b << 16);
		return Tcolor;
	};
}

Configuration(function(ContextRegister) {
	ContextRegister.register('Colors', Colors);
});

// FILE: js/Util/Endereco.js
var Endereco = function (restEngine, ScreenService, MessageService, ZHPromise) {
    var self = this;

    //Busca pelo CEP na API dos correios e retorna o resultado por promise
    self.buscarCep = function(CEP) {
        CEP = CEP.replace(/[\D]+/g,'');

        if(CEP.length == 8) {
            return restEngine.post('/lib_findAddress', {
                    'requestType':'Row',
                    'row': {'CEP': CEP}
            });
        } else {
            ScreenService.showMessage('CEP Inválido.');
        }
    };

    /* Busca pelo CEP na API dos correios e trata o retorno.
     * Usar apenas de exemplo para fazer um método próprio!
     */
    self.validarCep = function(widget, CEP) {
        self.buscarCep(CEP).then(function(response) {
            var endereco = response.dataset.ENDERECO;

            if(endereco) {
                widget.currentRow.CEP = CEP;
                widget.currentRow.CDPAIS = (endereco.CDPAIS)? endereco.CDPAIS : '';
                widget.currentRow.NMPAIS = (endereco.NMPAIS)? endereco.NMPAIS : '';
                widget.currentRow.SGESTADO = (endereco.SGESTADO)? endereco.SGESTADO : '';
                widget.currentRow.NMESTADO = (endereco.NMESTADO)? endereco.NMESTADO : '';
                widget.currentRow.CDMUNICIPIO = (endereco.CDMUNICIPIO)? endereco.CDMUNICIPIO : '';
                widget.currentRow.NMMUNICIPIO = (endereco.NMMUNICIPIO)? endereco.NMMUNICIPIO : '';
                widget.currentRow.CDBAIRRO = (endereco.CDBAIRRO)? endereco.CDBAIRRO : '';
                widget.currentRow.NMBAIRRO = (endereco.NMBAIRRO)? endereco.NMBAIRRO : '';
                widget.currentRow.CDLOGRADOURO = (endereco.CDLOGRADOURO)? endereco.CDLOGRADOURO : '';
                widget.currentRow.DSLOGRADOURO = (endereco.DSLOGRADOURO)? endereco.DSLOGRADOURO : '';
                widget.currentRow.DSENDERECO = (endereco.DSENDERECO)? endereco.DSENDERECO : '';
            } else {
                widget.currentRow.CEP = '';
            }
        }, function(error) {            
            MessageService.getMessageByCode("PROXY_CONNECTION_FAIL").then(function(errorMessage) {
                var row = {
                    "CEP": CEP, 
                    "errorMessage": errorMessage
                };
                widget.currentRow.CEP = '';

                if(error.data)
                    errorMessage = error.data.error;
            
                ScreenService.showMessageByCode("REQUEST_CEP_ERROR", row, Constants.errorMessage);
            });
        });
    };
};

Configuration(function (ContextRegister) {
    ContextRegister.register('Endereco', Endereco);
});

// FILE: js/Util/General.js
var General = function (ScreenService, templateManager, localStorageEngine, restEngine, maskEngine, ZhUtil, ZHPromise, ValidationEngine, metaDataFactory, MessageService) {
	var searchListDeleted;
	var parent = this;
	var cacheLoaded = false;

	//@TODO Criar objeto de mensagens para tradução.

	/*
	 * Função que atualiza o dataSourceFilter de um field que depende do resultado de
	 * outro. Realiza o reload apenas ao clicar no field, evitando requisições desnecessárias.
	 * OBS.: para o funcionamento correto, é necessário limpar o value do field dependente
	 * ao alterar o valor do field "pai".
	 *
	 * @param field dependentField
	 * @param array parameters
	 *
	 * Exemplo:
	 * General.onClickDependentField(meuField, {nomeParametro1: valorParametro1, nomeParametro2: valorParametro2});
	 */
	this.onClickDependentField = function (dependentField, parameters) {

		var dataSourceFilterNew = this.buildDataSourceFilter(angular.copy(dependentField.dataSourceFilter), parameters);

		var changedDataSourceFilter = compareDataSourceFilters(dependentField.selectWidget, dataSourceFilterNew, parameters);

		if (changedDataSourceFilter) {
			changeDependetFieldFilter(dependentField, dataSourceFilterNew);
		}

		if ((dependentField.selectWidget && changedDataSourceFilter) || (!dependentField.dataSource.data || !dependentField.dataSource.data.length) || searchListDeleted) {
			dependentField.reload();
		}
	};

	this.buildDataSourceFilter = function (dataSourceFilter, parameters) {
		if (!dataSourceFilter) {
			throw "DataSourceFilter is not defined!";
		}

		for (var position in dataSourceFilter) {
			if (parameters.hasOwnProperty(dataSourceFilter[position].name)) {
				dataSourceFilter[position].value = parameters[dataSourceFilter[position].name];
			}
		}

		return dataSourceFilter;
	};

	var changeDependetFieldFilter = function (dependentField, dataSourceFilterNew) {

		dependentField.dataSourceFilter = dataSourceFilterNew;
		dependentField.dataSource.lazyLoad = false;
		if (dependentField.selectWidget) {
			dependentField.selectWidget.dataSourceFilter = dataSourceFilterNew;
		}

		if (dependentField.selectWidget && dependentField.selectWidget.searchList) {

			searchListDeleted = true;
			delete dependentField.selectWidget.searchList;

		} else if (dependentField.selectWidget) {

			searchListDeleted = false;

		}

	};

	var compareDataSourceFilters = function (selectWidget, dataSourceFilterNew, parameters) {
		var changedDataSourceFilter = false;
		if (selectWidget) {
			var selectWidgetDataSourceFilter = selectWidget.dataSourceFilter;
			for (var position = 0; position < dataSourceFilterNew.length; position++) {
				if (parameters.hasOwnProperty(dataSourceFilterNew[position].name)) {
					if (selectWidgetDataSourceFilter[position].value != dataSourceFilterNew[position].value) {
						changedDataSourceFilter = true;
					}
				}
			}
		} else {
			changedDataSourceFilter = true;
		}
		return changedDataSourceFilter;
	};

	/*
	 * Função que gera e retorna a totalização e o nível para agrupamento dos pratos
	 * ou produtos correspondentes à máscara utilizada. Através de cada nível
	 * da máscara, é gerado o número correspondente à ele.
	 *
	 * @param string maskName
	 * @param int firstLevel
	 *
	 * @return array
	 *
	 * Exemplo:
	 * General.getLevelByMask('CDPICTPRAT', 1);
	 */
	this.getLevelByMask = function (maskName, firstLevel) {

		firstLevel = toNumber(firstLevel);

		var mask = getLocalVar(maskName);
		var splitMask = mask.split('.');
		var biggestLevel = splitMask.length;

		var level = [];
		var objLevel = {};

		for (var i = 0; i < biggestLevel; i++) {

			objLevel = {
				nivel: i + firstLevel,
				caracteres: i > 0 ? parseInt(level[i - 1].caracteres) + parseInt(splitMask[i].length) : parseInt(splitMask[i].length)
			};

			objLevel.nivel = objLevel.nivel.toString();
			objLevel.caracteres = objLevel.caracteres.toString();

			level.push(objLevel);
		}

		return level;
	};

	var toNumber = function (value) {

		if (!value && value !== 0) {

			throw 'firstLevel is not defined';

		} else if (typeof value !== 'number' && value) {

			value = parseInt(value);

			if (isNaN(parseInt(value))) {

				throw 'Invalid firstLevel';

			} else {

				return value;
			}
		}
		return value;
	};

	this.toggleReadOnlySelect = function (checkboxField, selectField) {

		if (checkboxField.checked) {
			selectField.readOnly = true;
			selectField.validations = {};
			selectField.setValue('');
		} else {
			selectField.readOnly = false;
			selectField.validations = {
				required: true
			};
		}
		templateManager.updateTemplate();
	};

	this.setLoggedUnit = function (widget) {
		widget.currentRow.CDFILIAL = getLocalVar('CDFILIAL');
		widget.currentRow.NMFILIAL = getLocalVar('NMFILIAL');
	};

	var currentIdgrupoper;
	var currentCallback;
	var currentParameters;
	var gruposDeOperador = {
		LCMR: 'A liberação de cardápio fora da meta dependente de autorização'
	};
	var fields = [
		{
			"name": "email",
			"label": "E-mail",
			"class": 12,
			"isVisible": true,
			"readOnly": false,
			"template": "field/text-edit.html",
			"events": [],
			"fieldGroup": "AUTH",
			"validations": {
				"required": true,
				"mail": true
			}
        },
		{
			"name": "senha",
			"label": "Senha",
			"class": 12,
			"isVisible": true,
			"readOnly": false,
			"fieldGroup": "AUTH",
			"template": "field/password-edit.html",
			"events": [],
			"validations": {
				"required": true
			}
        }
    ];
	var actions = [
		{
			"name": "cancelar",
			"label": "Cancelar",
			"idVisible": true,
			"hideIcon": true,
			"showAsAction": "back",
			"events": [
				{
					"name": "ActionEvent",
					"code": "ScreenService.closePopup();"
                }
            ]
        },
		{
			"name": "confirmar",
			"label": "Confirmar",
			"idVisible": true,
			"hideIcon": true,
			"showAsAction": "never",
			"events": [
				{
					"name": "ActionEvent",
					"code": "General.validateUser(args.owner.widget);"
                }
            ]
        }
    ];

	this.openAuthPopup = function (idgrupoper, message, callback, parameters) {

		if (!idgrupoper) {
			throw 'idgrupoper is not defined';
		}

		initAuthVariables(idgrupoper, callback, parameters);

		if (!message) {
			message = gruposDeOperador[currentIdgrupoper] || '';
		}

		var widgetAuth = metaDataFactory.widgetFactory({
			"id": 0,
			"name": "authWidget",
			"label": "Autenticação",
			"template": "widget/form.html",
			"container": templateManager.container,
			"isVisible": true,
			"popupNoBlock": false,
			"fieldGroups": [
				{
					"id": 100000,
					"name": "AUTH",
					"opened": true,
					"collapsible": false,
					"label": message
                }
            ],
			"fields": fields,
			"actions": actions,
			"events": []
		});

		ScreenService.openPopup(widgetAuth);

	};

	var initAuthVariables = function (idgrupoper, callback, parameters) {
		currentIdgrupoper = idgrupoper;
		currentCallback = callback || null;
		currentParameters = parameters || [];
	};

	this.validateUser = function (widget) {

		var self = this;

		if (widget.isValid()) {

			var email = widget.currentRow.email;
			var senha = widget.currentRow.senha;

			autenticar(email, senha).then(function (callback) {

				getPermission(callback.dataset.user.cdoperador).then(function (permission) {

					if (permission) {

						if (typeof currentCallback == 'function') {

							ScreenService.closePopup();

							currentCallback.apply(null, currentParameters);

						} else {

							throw 'callback is not a function';

						}

					} else {

						MessageService.showMessageByCode('lib#GEN_INVALID_OPERGROUP', null, { type: 'ERROR' } );

					}

				}, function (callback) {

					this.callbackError(callback);

				}.bind(self));

			}, function (callback) {

				this.callbackError(callback);

			}.bind(self));
		}

	};

	var autenticar = function (email, senha) {

		return restEngine.request('/Autenticar', {
			"requestType": "FilterData",
			"filter": [
				{
					name: "email",
					operator: "=",
					value: email
                },
				{
					name: "senha",
					operator: "=",
					value: senha
                }
            ]
		});

	};

	var getPermission = function (cdoperador) {

		return restEngine.request('/validateUserGroup', {
			"requestType": "Row",
			"row": {
				"idgrupoper": currentIdgrupoper,
				"cdoperador": cdoperador
			}
		}).then(function (callback) {

			return callback.dataset.permission.isValid;
		});

	};

	this.callbackError = function (callback) {

		if (callback.data) {

			ScreenService.showMessage(ScreenService.i18n(callback.data.error));

		} else {
			
			MessageService.showMessageByCode('lib#GEN_TIMEOUT', null, { type: 'ERROR' } );
		}
	};

	this.comparaPratoProduto = function (pinicial, pfinal, mascara) {
		var mask = {
			type: "fix",
			params: {
				mask: mascara
			}
		};
		pinicial = Util.applyMask(pinicial, mask, maskEngine, ZhUtil).split('.');
		pfinal = Util.applyMask(pfinal, mask, maskEngine, ZhUtil).split('.');
		var nvinicial = pinicial.length;
		var nvfinal = pfinal.length;
		var menornv;
		if (nvinicial > nvfinal) {
			menornv = nvfinal;
		} else {
			menornv = nvinicial;
		}

		var resultado = true;
		var i = 0;

		while (pinicial[i] == pfinal[i] && i < menornv) {
			i++;
		}

		if ((pinicial.hasOwnProperty(i) && !pfinal.hasOwnProperty(i)) || (pinicial[i] > pfinal[i])) {
			resultado = false;
		} else {
			resultado = true;
		}

		return resultado;
	};

	var reportWidget = {
		"id": 0,
		"name": "reportWidget",
		"label": "Tipo de Relatório",
		"template": "widget/form.html",
		"container": {},
		"isVisible": true,
		"popupNoBlock": false,
		"fields": [],
		"actions": [],
		"events": []
	};
	var reportFields = [
		{
			"id": 99999999,
			"name": "QR2TYPE",
			"label": "",
			"class": 12,
			"readOnly": false,
			"isVisible": true,
			"isVisibleForm": true,
			"isVisibleGrid": false,
			"template": "field/radio-group.html",
			"events": [],
			"valueField": "value",
			"descriptionField": "name",
			"defaultOption": 0,
			"dataSource": {
				"data": [
					{
						name: "pdf",
						value: "PDF"
					},
					{
						name: "xls",
						value: "XLS"
					},
					{
						name: "rtf",
						value: "RTF"
					},
					{
						name: "txt",
						value: "TXT"
					}
				]
			}
        }
    ];
	var reportActions = [
		{
			"name": "cancelar",
			"label": "Cancelar",
			"idVisible": true,
			"hideIcon": true,
			"showAsAction": "back",
			"events": [
				{
					"name": "ActionEvent",
					"code": "ScreenService.closePopup();"
                }
            ]
        },
		{
			"name": "confirmar",
			"label": "Confirmar",
			"idVisible": true,
			"hideIcon": true,
			"showAsAction": "never",
			"events": [
				{
					"name": "ActionEvent",
					"code": "General.generateReport(args.owner.widget, args);"
                }
            ]
        }
	];
	
	var reportCallback;
	var reportParameters;
	var reportWidgetParentName;

	this.openReportPopup = function (widget, callback, parameters, reportFormats) {

		reportCallback = callback;
		reportParameters = parameters || [];
		reportWidgetParentName = widget.name;
		reportWidget.container = widget.container;
		reportWidget.fields = reportFields;
		reportWidget.actions = reportActions;

		var reportWidgetInitialized = metaDataFactory.widgetFactory(reportWidget);

		updateReportWidgetFormats(reportWidgetInitialized, reportFormats);

		ScreenService.openPopup(reportWidgetInitialized);
	};

	var updateReportWidgetFormats = function(reportWidget, reportFormats) {
		if (Array.isArray(reportFormats) && reportFormats.length) {
			var formatField = reportWidget.getField("QR2TYPE");
			formatField.dataSource.data = reportFormats;
		}
	};

	this.generateReport = function (widget, args) {

		var reportWidgetParentCurrentRow = widget.container.getWidget(reportWidgetParentName).currentRow;

		reportWidgetParentCurrentRow.QR2TYPE = widget.currentRow.QR2TYPE;

		args.row = reportWidgetParentCurrentRow;

		if (typeof reportCallback == 'function') {

			reportCallback.apply(null, reportParameters);
		}

		ScreenService.closePopup();

	};

	this.saveRow = function (args, closeSwipe) {
		args.owner.widget.saveRow().then(function () {
			var currentRow = args.owner.widget.currentRow;
			currentRow.__is_new = false;
			currentRow.changed = false;
			args
				.owner
				.widget
				.reload();
			if (closeSwipe) {
				ScreenService.closeSwipe();
			}
		});
	};

	this.openSelectionOnce = function (name) {
		var filterWidget = templateManager.container.getWidget(name + "_FILTER");
		if (!filterWidget.wasOpened) {
			filterWidget.edit();
			ScreenService.openPopup(filterWidget);
			filterWidget.wasOpened = true;
		}
	};

	this.openSelection = function (name) {
		var filterWidget = templateManager.container.getWidget(name + "_FILTER");
		filterWidget.edit();
		ScreenService.openPopup(filterWidget);
	};

	this.getContainerName = function () {
		return templateManager.container.name;
	};

	this.backOrCancel = function (args) {
		var deferred = ZHPromise.defer();
		if (args.row.__is_new) {
			args.owner.widget.list(true);
			args.owner.widget.dataSource.data.pop();
			args.owner.widget.currentRow = {};
			deferred.resolve();
		} else if (args.owner.widget.mode === 'edit') {
			args.owner.widget.view();
			for (var i in args.owner.widget.backupRow) {
				args.owner.widget.currentRow[i] = args.owner.widget.backupRow[i];
			}
			deferred.resolve();
			return deferred.promise;
		}
		ScreenService.goBack();
		return deferred.promise;
	};

	this.edit = function (widget) {
		widget.backupRow = angular.copy(widget.currentRow);
		widget.edit();
	};

	this.modEdit = function (widget) {
		parent.edit(widget);
		var widgetParent = widget.widgets;
		if (widgetParent.length)
			parent.setVisibleforTabbed(widgetParent, false, widget);
		// widget.template = widget.formTemplate = widget.templateToForm;
	};

	this.cancelModEdit = function (args, widgetParent) {
		parent.backOrCancel(args).then(function (success) {
			var widget = args.owner.widget;
			var widgetParent = widget.widgets;
			if (widgetParent.length)
				parent.setVisibleforTabbed(widgetParent, true);
			// widget.template = widget.formTemplate = widget.templateToView;
		});
	};

	this.setVisibleforTabbed = function (widgets, isVisible, exception) {
		widgets.forEach(function (widget) {
			if (exception) {
				if (exception.name != widget.name)
					widget.isVisible = isVisible;
			} else {
				widget.isVisible = isVisible;
			}
		});
	};

	this.setContextVar = function (name, containerName, value) {
		localStorageEngine.setLocalVar(containerName + '_' + name, value);
	};

	this.getContextVar = function (name, containerName) {
		return localStorageEngine.getLocalVar(containerName + '_' + name);
	};

	var _getWidget = function (widgetName) {
		var isPopup = arguments[1] || null;
		if (!!templateManager.container) {
			var widget;
			if (!isPopup) {
				widget = templateManager.container.getWidget(widgetName);
			} else {
				widget = templateManager.container.getWidget(widgetName);
				if(widget)
					if(widget.hasOwnProperty('__filterPopup')) 
						widget = widget.__filterPopup;
					else{
						widget = widget.appliedFilter;
					}
			}
			if (widget) {
				return widget;
			}
		}
		return null;
	};

	var _getField = function (name, widgetName) {
		var widget = _getWidget(widgetName);
		var field = widget.getField(name);
		if (field) {
			return field;
		}
		return null;
	};

	var _getAction = function (name, widgetName) {
		var widget = _getWidget(widgetName);
		var action = widget.getAction(name);
		if (action) {
			return action;
		}
		return null;
	};

	this.getFieldValue = function (name, widgetName) {
		var isPopup = arguments[2] || null;
		var widget = _getWidget(widgetName, isPopup);
		if (widget && widget.currentRow) {
			return widget.currentRow[name];
		} else {
			return "";
		}
	};

	this.setEnableField = function (name, widgetName) {
		_getField(name, widgetName).readOnly = false;
	};

	this.setDisableField = function (name, widgetName) {
		_getField(name, widgetName).readOnly = true;
	};

	this.setVisibleField = function (name, widgetName) {
		_getField(name, widgetName).isVisible = true;
	};

	this.setInvisibleField = function (name, widgetName) {
		_getField(name, widgetName).isVisible = false;
	};

	this.setEnableAction = function (name, widgetName) {
		_getAction(name, widgetName).readOnly = false;
	};

	this.setDisableAction = function (name, widgetName) {
		_getAction(name, widgetName).readOnly = true;
	};

	this.setVisibleAction = function (name, widgetName) {
		_getAction(name, widgetName).isVisible = true;
	};

	this.setInvisibleAction = function (name, widgetName) {
		_getAction(name, widgetName).isVisible = false;
	};

	this.now = function () {
		return moment(new Date()).format('DD/MM/YYYY HH:mm:ss');
	};

	this.today = function () {
		return moment(new Date()).format('DD/MM/YYYY');
	};

	this.openReport = function (route, reportName, params) {
		params.__report_name = reportName;
		
		var lastActiveWidget = templateManager.container.getActiveWidget().lastActiveWidget;
	
		if (lastActiveWidget && lastActiveWidget.beforeOpenReport) {
		    lastActiveWidget.beforeOpenReport({
		        reportParams: params
		    });
		}
		
		return restEngine.post(route, {
			"requestType": "Row",
			"row": params
		}, null, null, null, null, 3000000).then(function (response) {
			if (response && response.messages) {
				var report = response.messages.pop();
				var reportOpened = window.open(report.message);
				if(!reportOpened){
					MessageService.showMessageByCode('lib#GEN_POPUP_BLOCKER', null, { type: 'ERROR' } );
				}
			}
		}).catch(function (response) {
			if (response.data && response.data.error) {
				ScreenService.showMessage(ScreenService.i18n(response.data.error), 'E');
			}
		});
	};

	// CRUD
	/**
     * O segundo parâmetro é opcional, sendo ele um objeto contendo os atributos
     * callback (function) e params (array). Após a validação da widget,
     * o método callback é executado.
     * Ex: var afterValid = {
     *      callback: function(a) {console.log(a);},
            params: ['valorDeA']
     * };
     */
	this.saveCrud = function (widget, afterValid) {
		var deferred = ZHPromise.defer();
		if (widget.isValid()) {
			if (afterValid && angular.isObject(afterValid)) {
				if (angular.isFunction(afterValid.callback))
					afterValid.callback.apply(null, afterValid.params);
			}

			var paramsNewCode = widget.paramsNewCode;
			if (paramsNewCode && paramsNewCode.__is_new_code) {
				widget.currentRow.__using_unit = paramsNewCode.__using_unit || false;
				widget.currentRow.__new_code_pk = paramsNewCode.__new_code_pk;
				widget.currentRow.__table_pk = paramsNewCode.__table_pk;
				widget.currentRow.__new_code_interval = paramsNewCode.__new_code_interval || 1;
				widget.currentRow.__new_code_length = paramsNewCode.__new_code_length || 5;
				widget.currentRow.__new_code_column_size = paramsNewCode.__new_code_column_size || 10;
				widget.currentRow.__cast_number = paramsNewCode.__cast_number || false;
			}

			var fieldsToValidateDuplication = widget.fieldsToValidateDuplication;
			if (fieldsToValidateDuplication && fieldsToValidateDuplication.length){
				setDuplicationValidateParamsToCurrentRow(widget);
			}

			widget.saveRow().then(function (success) {
				widget.activate();
				if (widget.currentRow.__is_new) {
					widget.list(true);
					ScreenService.goBack();
					widget.reload().then(function () {
						deferred.resolve(success);
					});
				} else {
					widget.computeDescriptionOrder();
					widget.view();
					deferred.resolve(success);
				}
			}, function (error) {
				var errorMessage = 'Timeout';
				if (error.data) {
					errorMessage = error.data.error;
				}
				ScreenService.showMessage(errorMessage);
				deferred.reject(errorMessage);
			});
		} else {
			// @todo create messages class
			deferred.reject("Preencha todos os campos corretamente!");
		}

		return deferred.promise;
	};

	/* setDuplicationValidateParamsToCurrentRow
	 *
	 * Caso o widget contenha o array 'fieldsToValidateDuplication', será verifi-
	 * cado, antes de salvar, se os valores dos campos a serem validados já exis-
	 * tem no banco.
	 *
	 * O array deve conter objeto(s) com o nome da coluna na tabela e a descricao
	 * do campo que sera exibida na resposta em caso de duplicacao.
	 *
	 * Exemplo:
	 *      "fieldsToValidateDuplication": [
	 *        {
	 *	        "name": "NMCAMPO",
	 *	        "description": "campo"
	 *        }
	 *      ]
	 */
	var setDuplicationValidateParamsToCurrentRow = function (widget) {
		try {
			var fieldsToValidate = widget.fieldsToValidateDuplication;
			var validationArray = [];

			checkValidateFieldsArray(fieldsToValidate);

			for (var index in fieldsToValidate) {
				var field = fieldsToValidate[index];

				if (!field.description) {
					field.description = field.name;
					var warningMsg = "Missing description for " + field.name +
					" field in 'fieldsToValidateDuplication' of " + widget.name;
					console.warn(warningMsg);
				}
				field.description = field.description.toLowerCase();

				validationArray.push(field);
			}

			if (validationArray.length) {
				widget.currentRow.__fieldsToValidateDuplication = validationArray;
			}
		} catch (e) {
			ScreenService.showMessage(e);
		}
	};

	var checkValidateFieldsArray = function (arrayToCheck) {
		for (var index in arrayToCheck) {
			var objectToCheck = arrayToCheck[index];

			if (typeof(objectToCheck) == "object") {
				if (!objectToCheck.name) {
					throw "Error in data save. Property 'fieldsToValidateDuplication' of widget has elements without name.";
				}
			} else {
				throw "Error in data save. Property 'fieldsToValidateDuplication' of widget has non-object elements.";
			}
		}
	};

	this.deleteCrud = function (widget) {
		var deferred = ZHPromise.defer();
		MessageService.confirmMessageByCode('lib#GEN_DELETE_REG').then(function (success) {
			widget.removeRow().then(function () {
				ScreenService.closeSwipe().then(function () {
					widget.activate();
					deferred.resolve();
				});
			}, function (error) {
				if (error.data && error.data.error.indexOf('ORA-02292') !== -1) {
					MessageService.showMessageByCode('lib#GEN_DELETE_BLOCK', null, { type: 'ERROR' } );
				} else {
					ScreenService.showMessage(error.data.error);
				}
				deferred.reject();
			});
		});
		return deferred.promise;
	};

    this.deleteCrudCheckedRows = function (widget) {
        var deferred = ZHPromise.defer();
        MessageService.confirmMessageByCode('lib#GEN_DELETE_REG').then(function (success) {
            widget.removeCheckedRows().then(function () {
                widget.reload();
                widget.unSelectAll();
                deferred.resolve();
            }, function (error) {
                if (error.data && error.data.error.indexOf('ORA-02292') !== -1) {
                    MessageService.showMessageByCode('lib#GEN_DELETE_BLOCK', null, { type: 'ERROR' } );
                } else {
                    ScreenService.showMessage(error.data.error);
                }
                deferred.reject();
            });
        });
        return deferred.promise;
    };

	this.justInteger = function (selector, retryCount) {
		if (!retryCount || retryCount > 5)
			retryCount = 5;
		if (!selector) {
			throw {
				"message": "Selector is not defined!"
			};
		}
		setTimeout(function () {
			var elem = $(selector);
			if (elem[0]) {
				var length = selector.split(',').length;
				for (var i = 0; i < length; i++) {
					if (elem.hasOwnProperty(i)) {
						elem[i].onkeypress = avoidNonInteger;
						elem[i].onpaste = preventEvent;
					}
				}
			} else {
				if (!retryCount) {
					console.error("Selector not found!");
				} else {
					retryCount--;
					this.justInteger(selector, retryCount);
				}
			}
		}.bind(this), 500);
	};

	function avoidNonInteger(e) {
		var integerNumbers = [48, 49, 50, 51, 52, 53, 54, 55, 56, 57];
		var numberCode = e.which;
		if (integerNumbers.indexOf(numberCode) < 0) {
			preventEvent(e);
		}
	}

	function preventEvent(e) {
		e.preventDefault();
	}

	function padLeft(value, length) {
		return (value.toString().length < length) ? padLeft("0" + value, length) : value;
	}

	function padRight(value, length) {
		return (value.toString().length < length) ? padRight(value + "0", length) : value;
	}

	this.getCurrentDate = function (format) {
		return moment().format(format);
	};

	this.setDateAttrToVarcharOnCurrentRow = function (currentRow, attrName) {
		this.setAttrOnCurrentRow(currentRow, attrName, currentRow[attrName].replace(':', ''));
	};

	this.setAttrOnCurrentRow = function (currentRow, attrName, value) {
		currentRow[attrName] = value;
	};

	this.setFloatAttrOnCurrentRow = function (currentRow, attrName) {
		this.setAttrOnCurrentRow(currentRow, attrName, this.valueToFloat(currentRow[attrName]));
	};

	this.valueToFloat = function (value) {
		if (typeof value == 'string' && !Util.isEmptyOrBlank(value)) {
			if (value.indexOf(',') == -1 && value.indexOf('.') == -1) {
				return parseFloat(value);
			} else if (value.indexOf(',') > value.indexOf('.')) {
				return parseFloat(value.replace(/\./g, '').replace(/\,/g, '.'));
			} else if (value.indexOf(',') < value.indexOf('.')) {
				return parseFloat(value.replace(/\,/g, ''));
			}
		} else {
			return value;
		}
	};

	this.toLocalDate = function (element, viewValue, params, callBack) {
		var value = viewValue || '';
		element.val(value);
		params.callback = callBack;
		$.currency.setMask(params, element);
	};

	this.toLocalDateFormat = function (value, params) {
		if (value) {
			var valueDate = moment(value, params.format);
			value = valueDate.format(params.toFormat);
		}

		return value;
	};

	maskEngine.registerMask('dateFormat', this.toLocalDate, this.toLocalDateFormat);

	var maskFunction = function (element, viewValue, params, callBack) {
		// do something
	};

	var maskFormatFunction = function (value, params) {
		if (value) {
			var length = value.length;
			if (length === 11)
				value = value.replace(/^(\d{3})(\d{3})(\d{3})(\d{2})/, "$1.$2.$3-$4");
			else if (length === 14)
				value = value.replace(/^(\d{2})(\d{3})(\d{3})(\d{4})(\d{2})/, "$1.$2.$3/$4-$5");
			return value;
		}
	};

	maskEngine.registerMask('CPFCNPJ', maskFunction, maskFormatFunction);

	/*
	 * Função que verifica quais widgets serão exibidas baseado em quais projetos ela pode ser exibida.
	 * A função deve ser executada no 'ContainerAfterInit' mas deve ser estudado a possibilidade de ser executado
	 * no 'EventAgregatorOnOpenContainer' para que assim essa configuração possa ser aplicada em multiplas telas.
	 */

	var constAllWidgets;

	this.setVisibilityByProjectID = function (widgets) {
		if (widgets.length > 1) {
			widgets.forEach(function (childWidget) {
				parent.setVisibilityByProjectID(childWidget.widgets);
				if (childWidget.projects) {
					childWidget.projects.forEach(function (proj) {
						childWidget.isVisible = proj.projectID == templateManager.project.id || proj.projectID == "allProjects" ? true : false;
					});
				}
			});

		}

	};

	this.validateFilterPopup = function (args) {
		if(args.owner.hasOwnProperty('__filterPopup')){
			var filterPopup = args.owner.__filterPopup;
		
		if (!filterPopup.isValid())
			args.e.preventDefault();
		}	
	};

	var timeFormats = {
		"hh": isValidHour,
		"mm": isValidMinutesOrSeconds,
		"ss": isValidMinutesOrSeconds,
		"hh:mm": isValidHourAndMinutes,
		"mm:ss": isValidMinutesAndSeconds,
		"hh:mm:ss": isValidTime,
	};

	function isValidHour(hour) {
		if (parseInt(hour) > 23 || parseInt(hour) < 0)
			return false;
		else
			return true;
	}

	function isValidMinutesOrSeconds(minuteOrSecond) {
		if (parseInt(minuteOrSecond) > 59 || parseInt(minuteOrSecond) < 0)
			return false;
		else
			return true;
	}

	function isValidHourAndMinutes(hourAndMinute) {
		if (hourAndMinute) {
			var timeArray = hourAndMinute.split(':');
			return isValidHour(timeArray[0]) && isValidMinutesOrSeconds(timeArray[1]);
		}
		return true;
	}

	function isValidMinutesAndSeconds(minutesAndSeconds) {
		if (minutesAndSeconds) {
			var timeArray = minutesAndSeconds.split(':');
			return isValidMinutesOrSeconds(timeArray[0]) && isValidMinutesOrSeconds(timeArray[1]);
		}
		return true;
	}

	function isValidTime(time) {
		if (time) {
			var timeArray = time.split(':');
			return isValidHour(timeArray[0]) && isValidMinutesOrSeconds(timeArray[1]) && isValidMinutesOrSeconds(timeArray[2]);
		}
		return true;
	}

	var validTime = function (value, format) {
		var validFunction;
		if (!format)
			throw 'format is not defined';
		if (typeof format == 'string' && timeFormats.hasOwnProperty(format.toLowerCase()))
			validFunction = timeFormats[format.toLowerCase()];
		else
			throw 'time format is not registered';
		return {
			"valid": validFunction(value),
			"message": ScreenService.i18n("Não é um tempo válido.")
		};
	};

	this.registerTimeFormat = function (format, formatFunction) {
		if (typeof format !== 'string')
			throw 'time format must be an string';
		if (timeFormats.hasOwnProperty(format.toLowerCase()))
			throw 'time format already registered';
		timeFormats[format] = formatFunction;
	};

	ValidationEngine.registerValidation('isValidTime', validTime);

	/*
	 * Função que preenche um valor com um único caractere até um certo tamanho.
	 * Faz zerofill pela esquerda por default.
	 *
	 * @param string value
	 * @param int length
	 * @param boolean toRight
	 * @param char filler
	 *
	 * @return string
	 *
	 * Exemplos:
	 * General.fill('123', 10);            //'0000000123'
	 * General.fill('123', 10, true);      //'1230000000'
	 * General.fill('123', 10, null, '_'); //'_______123'
	 */
	this.fill = function (value, length, toRight, filler) {
		if (value) {
			value = value.toString();

			if (filler) {
				filler = filler.toString()[0];
			} else filler = '0';

			if (toRight)
				while (value.length + filler.length <= length) value = value + filler;
			else
				while (value.length + filler.length <= length) value = filler + value;
		}
		return value;
	};

	/*
	 * Função que faz a validação de CNPJ.
	 *
	 * @param string CNPJ
	 *
	 * @return boolean
	 */
	function validCNPJ(CNPJ) {
		if (CNPJ === undefined || CNPJ === null)
			return false;

		CNPJ = CNPJ.toString().replace(/[\D]+/g, '');

		if (CNPJ.length != 14)
			return false;

		if (CNPJ == "00000000000000" ||
			CNPJ == "11111111111111" ||
			CNPJ == "22222222222222" ||
			CNPJ == "33333333333333" ||
			CNPJ == "44444444444444" ||
			CNPJ == "55555555555555" ||
			CNPJ == "66666666666666" ||
			CNPJ == "77777777777777" ||
			CNPJ == "88888888888888" ||
			CNPJ == "99999999999999")
			return false;

		var tamanho = CNPJ.length - 2;
		var numeros = CNPJ.substring(0, tamanho);
		var digitos = CNPJ.substring(tamanho);
		var soma = 0;
		var pos = tamanho - 7;

		for (var i = tamanho; i >= 1; i--) {
			soma += numeros.charAt(tamanho - i) * pos--;
			if (pos < 2)
				pos = 9;
		}

		var resultado = soma % 11 < 2 ? 0 : 11 - soma % 11;
		if (resultado != digitos.charAt(0)) //debugger;
			return false; //'resultado' é o 1º digito de validação do CNPJ

		tamanho = tamanho + 1;
		numeros = CNPJ.substring(0, tamanho);
		soma = 0;
		pos = tamanho - 7;

		for (i = tamanho; i >= 1; i--) {
			soma += numeros.charAt(tamanho - i) * pos--;
			if (pos < 2)
				pos = 9;
		}

		resultado = soma % 11 < 2 ? 0 : 11 - soma % 11;
		if (resultado != digitos.charAt(1)) //debugger;
			return false; //'resultado' é o 2º digito de validação do CNPJ

		return true;
	}

	this.validateCNPJ = validCNPJ;

	/*
	 * Função que faz a validação de CPF.
	 *
	 * @param string CPF
	 *
	 * @return boolean
	 */
	function validCPF(CPF) {
		if (CPF === undefined || CPF === null)
			return false;

		CPF = CPF.toString().replace(/[\D]+/g, '');

		if (CPF.length != 11)
			return false;

		if (CPF == "00000000000" ||
			CPF == "11111111111" ||
			CPF == "22222222222" ||
			CPF == "33333333333" ||
			CPF == "44444444444" ||
			CPF == "55555555555" ||
			CPF == "66666666666" ||
			CPF == "77777777777" ||
			CPF == "88888888888" ||
			CPF == "99999999999")
			return false;

		var soma = 0;
		var resto;

		for (var i = 1; i <= 9; i++) soma = soma + parseInt(CPF.substring(i - 1, i)) * (11 - i);
		resto = (soma * 10) % 11;

		if ((resto == 10) || (resto == 11)) resto = 0;
		if (resto != parseInt(CPF.substring(9, 10))) //debugger;
			return false; //'resto' é o 1º dígito de validação do CPF

		soma = 0;
		for (i = 1; i <= 10; i++) soma = soma + parseInt(CPF.substring(i - 1, i)) * (12 - i);
		resto = (soma * 10) % 11;

		if ((resto == 10) || (resto == 11)) resto = 0;
		if (resto != parseInt(CPF.substring(10, 11))) //debugger;
			return false; //'resto' é o 2º dígito de validação do CPF

		return true;
	}

	this.validateCPF = validCPF;

	/*
	 * Função que faz a formatação de uma inscrição,
	 * seguindo o padrão de código genérico, CPF, CNPJ e
	 * inscrição genérica. Caso o parâmetro "force" for
	 * true, o método tenta forçar uma inscrição válida.
	 *
	 * Retorna um objeto com as seguintes propriedades:
	 *  * parameter //string de entrada contendo apenas números
	 *  * value     //string formatada conforme o tipo da inscrição
	 *  * tipo.cod  //char do código padrão do tipo da inscrição
	 *  * tipo.desc //string de descrição do tipo da inscrição
	 *  * valid     //boolean
	 *
	 * @param string inscricao
	 * @param boolean force
	 *
	 * @return object
	 */
	this.inscricaoFormat = function (inscricao, force) {
		if (inscricao === undefined || inscricao === null || inscricao === '')
			return {
				'parameter': '',
				'value': '',
				'tipo': {
					'cod': null,
					'desc': null
				},
				'valid': false
			};

		if (force === undefined || force === null)
			force = false;
		inscricao = inscricao.toString().replace(/[\D]+/g, '');

		var obj = {};
		obj.tipo = {};

		if (inscricao.length <= 5) {
			obj.tipo.cod = 'O';
			obj.tipo.desc = 'Código Genérico';
			obj.valid = true;
			obj.value = this.fill(inscricao, 5);
		} else {
			if (inscricao.length == 11) {
				obj.tipo.cod = 'F';
				obj.tipo.desc = 'Pessoa Física';
				obj.valid = this.validateCPF(inscricao);
				obj.value = inscricao.substr(0, 3) + '.' + inscricao.substr(3, 3) + '.' + inscricao.substr(6, 3) + '-' + inscricao.substr(9, 2);
			} else if (inscricao.length == 14) {
				obj.tipo.cod = 'J';
				obj.tipo.desc = 'Pessoa Jurídica';
				obj.valid = this.validateCNPJ(inscricao);
				obj.value = inscricao.substr(0, 2) + '.' + inscricao.substr(2, 3) + '.' + inscricao.substr(5, 3) + '/' + inscricao.substr(8, 4) + '-' + inscricao.substr(12, 2);
			} else force = true;

			if (force && obj.valid !== true) {
				obj.tipo.cod = 'I';
				obj.tipo.desc = 'Inscrição Internacional';

				if (inscricao.length <= 20) {
					obj.valid = true;
					obj.value = this.fill(inscricao, 20);
				} else {
					obj.valid = false;
					obj.value = inscricao.substr(0, 20);
				}
			}
		}

		obj.parameter = inscricao;
		return obj;
	};

	var CPFValidation = function (value, validationAttrs) {
		return {
			"valid": validCPF(value),
			"message": ScreenService.i18n('CPF Inválido')
		};
	};

	ValidationEngine.registerValidation('CPF', CPFValidation);

	var CNPJValidation = function (value, validationAttrs) {
		return {
			"valid": validCNPJ(value),
			"message": ScreenService.i18n('CNPJ Inválido')
		};
	};

	ValidationEngine.registerValidation('CNPJ', CNPJValidation);

	this.callRestEngine = function (dataSource, requestType, requestValue, disableLoader) {
		var defer = ZHPromise.defer();
		var params = {};
		
		switch (requestType) {
		case "Row":
			params = {
				"requestType": "Row",
				"row": requestValue,
				"disableLoader": disableLoader
			};
			break;

		case "DataSet":
			params = {
				"requestType": "DataSet",
				"dataset": requestValue,
				"disableLoader": disableLoader
			};
			break;

		case "FilterData":
			params = {
				"requestType": "FilterData",
				"filter": requestValue,
				"disableLoader": disableLoader
			};
			break;

		default:
			return defer.reject("Erro na passagem de parâmetros para a requisição. O valor para requestType deve ser 'Row', 'DataSet' ou 'FilterData'.");
		}

		return restEngine.request(dataSource, params);
	};

	/*
	 * Função que muda a acessibilidade de uma ou mais
	 * widgets.
	 *
	 * @param array(objects) widgets
	 * @param boolean enabled
	 *
	 * Exemplos:
	 * General.changeWidgetAcessibility(widget.widgets, false); //Desabilita o acesso às widgets filhas
	 * General.changeWidgetAcessibility(widget.widgets, true);  //Habilita o acesso às widgets filhas e faz algo mais depois
	 */
	this.changeWidgetAcessibility = function (widgets, enabled) {
		widgets.forEach(function (widget) {
			widget.enabled = enabled;
		});

		templateManager.updateTemplate();
	};

	/*
	 * Função que altera o template de um form
	 * entre edição e visualização. Retorna um boolean
	 * que indica se a widget era do tipo form e a
	 * alteração foi realizada.
	 *
	 * @param object widget
	 *
	 * @return boolean
	 */
	this.formWidgetSwitchTemplate = function (widget) {
		if ((widget.template != "widget/form.html") && (widget.template != "widget/form-view.html")) return false;

		if (!widget.templateToForm) widget.templateToForm = "widget/form.html";
		if (!widget.templateToView) widget.templateToView = "widget/form-view.html";

		if (widget.template == widget.templateToForm) widget.template = widget.templateToView;
		else if (widget.template == widget.templateToView) widget.template = widget.templateToForm;

		templateManager.updateTemplate();

		return true;
	};

	/*
	 * Função que coloca uma widget em modo de edição,
	 * bloqueando as demais widgets. Retorna um boolean
	 * que indica se a alteração de modo foi executada.
	 *
	 * @param object widget
	 *
	 * @return boolean
	 */
	this.widgetEdit = function (widget) {
		if (!widget.editing) {
			//Trata a edição de uma widget filha do tipo form
			if (this.formWidgetSwitchTemplate(widget) && widget.parent) {
				var widgetsToDeactivate = widget.parent.widgets;

				this.changeWidgetAcessibility(
					widgetsToDeactivate.filter(function (subwidget) {
						return subwidget.name != widget.name;
					}).concat(widget.parent), //retorna um array com a widget parent e suas widgets filhas, exceto aquela que será editada
					false);
			} else //trata a edição dos demais casos
				this.changeWidgetAcessibility(widget.widgets, false);

			//propriedades a serem ignoradas na criação do backup
			var ignoredKeys = ["__rightActions", "__leftActions", "_children", "_parent", "__groupHeaders", "__index", "__isSelected", "__notSelectable", "$$hashKey"];

			//faz backup da currentRow para permitir a recuperação dos dados
			widget.backupRow = Util.clone(widget.currentRow, ignoredKeys);
			widget.edit();
			return true;
		} else return false;
	};

	/*
	 * Procedimento que cancela o formulário de uma
	 * widget, seja este de inserção ou de edição, e
	 * desbloqueia as demais widgets.
	 *
	 * @param object widget
	 */
	this.widgetCancelForm = function (widget) {
		//trata o cancelamento de uma widget filha do tipo form
		if (this.formWidgetSwitchTemplate(widget) && widget.parent) {
			var widgets = widget.parent.widgets;

			this.changeWidgetAcessibility(widgets.concat(widget.parent), true);
		} else //trata o cancelamento dos demais casos
			this.changeWidgetAcessibility(widget.widgets, true);

		//caso a widget estiver em modo de inserção, remove a row e fecha o swipe
		if (widget.currentRow.__is_new) {
			var indexOfCurrentRow = widget.dataSource.data.indexOf(widget.currentRow);
			if (indexOfCurrentRow !== -1) {
				widget.dataSource.data.pop();
			}

			widget.list();

			ScreenService.closeSwipe();
		} else { //caso a widget estiver em modo de edição, recupera o backup e entra no modo de visualização
			Object.keys(widget.backupRow).forEach(function (key) {
				widget.currentRow[key] = widget.backupRow[key];
			}); //copia dados coluna por coluna para não perder referência do objeto da currentRow
			widget.view();
		}
	};

	/*
	 * Procedimento que fecha o swipe e volta ao grid da
	 * própria widget. Provavelmente usado na action de
	 * 'voltar' do back_view.
	 *
	 * @param object widget
	 */
	this.widgetGoBackToList = function (widget) {
		ScreenService.closeSwipe();
		widget.list();
	};

	/*
	 * Procedimento que fecha o swipe e volta ao grid da
	 * widget parent. Provavelmente usado na action de
	 * 'voltar' do back_list.
	 *
	 * @param object widget
	 */
	this.widgetGoBackToParent = function (widget) {
		ScreenService.closeSwipe().then(function () {
			widget.parent.list();
			widget.parent.activate();
		});
	};

	/*
	 * Procedimento que habilita inserção em uma widget,
	 * bloqueando as demais widgets.
	 *
	 * @param object widget
	 */
	this.widgetNewRow = function (widget) {
		this.changeWidgetAcessibility(widget.widgets, false);

		widget.newRow();
	};

	/*
	 * Função que salva os dados de uma widget e retorna
	 * para o modo adequado de visualização ou listagem.
	 * Faz exibição de mensagens de aviso para o usuário
	 * conforme padronização e desbloqueia as demais
	 * widgets.
	 *
	 * Basicamente, um saveCrud adaptado ao padrão.
	 *
	 * @param object widget
	 *
	 * @return promise
	 */
	this.widgetSave = function (widget) {
		var deferred = ZHPromise.defer();

		if (widget.isValid()) {
			widget.currentRow.changed = true;

			if (!widget.currentRow.__is_new)
				widget.currentRow.__is_new = false;
			else if (widget.paramsNewCode && widget.paramsNewCode.__is_new_code) {
				widget.currentRow.__using_unit = widget.paramsNewCode.__using_unit || false;
				widget.currentRow.__new_code_pk = widget.paramsNewCode.__new_code_pk;
				widget.currentRow.__table_pk = widget.paramsNewCode.__table_pk;
				widget.currentRow.__new_code_interval = widget.paramsNewCode.__new_code_interval || 1;
				widget.currentRow.__new_code_length = widget.paramsNewCode.__new_code_length || 5;
				widget.currentRow.__new_code_column_size = widget.paramsNewCode.__new_code_column_size || 10;
				widget.currentRow.__cast_number = widget.paramsNewCode.__cast_number || false;
                if (!widget.currentRow.__columns_to_return && widget.paramsNewCode && widget.paramsNewCode.__columns_to_return)
                	widget.currentRow.__columns_to_return = widget.paramsNewCode.__columns_to_return;
			}

			widget.saveRow().then(function (response) {
				widget.currentRow.changed = false;
				delete widget.backupRow;

				if (this.formWidgetSwitchTemplate(widget) && widget.parent) {
					widget.view();

					var widgets = widget.parent.widgets;
					this.changeWidgetAcessibility(widgets.concat(widget.parent), true);
				} else {
					if (widget.currentRow.__is_new) {
						ScreenService.closeSwipe();
						widget.list();
					} else widget.view();

					this.changeWidgetAcessibility(widget.widgets, true);
				}

				if (widget.currentRow.__is_new) widget.currentRow.__is_new = false;
				else widget.reload();

				deferred.resolve(response);
			}.bind(this), function (error) {
				var errorMessage = 'Timeout';

				if (error.data) errorMessage = error.data.error;

				ScreenService.showMessage(errorMessage);
				deferred.reject(errorMessage);
			});
		} else deferred.reject("Preencha todos os campos corretamente!");

		return deferred;
	};

	/*
	 * Função para validar containers abertos a partir de outros containers.
	 * Se o container atual não foi aberto a partir do container pai, a
	 * callback é executada. Se nenhuma callback for passada nos parâmetros,
	 * o container pai é aberto.
	 *
	 * @param: object {parentContainerName, callback, scope, params}
	 *
	 * Exemplos:
	 * General.checkParentContainer({parentContainerName: 'pla_prato#pla01300_prato',callback: ScreenService.showMessage, scope: ScreenService, params:['Teste']});
	 * General.checkParentContainer({parentContainerName: 'pla_prato#pla01300_prato'});
	 */
	this.checkParentContainer = function (containerProperties) {
		containers = templateManager.containers;
		if (!containers.hasOwnProperty(containerProperties.parentContainerName)) {
			if (angular.isFunction(containerProperties.callback)) {
				containerProperties.callback.apply(containerProperties.scope, containerProperties.params);
			} else {
				ScreenService.openWindow(containerProperties.parentContainerName);
			}
		}
	};

	var messagesWidget = {
		"id": 0,
		"name": "messagesWidget",
		"label": "Mensagens",
		"messagesDataset": "",
		"template": "widget/form.html",
		"floatingControl": {
			"customizationAction": {
				"filter": false,
				"view": false,
				"layout": false
			}
		},
		"container": {},
		"isVisible": true,
		"popupNoBlock": false,
		"fields": [],
		"actions": [],
		"events": []
	};

	var messagesFields = [{
		"label": "",
		"name": "CONTENT",
		"readOnly": true,
		"template": "field/textarea.html",
		"textRows": 14,
		"isVisible": true,
		"class": 12,
		"descriptionOrder": true,
		"showOnView": true,
		"showOnForm": true,
		"showOnList": true
    }];

	var messagesActions = [{
		"name": "cancelar",
		"label": "Cancelar",
		"idVisible": true,
		"hideIcon": true,
		"showAsAction": "back",
		"events": [{
			"name": "ActionEvent",
			"code": "ScreenService.closePopup();"
        }]
    }, {
		"name": "exportar",
		"label": "Exportar",
		"idVisible": true,
		"icon": "export",
		"showAsAction": "always",
		"events": [{
			"name": "ActionEvent",
			"code": "General.generateFileByDataSet(args.owner.widget.messagesDataset);"
        }]
    }];

	/* Função abre um popup com um Text Area a título de mostrar erros em lista.
	 * Recebe a widget de origem e um dataset com mensagens a serem exibidas.
	 * @params: widget, dataset, popupName
	 */
	this.showErrorMessages = function (widget, dataset, popupName) {
		messagesWidget.container = widget.container;
		messagesWidget.fields = messagesFields;
		messagesWidget.actions = messagesActions;

		var messagesWidgetInitialized = metaDataFactory.widgetFactory(messagesWidget);
		var content = '';
		if (popupName !== undefined)
			messagesWidgetInitialized.label = popupName;
		messagesWidgetInitialized.messagesDataset = dataset;
		dataset.forEach(function (message) {
			content += message + '\n';
		});
		messagesWidgetInitialized.getField('CONTENT').setValue(content);
		ScreenService.openPopup(messagesWidgetInitialized);
	};

	/* Gera arquivo básico baseado em linhas de dataSet.
	 * @params: dataset, object {fileName}
	 * !!! fileExtension: por enquanto somente TXT;
	 * Exemplo:
	 * General.generateFileByDataSet(dataset, {fileExtension: 'txt', fileName: 'meuArquivo'});
	 */

	this.generateFileByDataSet = function (dataset, fileProperties) {
		var content = "";
		var name = 'content';
		var extension = 'text/plain';

		if (fileProperties !== undefined) {
			if (fileProperties.fileName !== undefined)
				name = fileProperties.fileName;
		}

		dataset.forEach(function (line) {
			content += line + "\r\n";
		});

		var element = document.createElement('a');
		element.setAttribute('href', 'data:' + extension + ';charset=utf-8,' + encodeURIComponent(content));
		element.setAttribute('download', name);

		element.style.display = 'none';
		document.body.appendChild(element);

		element.click();

		document.body.removeChild(element);
	};

	/**
	 * Este método verifica se a widget foi filtrada usando o zh-grid-filter
	 * @param Widget widget
	 * @return boolean
	 */
	this.isWidgetFiltered = function (widget) {
		var isFiltered = true;
		var currentFilter;
		if(widget.hasOwnProperty('__filterPopup'))
			currentFilter = widget.__filterPopup.currentFilter;
		else
			currentFilter = widget.appliedFilter.FILTER_ROW;
			
		var requiredFields = widget.fields.filter(function (field){
			return isRequiredFieldInFilter(field) || isRequiredFieldWithoutFilterProperties(field);
		});
		if(requiredFields.length && Array.isArray(currentFilter)) {
			isFiltered = false;
		}
		return isFiltered;
	};

	function isRequiredFieldInFilter(field) {
		return field.filterProperties && field.filterProperties.validations && field.filterProperties.validations.required;
	}

	function isRequiredFieldWithoutFilterProperties(field) {
		return field.isVisible && field.validations && field.validations.required && !field.filterProperties;
	}

	/**
	 * Este método valida a inserção de registros na widget
	 * @param Widget widget
	 */
	this.newRow = function (widget) {
		if(this.isWidgetFiltered(widget)) {
			widget.newRow();
		} else {
			MessageService.showMessageByCode('lib#GEN_NOT_FILTER', null, { type: 'ERROR' } );
		}
	};

    /*
     * Função que adiciona à currentRow o(s) valor(es)
     * da widget parent necessários para salvar o registro.
     *
     * @param object widget
     * @param object parents
     *
     * @return promise
     */

    this.saveWithParent = function(widget, parents) {
        if(Array.isArray(parents)) {
            parents.forEach(function(parent){
                widget.currentRow[parent] = widget.parent.currentRow[parent];
            });
            return this.widgetSave(widget);
        }
        else throw("\'Parents\' property should be an array, " + typeof parents + " given.");
    };
    
    /*
     * Aceita [- . , 0 1 2 3 4 5 6 7 8 9]
     *
     */
    
     this.justDigits = function(selector, retryCount) {
        if (!retryCount || retryCount > 5)
            retryCount = 5;
        if (!selector) {
            throw {
                "message": "Selector is not defined!"
            };
        }
        setTimeout(function() {
            var elem = $(selector);
            if (elem[0]) {
                var length = selector.split(',').length;
                for (var i = 0; i < length; i++) {
                    if (elem.hasOwnProperty(i)) {
                        elem[i].onkeypress = avoidNonDigits;
                        elem[i].onpaste = preventEvent;
                    }
                }
            } else {
                if (!retryCount) {
                    console.error("Selector not found!");
                } else {
                    retryCount--;
                    this.justDigits(selector, retryCount);
                }
            }
        }.bind(this), 500);
    };

    function avoidNonDigits(e) {
        var digits = [44, 45, 46, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57];
        var digitCode = e.which;
        if (digits.indexOf(digitCode) < 0) {
            preventEvent(e);
        }
    }

    /**
     * Função responsável por chamar a maskCurrency sempre que o 
     * usuário desfocar do campo onde ela é aplicada.
     * Função deve ser usada no evento FieldOnBlur, junto com a 
     * removeMask, essa no FieldOnFocus.
     * 
     * @param {Field} field - field.
     * @param {Char} decimal - Caráctere que será usado para a casa decimal.
     * @param {Char} thousand - Caráctere que será usado para as unidades de milhar.
     * @param {Number} precision - Quantidade de casas decimais.
     */

    this.callMaskCurrency = function(field, decimal, thousands, precision) {
    	precision = precision || 2;
        var value = field.value();
        var params = {
            "decimal": decimal,
            "thousands": thousands,
            "precision": precision
        };
        field.value(this.maskCurrency(value, params));
    };

    var maskFunction = function(element, viewValue, params, callBack) {
        // do something
    };

    /**
     * Função responsável por aplicar uma máscara do type currency
     * no field.
     * 
     * @param {String} value - value do field.
     * @param {Object} params - Objeto param da máscara com {decimal, thousand, precision}.
     */

    this.maskCurrency = function(value, params) {
        var thousands = Util.isEmptyOrBlank(params.thousands) ? params.thousand : params.thousands;
        if (!Util.isEmptyOrBlank(value)) {

            if (value[0] === '.' || value[0] === ',')
                value = '0' + value;
            if (params.decimal === ',')
                value = numberFormatBr(value);
            var newValue = "";
            value = value.split('.').join('');
            var dec = value.split(',')[1];
            var mil = [];
            var int = value.split(',')[0];

            if (dec === undefined) {
                dec = "";
                dec = dec.padEnd(params.precision, "0");
                int = value;
            } else if (dec.length < params.precision) {
                dec = dec.padEnd(params.precision, "0");
            } else if (dec.length > params.precision) {
                dec = parseFloat('1.' + dec).toFixed(params.precision).toString().split('.')[1];
            }

            var counter = angular.copy(int.length / 3);

            for (var i = 1; i <= counter; i++) {
                if (i != counter)
                    mil.push(thousands + int.substr(-3));
                else
                    mil.push(int.substr(-3));
                int = int.substr(0, (int.length - 3));
            }

            if (int != "") mil.push(int);

            mil = mil.reverse().join('');
            newValue = mil + params.decimal + dec;
            var regex = '^(^([0-9]{1,3}\\' + thousands + ')((\\d{3}\\' + thousands + '{1})|(\\d{3}\\' + params.decimal + '\\d{2,}))*$)|^(\\d{0,3}\\' + params.decimal + '\\d{2,})*$';
            regex = new RegExp(regex, 'g');
            if (regex.test(newValue))
                return newValue;
            else
                return 0;
        }
    };

    maskEngine.registerMask('maskCurrency', maskFunction, this.maskCurrency);
    
     /**
     * Função que retira os '.' das casas de milhar dos números
     * e troca as ',' dos decimais por '.'
     * Dessa forma o campo fica compativel com o BD do oracle.
     * 
     * @param {String} value - Valor numérico.
     */

    this.parseFloat = function(value) {
        if (/^(.*)(\.+).*(,+)(.*)$/gm.test(value)) {
            var loop = value.toString().split('.');
            for (var i = 0; i < loop.length - 1; i++) {
                value = value.toString().replace('.', '');
            }
        }
        if (/\,/g.test(value))
            value = value.toString().replace(',', '.');
        return parseFloat(value);
    };
    
    /**
     * Função que formata números float vindos do banco, ou em
     * padrão americano e passa para o formato brasileiro.
     * 
     * @param {String} value - Valor numérico.
     */
    
    var numberFormatBr = function(value) {
        if (/^(.*)(\,+).*(\.+)(.*)$/gm.test(value)) {
            var loop = value.toString().split(',');
            for (var i = 0; i < loop.length - 1; i++) {
                value = value.toString().replace(',', '');
            }
        }
        if (/^\d{1,}\.{1}\d*$/g.test(value))
            value = value.toString().replace('.', ',');
		else if(/^(\d*)([\.]*)((\d|\.)*)$/.test(value)){
			value = value.split('.');
			value[value.length-1] = ','+value[value.length-1];
			value = value.join('');
		}
        return value.toString();
    };
    
    /**
     * Função criada para corrigir o erro da maxlength.
     * Em vez do maxlength deve ser usada a propriedade maxLengthCurrency,
     * que considera apenas os números inteiros como length.
     * 
     * Função deve ser usada no evento FieldOnKeydown.
     * 
     * @param {Args} args - objeto args.
     * @param {Field} field - field com a propriedade maxLengthCurrency.
     */
    
    this.lengthCurrency = function(args, field) {
        var value;
        var fieldValue;
        
        if (field.inlineEditable && (field.widget.mode === "list" || field.widget.mode === "inline_edit")) {
            fieldValue = field.widget.currentRow[field.name + '_inline'];
            value = Util.isEmptyOrBlank(fieldValue) ? "" : fieldValue.toString();
        } else {
            fieldValue = field.value();
            value = Util.isEmptyOrBlank(fieldValue) ? "" : fieldValue.toString();
        }
    
        var realLength = value.split('-').join('').split('.').join('').split(',')[0].length;
        
        if (realLength >= field.maxLengthCurrency && !/^(\d+)(\,){1}(\d*)$/gm.test(value)) {
            var allowedKeys = [8, 37, 38, 39, 40, 46, 110, 188, 190, 194];
            if (!allowedKeys.includes(args.e.keyCode))
                args.e.preventDefault();
        }
    };
    
    var treatResponse = function(response, Authenticator) { //
		var url = response.responseURL;
	    var responseURL = null;
	    var responseData = response.response;
	    
	    if (url.indexOf('index.php/') > -1) {
	        responseURL = url.slice(url.indexOf('index.php/') + 9);
	    }
	    
		if(responseURL){
			var responseObj = JSON.parse(responseData);
	        var errorCode = responseObj.error;
			if(Authenticator){
				Authenticator.run(responseURL, responseObj, errorCode);
			} else if(errorCode && errorCode.indexOf('AUTH_') > -1){// Exception: AUTH_INVALID_UNIT 
	            var cleanError = parent.getCleanError(errorCode);
				MessageService.showMessageByCode(cleanError);
			}
		}
	};
	
	this.getCleanError = function(msg){
		return msg.match(/AUTH_[^\s]+/g)[0];
	};
	
	/**
	 * Overwrite XMLHttpRequest.prototype.open
	 * and add a listener on it.
	 */
	this.initRoutesListener = function(Authenticator) {
	    (function(open) {
	        XMLHttpRequest.prototype.open = function(method, url, async, user, pass) {
	            this.addEventListener("readystatechange", function() {
	            	try{
	                	treatResponse(this, Authenticator);
	            	} catch(e){
	            		return false;
	            	}
	            }, false);
	
	            open.call(this, method, url, async, user, pass);
	        };
	    })(XMLHttpRequest.prototype.open);
	};
	
	this.isValidFiliaisValuesCP = function(values){
		var arrFilialValida = getLocalVar('CPFILIALVALIDA');
        if(arrFilialValida && cacheLoaded){ 
        	var arrValues = [];
        	Array.isArray(values)? arrValues = values : arrValues.push(values);
        	var isInvalid = arrValues.some(function(value){return !arrFilialValida.includes(value)}.bind(this));
        	return !isInvalid;
        }else{
        	this.callRestEngine('lib#/lib_getValidOrganizationAndBranches', 'FilterData', []).then( function(result){
        		cacheLoaded = true; 
        		if(result.dataset){
        			var arrayToPush = [];
        			result.dataset.validBranches.forEach(function(row){arrayToPush.push(row.FILIAL)}.bind(this));
					setLocalVar('CPFILIALVALIDA', arrayToPush);
					this.isValidFiliaisValuesCP(values);
        		}
        	}.bind(this));
        }
	};
	
	this.validateFieldFiliaisCP = function(field){
		var arrFilialValida = getLocalVar('CPFILIALVALIDA');
		var filialValues;
        if(arrFilialValida && cacheLoaded){ 
            if(field.name == 'CDFILIAL')
                filialValues = field.value();
            else{
                if(field.outData.CDFILIAL){
                    filialValues = field.widget.currentRow[field.outData.CDFILIAL];
                }else{
                    return console.log('Não existe o campo CDFILIAL neste FIELD, usar a função validateFieldFiliaisCP(field)');   
                }
                if(filialValues && filialValues.length > 0){
                	var arrValues = [];
		        	Array.isArray(filialValues)? arrValues = filialValues : arrValues.push(filialValues);
		            var filtered = arrValues.filter(function(filial){return arrFilialValida.includes(filial)}.bind(this));
		            var invalids = arrValues.filter(function(filial){return !arrFilialValida.includes(filial)}.bind(this));
		            
		            if(filtered.length == 0 || !this.isValidFiliaisValuesCP(arrValues)){
		            	MessageService.showMessageByCode('lib#CP_BRANCH_NOT_ALLOWED', null, { type: 'ERROR' });
		            	var payload = {CDFILIAL:invalids};
		            	this.callRestEngine('lib#/lib_saveOrgFilial', 'DataSet', [payload]);
		            	/*
		            	Descomentar essa parte quando for para bloquear totalmente o uso de unidades nao cadastradas
		            	
		            	field.setValue('');
		            	field.widget.currentRow[field.name] = '';
			            //remove valores nao liberados do datasource.data
			            var filteredDataSet = field.dataSource.data.filter(function(dataSetRow){return arrFilialValida.some(function(row){return row == dataSetRow.CDFILIAL}.bind(this))}.bind(this));
			            field.dataSource.data = filteredDataSet;
			            
			            //Remove valores nao liberados do spam do autocomplete.
			            if(field.template == 'zh-select-autocomplete#field/select-autocomplete.html'){
				            var spamList = field.element.context.parentElement.getElementsByClassName('list-items')[0].children;
				            for (var i = 0; i < spamList.length -1; i++) {
				            	if(spamList[i].className != 'view-more' && !arrFilialValida.some(function(row){return spamList[i].getAttribute('data-item-identifier').indexOf(row) >= 0}.bind(this))){
							    	spamList[i].remove();
				            		i--
				            	}
							}
			            }//fim if
			            */
		            }
                }
            }
        }else{
        	this.callRestEngine('lib#/lib_getValidOrganizationAndBranches', 'FilterData', []).then(function(result){
        		cacheLoaded = true; 
        		if(result.dataset){
        			var arrayToPush = [];
        			result.dataset.validBranches.forEach(function(row){arrayToPush.push(row.FILIAL)}.bind(this));
					setLocalVar('CPFILIALVALIDA', arrayToPush);
					this.validateFieldFiliaisCP(field);
        		}
        	}.bind(this));
        }
	};
	
	this.setCurrentRowWithOutData = function(currentRow, valuesToSetOnCurrentRow, outDataValue) {
        for (var key in outDataValue) {
            if(Array.isArray(outDataValue[key])){
                var newArray = [];
                outDataValue[key].forEach(function(value){ newArray[value] = value}.bind(this)); // jshint ignore:line
                this.setCurrentRowWithOutData(currentRow, valuesToSetOnCurrentRow, newArray);
            }
            else
                currentRow[outDataValue[key]] = valuesToSetOnCurrentRow[key];
        }
    };
	
};

Configuration(function (ContextRegister) {
	ContextRegister.register('General', General);
});

// FILE: js/Util/LogDecorator.js
function LogDecorator(ZhuLogHelper) {
    /* Widget Getters */
    var getContentWidget = function(gridWidget) {
        return gridWidget.widgets[0].widgets[0];
    };

    /* Field Names */
    const ROUTE_FIELD_NAME              = 'ROUTE';
    const ROUTE_LABEL_FIELD_NAME        = 'ROUTE_LABEL';
    const TIME_FIELD_NAME               = 'TIMESTAMP';
    const USER_ID_FIELD_NAME            = 'USER_ID';
    const USER_NAME_FIELD_NAME          = 'USER_NAME';
    const PRODUCT_ID_FIELD_NAME         = 'PRODUCT_ID';
    const CONTENT_FIELD_NAME            = 'CONTENT';
    const HTTP_RESPONSE_CODE_FIELD_NAME = 'HTTP_RESPONSE_CODE';
    const REQUEST_TYPE_FIELD_NAME       = 'REQUEST_TYPE';
    const REQUEST_ID_FIELD_NAME         = 'REQ_ID';
    const TYPE_FIELD_NAME               = 'TYPE';
    const CONTAINER_FIELD_NAME_NAME     = 'CONTAINER_NAME';
    const WIDGET_NAME_FIELD_NAME        = 'WIDGET_NAME';
    const ORGANIZATION_ID_FIELD_NAME    = 'ORGANIZATION_ID';

    /* Field Labels */
    const USER_NAME_FIELD_LABEL    = 'User Name';
    const ROUTE_LABEL_FIELD_LABEL  = 'Action';

    /* Field Templates */
    const TEXT_EDIT_TEMPLATE       = 'field/text-edit.html';
    const SELECT_NATIVE_TEMPLATE   = 'field/select-native.html';
    const SELECT_MULTIPLE_TEMPLATE = 'field/select-multiple.html';
    const DATE_INTERVAL_TEMPLATE   = 'zh-interval-component#field/interval.html';
    const DATETIME_TEMPLATE        = 'field/datetime.html';

    var filterFieldsInAdvancedFieldGroup = [REQUEST_ID_FIELD_NAME, TYPE_FIELD_NAME, HTTP_RESPONSE_CODE_FIELD_NAME, CONTENT_FIELD_NAME];
    var fieldsNotUpdateTemplate          = [ROUTE_LABEL_FIELD_NAME];

    var updateWidgetFields = function (widget) {
        var routeField          = ZhuLogHelper.getField(widget, ROUTE_FIELD_NAME);
        var userNameField       = Util.clone(routeField);
        var routeLabelField     = Util.clone(routeField);

        userNameField.name     = USER_NAME_FIELD_NAME;
        userNameField.label    = USER_NAME_FIELD_LABEL;
        routeLabelField.name   = ROUTE_LABEL_FIELD_NAME;
        routeLabelField.label  = ROUTE_LABEL_FIELD_LABEL;

        ZhuLogHelper.moveField(widget, USER_ID_FIELD_NAME,        1);
        ZhuLogHelper.addField (widget, userNameField,             2);
        ZhuLogHelper.moveField(widget, TIME_FIELD_NAME,           3);
        ZhuLogHelper.moveField(widget, CONTAINER_FIELD_NAME_NAME, 4);
        ZhuLogHelper.moveField(widget, WIDGET_NAME_FIELD_NAME,    5);
        ZhuLogHelper.moveField(widget, ROUTE_FIELD_NAME,          6);
        ZhuLogHelper.addField (widget, routeLabelField,           7);

        ZhuLogHelper.editField(widget, ROUTE_LABEL_FIELD_NAME, {
            valueField: ROUTE_FIELD_NAME,
            descriptionField: ROUTE_LABEL_FIELD_NAME,
            template: SELECT_NATIVE_TEMPLATE,
            dataSource: {
                data: window.routesTranslate || []
            },
            filterProperties: {
                template: SELECT_MULTIPLE_TEMPLATE,
                operator: 'IN'
            },
            showOnList: true,
            maxWidth: '12%',
            class: 3
        });

        ZhuLogHelper.editField(widget, USER_ID_FIELD_NAME,        { showOnList: true, maxWidth: '10%', class: 4 });
        ZhuLogHelper.editField(widget, USER_NAME_FIELD_NAME,      { showOnList: true, maxWidth: '15%', class: 4 });
        ZhuLogHelper.editField(widget, CONTAINER_FIELD_NAME_NAME, { showOnList: true, maxWidth: '15%', class: 3 });
        ZhuLogHelper.editField(widget, WIDGET_NAME_FIELD_NAME,    { showOnList: true, maxWidth: '15%', class: 3 });
        ZhuLogHelper.editField(widget, TIME_FIELD_NAME,           { showOnList: true, maxWidth: '10%', class: 4 });
        ZhuLogHelper.editField(widget, ROUTE_FIELD_NAME,          { showOnList: true, maxWidth: '15%', class: 3 });
        ZhuLogHelper.editField(widget, TYPE_FIELD_NAME,           { showOnList: true, maxWidth: '8%' , class: 3 });

        ZhuLogHelper.removeField(widget, PRODUCT_ID_FIELD_NAME);
        ZhuLogHelper.removeField(widget, ORGANIZATION_ID_FIELD_NAME);
    };

    var updateWidgetFieldsGridOnly = function(gridWidget) {
        gridWidget.fields.forEach(function(field) {
            if(field.name && !(filterFieldsInAdvancedFieldGroup.indexOf(field.name) != -1)) {
                field.fieldGroup = null;
            }
            if(field.filterProperties) {
                if(fieldsNotUpdateTemplate.indexOf(field.name) == -1) {
                    field.template = field.filterProperties.template;
                }
                if(field.filterProperties.template == TEXT_EDIT_TEMPLATE) {
                    field.filterProperties.operator = 'LIKE';
                }
            }
        });

        //General filter fields
        ZhuLogHelper.editField(gridWidget, TIME_FIELD_NAME, {
            template: DATETIME_TEMPLATE,
            dateFormat: "DD/MM/YYYY",
            timeFormat: "HH:mm:ss",
            displayFormat: "DD/MM/YYYY HH:mm:ss",
            "datetime-dateFormat": "dd/mm/yy",
            "datetime-timeFormat": "HH:ii:ss",
            filterProperties: {
                isVisible: true,
                showOnForm: true,
                label: 'Date',
                template: DATE_INTERVAL_TEMPLATE,
                dateFormat: "DD/MM/YYYY",
                displayFormat: "DD/MM/YYYY",
                intervals: [ {
                    "label": "Última semana",
                    "period": "last-week"
                }, {
                    "label": "Último mês",
                    "period": "last-month"
                } ]
            }
        });

        //Advanced filter fields
        ZhuLogHelper.editField(gridWidget, TYPE_FIELD_NAME, { class: 4 });
        ZhuLogHelper.editField(gridWidget, HTTP_RESPONSE_CODE_FIELD_NAME, {
            class: 4,
            isVisible: false,
            filterProperties: {
                isVisible: true,
                operator : 'LIKE'
            }
        });
        ZhuLogHelper.editField(gridWidget, REQUEST_ID_FIELD_NAME, {
            class: 4,
            isVisible: false,
            filterProperties: {
                isVisible: true,
                operator : 'LIKE'
            }
        });
        ZhuLogHelper.editField(gridWidget, CONTENT_FIELD_NAME, {
            isVisible: false,
            fieldGroup: 'advancedFilter',
            template : TEXT_EDIT_TEMPLATE,
            filterProperties: {
                isVisible: true,
                operator : 'LIKE',
                class    : 12
            }
        });
    };

    var updateWidgetFieldsFormOnly = function(formWidget) {
        ZhuLogHelper.editField(formWidget, HTTP_RESPONSE_CODE_FIELD_NAME, { class: 2 });
        ZhuLogHelper.editField(formWidget, REQUEST_TYPE_FIELD_NAME,       { class: 3 });
    };

    this.decorateWidget = function(gridWidget) {
        updateWidgetFields(gridWidget);
        updateWidgetFieldsGridOnly(gridWidget);

        var formWidget = getContentWidget(gridWidget);
        updateWidgetFields(formWidget);
        updateWidgetFieldsFormOnly(formWidget);

        gridWidget.currentRowDefaultFilter = {
            TIMESTAMP: {
                start : moment().add(-1, 'days').format('DD/MM/YYYY'),
                end   : moment().format('DD/MM/YYYY'),
                period: undefined
            }
        };
    };

    this.normalizeRows    = function(rows) { return rows; };
    this.normalizeFilters = function(filters) {};
}

Configuration(function(ContextRegister){
    ContextRegister.register('LogDecorator', LogDecorator);
});


// FILE: js/Util/MenuBuilder.js
var MenuBuilder = function (restEngine, ZHPromise, templateManager, metaDataFactory, eventAggregator, $window, requestDataSourceEngine, ApplicationContext) {
    var localProductMenu;
    var attrToReplace = [
        "label",
        "showMenu",
        "showHeader",
        "showDescriptionOrder",
        "onRequestIdleTimeout",
        "mainWindow",
        "logLevel",
        "aclEnable",
        "showMenuSearch",
        "userDataActions",
        "reportServiceUrl",
        "reportsPath",
        "inDeveloperMode",
        "showDevtoolsInSameWindow",
        "shouldBackToMainWindowOnReload",
        "shortcutKeys"
    ];

    var requestProductMenu = function () {
        var modulesPackage = $window.modulesPackage || "modules";
        return restEngine.requestMetaData(modulesPackage + "#json/containers.json").then(function (response) {
            var productObjMenu = response.data;
            var keys = Object.keys(productObjMenu);
            // get first project menu found
            return productObjMenu[keys[0]];
        });
    };

    var removeEmptyMenuGroups = function(groupMenus) {
        return groupMenus.filter(function(group) {
            return (group.menus && group.menus.length != 0) || group.name == "zhHistory";
        });
    };

    var orderMenus = function(menus) {
        menus.map(function(menu) {
            if(menu.menus) {
                menu.menus = orderMenus(menu.menus);
            }
            return menu;
        });

        return sortMenus(menus);
    };

    var sortMenus = function(menus) {
        return menus.sort(function(menuA, menuB) {
            if (menuA.order && menuB.order) {
                if (menuA.order < menuB.order) {
                    return -1;
                }
                if (menuA.order > menuB.order) {
                    return 1;
                }
            }
            if (!menuA.order && menuB.order) {
                return -1;
            }
            if (menuA.order && menuB.order) {
                return 1;
            }
            return 0;
        });
    };

    var prepareMenus = function (response) {
        var groupMenus = response.dataset.menu;
        window.routesTranslate = response.dataset.routesTranslate;
        var zhuLogWidget = templateManager.container ? templateManager.container.getWidget('zhuLog') : false;
        if(zhuLogWidget) {
            zhuLogWidget.getField('ROUTE_LABEL').dataSource.data = window.routesTranslate;
            $(window).trigger('resize.grid');
        }
        groupMenus = orderMenus(removeEmptyMenuGroups(groupMenus));
        var groupMenuHistory = [templateManager.project.getMenu("zhHistory")];
        templateManager.project.groupMenu = metaDataFactory.groupMenuFactory(groupMenus.concat(groupMenuHistory));

        //Force framework to apply ACL Rules
        var aux = {};
        Object.keys(templateManager.aclRules).forEach(function(ruleKey){
            aux[ruleKey] = templateManager.aclRules[ruleKey];
        });
        templateManager.aclRules = aux;
        //Force framework to apply ACL Rules

        eventAggregator.publish('menuBuilded');
    };

    var replaceProductAttrOnMenu = function (productMenu) {
        attrToReplace.forEach(function (attr) {
            templateManager.project[attr] = productMenu[attr];
        });
    };

    var setLocalProductMenu = function () {
        if (!$window.modulesPackage) {
            requestProductMenu().then(function (productMenu) {
                localProductMenu = productMenu;
            });
        }
    };

    var getCurrentModule = function() {
        var currentModule = window.location.hash.split('/').filter(function (_) {
            return _.length;
        }).pop();
        if (currentModule && currentModule.length > 0) {
            currentModule = currentModule.split(/_|#/)[0];
        }
        return currentModule;
    };

    if(!window.notUseMicroservice) {
        eventAggregator.subscribe('loginSuccess', function (loginResponse) {
            eventAggregator.publish('AboutOnClick');
            if (!$window.modulesPackage && !$window.keepTitle) {
                replaceProductAttrOnMenu(localProductMenu);
                templateManager.updateTitle(templateManager.project.label);
            }
            var filter = [{
                "name": "CONCATENATE_GROUP_MENU",
                "operator" : "=",
                "value" :  true
            }, {
                "name": "VISIBLE_ELEMENTS",
                "operator" : "=",
                "value" :  loginResponse.VISIBLE_ELEMENTS || []
            }, {
                "name": "EXPIRED_ELEMENTS",
                "operator" : "=",
                "value" :  loginResponse.EXPIRED_ELEMENTS || []
            }, {
                "name": "URL_ORIGIN",
                "operator" : "=",
                "value" :  window.location.origin
            }, {
                "name": "CURRENT_MODULE",
                "operator" : "=",
                "value" :  getCurrentModule()
            }, {
                "name": "CURRENT_LANGUAGE",
                "operator" : "=",
                "value" :  window.lang
            } ];
            requestDataSourceEngine.getDataSource('lib#/lib_buildMenu', filter)
                .then(prepareMenus)
                .catch(ApplicationContext.LibUtilities.showErrorMessage);
        });

        setLocalProductMenu();
    }
};

Configuration(function (ContextRegister) {
    ContextRegister.register('MenuBuilder', MenuBuilder);
});

// FILE: js/Util/Messages.js
function LibMessages(){
    this.ALE_EXPIRED_SESSION = 'Sua sessão expirou.<br/>Você será redirecionado para efetuar login novamente.';
    this.ALE_MIGRATION_IS_PENDENT = 'ATENÇÃO!<br/><br/>Esse produto foi atualizado recentemente, com necessidade de alterações na estrutura do banco de dados, sem que essas alterações tenham sido aplicadas.<br/>A utilização do produto nessa situação poderá acarretar erros.<br/><br/>Solicite ao administrador do sistema a regularização da alteração na estrutura do bando de dados.', 'INFORMATION';

    this.ERR_ATTEMPT_END = 'Tentativas esgotadas. Redirecionando...';
    this.ERR_ATTEMPT_PARTIAL = 'Senha incorreta.<br/>Tentativa %1/3';
    this.ERR_EXPIRED_SESSION_LOGIN = 'Sessão expirada. Redirecionando...';
}

Configuration(function(ContextRegister){
    ContextRegister.register('LibMessages', LibMessages);
});


// FILE: js/Util/ReportDecorator.js
function ReportDecorator(eventAggregator, restEngine, templateManager, ZhLogger, ScreenService, eventEngine) {
    
    this.onContainerOpen = function() {
        try {
            var container = templateManager.container;
            validContainer(container);
            if (container.customReportsConfig) {
                var customReportsConfig = container.customReportsConfig;
                validCustomReportsConfig(customReportsConfig);
                var widget = selectWidget(container, customReportsConfig.widgetName);
                var containerName = container.customReportsConfig ? container.customReportsConfig.reportCodeName : container.name;
                
                var fieldToChangeData = selectField(widget, customReportsConfig.fieldName);
                
                if (customReportsConfig.reportIsTheMainFunction === undefined || customReportsConfig.reportIsTheMainFunction === true) {
                    buildData(containerName, fieldToChangeData);
                } else {
                    const separator = "', '";
                    const eventCode = "ReportDecorator.triggerBuildData('" + containerName + separator + customReportsConfig.widgetName + separator + customReportsConfig.fieldName + "')";
                    
                    addEvent({
                        entity: widget,
                        event: {
                            name: 'WidgetOnEnterOnce',
                            code: eventCode,
                            bind: true,
                        }
                    });
                }
                widget.beforeOpenReport = beforeOpenReport;
            }
        } catch (e) {
            ZhLogger.warning(e);
        }
    };
    eventAggregator.subscribe('onContainerOpen',this.onContainerOpen);
    
    this.triggerBuildData = function(containerName, widgetName, fieldName) {
        const container = templateManager.container;
        
        validContainer(container);
        
        const widget = selectWidget(container, widgetName);
        const fieldToChangeData = selectField(widget, fieldName);
        
        try {
            buildData(containerName, fieldToChangeData);
        } catch (e) {
            ZhLogger.warning(e);
        }
    };
    
    function buildData(containerName, fieldToChangeData) {
        const route = getServiceUrlBasedOnTriggerPackage() + '#/lib_getDataReportField';
        
        restEngine.post(route, {
            "requestType": "Row",
            "row": [containerName.substr(0, 6)]
        }).then(function (callback) {
            try {
                var data = callback.dataset.dataReport;
                
                handleErrors(data);
                
                const formattedData = getFormattedData(fieldToChangeData, data);
                
                formattedData.forEach(function(row) {
                    row.description = ScreenService.i18n(row.description);
                });
                
                setDataSource(fieldToChangeData, formattedData);
                applyDefaultValue(fieldToChangeData);
                
                /**
                 * Força o select do item para que haja alteração visual.
                 * Operações visuais como updateTemplate e redraw não surtiram efeitos.
                 */
                setTimeout(function() {
                    clickOnSelectedOption(fieldToChangeData.name);
                }, 500);
                
                addEvent({
                    entity: fieldToChangeData.getParent(),
                    event: {
                        name: 'WidgetOnEnter',
                        code: "ReportDecorator.onEnterReportWidget('" + fieldToChangeData.name + "')",
                        bind: true,
                    }
                });
            } catch (e) {
                ZhLogger.warning(e);
            }
        }.bind(this), function(error) {
            if (error.data && error.data.error) {
                throw error.data.error;
            } else {
                throw ScreenService.i18n('Ocorreu um erro ao buscar a lista de relátorios da tela.');
            }
        });
    }
    
    function getServiceUrlBasedOnTriggerPackage() {
        const fileName = templateManager.container.fileName;
        const aliasSplited = fileName.split('#').shift().split('_');
        
        if (aliasSplited.length) {
            const packageName = aliasSplited.shift();
            
            if (packageName) return packageName;
        }
        
        return 'lib';
    }
    
    function getFormattedData(fieldToChangeData, data) {
        return data
                .filter(function(reportElement) {
                    return !Array.isArray(reportElement);
                })
                .map(function(reportElement) {
                    if (Array.isArray(reportElement)) return;
                    
                    const newElement = {};
                    
                    newElement[fieldToChangeData.valueField] = reportElement.value;
                    newElement[fieldToChangeData.descriptionField] = reportElement.description;
                    newElement[fieldToChangeData.strategyField] = reportElement.strategy;
                    
                    return newElement;
                });
    }
    
    function handleErrors(data) {
        const errorIndex = data.findIndex(function(reportElement) {
            return Array.isArray(reportElement);
        });
        
        if (errorIndex === -1) return;
            
        if (data.length === 1) {
            const message = ScreenService.i18n('Ocorreu um erro ao buscar a lista de relatórios da tela.');
            
            ScreenService.errorNotification(message);
            
            throw message + ScreenService.i18n('Consulte a requisição correspondente para mais detalhes.');
        } else {
            const isQr2Parametrized = data[errorIndex].findIndex(function(error) {
                return error === ScreenService.i18n('Servidor de relatórios QR2 não está parametrizado.');
            }) === -1;
            
            const isBirtParametrized = data[errorIndex].findIndex(function(error) {
                return error === ScreenService.i18n('Servidor de relatórios BIRT não está parametrizado.');
            }) === -1;
            
            if (isQr2Parametrized || isBirtParametrized) {
                ScreenService.errorNotification(ScreenService.i18n('Alguns relatórios podem não estar disponíveis.'));
            }
            
        	ZhLogger.warning(ScreenService.i18n('Alguns relatórios podem não estar disponíveis. Consulte a requisição correspondente para mais detalhes.'));
        }
    }
    
    function setDataSource(fieldToChangeData, data) {
        if (!fieldToChangeData.dataSource.data || fieldToChangeData.dataSource.data.length == 0) {
            fieldToChangeData.dataSource.data = data;
        } else {
            const valueField = fieldToChangeData.valueField;
            const descriptionField = fieldToChangeData.descriptionField;
            const strategyField = fieldToChangeData.strategyField;
            
            const removingDuplicatedReports = function(report, index, reports) {
                return index === reports.findIndex(function(r) {
                    return r[valueField] === report[valueField] &&
                           r[descriptionField] === report[descriptionField] &&
                           r[strategyField] === report[strategyField];
                });
            };
            
            const newData = fieldToChangeData.dataSource.data.concat(data);
            
            fieldToChangeData.dataSource.data = newData.filter(removingDuplicatedReports);
        }
    }
    
    function applyDefaultValue(fieldToChangeData) {
        if (!fieldToChangeData.defaultValue || fieldToChangeData.defaultValue === 'firstRow') {
            const firstRow = fieldToChangeData.dataSource.getFirstRow();
            
            fieldToChangeData.defaultValue = firstRow[fieldToChangeData.valueField];
        }
        
        fieldToChangeData.applyDefaultValue();
    }
    
    function clickOnSelectedOption(fieldName) {
        const baseSelector = "#" + fieldName + " + div";
        const baseElement = document.querySelector(baseSelector);
        
        if (!baseElement) {
            return setTimeout(function recursiveCallClickOnSelectedOption() {
                clickOnSelectedOption(fieldName);
            }, 500);
        }
        
        document.querySelector(baseSelector).click();
        
        const selectedElementSelector = baseSelector + ' li[class*="selected"]';
        
        document.querySelector(selectedElementSelector).click();
    }
    
    function selectWidget(container, widgetName) {
        var widget = container.getWidget(widgetName);
        
        if (widget) {
            return widget;
        } else {
            throw ScreenService.i18n("A widget informada não existe dentro desse container.");
        }
    }
    
    function selectField(widget, fieldName) {
        var field = widget.getField(fieldName);
        
        if (field) {
            if (field.dataSource) {
                return field;
            } else {
                throw ScreenService.i18n("O field informado não contém a propriedade dataSource.");    
            }
        } else {
            throw ScreenService.i18n("O field informado não existe na widget informada.");
        }
    }
    
    function validContainer(container) {
        if (!container) {
            throw ScreenService.i18n("Container não existe.");
        }
    }
    
    function validCustomReportsConfig(config) {
        if (!config.widgetName) {
            throw ScreenService.i18n('A propriedade widgetName não existe dentro de customReportsConfig.');
        }
        
        if (!config.fieldName) {
            throw ScreenService.i18n('A propriedade fieldName não existe dentro de customReportsConfig.');
        }
    }
    
    function eventExistsByCode(events, searchedCode) {
        return events.filter(function(event){
            return event.code.indexOf(searchedCode) != -1;
        }).length > 0;
    }
    
    function eventExistsByName(events, searchedName) {
        return events.findIndex(function(event){
            return event.name === searchedName;
        }) !== -1;
    }
    
    function addCodeOnEvent(events, eventName, eventCode, placeOn) {
        if (!placeOn) placeOn = 'right';
        
        const eventIndex = events.findIndex(function(event) {
            return event.name === eventName;
        });
        const event = events[eventIndex];
        const endSemicolonIndex = event.code.lastIndexOf(';');
        const codeHasEndSemicolon = endSemicolonIndex !== -1 && endSemicolonIndex === event.code.length - 1;
        
        if (!codeHasEndSemicolon) {
            event.code += ';';
        }
        
        if (placeOn === 'right') {
            events[eventIndex].code += eventCode;
        } else {
            const newCode = eventCode + ';' + events[eventIndex].code;
            
            events[eventIndex].code = newCode;
        }
    }
    
    function addEvent(params) {
        const entity = params.entity;
        const event = params.event;
        
        const name = event.name;
        const code = event.code;
        const events = entity.events;
        
        if (eventExistsByName(events, name)) {
            if (!eventExistsByCode(events, code)) {
                addCodeOnEvent(events, name, code, event.placeOn);
            }
        } else {
            events.push({
                name: name,
                code: code,
            });
            
            if (event.bind) {
                eventEngine.bindEvent(entity, name, code);
            }
        }
    }
    
    function getSelectedOption(fieldName) {
        const selector = '#' + fieldName + ' + div li[class*="selected"]';
        
        return document.querySelector(selector);
    }
    
    function getCurrent(fieldName) {
        const selector = '#' + fieldName + ' + div > span';
        
        return document.querySelector(selector).textContent;
    }
    
    this.onEnterReportWidget = function(fieldName) {
        const field = templateManager.container.getActiveWidget().getField(fieldName);
        
        if (!field.value()) {
            applyDefaultValue(field);
        }
        
        if (!getSelectedOption(fieldName)) {
            setTimeout(function runClickOnSelectedOption() {
                const selectedOption = getSelectedOption(fieldName);
                
                if (!selectedOption) {
                    return setTimeout(runClickOnSelectedOption, 500);
                }
                
                const current = getCurrent(fieldName);
                
                if (!current) {
                    return clickOnSelectedOption(fieldName);
                }
            }, 500);
        }
    };
    
    function beforeOpenReport(params) {
        const reportParams = params.reportParams;
        const reportNameSplitted = reportParams.__report_name.split('.');
        const reportName = reportNameSplitted[0];
        const strategy = reportNameSplitted[1];
        
        reportParams.__report_name = reportName;
        reportParams.STRATEGY = strategy;
    }
}

Configuration(function(ContextRegister){
    ContextRegister.register('ReportDecorator', ReportDecorator);
});

// FILE: js/Util/ShortcutDecorator.js
function ShortcutDecorator(ApplicationContext, templateManager) {

    /**
     *  Default keys for CRUD icons
     */
    const defaultCRUDShortcutKeys = {
        "add": "mod+a",
        "edit": "mod+e",
        "delete": "mod+d"
    };

    /**
     * 
     * Get the 'mod' key name according to OS (Ctrl or Command)
     * @returns String(Ctrl, Command) / Boolean(false)
     */
    function getTooltipModKey() {
        var platform = window.navigator.platform,
            commandPlatforms = ['Macintosh', 'MacIntel', 'MacPPC', 'Mac68K'],
            ctrlPlatforms = ['Win32', 'Win64', 'Windows', 'WinCE'],
            mod = false;

        if (commandPlatforms.indexOf(platform) !== -1) {
            mod = 'Command + ';
        } else if (ctrlPlatforms.indexOf(platform) !== -1 || /Linux/.test(platform)) {
            mod = 'Ctrl + ';
        }
        return mod;
    }

    /**
     * 
     * Get shortcut key from shortcutKeys object of widget, if not defined, 
     * from project property and if not defined, 
     * from defaultCRUDShortcutKeys const in this function.
     * @param {any} widget 
     * @param {any} shortcut 
     * @returns String(Shortcut key) / Undefined
     */
    function getShortcutKey(widget, shortcut) {
        return (
            Util.getNestedProperty(widget, ['shortcutKeys', shortcut]) ||
            Util.getNestedProperty(templateManager, ['project', 'shortcutKeys', shortcut]) ||
            defaultCRUDShortcutKeys[shortcut]
        );
    }
/**
 * 
 * Iterate recursively in widgets of container applying shortcut key in actions. 
 * @param {any} widgets 
 */
function applyShortcutOnAction(widgets) {
        var modTooltip = getTooltipModKey();
        widgets.forEach(function (widget) {
            if (widget.actions) {
                widget.actions.forEach(function (action) {
                    if (action.icon === 'plus' && !action.skipShortcut && !action.shortcutKey) {
                        action.shortcutKey = getShortcutKey(widget, 'add');
                    } else if (action.icon === 'pencil' && !action.skipShortcut && !action.shortcutKey) {
                        action.shortcutKey = getShortcutKey(widget, 'edit');
                    } else if (action.icon === 'trash' && !action.skipShortcut && !action.shortcutKey) {
                        action.shortcutKey = getShortcutKey(widget, 'delete');
                    } else if (!action.skipShortcut && !action.shortcutKey) {
                        action.shortcutKey = getShortcutKey(widget, action.icon);
                    }
                    if (modTooltip && action.shortcutKey && !action.tooltip && templateManager.project.showShortcutKeyAsTooltip !== false) {
                        action.tooltip = action.shortcutKey.toUpperCase().replace('MOD+', modTooltip);
                    }
                });
            }
            if (widget.widgets && widget.widgets.length) {
                applyShortcutOnAction(widget.widgets);
            }
        });
    }

    /**
     * 
     * If project have the property enableCRUDShortcutKeys == true, applies the shortcut keys in actions
     * @param {any} containerName 
     * @param {any} container 
     * @returns Container(container)
     */
    this.apply = function (containerName, container) {
        if (templateManager.project.enableCRUDShortcutKeys == true) {
            applyShortcutOnAction(container.widgets);
        }
        return container;
    };

}

Configuration(function (ContainerDecoratorProvider, ContextRegister, ApplicationContext, templateManager) {
    ContextRegister.register('ShortcutDecorator', ShortcutDecorator);
    ContainerDecoratorProvider.registerProvider(new ShortcutDecorator(ApplicationContext, templateManager));
});


// FILE: js/Util/Utilities.js
function LibUtilities(ScreenService, eventAggregator, templateManager, requestDataSourceEngine, restEngine, MessageService) {
    var self = this;
    this.authenticationContainer = 'login#authentication';
    this.expiredSessionMethod = null;

    this.showErrorMessage = function(response) {
        return MessageService.getMessageByCode('lib#UNEXPECTED_ERROR').then(function(defaultMessage) {
            if (response && response.data && response.data.error) {
                var error = response.data.error;
                if (self.isJson(error)) {
                    error = JSON.parse(error);
                    var params = error.PARAMS || null;
                    var messageCode = error.CODE || 'UNEXPECTED_ERROR';
                    return MessageService.getMessageByCode('lib#' + messageCode).then(function(message) {
                        return ScreenService.showMessage(message, 'ERROR', null, params);
                    }).catch(function() {
                        return ScreenService.showMessage(messageCode, 'ERROR', null, params);
                    });
                } else {
                    var message = Util.isEmptyOrBlank(error) ? defaultMessage : error.split("Exception:").pop();
                    if(!message.includes('ALE_SESSION_WILL_BE_ENDED')) {
                        return ScreenService.showMessage(message, 'ERROR');
                    }
                }
            } else {
                return ScreenService.showMessage(defaultMessage, 'ERROR');
            }
        });
    };

    this.redirectToLogin = function() {
        if(window.openLoginContainerWithoutRedirect) {
            ScreenService.openWindow(self.authenticationContainer);
        } else {
            self.openWindow(self.authenticationContainer);
        }
    };

    eventAggregator.subscribe("EventOnRequestStart", function (eventData) {
        var validateExpiredSessionRoute = 'lib_validateExpiredSession';
        var logoutRoute = 'lib_logout';
        var loginRoute  = 'login';
        var validateUserRoute = 'validateUser';

        var requestConfig = eventData.requestConfig;
        if (requestConfig && requestConfig.url && shouldAddRequestInfo(requestConfig.url) && templateManager.container) {
            requestConfig.data.origin = requestConfig.data.origin || {};
            var widget;
            var container = templateManager.loadingContainerJson;
            if(container) {
                widget = getFirstWidgetWithDataSourceRest(container.widgets);
                if(!widget) {
                    widget = container.widgets[0];
                }
            } else {
                container = templateManager.container;
                widget = container.getActiveWidget();
            }

            requestConfig.data.origin.containerLabel = container.label || container.name;
            requestConfig.data.origin.widgetLabel = widget.label || widget.name;
        }

        var route = requestConfig.url.split('/').pop();
        if(route != validateExpiredSessionRoute) {
            factoryExpiredSessionMethods();
        }
        if(route != logoutRoute && route != loginRoute) {
            var token = localStorage.getItem('LOGIN_TOKEN');
            var hash = localStorage.getItem('LOGIN_HASH');
            var keepConnected = localStorage.getItem('LOGIN_KEEP_CONNECTED');
            if(window.externalTokens) {
                window.externalTokens.some(function(externalToken) {
                    if(eventData.requestConfig.url.includes(externalToken.url)) {
                        token = externalToken.token;
                        keepConnected = externalToken.keepConnected || keepConnected;
                        return true;
                    }
                    return false;
                });
            }
            if (token) {
                requestConfig.headers['OAuth-Token'] = token;
            }
            if (hash) {
                requestConfig.headers['OAuth-Hash'] = hash;
                requestConfig.headers['OAuth-Project'] = window.tekLoginProjectId;
            }
            if(route == validateUserRoute) {
                keepConnected = 'Yes';
            }
            requestConfig.headers['OAuth-KeepConnected'] = keepConnected;
        }
    });

    var shouldAddRequestInfo = function(url) {
        return !url.match(/.json/i) &&
            !url.match(/.html/i) &&
            !url.match(/.svg/i);
    };

    var getFirstWidgetWithDataSourceRest = function(widgets) {
        for(var i = 0; i < widgets.length; i++) {
            if(widgets[i].dataSource && widgets[i].dataSource.rest == true) {
                return widgets[i];
            } else {
                return getFirstWidgetWithDataSourceRest(widgets[i]);
            }
        }
    };

    var factoryExpiredSessionMethods = function() {
        if(templateManager.project && templateManager.project.onRequestIdleTimeout) {
            if(self.expiredSessionMethod) {
                clearTimeout(self.expiredSessionMethod);
            }
            self.expiredSessionMethod = Util.doAsync(validateExpiredSession, templateManager.project.onRequestIdleTimeout);
        }
    };

    var validateExpiredSession = function() {
        var timeout = templateManager.project.onRequestIdleTimeout;
        var filter = [ {
            name: 'TIMEOUT',
            value: timeout,
            operator: '='
        } ];

        requestDataSourceEngine.getDataSource('lib#/lib_validateExpiredSession', filter).then(function(response){
            if(response && response.dataset && response.dataset.expiredSessionInfo) {
                var expiredSessionInfo = response.dataset.expiredSessionInfo;
                if(expiredSessionInfo.IS_EXPIRED) {
                    eventAggregator.publish('LibExpiredSession');
                } else {
                    if(self.expiredSessionMethod) {
                        clearTimeout(self.expiredSessionMethod);
                    }
                    Util.doAsync(validateExpiredSession, expiredSessionInfo.TIMEOUT);
                }
            } else {
                self.showErrorMessage(response);
            }
        }).catch(self.showErrorMessage);
    };

    this.changeLoginResponseToOldParams = function(loginResponse) {
        if(loginResponse) {
            return {
                cdoperador:          loginResponse.USER_ID,
                nmoperador:          loginResponse.USER_NAME,
                dsemailoper:         loginResponse.EMAIL,
                nrorg:               loginResponse.ORGANIZATION_ID,
                nmorg:               loginResponse.TRADING_NAME,
                nmrazsocialorg:      loginResponse.COMPANY_NAME,
                perfilDeAcesso:      loginResponse.ACCESS_PROFILE,

                cdempresa:           loginResponse.CDEMPRESA     || null,
                cdfilialselecionada: loginResponse.CDFILIAL      || null,
                cdpictprat:          loginResponse.CDPICTPRAT    || null,
                cdpictprod:          loginResponse.CDPICTPROD    || null,
                ididioma:            loginResponse.IDIDIOMA      || null,
                nmacesso:            loginResponse.NMACESSO      || null,
                nmcomploper:         loginResponse.NMCOMPLOPER   || null,
                nmfilialselecionada: loginResponse.NMFILIAL      || null,
                nrestruttrab:        loginResponse.NRESTRUTTRAB  || null,
                nrorgtrab:           loginResponse.NRORGTRAB     || null,
                nrparcnegocio:       loginResponse.NRPARCNEGOCIO || null,

                logged:              loginResponse.LOGGED,
                senhaExpirada:       loginResponse.EXPIRED_PASSWORD,
                version:             loginResponse.VERSION
            };
        }
    };

    var getCurrentModule = function() {
        var currentModule = window.location.hash.split('/').filter(function (_) {
            return _.length;
        }).pop();
        if (currentModule && currentModule.length > 0) {
            currentModule = currentModule.split(/_|#/)[0];
        }
        return currentModule;
    };

    this.openMicroServiceUrl = function(args) {
        var containerName = args.owner.msContainerName;
        var currentModule, module;

        if(containerName.indexOf('#') == -1) {
            currentModule = module = '';
        } else {
            var subModule = containerName.split('#')[0];
            module        = subModule.split('_')[0];
            currentModule = getCurrentModule();
        }

        if (module && currentModule && (module != currentModule)) {
            var filter = [ {
                name: 'USER',
                value: localStorage.getItem('LOGIN_USER'),
                operator: '='
            }, {
                name: 'IS_LOGGED',
                value: localStorage.getItem('IS_LOGGED') || false,
                operator: '='
            }, {
                name: 'KEEP_CONNECTED',
                value: localStorage.getItem('LOGIN_KEEP_CONNECTED') || 'No',
                operator: '='
            }, {
                name: 'LOGIN_LANGUAGE',
                value: localStorage.getItem('LOGIN_LANGUAGE') || window.lang,
                operator: '='
            }  ];

            ScreenService.showLoader();
            requestDataSourceEngine.getDataSource(module + '#/lib_startSession', filter).then(function() {
                ScreenService.hideLoader();
                ScreenService.openLink(args.owner.url);
            }).catch(function(error) {
                ScreenService.hideLoader();
                self.showErrorMessage(error);
            });
        }
    };

    this.openLinkByMenu = function(menu) {
        if(typeof menu === 'string') {
            menu = templateManager.project.getMenu(menu);
        }

        var args = { owner: {
            msContainerName: menu.msContainerName,
            url: menu.url
        } };
        self.openMicroServiceUrl(args);
    };

    this.openWindow = function(windowName, newWindow) {
        return requestModulesMetadata().then(function (modules) {
            var subModule = windowName.split('#')[0];
            var module = subModule.split('_')[0];
            var url = window.location.origin + '/' + modules[module].baseUrl + "/#/" + windowName;
            if (ScreenService.openLink) {
                ScreenService.openLink(url, newWindow);
            } else {
                ScreenService.openWindow(windowName);
            }
        });
    };

    var requestModulesMetadata = function () {
        var modulesPackage = window.modulesPackage || "modules";
        return restEngine.requestMetaData(modulesPackage + "#json/modules.json").then(function (response) {
            return response.data;
        });
    };

    eventAggregator.subscribe("AboutOnClick", function () {
        if(!templateManager.versionData) {
            templateManager.versionData = true;
            var filter = [ {
                name: 'CURRENT_MODULE',
                operator: '=',
                value: getCurrentModule()
            } ];
            ScreenService.showLoader();
            requestDataSourceEngine.getDataSource('lib#/lib_getVersionInfo', filter).then(function (response) {
                ScreenService.hideLoader();
                templateManager.versionData = response.dataset.versionInfo;
                templateManager.versionData.dependencies.current = templateManager.versionData.dependencies.frontend;
                templateManager.versionData.dependencies.changeCurrentVersion = function(newVersion) {
                    templateManager.versionData.dependencies.current = templateManager.versionData.dependencies[newVersion];
                };

                if (!!templateManager.versionData.dependencies) {
                    localStorage.setItem('versionData', JSON.stringify(templateManager.versionData));
                } else {
                    localStorage.setItem('versionData', JSON.stringify(false));
                }
            }).catch(function(error) {
                ScreenService.hideLoader();
                self.showErrorMessage(error);
            });
        }
    });

    eventAggregator.subscribe('onContainerOpen', function(args) {
        var versionData = JSON.parse(localStorage.getItem('versionData'));

        if (!args.container.isNext && versionData && templateManager.versionData) {
            templateManager.versionData.name = versionData.name;
            templateManager.versionData.version = versionData.version;
            templateManager.versionData.dependencies.backend = versionData.dependencies.backend;
            templateManager.versionData.dependencies.frontend = versionData.dependencies.frontend;
            templateManager.versionData.dependencies.modules = versionData.dependencies.modules;
            templateManager.versionData.dependencies.changeCurrentVersion('frontend');
            templateManager.updateTemplate();
        }
    });

    eventAggregator.subscribe("EventOnRequestError", function (eventData) {
        if(eventData.e && eventData.e.e && eventData.e.e.data && eventData.e.e.data.data) {
            var error = eventData.e.e.data.data;
            var config = eventData.e.e.data.config;
            //Expired or Invalid Token
            if(error.errorCode == 101 || error.errorCode == 100)  {
                eventAggregator.publish('LibInvalidToken', error.errorCode);
            } else if(error.errorCode == 102){
                eventAggregator.publish('LibInvalidTokenSupportOperator');
            } else if(error.errorCode == 20){
                eventAggregator.publish('LibConcurrentAccess');
            }
        }
    });

    this.isJson = function(str) {
        var result = null;

        try {
            result = JSON.parse(str);
        } catch (e) { }

        return result;
    };

    /**
     * @param $collectionIds  => ID ou ARRAY da(s) coleta(s) (Cod Filial, Cod Operador, Cod da Loja, ...)
     * @param $operationId    => ID da operação (Retirada, Cardápio, Login, ...)
     * @param $productId      => Código do Produto (opcional).
     * @param $operatorCode   => Código do Operador (opcional).
     * @param $operatorName   => Nome do Operador (opcional).
     * @param $organizationId => Código do organização (opcional).
     */
    this.saveCollectedData = function(collectionIds, operationId, productId, operatorCode, operatorName, organizationId) {
        var row = {
            COLLECTION_IDS : collectionIds,
            OPERATION_ID   : operationId,
            PRODUCT_ID     : productId		|| null,
            OPERATOR_CODE  : operatorCode   || null,
            OPERATOR_NAME  : operatorName   || null,
            ORGANIZATION_ID: organizationId || null,
            changed        : true
        };

        return requestDataSourceEngine.setDataSource('lib#/lib_saveCollectedData', [row]);
    };
}

Configuration(function(ContextRegister){
    ContextRegister.register('LibUtilities', LibUtilities);
});


// FILE: js/Util/ViewFloatMask.js
var ViewFloatMask = function(maskEngine) {
    var keypressHandler = function (e, element, params) {
        var opt = Util.extend(Util.clone($.currency.i18n[$.currency.lang]), (params || {}), true);
        var thousandsCode = opt.thousands.charCodeAt();
        var isThousands = (thousandsCode === e.which);
        var is_number = (e.which >= 48 && e.which <= 57);
        var is_dot = (e.which == 46);
        var is_comma = (e.which == 44);
        var is_minus = (e.which == 45);
        var hasSeparator = (element.val().indexOf(opt.decimal) != -1 || element.val().indexOf(opt.thousands) != -1);
        var hasNegative = (element.val().length > 0 || !opt.allowNegative);

        if ((hasSeparator && (is_dot || is_comma)) || (hasNegative && is_minus) || isThousands)
            e.preventDefault();

        if (is_dot || is_comma || is_number || is_minus)
            element.data('maskOptions', opt);
        else
            e.preventDefault();
    };

    var keyupHandler = function (e, element, params) {

        if(params.precision){
            var value = element[0].value;
            var decimals = value.substring(value.indexOf(params.decimal || ",")+1, value.length);
            if(value != decimals){
                if(decimals.length > params.precision){
                    element[0].value = value.substring(0, value.indexOf(params.decimal || ",")+(params.precision + 1));
                }

            }

        }

    };

    var viewFloat = function(element, viewValue, params, callBack) {
        var value = viewValue || '';
        element.val(value);
        params.callback = callBack;
        params.showRound = !('showRound' in params) ? true : params.showRound;
        params.showSymbol = false;

        element.on("keypress", function(event) {
            keypressHandler(event, element, params);
        });

        element.on("keyup", function(event) {
            keyupHandler(event, element, params);
        });

        element.on("blur", function() {
            element.text(unMaskViewFloat(element.val(), params));
            element.val(viewFloatFormat(element.val(), params));
            params.callback(element.text());
        });

        if (!!params.showRound) {
            element.on("focus", function() {
                var value = element.text();
                var viewValue = viewFloatFormat(element.val(), params);
                var currentValue = viewFloatFormat(element.text(), params);

                if (currentValue !== viewValue)
                    value = element.val();

                element.val(viewFloatFormat(value, params));
                element.select();
            });
        }
    };

    var viewFloatFormat = function(value, params) {
        var defaultOptions = Util.clone($.currency.i18n[$.currency.lang]);

        var valueFormated = "";
        try {
            var options = Util.extend(defaultOptions, (params || {}), true);
            valueFormated = $.currency.string(value, options);
        } catch (e) {
            valueFormated = value;
        }
        return valueFormated;
    };

    var unMaskViewFloat = function(value, params) {
        var opt = Util.extend(Util.clone($.currency.i18n[$.currency.lang]), (params || {}), true);
        var fltValue = opt.allowZero && !opt.allowEmpty ? 0 : "";
        var valueFormated = value;

        if (!Util.isEmptyOrBlank(valueFormated)) {
            var decimal = opt.decimal;
            var thousands = opt.thousands;

            if (typeof valueFormated === "string") {
                if(opt.showSymbol)
                    valueFormated = valueFormated.replace(opt.symbol, '');

                if(thousands)
                    valueFormated = valueFormated.replace(new RegExp('\\' + thousands, 'g'), '');

                valueFormated = valueFormated.replace(new RegExp('\\' + decimal, 'g'), '.');
                valueFormated = removeInvalidChar(valueFormated);
            }
            fltValue = parseFloat(valueFormated);

            if ((!opt.allowZero && fltValue === 0) || $.currency.isInvalidValue(fltValue, opt))
                valueFormated = "";
        }
        return valueFormated;
    };

    var removeInvalidChar = function(value) {
        var index = value.indexOf('.');
        return index + 1 === value.length ? value.slice(0, index) : value;
    };

    var maskViewFloat = function(value, params) {
        var opt = Util.extend(Util.clone($.currency.i18n[$.currency.lang]), (params || {}), true);

        if (value)
            value = value.replace(new RegExp('\\' + '.', 'g'), opt.decimal);

        return value;
    };

    this.register = maskEngine.registerMask('viewFloat', viewFloat, viewFloatFormat);
};

Configuration(function(ContextRegister) {
    ContextRegister.register('ViewFloatMask', ViewFloatMask);
});

// FILE: js/Util/WidgetsMetaData.js
function WidgetsMetaData() {
    this.getExpiredSession = function() {
        return {
            "name": "EXPIRED_SESSION",
            "label": "Sessão Expirada",
            "isVisible": true,
            "showDescriptionOrder": false,
            "showAsModal": true,
            "template": "widget/form.html",
            "tekLibExpiredSession": true,
            "actions": [
                {
                    "name": "CONFIRM",
                    "label": "Confirmar",
                    "showAsAction": "never",
                    "events": [
                        {
                            "name": "ActionEvent",
                            "code": "LibLoginController.expiredSessionActionEventConfirm(args)"
                        }
                    ]
                },
                {
                    "name": "CANCEL",
                    "label": "Sair",
                    "showAsAction": "back",
                    "events": [
                        {
                            "name": "ActionEvent",
                            "code": "LibLoginController.expiredSessionActionEventCancel()"
                        }
                    ]
                }
            ],
            "events": [],
            "dataSource": [],
            "fields": [
                {
                    "name": "OPERATOR",
                    "label": "Usuário",
                    "template": "field/text-edit.html",
                    "class": 12,
                    "readOnly": true,
                    "isVisible": true,
                    "showOnList": true,
                    "showOnForm": true
                },
                {
                    "name": "PASSWORD",
                    "label": "Senha",
                    "template": "field/password.html",
                    "class": 12,
                    "focused": true,
                    "validations":{
                        required: true
                    },
                    "isVisible": true,
                    "showOnList": true,
                    "showOnForm": true,
                    "events":[
                        {
                            "name": "FieldOnKeyup",
                            "code": "LibLoginController.expiredSessionFieldOnKeyupPassword(args)"
                        }
                    ]
                }
            ]
        };
    };
}

Configuration(function(ContextRegister) {
    ContextRegister.register('WidgetsMetaData', WidgetsMetaData);
});


// FILE: js/Service/Login.js
function LibLoginService(requestDataSourceEngine){
    this.startSession = function(user) {
        var filter = [ {
            name: 'USER',
            value: user,
            operator: '='
        }, {
            name: 'IS_LOGGED',
            value: localStorage.getItem('IS_LOGGED') || false,
            operator: '='
        }, {
            name: 'LOGIN_TOKEN',
            value: localStorage.getItem('LOGIN_TOKEN'),
            operator: '='
        }, {
            name: 'LOGIN_LANGUAGE',
            value: localStorage.getItem('LOGIN_LANGUAGE') || window.lang,
            operator: '='
        } ];

        return requestDataSourceEngine.getDataSource('lib#/lib_startSession', filter, 1, undefined, undefined, undefined, 120000)
            .then(function(data) {
                if(typeof data == 'string') {
                    return {
                        isError : true,
                        message : data
                    };
                }
                return data && data.dataset ? data.dataset.system : false;
            });
    };

    this.validateUser = function(cdOperator, password, isSupportOperator) {
        var filter = [ {
            name: 'USER',
            value: cdOperator,
            operator: '='
        }, {
            name: 'PASSWORD',
            value: password,
            operator: '='
        }, {
            name: 'IS_SUPPORT_OPERATOR',
            value: isSupportOperator,
            operator: '='
        } ];

        return requestDataSourceEngine.getDataSource('login#/validateUser', filter);
    };

    this.logout = function() {
        var filter = [ {
            name: 'PROJECT',
            value: window.tekLoginProjectId,
            operator: '='
        }, {
            name: 'ERASE_HASH',
            value: localStorage.getItem('LOGIN_ERASE_HASH'),
            operator: '='
        }, {
            name: 'HASH',
            value: localStorage.getItem('LOGIN_HASH'),
            operator: '='
        } ];
        return requestDataSourceEngine.getDataSource('lib#/lib_logout', filter, 1, undefined, undefined, undefined, 120000);
    };

    this.getModulesVersion = function(){
        return requestDataSourceEngine.getDataSource('lib#/lib_getModulesVersion', []);
    };

    this.generateModulesVersionFile = function() {
        return requestDataSourceEngine.setDataSource('lib#/lib_generateModulesVersionFile', [ { changed: true } ]);
    };

    this.downloadModulesVersionFile = function(fileName) {
        var serviceUrl = window.serviceUrl;
        window.open(serviceUrl + "/lib_downloadModulesVersionFile?requestType=DataSet&dataset[0][FILE_NAME]=" + fileName);
    };

    this.updateSession = function(user, accessProfile, otherSessionValues) {
        var filter = [ {
            name: 'USER',
            value: user,
            operator: '='
        }, {
            name: 'ACCESS_PROFILE',
            value: accessProfile,
            operator: '='
        }, {
            name: 'OTHER_SESSION_VALUES',
            value: otherSessionValues,
            operator: '='
        }, {
            name: 'LOGIN_USER',
            value: localStorage.getItem('LOGIN_USER'),
            operator: '='
        } ];

        return requestDataSourceEngine.getDataSource('lib#/lib_updateSession', filter);
    };
}

Configuration(function(ContextRegister){
    ContextRegister.register('LibLoginService', LibLoginService);
});



// FILE: js/Controller/Login.js
function LibLoginController(LibLoginService, LibUtilities, localStorageEngine, templateManager, eventAggregator,
                            ScreenService, metaDataFactory, WidgetsMetaData, ZhuAclController, ZhLogger, ZHPromise, MessageService) {
    var self = this;
    var loginUserId, loginUserName, loginIsSupOper, loginSupOperId;
    window.tekLoginProjectId = angular.copy(window.projectId);

    var factoryExpiredSessionWidget = function() {
        return metaDataFactory.widgetFactory(WidgetsMetaData.getExpiredSession(), templateManager.container);
    };

    var updateLanguage = function () {
        var language = localStorage.getItem('LOGIN_LANGUAGE') || window.lang;
        window.lang = language;
        ScreenService.setLanguage(language);
        localStorageEngine.setLocalVar('language', language);
    };

    var redirectToRedirectionProduct = function (redirectUrl, defer) {
        if (window.ZhNativeInterface) {
            window.ZhNativeInterface.redirect(redirectUrl);
        } else {
            window.location = redirectUrl;
        }
        defer.resolve({});
    };

    var updateToken = function () {
        var authToken = Util.getUrlParameter('authToken');
        if (authToken) {
            localStorage.setItem('LOGIN_TOKEN', authToken);
        }
        return authToken;
    };

    this.authenticate = function(forceAuthenticate) {
        templateManager.project.elementListDefaultRule = templateManager.project.elementListDefaultRule || 'I';
        updateLanguage();

        var defer = ZHPromise.defer();
        forceAuthenticate = forceAuthenticate === true;

        if(window.location.hash.replace('#/', '') != LibUtilities.authenticationContainer || forceAuthenticate) {
            var setAclEventId;
            var user = localStorage.getItem('LOGIN_USER');
            var redirectUrl = localStorage.getItem('LOGIN_REDIRECT_URL');
            var authToken = updateToken();

            if(redirectUrl && !redirectUrl.includes(window.location.hostname)) {
                redirectToRedirectionProduct(redirectUrl, defer);
            } else if(!user && !authToken) {
                LibUtilities.redirectToLogin();
                defer.resolve({});
            } else {
                var setAclFunction = function () {
                    setAcl(defer.promise, setAclEventId);
                };
                setAclEventId = eventAggregator.subscribe('onContainerOpen', setAclFunction);

                ScreenService.showLoader();
                LibLoginService.startSession(user).then(function (response) {
                    ScreenService.hideLoader();
                    startSessionResponse(response, defer);
                }).catch(function (error) {
                    ScreenService.hideLoader();
                    //Expired or Invalid Token
                    if(error.data && (error.data.errorCode == 101 || error.data.errorCode == 100)) {
                        self.logout();
                    } else if(error.data.errorCode == 20){
                        localStorage.setItem('LOGIN_ERASE_HASH', 'Y');
                        MessageService.showCustomDialogByCode('lib#ALE_SESSION_WILL_BE_ENDED', null, {
                            type: 'INFORMATION',
                            actions: [ {
                                label: ScreenService.i18n("Ok"),
                                code: function(){
                                    self.logout()
                                }
                            } ]
                        });
                    } else{
                        defer.reject(error);
                        LibUtilities.showErrorMessage(error);
                    }
                });
            }
        }

        return defer.promise;
    };

    var startSessionResponse = function(response, defer) {
        if (response.isError) {
            defer.reject(response.message);
        } else {
            if (!response.USER_ID) {
                self.logout();
            } else if (response.SESSION_EXPIRED) {
                logoutExpiredSession(true);
            } else {
                localStorage.setItem('IS_LOGGED', true);
                if(response.LOGIN_USER && response.LOGIN_TOKEN) {
                    localStorage.setItem('LOGIN_USER', response.LOGIN_USER);
                    localStorage.setItem('LOGIN_TOKEN', response.LOGIN_TOKEN);
                }
                if(response.IS_SUPPORT_OPERATOR) {
                    loginIsSupOper = response.IS_SUPPORT_OPERATOR;
                    loginSupOperId = response.SUPPORT_OPERATOR_ID;
                }

                loginUserId   = response.USER_ID;
                loginUserName = response.USER_NAME;

                if(response.IS_PENDENT_MIGRATION) {
                    MessageService.showMessageByCode('lib#ALE_MIGRATION_IS_PENDENT', null, { type: 'INFORMATION' });
                }

                defer.resolve(response);
            }
        }
    };

    this.logout = function() {
        ScreenService.showLoader();
        LibLoginService.logout().then(function () {
            ScreenService.hideLoader();
            localStorage.removeItem('IS_LOGGED');
            localStorage.removeItem('LOGIN_USER');
            localStorage.removeItem('LOGIN_TOKEN');
            localStorage.removeItem('LOGIN_ERASE_HASH');
            localStorage.removeItem('LOGIN_REDIRECT_URL');
            LibUtilities.redirectToLogin();
        }).catch(function(error) {
            ScreenService.hideLoader();
            LibUtilities.showErrorMessage(error);
        });
    };

    var setAcl = function (loginPromise, setAclEventId) {
        loginPromise.then(function(response) {
            if(!window.productApplyAcl) {
                ZhuAclController.setUserRules(response.ACCESS_PROFILE, window.projectId, response.USER_ID, response.ORGANIZATION_ID,
                    {
                        canConfigureAcl: response.ACL_ADMINISTRATOR,
                        rules          : response.ACL_ADMINISTRATOR ? [] : false,
                        defaultRule    : response.ACL_ADMINISTRATOR ? 'A' : false
                    }
                );
                templateManager.project.aclDefaultRule = 'A';
            }
            eventAggregator.unSubscribe('onContainerOpen', setAclEventId);
        }).catch(LibUtilities.showErrorMessage);
    };

    eventAggregator.subscribe("LibExpiredSession", function () {
        if(!templateManager.container.getActiveWidget().tekLibExpiredSession) {
            var expiredSessionWidget = factoryExpiredSessionWidget();
            expiredSessionWidget.attempts = 0;
            expiredSessionWidget.dataSource.data = [];
            expiredSessionWidget.newRow();
            expiredSessionWidget.currentRow.OPERATOR = loginUserId + ' - ' + loginUserName;
            ScreenService.openPopup(expiredSessionWidget);
            localStorageEngine.setLocalVar('LOGIN_EXPIRED_SESSION', true);

        }
    });

    eventAggregator.subscribe("LibInvalidToken", function (errorCode) {
        //Expired Token
        if(errorCode == 101) {
            MessageService.showCustomDialogByCode('lib#ALE_EXPIRED_SESSION', null, {
                type: 'INFORMATION',
                actions: [ {
                    label: ScreenService.i18n("Ok"),
                    code: self.logout
                } ]
            });
        }
        //Invalid Token
        else if(errorCode == 100) {
            self.logout()
        }
    });

    eventAggregator.subscribe("LibInvalidTokenSupportOperator", function (errorCode) {
        //Expired Token Support Operator
        MessageService.showCustomDialogByCode('lib#ALE_EXPIRED_SESSION_SUPPORT_OPERATOR', null, {
            type: 'INFORMATION',
            actions: [{
                label: ScreenService.i18n("Ok"),
                code: self.logout
            }]
        });
    });

    eventAggregator.subscribe("LibConcurrentAccess", function () {
        localStorage.setItem('LOGIN_ERASE_HASH', 'Y');
        MessageService.showCustomDialogByCode('lib#ALE_SESSION_WILL_BE_ENDED', null, {
            type: 'INFORMATION',
            actions: [ {
                label: ScreenService.i18n("Ok"),
                code: function(){
                    self.logout()
                }
            } ]
        });
    });

    var logoutExpiredSession = function (afterLogin) {
        localStorageEngine.setLocalVar('LOGIN_EXPIRED_SESSION', false);
        var message = afterLogin ? 'ERR_EXPIRED_SESSION_LOGIN' : 'ERR_ATTEMPT_END';
        MessageService.getMessageByCode('lib#' + message).then(function(loadingMessage) {
            ScreenService.changeLoadingMessage(ScreenService.i18n(loadingMessage));
            ScreenService.showLoader();
            Util.doAsync(self.logout, 5000);
        });
    };

    this.expiredSessionActionEventConfirm = function(args) {
        var expiredSessionWidget = args.owner.widget ? args.owner.widget : args.owner.field.widget;
        if(expiredSessionWidget.isValid()) {
            var password = expiredSessionWidget.currentRow.PASSWORD;
            var userId   = loginSupOperId || loginUserId;
            ScreenService.showLoader();
            LibLoginService.validateUser(userId, password, loginIsSupOper)
                .then(function() {
                    // Requisição getModulesVersion chamada para atualizar o tempo de sessão local (produto ou módulo)
                    LibLoginService.getModulesVersion();
                    ScreenService.hideLoader();
                    localStorageEngine.setLocalVar('LOGIN_EXPIRED_SESSION', false);
                    ScreenService.closePopup();
                }).catch(function(error) {
                    ScreenService.hideLoader();
                    if(error.data && error.data.errorCode && error.data.errorCode == 20) {
                        localStorageEngine.setLocalVar('LOGIN_EXPIRED_SESSION', false);
                        eventAggregator.publish('LibConcurrentAccess');
                    } else if(error.data && error.data.errorCode && error.data.errorCode == 102) {
                        localStorageEngine.setLocalVar('LOGIN_EXPIRED_SESSION', false);
                        eventAggregator.publish('LibInvalidTokenSupportOperator');
                    } else {
                        var params = {attempts: ++expiredSessionWidget.attempts};
                        MessageService.showMessageByCode('lib#ERR_ATTEMPT_PARTIAL', params, {type: 'ERROR'});
                        if (expiredSessionWidget.attempts >= 3) {
                            logoutExpiredSession();
                        }
                    }
                });
        }
    };

    this.expiredSessionActionEventCancel = function() {
        localStorageEngine.setLocalVar('LOGIN_EXPIRED_SESSION', false);
        self.logout();
    };

    this.expiredSessionFieldOnKeyupPassword = function(args) {
        var key = window.event.keyCode;

        //13 = ENTER
        if(key == 13) {
            this.expiredSessionActionEventConfirm(args);
        }
    };

    this.downloadModulesVersionFile = function() {
        return LibLoginService.generateModulesVersionFile().then(function(response) {
            if(response && response.dataset) {
                var fileName = response.dataset.generatedFile[0];
                LibLoginService.downloadModulesVersionFile(fileName);
                return true;
            } else {
                LibUtilities.showErrorMessage(response);
                return false;
            }
        }).catch(LibUtilities.showErrorMessage);
    };

    /**
     * @param user -> Object or null.
     *                {
     *                    NAME:  'User Name',
     *                    EMAIL: 'user.email@teknisa.com'
     *                }
     * @param accessProfile -> Array of objects or null. ID is the column NRPERFILACESSO from table PERFILACESSO.
     *                         [
     *                             {
     *                                 ID: '1',
     *                                 IDPERFILACESSOADM: 'S'
     *                             },
     *                             {
     *                                 ID: '2',
     *                                 IDPERFILACESSOADM: 'N'
     *                             }
     *                         ]
     * @param otherSessionValues -> Object or null. PS.: CDFILIALSELECIONADA not exists in session. Use CDFILIAL.
     *                              {
     *                                  CDFILIAL:  '9999',
     *                                  NRPARCNEGOCIO: '1',
     *                                  CDPICTPROD: 'a.a.aa.aaa'
     *                              }
     * @returns Promise
     */
    this.updateSession = function(user, accessProfile, otherSessionValues) {
        var defer = ZHPromise.defer();
        ScreenService.showLoader();
        LibLoginService.updateSession(user, accessProfile, otherSessionValues).then(function(response) {
            ScreenService.hideLoader();
            if(response && response.dataset && response.dataset.sessionUpdated) {
                var sessionUpdated = response.dataset.sessionUpdated[0];
                localStorage.setItem('LOGIN_USER', sessionUpdated);
                defer.resolve();
            } else {
                defer.reject(response);
            }
        }).catch(function(error) {
            ScreenService.hideLoader();
            defer.reject(error);
        });

        return defer.promise;
    };

    this.expiredMenuOnClick = function() {
        MessageService.showMessageByCode('lib#ALE_EXPIRED_MENU', null, { type: 'ERROR' } );
    };
}

Configuration(function(ContextRegister){
    ContextRegister.register('LibLoginController', LibLoginController);
});

// FILE: js/Listener/ZdNext.js
function LibZdNextListener(ScreenService, LibLoginService, LibUtilities, templateManager) {
    window.addEventListener('message', handleMessageEvent);

    function handleMessageEvent(event) {
        if(event.data.type === 'logoutByZdNext') {
            logoutByZdNext()
        } else if (event.data.type === 'versionInfo') {
            var versionInfo = event.data.data.versionInfo;
            templateManager.versionData.name = versionInfo.name;
            templateManager.versionData.version = versionInfo.version;
            templateManager.versionData.dependencies.backend = versionInfo.backend;
            templateManager.versionData.dependencies.frontend = versionInfo.frontend;
            templateManager.versionData.dependencies.modules = versionInfo.modules;
            templateManager.versionData.dependencies.changeCurrentVersion('frontend');
            templateManager.updateTemplate();
        }
    }

    var logoutByZdNext = function() {
        ScreenService.showLoader();
        LibLoginService.logout().then(function () {
            ScreenService.hideLoader();
            localStorage.removeItem('IS_LOGGED');
            localStorage.removeItem('LOGIN_USER');
            localStorage.removeItem('LOGIN_TOKEN');
            localStorage.removeItem('LOGIN_ERASE_HASH');
            localStorage.removeItem('LOGIN_REDIRECT_URL');
            LibUtilities.redirectToLogin();
        }).catch(function(error) {
            ScreenService.hideLoader();
            LibUtilities.showErrorMessage(error);
        });
    };
}

Configuration(function(ContextRegister){
    ContextRegister.register('LibZdNextListener', LibZdNextListener);
});


// FILE: ./assets/js/libraries/QRCodeGenerator.js
/**
 * @fileoverview
 * - Using the 'QRCode for Javascript library'
 * - Fixed dataset of 'QRCode for Javascript library' for support full-spec.
 * - this library has no dependencies.
 * 
 * @author davidshimjs
 * @see <a href="http://www.d-project.com/" target="_blank">http://www.d-project.com/</a>
 * @see <a href="http://jeromeetienne.github.com/jquery-qrcode/" target="_blank">http://jeromeetienne.github.com/jquery-qrcode/</a>
 */
var QRCode;

(function () {
	//---------------------------------------------------------------------
	// QRCode for JavaScript
	//
	// Copyright (c) 2009 Kazuhiko Arase
	//
	// URL: http://www.d-project.com/
	//
	// Licensed under the MIT license:
	//   http://www.opensource.org/licenses/mit-license.php
	//
	// The word "QR Code" is registered trademark of 
	// DENSO WAVE INCORPORATED
	//   http://www.denso-wave.com/qrcode/faqpatent-e.html
	//
	//---------------------------------------------------------------------
	function QR8bitByte(data) {
		this.mode = QRMode.MODE_8BIT_BYTE;
		this.data = data;
		this.parsedData = [];

		// Added to support UTF-8 Characters
		for (var i = 0, l = this.data.length; i < l; i++) {
			var byteArray = [];
			var code = this.data.charCodeAt(i);

			if (code > 0x10000) {
				byteArray[0] = 0xF0 | ((code & 0x1C0000) >>> 18);
				byteArray[1] = 0x80 | ((code & 0x3F000) >>> 12);
				byteArray[2] = 0x80 | ((code & 0xFC0) >>> 6);
				byteArray[3] = 0x80 | (code & 0x3F);
			} else if (code > 0x800) {
				byteArray[0] = 0xE0 | ((code & 0xF000) >>> 12);
				byteArray[1] = 0x80 | ((code & 0xFC0) >>> 6);
				byteArray[2] = 0x80 | (code & 0x3F);
			} else if (code > 0x80) {
				byteArray[0] = 0xC0 | ((code & 0x7C0) >>> 6);
				byteArray[1] = 0x80 | (code & 0x3F);
			} else {
				byteArray[0] = code;
			}

			this.parsedData.push(byteArray);
		}

		this.parsedData = Array.prototype.concat.apply([], this.parsedData);

		if (this.parsedData.length != this.data.length) {
			this.parsedData.unshift(191);
			this.parsedData.unshift(187);
			this.parsedData.unshift(239);
		}
	}

	QR8bitByte.prototype = {
		getLength: function (buffer) {
			return this.parsedData.length;
		},
		write: function (buffer) {
			for (var i = 0, l = this.parsedData.length; i < l; i++) {
				buffer.put(this.parsedData[i], 8);
			}
		}
	};

	function QRCodeModel(typeNumber, errorCorrectLevel) {
		this.typeNumber = typeNumber;
		this.errorCorrectLevel = errorCorrectLevel;
		this.modules = null;
		this.moduleCount = 0;
		this.dataCache = null;
		this.dataList = [];
	}

	QRCodeModel.prototype={addData:function(data){var newData=new QR8bitByte(data);this.dataList.push(newData);this.dataCache=null;},isDark:function(row,col){if(row<0||this.moduleCount<=row||col<0||this.moduleCount<=col){throw new Error(row+","+col);}
	return this.modules[row][col];},getModuleCount:function(){return this.moduleCount;},make:function(){this.makeImpl(false,this.getBestMaskPattern());},makeImpl:function(test,maskPattern){this.moduleCount=this.typeNumber*4+17;this.modules=new Array(this.moduleCount);for(var row=0;row<this.moduleCount;row++){this.modules[row]=new Array(this.moduleCount);for(var col=0;col<this.moduleCount;col++){this.modules[row][col]=null;}}
	this.setupPositionProbePattern(0,0);this.setupPositionProbePattern(this.moduleCount-7,0);this.setupPositionProbePattern(0,this.moduleCount-7);this.setupPositionAdjustPattern();this.setupTimingPattern();this.setupTypeInfo(test,maskPattern);if(this.typeNumber>=7){this.setupTypeNumber(test);}
	if(this.dataCache==null){this.dataCache=QRCodeModel.createData(this.typeNumber,this.errorCorrectLevel,this.dataList);}
	this.mapData(this.dataCache,maskPattern);},setupPositionProbePattern:function(row,col){for(var r=-1;r<=7;r++){if(row+r<=-1||this.moduleCount<=row+r)continue;for(var c=-1;c<=7;c++){if(col+c<=-1||this.moduleCount<=col+c)continue;if((0<=r&&r<=6&&(c==0||c==6))||(0<=c&&c<=6&&(r==0||r==6))||(2<=r&&r<=4&&2<=c&&c<=4)){this.modules[row+r][col+c]=true;}else{this.modules[row+r][col+c]=false;}}}},getBestMaskPattern:function(){var minLostPoint=0;var pattern=0;for(var i=0;i<8;i++){this.makeImpl(true,i);var lostPoint=QRUtil.getLostPoint(this);if(i==0||minLostPoint>lostPoint){minLostPoint=lostPoint;pattern=i;}}
	return pattern;},createMovieClip:function(target_mc,instance_name,depth){var qr_mc=target_mc.createEmptyMovieClip(instance_name,depth);var cs=1;this.make();for(var row=0;row<this.modules.length;row++){var y=row*cs;for(var col=0;col<this.modules[row].length;col++){var x=col*cs;var dark=this.modules[row][col];if(dark){qr_mc.beginFill(0,100);qr_mc.moveTo(x,y);qr_mc.lineTo(x+cs,y);qr_mc.lineTo(x+cs,y+cs);qr_mc.lineTo(x,y+cs);qr_mc.endFill();}}}
	return qr_mc;},setupTimingPattern:function(){for(var r=8;r<this.moduleCount-8;r++){if(this.modules[r][6]!=null){continue;}
	this.modules[r][6]=(r%2==0);}
	for(var c=8;c<this.moduleCount-8;c++){if(this.modules[6][c]!=null){continue;}
	this.modules[6][c]=(c%2==0);}},setupPositionAdjustPattern:function(){var pos=QRUtil.getPatternPosition(this.typeNumber);for(var i=0;i<pos.length;i++){for(var j=0;j<pos.length;j++){var row=pos[i];var col=pos[j];if(this.modules[row][col]!=null){continue;}
	for(var r=-2;r<=2;r++){for(var c=-2;c<=2;c++){if(r==-2||r==2||c==-2||c==2||(r==0&&c==0)){this.modules[row+r][col+c]=true;}else{this.modules[row+r][col+c]=false;}}}}}},setupTypeNumber:function(test){var bits=QRUtil.getBCHTypeNumber(this.typeNumber);for(var i=0;i<18;i++){var mod=(!test&&((bits>>i)&1)==1);this.modules[Math.floor(i/3)][i%3+this.moduleCount-8-3]=mod;}
	for(var i=0;i<18;i++){var mod=(!test&&((bits>>i)&1)==1);this.modules[i%3+this.moduleCount-8-3][Math.floor(i/3)]=mod;}},setupTypeInfo:function(test,maskPattern){var data=(this.errorCorrectLevel<<3)|maskPattern;var bits=QRUtil.getBCHTypeInfo(data);for(var i=0;i<15;i++){var mod=(!test&&((bits>>i)&1)==1);if(i<6){this.modules[i][8]=mod;}else if(i<8){this.modules[i+1][8]=mod;}else{this.modules[this.moduleCount-15+i][8]=mod;}}
	for(var i=0;i<15;i++){var mod=(!test&&((bits>>i)&1)==1);if(i<8){this.modules[8][this.moduleCount-i-1]=mod;}else if(i<9){this.modules[8][15-i-1+1]=mod;}else{this.modules[8][15-i-1]=mod;}}
	this.modules[this.moduleCount-8][8]=(!test);},mapData:function(data,maskPattern){var inc=-1;var row=this.moduleCount-1;var bitIndex=7;var byteIndex=0;for(var col=this.moduleCount-1;col>0;col-=2){if(col==6)col--;while(true){for(var c=0;c<2;c++){if(this.modules[row][col-c]==null){var dark=false;if(byteIndex<data.length){dark=(((data[byteIndex]>>>bitIndex)&1)==1);}
	var mask=QRUtil.getMask(maskPattern,row,col-c);if(mask){dark=!dark;}
	this.modules[row][col-c]=dark;bitIndex--;if(bitIndex==-1){byteIndex++;bitIndex=7;}}}
	row+=inc;if(row<0||this.moduleCount<=row){row-=inc;inc=-inc;break;}}}}};QRCodeModel.PAD0=0xEC;QRCodeModel.PAD1=0x11;QRCodeModel.createData=function(typeNumber,errorCorrectLevel,dataList){var rsBlocks=QRRSBlock.getRSBlocks(typeNumber,errorCorrectLevel);var buffer=new QRBitBuffer();for(var i=0;i<dataList.length;i++){var data=dataList[i];buffer.put(data.mode,4);buffer.put(data.getLength(),QRUtil.getLengthInBits(data.mode,typeNumber));data.write(buffer);}
	var totalDataCount=0;for(var i=0;i<rsBlocks.length;i++){totalDataCount+=rsBlocks[i].dataCount;}
	if(buffer.getLengthInBits()>totalDataCount*8){throw new Error("code length overflow. ("
	+buffer.getLengthInBits()
	+">"
	+totalDataCount*8
	+")");}
	if(buffer.getLengthInBits()+4<=totalDataCount*8){buffer.put(0,4);}
	while(buffer.getLengthInBits()%8!=0){buffer.putBit(false);}
	while(true){if(buffer.getLengthInBits()>=totalDataCount*8){break;}
	buffer.put(QRCodeModel.PAD0,8);if(buffer.getLengthInBits()>=totalDataCount*8){break;}
	buffer.put(QRCodeModel.PAD1,8);}
	return QRCodeModel.createBytes(buffer,rsBlocks);};QRCodeModel.createBytes=function(buffer,rsBlocks){var offset=0;var maxDcCount=0;var maxEcCount=0;var dcdata=new Array(rsBlocks.length);var ecdata=new Array(rsBlocks.length);for(var r=0;r<rsBlocks.length;r++){var dcCount=rsBlocks[r].dataCount;var ecCount=rsBlocks[r].totalCount-dcCount;maxDcCount=Math.max(maxDcCount,dcCount);maxEcCount=Math.max(maxEcCount,ecCount);dcdata[r]=new Array(dcCount);for(var i=0;i<dcdata[r].length;i++){dcdata[r][i]=0xff&buffer.buffer[i+offset];}
	offset+=dcCount;var rsPoly=QRUtil.getErrorCorrectPolynomial(ecCount);var rawPoly=new QRPolynomial(dcdata[r],rsPoly.getLength()-1);var modPoly=rawPoly.mod(rsPoly);ecdata[r]=new Array(rsPoly.getLength()-1);for(var i=0;i<ecdata[r].length;i++){var modIndex=i+modPoly.getLength()-ecdata[r].length;ecdata[r][i]=(modIndex>=0)?modPoly.get(modIndex):0;}}
	var totalCodeCount=0;for(var i=0;i<rsBlocks.length;i++){totalCodeCount+=rsBlocks[i].totalCount;}
	var data=new Array(totalCodeCount);var index=0;for(var i=0;i<maxDcCount;i++){for(var r=0;r<rsBlocks.length;r++){if(i<dcdata[r].length){data[index++]=dcdata[r][i];}}}
	for(var i=0;i<maxEcCount;i++){for(var r=0;r<rsBlocks.length;r++){if(i<ecdata[r].length){data[index++]=ecdata[r][i];}}}
	return data;};var QRMode={MODE_NUMBER:1<<0,MODE_ALPHA_NUM:1<<1,MODE_8BIT_BYTE:1<<2,MODE_KANJI:1<<3};var QRErrorCorrectLevel={L:1,M:0,Q:3,H:2};var QRMaskPattern={PATTERN000:0,PATTERN001:1,PATTERN010:2,PATTERN011:3,PATTERN100:4,PATTERN101:5,PATTERN110:6,PATTERN111:7};var QRUtil={PATTERN_POSITION_TABLE:[[],[6,18],[6,22],[6,26],[6,30],[6,34],[6,22,38],[6,24,42],[6,26,46],[6,28,50],[6,30,54],[6,32,58],[6,34,62],[6,26,46,66],[6,26,48,70],[6,26,50,74],[6,30,54,78],[6,30,56,82],[6,30,58,86],[6,34,62,90],[6,28,50,72,94],[6,26,50,74,98],[6,30,54,78,102],[6,28,54,80,106],[6,32,58,84,110],[6,30,58,86,114],[6,34,62,90,118],[6,26,50,74,98,122],[6,30,54,78,102,126],[6,26,52,78,104,130],[6,30,56,82,108,134],[6,34,60,86,112,138],[6,30,58,86,114,142],[6,34,62,90,118,146],[6,30,54,78,102,126,150],[6,24,50,76,102,128,154],[6,28,54,80,106,132,158],[6,32,58,84,110,136,162],[6,26,54,82,110,138,166],[6,30,58,86,114,142,170]],G15:(1<<10)|(1<<8)|(1<<5)|(1<<4)|(1<<2)|(1<<1)|(1<<0),G18:(1<<12)|(1<<11)|(1<<10)|(1<<9)|(1<<8)|(1<<5)|(1<<2)|(1<<0),G15_MASK:(1<<14)|(1<<12)|(1<<10)|(1<<4)|(1<<1),getBCHTypeInfo:function(data){var d=data<<10;while(QRUtil.getBCHDigit(d)-QRUtil.getBCHDigit(QRUtil.G15)>=0){d^=(QRUtil.G15<<(QRUtil.getBCHDigit(d)-QRUtil.getBCHDigit(QRUtil.G15)));}
	return((data<<10)|d)^QRUtil.G15_MASK;},getBCHTypeNumber:function(data){var d=data<<12;while(QRUtil.getBCHDigit(d)-QRUtil.getBCHDigit(QRUtil.G18)>=0){d^=(QRUtil.G18<<(QRUtil.getBCHDigit(d)-QRUtil.getBCHDigit(QRUtil.G18)));}
	return(data<<12)|d;},getBCHDigit:function(data){var digit=0;while(data!=0){digit++;data>>>=1;}
	return digit;},getPatternPosition:function(typeNumber){return QRUtil.PATTERN_POSITION_TABLE[typeNumber-1];},getMask:function(maskPattern,i,j){switch(maskPattern){case QRMaskPattern.PATTERN000:return(i+j)%2==0;case QRMaskPattern.PATTERN001:return i%2==0;case QRMaskPattern.PATTERN010:return j%3==0;case QRMaskPattern.PATTERN011:return(i+j)%3==0;case QRMaskPattern.PATTERN100:return(Math.floor(i/2)+Math.floor(j/3))%2==0;case QRMaskPattern.PATTERN101:return(i*j)%2+(i*j)%3==0;case QRMaskPattern.PATTERN110:return((i*j)%2+(i*j)%3)%2==0;case QRMaskPattern.PATTERN111:return((i*j)%3+(i+j)%2)%2==0;default:throw new Error("bad maskPattern:"+maskPattern);}},getErrorCorrectPolynomial:function(errorCorrectLength){var a=new QRPolynomial([1],0);for(var i=0;i<errorCorrectLength;i++){a=a.multiply(new QRPolynomial([1,QRMath.gexp(i)],0));}
	return a;},getLengthInBits:function(mode,type){if(1<=type&&type<10){switch(mode){case QRMode.MODE_NUMBER:return 10;case QRMode.MODE_ALPHA_NUM:return 9;case QRMode.MODE_8BIT_BYTE:return 8;case QRMode.MODE_KANJI:return 8;default:throw new Error("mode:"+mode);}}else if(type<27){switch(mode){case QRMode.MODE_NUMBER:return 12;case QRMode.MODE_ALPHA_NUM:return 11;case QRMode.MODE_8BIT_BYTE:return 16;case QRMode.MODE_KANJI:return 10;default:throw new Error("mode:"+mode);}}else if(type<41){switch(mode){case QRMode.MODE_NUMBER:return 14;case QRMode.MODE_ALPHA_NUM:return 13;case QRMode.MODE_8BIT_BYTE:return 16;case QRMode.MODE_KANJI:return 12;default:throw new Error("mode:"+mode);}}else{throw new Error("type:"+type);}},getLostPoint:function(qrCode){var moduleCount=qrCode.getModuleCount();var lostPoint=0;for(var row=0;row<moduleCount;row++){for(var col=0;col<moduleCount;col++){var sameCount=0;var dark=qrCode.isDark(row,col);for(var r=-1;r<=1;r++){if(row+r<0||moduleCount<=row+r){continue;}
	for(var c=-1;c<=1;c++){if(col+c<0||moduleCount<=col+c){continue;}
	if(r==0&&c==0){continue;}
	if(dark==qrCode.isDark(row+r,col+c)){sameCount++;}}}
	if(sameCount>5){lostPoint+=(3+sameCount-5);}}}
	for(var row=0;row<moduleCount-1;row++){for(var col=0;col<moduleCount-1;col++){var count=0;if(qrCode.isDark(row,col))count++;if(qrCode.isDark(row+1,col))count++;if(qrCode.isDark(row,col+1))count++;if(qrCode.isDark(row+1,col+1))count++;if(count==0||count==4){lostPoint+=3;}}}
	for(var row=0;row<moduleCount;row++){for(var col=0;col<moduleCount-6;col++){if(qrCode.isDark(row,col)&&!qrCode.isDark(row,col+1)&&qrCode.isDark(row,col+2)&&qrCode.isDark(row,col+3)&&qrCode.isDark(row,col+4)&&!qrCode.isDark(row,col+5)&&qrCode.isDark(row,col+6)){lostPoint+=40;}}}
	for(var col=0;col<moduleCount;col++){for(var row=0;row<moduleCount-6;row++){if(qrCode.isDark(row,col)&&!qrCode.isDark(row+1,col)&&qrCode.isDark(row+2,col)&&qrCode.isDark(row+3,col)&&qrCode.isDark(row+4,col)&&!qrCode.isDark(row+5,col)&&qrCode.isDark(row+6,col)){lostPoint+=40;}}}
	var darkCount=0;for(var col=0;col<moduleCount;col++){for(var row=0;row<moduleCount;row++){if(qrCode.isDark(row,col)){darkCount++;}}}
	var ratio=Math.abs(100*darkCount/moduleCount/moduleCount-50)/5;lostPoint+=ratio*10;return lostPoint;}};var QRMath={glog:function(n){if(n<1){throw new Error("glog("+n+")");}
	return QRMath.LOG_TABLE[n];},gexp:function(n){while(n<0){n+=255;}
	while(n>=256){n-=255;}
	return QRMath.EXP_TABLE[n];},EXP_TABLE:new Array(256),LOG_TABLE:new Array(256)};for(var i=0;i<8;i++){QRMath.EXP_TABLE[i]=1<<i;}
	for(var i=8;i<256;i++){QRMath.EXP_TABLE[i]=QRMath.EXP_TABLE[i-4]^QRMath.EXP_TABLE[i-5]^QRMath.EXP_TABLE[i-6]^QRMath.EXP_TABLE[i-8];}
	for(var i=0;i<255;i++){QRMath.LOG_TABLE[QRMath.EXP_TABLE[i]]=i;}
	function QRPolynomial(num,shift){if(num.length==undefined){throw new Error(num.length+"/"+shift);}
	var offset=0;while(offset<num.length&&num[offset]==0){offset++;}
	this.num=new Array(num.length-offset+shift);for(var i=0;i<num.length-offset;i++){this.num[i]=num[i+offset];}}
	QRPolynomial.prototype={get:function(index){return this.num[index];},getLength:function(){return this.num.length;},multiply:function(e){var num=new Array(this.getLength()+e.getLength()-1);for(var i=0;i<this.getLength();i++){for(var j=0;j<e.getLength();j++){num[i+j]^=QRMath.gexp(QRMath.glog(this.get(i))+QRMath.glog(e.get(j)));}}
	return new QRPolynomial(num,0);},mod:function(e){if(this.getLength()-e.getLength()<0){return this;}
	var ratio=QRMath.glog(this.get(0))-QRMath.glog(e.get(0));var num=new Array(this.getLength());for(var i=0;i<this.getLength();i++){num[i]=this.get(i);}
	for(var i=0;i<e.getLength();i++){num[i]^=QRMath.gexp(QRMath.glog(e.get(i))+ratio);}
	return new QRPolynomial(num,0).mod(e);}};function QRRSBlock(totalCount,dataCount){this.totalCount=totalCount;this.dataCount=dataCount;}
	QRRSBlock.RS_BLOCK_TABLE=[[1,26,19],[1,26,16],[1,26,13],[1,26,9],[1,44,34],[1,44,28],[1,44,22],[1,44,16],[1,70,55],[1,70,44],[2,35,17],[2,35,13],[1,100,80],[2,50,32],[2,50,24],[4,25,9],[1,134,108],[2,67,43],[2,33,15,2,34,16],[2,33,11,2,34,12],[2,86,68],[4,43,27],[4,43,19],[4,43,15],[2,98,78],[4,49,31],[2,32,14,4,33,15],[4,39,13,1,40,14],[2,121,97],[2,60,38,2,61,39],[4,40,18,2,41,19],[4,40,14,2,41,15],[2,146,116],[3,58,36,2,59,37],[4,36,16,4,37,17],[4,36,12,4,37,13],[2,86,68,2,87,69],[4,69,43,1,70,44],[6,43,19,2,44,20],[6,43,15,2,44,16],[4,101,81],[1,80,50,4,81,51],[4,50,22,4,51,23],[3,36,12,8,37,13],[2,116,92,2,117,93],[6,58,36,2,59,37],[4,46,20,6,47,21],[7,42,14,4,43,15],[4,133,107],[8,59,37,1,60,38],[8,44,20,4,45,21],[12,33,11,4,34,12],[3,145,115,1,146,116],[4,64,40,5,65,41],[11,36,16,5,37,17],[11,36,12,5,37,13],[5,109,87,1,110,88],[5,65,41,5,66,42],[5,54,24,7,55,25],[11,36,12],[5,122,98,1,123,99],[7,73,45,3,74,46],[15,43,19,2,44,20],[3,45,15,13,46,16],[1,135,107,5,136,108],[10,74,46,1,75,47],[1,50,22,15,51,23],[2,42,14,17,43,15],[5,150,120,1,151,121],[9,69,43,4,70,44],[17,50,22,1,51,23],[2,42,14,19,43,15],[3,141,113,4,142,114],[3,70,44,11,71,45],[17,47,21,4,48,22],[9,39,13,16,40,14],[3,135,107,5,136,108],[3,67,41,13,68,42],[15,54,24,5,55,25],[15,43,15,10,44,16],[4,144,116,4,145,117],[17,68,42],[17,50,22,6,51,23],[19,46,16,6,47,17],[2,139,111,7,140,112],[17,74,46],[7,54,24,16,55,25],[34,37,13],[4,151,121,5,152,122],[4,75,47,14,76,48],[11,54,24,14,55,25],[16,45,15,14,46,16],[6,147,117,4,148,118],[6,73,45,14,74,46],[11,54,24,16,55,25],[30,46,16,2,47,17],[8,132,106,4,133,107],[8,75,47,13,76,48],[7,54,24,22,55,25],[22,45,15,13,46,16],[10,142,114,2,143,115],[19,74,46,4,75,47],[28,50,22,6,51,23],[33,46,16,4,47,17],[8,152,122,4,153,123],[22,73,45,3,74,46],[8,53,23,26,54,24],[12,45,15,28,46,16],[3,147,117,10,148,118],[3,73,45,23,74,46],[4,54,24,31,55,25],[11,45,15,31,46,16],[7,146,116,7,147,117],[21,73,45,7,74,46],[1,53,23,37,54,24],[19,45,15,26,46,16],[5,145,115,10,146,116],[19,75,47,10,76,48],[15,54,24,25,55,25],[23,45,15,25,46,16],[13,145,115,3,146,116],[2,74,46,29,75,47],[42,54,24,1,55,25],[23,45,15,28,46,16],[17,145,115],[10,74,46,23,75,47],[10,54,24,35,55,25],[19,45,15,35,46,16],[17,145,115,1,146,116],[14,74,46,21,75,47],[29,54,24,19,55,25],[11,45,15,46,46,16],[13,145,115,6,146,116],[14,74,46,23,75,47],[44,54,24,7,55,25],[59,46,16,1,47,17],[12,151,121,7,152,122],[12,75,47,26,76,48],[39,54,24,14,55,25],[22,45,15,41,46,16],[6,151,121,14,152,122],[6,75,47,34,76,48],[46,54,24,10,55,25],[2,45,15,64,46,16],[17,152,122,4,153,123],[29,74,46,14,75,47],[49,54,24,10,55,25],[24,45,15,46,46,16],[4,152,122,18,153,123],[13,74,46,32,75,47],[48,54,24,14,55,25],[42,45,15,32,46,16],[20,147,117,4,148,118],[40,75,47,7,76,48],[43,54,24,22,55,25],[10,45,15,67,46,16],[19,148,118,6,149,119],[18,75,47,31,76,48],[34,54,24,34,55,25],[20,45,15,61,46,16]];QRRSBlock.getRSBlocks=function(typeNumber,errorCorrectLevel){var rsBlock=QRRSBlock.getRsBlockTable(typeNumber,errorCorrectLevel);if(rsBlock==undefined){throw new Error("bad rs block @ typeNumber:"+typeNumber+"/errorCorrectLevel:"+errorCorrectLevel);}
	var length=rsBlock.length/3;var list=[];for(var i=0;i<length;i++){var count=rsBlock[i*3+0];var totalCount=rsBlock[i*3+1];var dataCount=rsBlock[i*3+2];for(var j=0;j<count;j++){list.push(new QRRSBlock(totalCount,dataCount));}}
	return list;};QRRSBlock.getRsBlockTable=function(typeNumber,errorCorrectLevel){switch(errorCorrectLevel){case QRErrorCorrectLevel.L:return QRRSBlock.RS_BLOCK_TABLE[(typeNumber-1)*4+0];case QRErrorCorrectLevel.M:return QRRSBlock.RS_BLOCK_TABLE[(typeNumber-1)*4+1];case QRErrorCorrectLevel.Q:return QRRSBlock.RS_BLOCK_TABLE[(typeNumber-1)*4+2];case QRErrorCorrectLevel.H:return QRRSBlock.RS_BLOCK_TABLE[(typeNumber-1)*4+3];default:return undefined;}};function QRBitBuffer(){this.buffer=[];this.length=0;}
	QRBitBuffer.prototype={get:function(index){var bufIndex=Math.floor(index/8);return((this.buffer[bufIndex]>>>(7-index%8))&1)==1;},put:function(num,length){for(var i=0;i<length;i++){this.putBit(((num>>>(length-i-1))&1)==1);}},getLengthInBits:function(){return this.length;},putBit:function(bit){var bufIndex=Math.floor(this.length/8);if(this.buffer.length<=bufIndex){this.buffer.push(0);}
	if(bit){this.buffer[bufIndex]|=(0x80>>>(this.length%8));}
	this.length++;}};var QRCodeLimitLength=[[17,14,11,7],[32,26,20,14],[53,42,32,24],[78,62,46,34],[106,84,60,44],[134,106,74,58],[154,122,86,64],[192,152,108,84],[230,180,130,98],[271,213,151,119],[321,251,177,137],[367,287,203,155],[425,331,241,177],[458,362,258,194],[520,412,292,220],[586,450,322,250],[644,504,364,280],[718,560,394,310],[792,624,442,338],[858,666,482,382],[929,711,509,403],[1003,779,565,439],[1091,857,611,461],[1171,911,661,511],[1273,997,715,535],[1367,1059,751,593],[1465,1125,805,625],[1528,1190,868,658],[1628,1264,908,698],[1732,1370,982,742],[1840,1452,1030,790],[1952,1538,1112,842],[2068,1628,1168,898],[2188,1722,1228,958],[2303,1809,1283,983],[2431,1911,1351,1051],[2563,1989,1423,1093],[2699,2099,1499,1139],[2809,2213,1579,1219],[2953,2331,1663,1273]];
	
	function _isSupportCanvas() {
		return typeof CanvasRenderingContext2D != "undefined";
	}
	
	// android 2.x doesn't support Data-URI spec
	function _getAndroid() {
		var android = false;
		var sAgent = navigator.userAgent;
		
		if (/android/i.test(sAgent)) { // android
			android = true;
			var aMat = sAgent.toString().match(/android ([0-9]\.[0-9])/i);
			
			if (aMat && aMat[1]) {
				android = parseFloat(aMat[1]);
			}
		}
		
		return android;
	}
	
	var svgDrawer = (function() {

		var Drawing = function (el, htOption) {
			this._el = el;
			this._htOption = htOption;
		};

		Drawing.prototype.draw = function (oQRCode) {
			var _htOption = this._htOption;
			var _el = this._el;
			var nCount = oQRCode.getModuleCount();
			var nWidth = Math.floor(_htOption.width / nCount);
			var nHeight = Math.floor(_htOption.height / nCount);

			this.clear();

			function makeSVG(tag, attrs) {
				var el = document.createElementNS('http://www.w3.org/2000/svg', tag);
				for (var k in attrs)
					if (attrs.hasOwnProperty(k)) el.setAttribute(k, attrs[k]);
				return el;
			}

			var svg = makeSVG("svg" , {'viewBox': '0 0 ' + String(nCount) + " " + String(nCount), 'width': '100%', 'height': '100%', 'fill': _htOption.colorLight});
			svg.setAttributeNS("http://www.w3.org/2000/xmlns/", "xmlns:xlink", "http://www.w3.org/1999/xlink");
			_el.appendChild(svg);

			svg.appendChild(makeSVG("rect", {"fill": _htOption.colorLight, "width": "100%", "height": "100%"}));
			svg.appendChild(makeSVG("rect", {"fill": _htOption.colorDark, "width": "1", "height": "1", "id": "template"}));

			for (var row = 0; row < nCount; row++) {
				for (var col = 0; col < nCount; col++) {
					if (oQRCode.isDark(row, col)) {
						var child = makeSVG("use", {"x": String(col), "y": String(row)});
						child.setAttributeNS("http://www.w3.org/1999/xlink", "href", "#template")
						svg.appendChild(child);
					}
				}
			}
		};
		Drawing.prototype.clear = function () {
			while (this._el.hasChildNodes())
				this._el.removeChild(this._el.lastChild);
		};
		return Drawing;
	})();

	var useSVG = document.documentElement.tagName.toLowerCase() === "svg";

	// Drawing in DOM by using Table tag
	var Drawing = useSVG ? svgDrawer : !_isSupportCanvas() ? (function () {
		var Drawing = function (el, htOption) {
			this._el = el;
			this._htOption = htOption;
		};
			
		/**
		 * Draw the QRCode
		 * 
		 * @param {QRCode} oQRCode
		 */
		Drawing.prototype.draw = function (oQRCode) {
            var _htOption = this._htOption;
            var _el = this._el;
			var nCount = oQRCode.getModuleCount();
			var nWidth = Math.floor(_htOption.width / nCount);
			var nHeight = Math.floor(_htOption.height / nCount);
			var aHTML = ['<table style="border:0;border-collapse:collapse;">'];
			
			for (var row = 0; row < nCount; row++) {
				aHTML.push('<tr>');
				
				for (var col = 0; col < nCount; col++) {
					aHTML.push('<td style="border:0;border-collapse:collapse;padding:0;margin:0;width:' + nWidth + 'px;height:' + nHeight + 'px;background-color:' + (oQRCode.isDark(row, col) ? _htOption.colorDark : _htOption.colorLight) + ';"></td>');
				}
				
				aHTML.push('</tr>');
			}
			
			aHTML.push('</table>');
			_el.innerHTML = aHTML.join('');
			
			// Fix the margin values as real size.
			var elTable = _el.childNodes[0];
			var nLeftMarginTable = (_htOption.width - elTable.offsetWidth) / 2;
			var nTopMarginTable = (_htOption.height - elTable.offsetHeight) / 2;
			
			if (nLeftMarginTable > 0 && nTopMarginTable > 0) {
				elTable.style.margin = nTopMarginTable + "px " + nLeftMarginTable + "px";	
			}
		};
		
		/**
		 * Clear the QRCode
		 */
		Drawing.prototype.clear = function () {
			this._el.innerHTML = '';
		};
		
		return Drawing;
	})() : (function () { // Drawing in Canvas
		function _onMakeImage() {
			this._elImage.src = this._elCanvas.toDataURL("image/png");
			setLocalVar("qrcode_uri", this._elCanvas.toDataURL("image/png"));
			this._elImage.style.display = "inline-block";
			this._elCanvas.style.display = "none";			
		}
		
		// Android 2.1 bug workaround
		// http://code.google.com/p/android/issues/detail?id=5141
		if (this._android && this._android <= 2.1) {
	    	var factor = 1 / window.devicePixelRatio;
	        var drawImage = CanvasRenderingContext2D.prototype.drawImage; 
	    	CanvasRenderingContext2D.prototype.drawImage = function (image, sx, sy, sw, sh, dx, dy, dw, dh) {
	    		if (("nodeName" in image) && /img/i.test(image.nodeName)) {
		        	for (var i = arguments.length - 1; i >= 1; i--) {
		            	arguments[i] = arguments[i] * factor;
		        	}
	    		} else if (typeof dw == "undefined") {
	    			arguments[1] *= factor;
	    			arguments[2] *= factor;
	    			arguments[3] *= factor;
	    			arguments[4] *= factor;
	    		}
	    		
	        	drawImage.apply(this, arguments); 
	    	};
		}
		
		/**
		 * Check whether the user's browser supports Data URI or not
		 * 
		 * @private
		 * @param {Function} fSuccess Occurs if it supports Data URI
		 * @param {Function} fFail Occurs if it doesn't support Data URI
		 */
		function _safeSetDataURI(fSuccess, fFail) {
            var self = this;
            self._fFail = fFail;
            self._fSuccess = fSuccess;

            // Check it just once
            if (self._bSupportDataURI === null) {
                var el = document.createElement("img");
                var fOnError = function() {
                    self._bSupportDataURI = false;

                    if (self._fFail) {
                        self._fFail.call(self);
                    }
                };
                var fOnSuccess = function() {
                    self._bSupportDataURI = true;

                    if (self._fSuccess) {
                        self._fSuccess.call(self);
                    }
                };

                el.onabort = fOnError;
                el.onerror = fOnError;
                el.onload = fOnSuccess;
                el.src = "data:image/gif;base64,iVBORw0KGgoAAAANSUhEUgAAAAUAAAAFCAYAAACNbyblAAAAHElEQVQI12P4//8/w38GIAXDIBKE0DHxgljNBAAO9TXL0Y4OHwAAAABJRU5ErkJggg=="; // the Image contains 1px data.
                return;
            } else if (self._bSupportDataURI === true && self._fSuccess) {
                self._fSuccess.call(self);
            } else if (self._bSupportDataURI === false && self._fFail) {
                self._fFail.call(self);
            }
		};
		
		/**
		 * Drawing QRCode by using canvas
		 * 
		 * @constructor
		 * @param {HTMLElement} el
		 * @param {Object} htOption QRCode Options 
		 */
		var Drawing = function (el, htOption, dataURI) {
    		this._bIsPainted = false;
    		this._android = _getAndroid();
		
			this._htOption = htOption;
			this._elCanvas = document.createElement("canvas");
			this._elCanvas.width = htOption.width;
			this._elCanvas.height = htOption.height;
			el.appendChild(this._elCanvas);
			this._el = el;
			this._oContext = this._elCanvas.getContext("2d");
			this._bIsPainted = false;
			this._elImage = document.createElement("img");
			this._elImage.alt = "qrCodeGenerated";
			this._elImage.style.display = "none";
			this._el.appendChild(this._elImage);
			this._bSupportDataURI = null;
			
		};
			
		/**
		 * Draw the QRCode
		 * 
		 * @param {QRCode} oQRCode 
		 */
		Drawing.prototype.draw = function (oQRCode) {
            var _elImage = this._elImage;
            var _oContext = this._oContext;
            var _htOption = this._htOption;
            
			var nCount = oQRCode.getModuleCount();
			var nWidth = _htOption.width / nCount;
			var nHeight = _htOption.height / nCount;
			var nRoundedWidth = Math.round(nWidth);
			var nRoundedHeight = Math.round(nHeight);

			_elImage.style.display = "none";
			this.clear();
			
			for (var row = 0; row < nCount; row++) {
				for (var col = 0; col < nCount; col++) {
					var bIsDark = oQRCode.isDark(row, col);
					var nLeft = col * nWidth;
					var nTop = row * nHeight;
					_oContext.strokeStyle = bIsDark ? _htOption.colorDark : _htOption.colorLight;
					_oContext.lineWidth = 1;
					_oContext.fillStyle = bIsDark ? _htOption.colorDark : _htOption.colorLight;					
					_oContext.fillRect(nLeft, nTop, nWidth, nHeight);
					
					// 안티 앨리어싱 방지 처리
					_oContext.strokeRect(
						Math.floor(nLeft) + 0.5,
						Math.floor(nTop) + 0.5,
						nRoundedWidth,
						nRoundedHeight
					);
					
					_oContext.strokeRect(
						Math.ceil(nLeft) - 0.5,
						Math.ceil(nTop) - 0.5,
						nRoundedWidth,
						nRoundedHeight
					);
				}
			}
			
			this._bIsPainted = true;
		};
			
		/**
		 * Make the image from Canvas if the browser supports Data URI.
		 */
		Drawing.prototype.makeImage = function () {
			if (this._bIsPainted) {
				_safeSetDataURI.call(this, _onMakeImage);
			}
		};
			
		/**
		 * Return whether the QRCode is painted or not
		 * 
		 * @return {Boolean}
		 */
		Drawing.prototype.isPainted = function () {
			return this._bIsPainted;
		};
		
		/**
		 * Clear the QRCode
		 */
		Drawing.prototype.clear = function () {
			this._oContext.clearRect(0, 0, this._elCanvas.width, this._elCanvas.height);
			this._bIsPainted = false;
		};
		
		/**
		 * @private
		 * @param {Number} nNumber
		 */
		Drawing.prototype.round = function (nNumber) {
			if (!nNumber) {
				return nNumber;
			}
			
			return Math.floor(nNumber * 1000) / 1000;
		};
		
		return Drawing;
	})();
	
	/**
	 * Get the type by string length
	 * 
	 * @private
	 * @param {String} sText
	 * @param {Number} nCorrectLevel
	 * @return {Number} type
	 */
	function _getTypeNumber(sText, nCorrectLevel) {			
		var nType = 1;
		var length = _getUTF8Length(sText);
		
		for (var i = 0, len = QRCodeLimitLength.length; i <= len; i++) {
			var nLimit = 0;
			
			switch (nCorrectLevel) {
				case QRErrorCorrectLevel.L :
					nLimit = QRCodeLimitLength[i][0];
					break;
				case QRErrorCorrectLevel.M :
					nLimit = QRCodeLimitLength[i][1];
					break;
				case QRErrorCorrectLevel.Q :
					nLimit = QRCodeLimitLength[i][2];
					break;
				case QRErrorCorrectLevel.H :
					nLimit = QRCodeLimitLength[i][3];
					break;
			}
			
			if (length <= nLimit) {
				break;
			} else {
				nType++;
			}
		}
		
		if (nType > QRCodeLimitLength.length) {
			throw new Error("Too long data");
		}
		
		return nType;
	}

	function _getUTF8Length(sText) {
		var replacedText = encodeURI(sText).toString().replace(/\%[0-9a-fA-F]{2}/g, 'a');
		return replacedText.length + (replacedText.length != sText ? 3 : 0);
	}
	
	/**
	 * @class QRCode
	 * @constructor
	 * @example 
	 * new QRCode(document.getElementById("test"), "http://jindo.dev.naver.com/collie");
	 *
	 * @example
	 * var oQRCode = new QRCode("test", {
	 *    text : "http://naver.com",
	 *    width : 128,
	 *    height : 128
	 * });
	 * 
	 * oQRCode.clear(); // Clear the QRCode.
	 * oQRCode.makeCode("http://map.naver.com"); // Re-create the QRCode.
	 *
	 * @param {HTMLElement|String} el target element or 'id' attribute of element.
	 * @param {Object|String} vOption
	 * @param {String} vOption.text QRCode link data
	 * @param {Number} [vOption.width=256]
	 * @param {Number} [vOption.height=256]
	 * @param {String} [vOption.colorDark="#000000"]
	 * @param {String} [vOption.colorLight="#ffffff"]
	 * @param {QRCode.CorrectLevel} [vOption.correctLevel=QRCode.CorrectLevel.H] [L|M|Q|H] 
	 */
	QRCode = function (el, vOption) {
		this._htOption = {
			width : 256, 
			height : 256,
			typeNumber : 4,
			colorDark : "#000000",
			colorLight : "#ffffff",
			correctLevel : QRErrorCorrectLevel.H
		};
		
		if (typeof vOption === 'string') {
			vOption	= {
				text : vOption
			};
		}
		
		// Overwrites options
		if (vOption) {
			for (var i in vOption) {
				this._htOption[i] = vOption[i];
			}
		}
		
		if (typeof el == "string") {
			el = document.getElementById(el);
		}

		if (this._htOption.useSVG) {
			Drawing = svgDrawer;
		}
		
		this._android = _getAndroid();
		this._el = el;
		this._oQRCode = null;
		this._oDrawing = new Drawing(this._el, this._htOption);
		
		if (this._htOption.text) {
			this.makeCode(this._htOption.text);	
		}
	};
	
	/**
	 * Make the QRCode
	 * 
	 * @param {String} sText link data
	 */
	QRCode.prototype.makeCode = function (sText) {
		this._oQRCode = new QRCodeModel(_getTypeNumber(sText, this._htOption.correctLevel), this._htOption.correctLevel);
		this._oQRCode.addData(sText);
		this._oQRCode.make();
		this._oDrawing.draw(this._oQRCode);			
		this.makeImage();
	};
	
	/**
	 * Make the Image from Canvas element
	 * - It occurs automatically
	 * - Android below 3 doesn't support Data-URI spec.
	 * 
	 * @private
	 */
	QRCode.prototype.makeImage = function () {
		if (typeof this._oDrawing.makeImage == "function" && (!this._android || this._android >= 3)) {
			this._oDrawing.makeImage();
		}
	};
	
	/**
	 * Clear the QRCode
	 */
	QRCode.prototype.clear = function () {
		this._oDrawing.clear();
	};
	
	/**
	 * @name QRCode.CorrectLevel
	 */
	QRCode.CorrectLevel = QRErrorCorrectLevel;
})();

